(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1177658,      28656]
NotebookOptionsPosition[   1115859,      27675]
NotebookOutlinePosition[   1116487,      27698]
CellTagsIndexPosition[   1116444,      27695]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Supplementary material - Modeling the fluid mechanics \
in single-flow batteries with an adjacent channel for improved reactant \
transport",
 FontWeight->"Bold"]], "Title",
 CellChangeTimes->{{3.7888375029611826`*^9, 3.78883753375414*^9}, {
   3.788837576248497*^9, 3.7888375783555355`*^9}, {3.7890341270771756`*^9, 
   3.789034131064412*^9}, {3.790932620471627*^9, 3.7909326506638856`*^9}, {
   3.7911943109846516`*^9, 3.7911943207694025`*^9}, 3.8410696054238825`*^9, {
   3.841898826147249*^9, 
   3.8418988313647957`*^9}},ExpressionUUID->"19273035-3e29-4c96-991c-\
ae2d54103ec3"],

Cell["Sofia Kuperman, Amir Gat, 2021", "Author",
 CellChangeTimes->{{3.7891079778396964`*^9, 3.789107986479091*^9}, 
   3.790932654802536*^9, {3.8145043607095923`*^9, 3.81450436563575*^9}, {
   3.8410685628790627`*^9, 3.8410685999991827`*^9}, {3.841069618055455*^9, 
   3.8410696184928784`*^9}},ExpressionUUID->"bcbbeaa5-27b4-4ee7-8d76-\
ba3e39cd575b"],

Cell["Technion - Israel Institute of Technology", "Affiliation",
 CellChangeTimes->{{3.789108028801997*^9, 
  3.789108040573594*^9}},ExpressionUUID->"8b2733a5-9a8d-4708-af8f-\
61c057274fba"],

Cell["\<\
 Redox flow batteries (RFBs) are an emerging technology envisioned towards \
storage of renewably generated electricity. A promising sub-class of RFBs \
utilizes single-flow membraneless architectures in an effort to minimize \
system cost and complexity. To support multiple functions, including reactant \
separation and fast reactant transport to electrode surfaces, electrolyte \
flow must be carefully designed and optimized. In this work, we propose \
adding a secondary channel adjacent to a permeable battery electrode, and \
analyze the effects on the single electrolyte flow as well as on the reactant \
concentration boundary layer at the electrode. We find that an adjacent \
channel with gradually changing thickness leads to a desired nearly-uniform \
flow through the electrode to the adjacent channel. Consequently, the \
thickness of the concentration boundary layer is significantly reduced, \
increasing reactant transport to the electrode surface to 140% of the rate of \
a battery with a constant width adjacent channel, and350% of the rate of no \
adjacent channel. Overall, this theory provides insight into the important \
role of flow physics on this promising sub-class of flow batteries and will \
pave the way to create more efficient flow batteries.
 
DOI:***\
\>", "Abstract",
 CellChangeTimes->{{3.7888376462858257`*^9, 3.788837708927074*^9}, 
   3.7888388095096436`*^9, {3.7891079413487663`*^9, 3.7891079560109215`*^9}, {
   3.7891080667826653`*^9, 3.7891080774554276`*^9}, {3.790932658123436*^9, 
   3.790932686079152*^9}, {3.84106949368865*^9, 3.8410695670595055`*^9}, {
   3.841069599050658*^9, 
   3.8410696239933395`*^9}},ExpressionUUID->"c0409e74-8f65-4914-b95a-\
00bc4b8216c5"],

Cell[CellGroupData[{

Cell["0. Auxiliary Functions", "Section",
 CellChangeTimes->{{3.790177957992977*^9, 3.790177971259482*^9}, {
  3.803481744059984*^9, 
  3.8034817451743436`*^9}},ExpressionUUID->"2395983e-de10-4577-9e31-\
9b4c94b0947f"],

Cell["\<\
This section is used for the definition of auxiliary modules to be used \
within the document.\
\>", "Text",
 CellChangeTimes->{{3.7901779728253202`*^9, 3.7901780055666103`*^9}, {
  3.790178111685009*^9, 3.790178111686004*^9}, {3.7910994240358043`*^9, 
  3.7910994240373936`*^9}},ExpressionUUID->"5aa68ab7-2c1b-42dc-bb8c-\
0ed8b1fb8110"],

Cell["\<\
The MakeEquationListFlat[EquationList_] function eliminates the {{}} \
appearing within list of manipulated equations\
\>", "Text",
 CellChangeTimes->{{3.7901779728253202`*^9, 3.7901780055666103`*^9}, {
  3.790178112476886*^9, 3.790178143973608*^9}, {3.791101809982891*^9, 
  3.7911018199215717`*^9}},ExpressionUUID->"c7875bf6-8b02-46ea-94f0-\
f6a5ad39bf73"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeEquationListFlat", "[", "EquationList_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "FlatEquationList", "}"}], ",", " ", 
    RowBox[{
     RowBox[{"NumberOfEquations", "=", 
      RowBox[{"Length", "[", "EquationList", "]"}]}], ";", 
     RowBox[{"FlatEquationList", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"EquationList", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], " ", "-", " ", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"EquationList", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], " ", "==", " ", "0"}], "}"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"n", "=", "2"}], ",", 
       RowBox[{"n", "<=", "NumberOfEquations"}], ",", 
       RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"FlatEquationList", " ", "=", " ", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "FlatEquationList", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"EquationList", "[", 
                RowBox[{"[", 
                 RowBox[{"n", ",", "1"}], "]"}], "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], " ", "-", " ", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"EquationList", "[", 
                RowBox[{"[", 
                 RowBox[{"n", ",", "2"}], "]"}], "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], " ", "==", " ", "0"}], 
           "}"}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}], ";", 
     RowBox[{"FlatEquationList", "=", 
      RowBox[{"Flatten", "[", "FlatEquationList", "]"}]}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{3.7911017645740013`*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"0b960dd4-4a29-4a06-80a1-50233a1f6df7"],

Cell["\<\
The first function is the order grabbing function GetEquationListOrder\
\>", "Text",ExpressionUUID->"77071268-2614-47f0-8ddb-cf7ba61c0c60"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetEquationListOrder", "[", 
   RowBox[{"EquationList_", ",", "OrderEps_", ",", "SmallParameter_"}], "]"}],
   ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "EquationListOrder0", "}"}], ",", " ", 
    RowBox[{
     RowBox[{"NumberOfEquations", "=", 
      RowBox[{"Length", "[", "EquationList", "]"}]}], ";", 
     RowBox[{"EquationListOrder0", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"CoefficientList", "[", 
           RowBox[{
            FormBox[
             RowBox[{
              RowBox[{"EquationList", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}],
             TraditionalForm], ",", " ", "SmallParameter", ",", 
            RowBox[{"OrderEps", "+", "1"}]}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"OrderEps", "+", "1"}], "]"}], "]"}], " ", "-", " ", 
         RowBox[{
          RowBox[{"CoefficientList", "[", 
           RowBox[{
            FormBox[
             RowBox[{
              RowBox[{"EquationList", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}],
             TraditionalForm], " ", ",", "SmallParameter", ",", 
            RowBox[{"OrderEps", "+", "1"}]}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"OrderEps", "+", "1"}], "]"}], "]"}]}], " ", "==", " ", 
        "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"n", "=", "2"}], ",", 
       RowBox[{"n", "<=", "NumberOfEquations"}], ",", 
       RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"EquationListOrder0", " ", "=", " ", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "EquationListOrder0", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"CoefficientList", "[", 
               RowBox[{
                FormBox[
                 RowBox[{
                  RowBox[{"EquationList", "[", 
                   RowBox[{"[", "n", "]"}], "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}],
                 TraditionalForm], ",", "  ", "SmallParameter", ",", 
                RowBox[{"OrderEps", "+", "1"}]}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"OrderEps", "+", "1"}], "]"}], "]"}], " ", "-", " ", 
             RowBox[{
              RowBox[{"CoefficientList", "[", 
               RowBox[{
                FormBox[
                 RowBox[{
                  RowBox[{"EquationList", "[", 
                   RowBox[{"[", "n", "]"}], "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}],
                 TraditionalForm], ",", " ", "SmallParameter", ",", 
                RowBox[{"OrderEps", "+", "1"}]}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"OrderEps", "+", "1"}], "]"}], "]"}]}], " ", "==", " ",
             "0"}], "}"}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}], ";", 
     RowBox[{"EquationListOrder0", "=", 
      RowBox[{"Flatten", "[", "EquationListOrder0", "]"}]}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.7901781018466573`*^9, {3.791098931215973*^9, 3.791098940261235*^9}, {
   3.791099556948417*^9, 3.7910995659201803`*^9}, {3.7911000254780197`*^9, 
   3.791100030690032*^9}, {3.791101692208741*^9, 3.791101707656724*^9}, {
   3.7911017977791967`*^9, 3.7911017992145643`*^9}, {3.7911855592877073`*^9, 
   3.791185566613035*^9}, {3.7911856317474513`*^9, 3.7911856528685884`*^9}, {
   3.7911856913440056`*^9, 3.791185701525694*^9}, {3.791185792298374*^9, 
   3.7911858166493587`*^9}, {3.7911858544219275`*^9, 
   3.7911858579839115`*^9}, {3.791185978939666*^9, 3.791185993251944*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"353dcac6-eafd-4edc-ab92-19c7a43e76ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"clean2", "[", "expr_", "]"}], " ", ":=", " ", "\n", " ", 
  RowBox[{
   RowBox[{"HoldForm", "[", "expr", "]"}], " ", "/.", " ", "\n", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"h_Symbol", "[", "args___", "]"}], " ", "/;", " ", 
     RowBox[{
      RowBox[{"Context", "@", 
       RowBox[{"Unevaluated", "@", "h"}]}], " ", "=!=", " ", 
      "\"\<System`\>\""}]}], " ", "\[RuleDelayed]", " ", "h"}]}]}]], "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"77f33537-db7c-40e7-9908-66fa5edf4f3a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pdConv", "[", "f_", "]"}], " ", ":=", " ", "\n", " ", 
  RowBox[{"TraditionalForm", "[", "  ", 
   RowBox[{"f", " ", "/.", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", "inds__", "]"}], "[", "g_", "]"}], "[", 
      "vars__", "]"}], " ", "\[RuleDelayed]", "     ", 
     RowBox[{"Apply", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Defer", "[", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"g", "[", "vars", "]"}], ",", " ", "##"}], "]"}], "]"}], 
        " ", "&"}], ",", " ", "\n", "     ", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", "vars", "}"}], ",", " ", 
           RowBox[{"{", "inds", "}"}]}], "}"}], "]"}], " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"var_", ",", " ", "0"}], "}"}], " ", "\[RuleDelayed]", 
           " ", "\n", "        ", 
           RowBox[{"Sequence", "[", "]"}]}], ",", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"var_", ",", " ", "1"}], "}"}], " ", "\[RuleDelayed]", 
           " ", 
           RowBox[{"{", "var", "}"}]}]}], "}"}]}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"be5b7b79-3ca4-4742-a94e-8f2a0cfffe5f"],

Cell[BoxData[
 RowBox[{"centering", ":=", 
  RowBox[{
   RowBox[{"CellPrint", "[", 
    RowBox[{"ExpressionCell", "[", 
     RowBox[{"#", ",", "\"\<Output\>\"", ",", 
      RowBox[{"TextAlignment", "\[Rule]", "Center"}]}], "]"}], "]"}], 
   "&"}]}]], "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"0a9f229e-b00d-43a5-a26a-fad379b74286"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TextbookEq", "[", "expr_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"TraditionalForm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"TableForm", "[", "expr", "]"}], "  ", "//", " ", "pdConv"}],
         " ", "}"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", "//", " ", "clean2"}], "]"}], "//",
    "centering"}]}]], "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"d3e10b67-726d-4abe-95ec-5818c33cd474"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. Problem formulation  and governing equations", "Section",
 CellChangeTimes->{{3.7888375508081427`*^9, 3.7888375739266186`*^9}, {
   3.788838535529595*^9, 3.7888385420849857`*^9}, {3.7901775606478295`*^9, 
   3.7901775624140835`*^9}, 3.791171188164546*^9, {3.81156979624876*^9, 
   3.811569797608038*^9}, {3.814530556138447*^9, 3.8145305569233093`*^9}, {
   3.8152011919399242`*^9, 3.8152011942575865`*^9}, {3.8152016136035438`*^9, 
   3.8152016147888765`*^9}, {3.8152067770551257`*^9, 3.815206780936907*^9}, 
   3.8410686150364237`*^9},ExpressionUUID->"eea2d571-8449-4306-a2a9-\
c64778570680"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.841069828100247*^9, 3.841069828115822*^9}, 
   3.841069858826818*^9},
 CellLabel->"In[7]:=",ExpressionUUID->"cec20e76-96a7-4666-bb2b-6c088bd47e8b"],

Cell["\<\
We examine the steady viscous Newtonian flow within a system having an inlet \
on one side and an outlet on the other where the flow is pressure driven.\
\>", "Text",
 CellChangeTimes->{{3.7888377167429237`*^9, 3.788837741616317*^9}, {
   3.788838305578503*^9, 3.788838327747986*^9}, {3.788838480569229*^9, 
   3.7888384951612473`*^9}, {3.78883854972309*^9, 3.788838569252815*^9}, {
   3.7888386153703403`*^9, 3.7888386365366287`*^9}, {3.7888387041443787`*^9, 
   3.788838719855054*^9}, {3.7888389203114977`*^9, 3.788838938636177*^9}, {
   3.7888391806708555`*^9, 3.7888392160688567`*^9}, {3.790932699247706*^9, 
   3.7909327204778786`*^9}, 3.8035575470044804`*^9, {3.8151469762806635`*^9, 
   3.8151469910731544`*^9}, {3.815152976344731*^9, 3.815153066155376*^9}, 
   3.8151532237010994`*^9, {3.8151980729114275`*^9, 3.8151980738939295`*^9}, {
   3.8152010464184732`*^9, 3.8152010760738263`*^9}, {3.81520111853883*^9, 
   3.815201166172368*^9}, {3.8152012225081406`*^9, 3.8152012246618977`*^9}, {
   3.8152013155234957`*^9, 3.8152013208304377`*^9}, {3.8152016969429636`*^9, 
   3.8152017037470927`*^9}, {3.8152017949763093`*^9, 
   3.8152017957878933`*^9}, {3.815204454794386*^9, 
   3.8152045775097227`*^9}},ExpressionUUID->"73870970-5ff3-4ada-9009-\
1e27e30f37a4"],

Cell["\<\
The system, schematically depicted in Figure 1, consists of two channels \
parted by a permeable separator layer, allowing mass transfer between the \
them. The Cartesian coordinate system (x,y), is also shown, where the x axis \
denotes the downstream direction and y is perpendicular thereto.\
\>", "Text",
 CellChangeTimes->{{3.81515316392505*^9, 3.8151531803615775`*^9}, {
  3.8152012484421887`*^9, 3.8152013126221704`*^9}, {3.8152013683978157`*^9, 
  3.8152014019294767`*^9}, {3.8152014339610324`*^9, 3.815201447895965*^9}, {
  3.8152016324716816`*^9, 3.8152016656687326`*^9}, {3.815201708426346*^9, 
  3.815201770071032*^9}, {3.815201823839669*^9, 3.815201849653787*^9}, {
  3.815204607231589*^9, 3.815204651480023*^9}, {3.81521011418365*^9, 
  3.815210145954339*^9}, {3.8152101842282887`*^9, 
  3.8152101846750298`*^9}},ExpressionUUID->"eb657082-1e1e-4565-b41c-\
38d021bf754a"],

Cell[BoxData[
 RowBox[{
  GraphicsBox[GeometricTransformationBox[GraphicsGroupBox[{InsetBox[
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJzsvQl4FFXax9twx094DHIZrzNGBZxhwiADExVRIjrAIBhRCAoBZWv2VQmR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          "], {{0, 547.2}, {609.6, 0}}, {0, 255},
          ColorFunction->RGBColor,
          ImageResolution->120],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        DefaultBaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{609.6, 547.2},
        PlotRange->{{0, 609.6}, {0, 547.2}}], 
       Scaled[{0.18551556185098306, 0.5483598339805961}], 
       Center, {0.45134982353750036, 0.3691661701271653}, {{1., 0.}, {0., 
       1.}}], InsetBox[
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJzs3X2QZWld4Hl3t9qZwdhmI3Yr/6GjZ1apRCLo3VbGKlAoutWhkhkXZ7DF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          "], {{0, 461.4}, {975., 0}}, {0, 255},
          ColorFunction->RGBColor,
          ImageResolution->120],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        DefaultBaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{975., 461.4},
        PlotRange->{{0, 975.}, {0, 461.4}}], 
       Scaled[{0.6265173332472979, 0.5483598339805962}], 
       Center, {0.6955769789008903, 0.5055551311628189}, {{1., 0.}, {0., 
       1.}}]}], {{{{0.9999999999999999, 0.}, {0., 0.9999999999999999}}, {
      0.06425461442696549, -0.027989821882951516`}}}],
   ContentSelectable->True,
   ImagePadding->{{0., 0.}, {0., 0.}},
   ImageSize->{655.9090909090907, 494.5454545454545},
   PlotRange->{{0., 1.3333333333333335`}, {0., 1.}},
   PlotRangePadding->Automatic,
   ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], ";"}]], "Input",
 CellChangeTimes->{
  3.8410701120808134`*^9, {3.8410701647049108`*^9, 3.841070243735179*^9}, {
   3.841070296765551*^9, 3.8410703059675856`*^9}, 3.841072401368534*^9},
 CellLabel->"In[8]:=",ExpressionUUID->"c87f77d4-6b2a-4f50-a6e9-9333701b677f"],

Cell["\<\
Fig. 1.  Schematic illustration of the configuration of the examined system, \
showing the coordinate system and key parameters used for the analysis. The \
separator layer (dashed line) allows the steady viscous flow, induced by a \
pressure gradient in the downstream direction, to cross to the lower channel \
and visa versa.\
\>", "Text",
 CellChangeTimes->{{3.8152018980517125`*^9, 3.8152021208968716`*^9}, {
  3.815202246717372*^9, 3.815202249385852*^9}, {3.8152023005082736`*^9, 
  3.815202322524582*^9}, {3.8152024057543736`*^9, 3.8152024707981744`*^9}, {
  3.81520353885508*^9, 3.8152035840578156`*^9}, {3.815204425893048*^9, 
  3.8152044504208956`*^9}, {3.8152056109085145`*^9, 3.81520561234268*^9}, {
  3.815210049976683*^9, 3.815210086753484*^9}, {3.8410703448685446`*^9, 
  3.8410703454502287`*^9}},
 TextAlignment->Center,ExpressionUUID->"b44a7701-412c-4896-a4a9-3eeff409dd91"],

Cell["\<\
The examined system of length l, consists of two parts, the main channel \
(Region 1) and a secondary channel (Region 2). The former is a channel \
characterized by height h_1, and the latter having a a bottom wall expanding \
downstream which is defined by\
\>", "Text",
 CellChangeTimes->{{3.8151477991213827`*^9, 3.8151478012086067`*^9}, {
  3.8151478331082354`*^9, 3.815147924656561*^9}, {3.815210160750805*^9, 
  3.815210170694092*^9}},ExpressionUUID->"1b1cc54f-7a9e-4a89-ba9b-\
ab8bcfe7d0a5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"h2Eq", " ", "=", " ", 
   RowBox[{
    RowBox[{"h2", "[", "x", "]"}], " ", "==", " ", 
    RowBox[{"h2", " ", 
     RowBox[{"(", 
      RowBox[{"1", " ", "+", " ", 
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"x", "/", "l"}], ")"}]}]}], ")"}]}]}]}], ";", 
  RowBox[{"TextbookEq", "[", "h2Eq", "]"}]}]], "Input",
 CellChangeTimes->{{3.8151470660855308`*^9, 3.815147066602214*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"23076d1a-da92-492c-8c3e-48cbfc142d2e"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"h2", "\[LongEqual]", 
     RowBox[{"h2", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"a1", " ", "x"}], "l"]}], ")"}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900787465022*^9},
 TextAlignment->Center,ExpressionUUID->"9310b1bc-c09d-4c7e-8ab5-f8a4574d2495"]
}, Open  ]],

Cell["\<\
The regions are parted by a separator layer having permeability k, which is \
defined as the relative amount of the fluid which is able to pass through the \
layer, according to the porosity of the layer. I.e., the velocity of the \
fluid perpendicular to the layer will be governed by\
\>", "Text",
 CellChangeTimes->{{3.8151479434641714`*^9, 3.8151479644736004`*^9}, {
  3.8151480420327263`*^9, 3.8151482487146015`*^9}, {3.815149031275217*^9, 
  3.8151490371788344`*^9}, {3.8151490921143446`*^9, 3.8151491817880273`*^9}, {
  3.815149236331534*^9, 3.8151492488762817`*^9}, {3.8151500375326233`*^9, 
  3.8151500474083815`*^9}, {3.8151501097590857`*^9, 3.8151501508404355`*^9}, {
  3.8151502496826706`*^9, 3.815150288587259*^9}, {3.8151503429786725`*^9, 
  3.8151503546669025`*^9}, {3.815211033778443*^9, 
  3.8152110715586133`*^9}},ExpressionUUID->"351a562b-3f7f-4a23-ba0a-\
2167e901c0f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"UYKratio", " ", "=", " ", 
   RowBox[{"Uy", " ", "==", " ", 
    RowBox[{
     RowBox[{"k", "/", "\[Mu]"}], " ", "\[CapitalDelta]P"}]}]}], ";", 
  RowBox[{"TextbookEq", "[", "UYKratio", "]"}]}]], "Input",
 CellChangeTimes->{{3.8152110908414955`*^9, 3.815211158489512*^9}, {
  3.8266905069554653`*^9, 3.826690508804599*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"6f2e0931-0cf1-4569-9218-48b468c7e6ce"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"Uy", "\[LongEqual]", 
     FractionBox[
      RowBox[{"k", " ", "\[CapitalDelta]P"}], "\[Mu]"]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900787607939*^9},
 TextAlignment->Center,ExpressionUUID->"b966943c-5f24-4fa7-b159-929922f88734"]
}, Open  ]],

Cell["\<\
where Ux_i and Uy_i denote the velocity in the direction of the coordinate \
and the index indicates the region.\
\>", "Text",
 CellChangeTimes->{{3.8152324867926846`*^9, 
  3.815232590739436*^9}},ExpressionUUID->"d97ef102-cfd4-4fb9-afd5-\
e1cbd6114ae7"],

Cell[CellGroupData[{

Cell["A. Governing equations in dimensional form", "Subsection",
 CellChangeTimes->{{3.815147973839184*^9, 3.8151479743029137`*^9}, {
  3.8152107907646465`*^9, 3.815210813930292*^9}, {3.8152213500217104`*^9, 
  3.81522135853381*^9}},ExpressionUUID->"6ac3a1bd-4f2f-4f52-b0f3-\
b9f2bfbc715d"],

Cell["\<\
Assuming steady Newtonian, incompressible flow with negligible inertial \
effects, the fluid motion, having a dynamics viscosity, \[Mu], is governed by \
the Stokes equations. The equations governing the fluid in region 1 are given \
thus by:\
\>", "Text",
 CellChangeTimes->{{3.791014532017462*^9, 3.7910145566689076`*^9}, {
  3.815218633027135*^9, 3.8152186503041925`*^9}, {3.8152206134535294`*^9, 
  3.8152206813326025`*^9}, {3.815222014170085*^9, 
  3.8152221093984065`*^9}},ExpressionUUID->"525056cf-99cc-4615-babe-\
1139819071f5"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TextbookEq", "[", 
  RowBox[{"XMomentumConservationEq1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"{", "x", "}"}]], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"{", "x", "}"}]], 
           RowBox[{"ux1", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"{", "y", "}"}]], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"{", "y", "}"}]], 
           RowBox[{"ux1", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"{", "x", "}"}]], 
      RowBox[{"p1", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], "\[Equal]", "0"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"TextbookEq", "[", 
  RowBox[{"YMomentumConservationEq1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"{", "x", "}"}]], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"{", "x", "}"}]], 
           RowBox[{"uy1", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"{", "y", "}"}]], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"{", "y", "}"}]], 
           RowBox[{"uy1", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"{", "y", "}"}]], 
      RowBox[{"p1", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], "\[Equal]", "0"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.788839797859522*^9, 3.788839809975831*^9}, {
   3.7888398798637342`*^9, 3.788839883990715*^9}, {3.7888399476930747`*^9, 
   3.7888400080512514`*^9}, {3.7888400445721493`*^9, 3.788840083322888*^9}, {
   3.788840150298377*^9, 3.78884017897173*^9}, {3.788840682468311*^9, 
   3.7888407046623063`*^9}, {3.788845353091885*^9, 3.788845390394099*^9}, 
   3.7891047281726217`*^9, 3.789114514428746*^9, {3.7909328678062315`*^9, 
   3.7909329086484556`*^9}, {3.7909333105822725`*^9, 3.790933312810939*^9}, 
   3.7909346609271784`*^9, {3.7909348312503276`*^9, 3.7909348511466312`*^9}, {
   3.791001126747966*^9, 3.7910011575740604`*^9}, {3.7910145731168337`*^9, 
   3.791014584799397*^9}, {3.791014626498102*^9, 3.7910146269060116`*^9}, {
   3.7940487234537554`*^9, 3.7940487249558363`*^9}, 3.803053579138955*^9, {
   3.814530766403661*^9, 3.814530785770915*^9}, {3.8152206930408306`*^9, 
   3.815220694854805*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"196d40ba-55d2-4b1e-bd89-aff1a96c25c1"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[PartialD]", "p1"}], 
        RowBox[{"\[PartialD]", "x"}],
        MultilineFunction->None]}], "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "ux1"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["x", "2"]}],
          MultilineFunction->None], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "ux1"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["y", "2"]}],
          MultilineFunction->None]}], ")"}]}]}], "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900787732867*^9},
 TextAlignment->Center,ExpressionUUID->"3d9da367-06df-4451-89c1-b53212989d24"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[PartialD]", "p1"}], 
        RowBox[{"\[PartialD]", "y"}],
        MultilineFunction->None]}], "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "uy1"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["x", "2"]}],
          MultilineFunction->None], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "uy1"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["y", "2"]}],
          MultilineFunction->None]}], ")"}]}]}], "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007877818384`*^9},
 TextAlignment->Center,ExpressionUUID->"2f09ab58-cff0-49ce-b3b3-599dbac07b75"]
}, Open  ]],

Cell["along with the conservation of mass", "Text",
 CellChangeTimes->{{3.8152207066749725`*^9, 
  3.8152207251313496`*^9}},ExpressionUUID->"9910fcd1-eb8d-4e18-83f1-\
57a9881512c3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"MassConservationEq1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"{", "x", "}"}]], 
      RowBox[{"ux1", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"{", "y", "}"}]], 
      RowBox[{"uy1", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], "\[Equal]", "0"}]}], 
  "]"}]], "Input",
 CellLabel->"In[13]:=",ExpressionUUID->"d16e26f0-6baf-4686-a356-d7bb910bfbf6"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"\[PartialD]", "ux1"}], 
       RowBox[{"\[PartialD]", "x"}],
       MultilineFunction->None], "+", 
      FractionBox[
       RowBox[{"\[PartialD]", "uy1"}], 
       RowBox[{"\[PartialD]", "y"}],
       MultilineFunction->None]}], "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007878907747`*^9},
 TextAlignment->Center,ExpressionUUID->"1bca8093-1fcd-498c-9453-b48d9eee41f0"]
}, Open  ]],

Cell["\<\
The suitable boundary conditions are no slip at the top and bottom of the \
region,\
\>", "Text",
 CellChangeTimes->{{3.7910146130237303`*^9, 3.7910146212419386`*^9}, {
   3.8025348090663395`*^9, 3.802534815002925*^9}, {3.8145278756459417`*^9, 
   3.8145278757768526`*^9}, {3.815220749216448*^9, 3.815220782840251*^9}, 
   3.815220839113762*^9},ExpressionUUID->"097baf14-5f8a-42bc-8596-\
0692dabe46f3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TextbookEq", "[", 
  RowBox[{"NoSlipUP1", "=", 
   RowBox[{
    RowBox[{"ux1", "[", 
     RowBox[{"x", ",", "h1"}], "]"}], "\[Equal]", "0"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"TextbookEq", "[", 
  RowBox[{"NoSlipDN1", "=", 
   RowBox[{
    RowBox[{"ux1", "[", 
     RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.791014641870249*^9, 3.7910146627266483`*^9}, {
   3.802534768861478*^9, 3.802534846429854*^9}, {3.802592731659672*^9, 
   3.802592737740167*^9}, {3.8025968623574944`*^9, 3.802596887062275*^9}, 
   3.815220801470445*^9, {3.8152209219682875`*^9, 3.81522093453604*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"a33cdf8a-7ed4-4f67-a504-a003105a70d2"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"ux1", "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007880306945`*^9},
 TextAlignment->Center,ExpressionUUID->"af1504e1-6031-4e9c-a4f7-61c8565a4b01"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"ux1", "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007880816655`*^9},
 TextAlignment->Center,ExpressionUUID->"8b027637-dcce-4b98-835f-649f870b582e"]
}, Open  ]],

Cell["no penetration at the top of the channel,", "Text",
 CellChangeTimes->{{3.815220805753995*^9, 
  3.8152208444274344`*^9}},ExpressionUUID->"7844086c-30b6-4bcd-b2e0-\
1638ec1346df"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"NoPenetrationUP1", "=", 
   RowBox[{
    RowBox[{"uy1", "[", 
     RowBox[{"x", ",", "h1"}], "]"}], "\[Equal]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.815220870424981*^9, {3.8152209589639564`*^9, 3.8152209618591156`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"03a84678-abd6-46e9-9988-713908547daa"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"uy1", "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900788210592*^9},
 TextAlignment->Center,ExpressionUUID->"7c6bfb4a-bfcd-4469-a1c6-52309ccb7e8d"]
}, Open  ]],

Cell["\<\
and a velocity perpendicular to the channel at the separator layer\
\>", "Text",
 CellChangeTimes->{{3.815220873424271*^9, 
  3.81522090640629*^9}},ExpressionUUID->"6728a912-ae30-42d1-bf58-\
b843a60d484c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"FluxDN1", "=", 
   RowBox[{
    RowBox[{"uy1", "[", 
     RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", 
    RowBox[{"k", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "-", 
        RowBox[{"p1", "[", 
         RowBox[{"x", ",", "0"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"w", " ", "\[Mu]"}], ")"}]}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.815220911710182*^9, {3.815220975359334*^9, 3.8152209768834543`*^9}, {
   3.8266903906622705`*^9, 3.8266903917656965`*^9}, {3.826690596971007*^9, 
   3.8266906184638596`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"ad9c1f35-890d-4e6d-b20e-b1b72d350c2e"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"uy1", "\[LongEqual]", 
     FractionBox[
      RowBox[{"k", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "p1"}], "+", "p2"}], ")"}]}], 
      RowBox[{"w", " ", "\[Mu]"}]]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900788563387*^9},
 TextAlignment->Center,ExpressionUUID->"76ad61ee-9053-43c0-a7bf-8742bcc31e14"]
}, Open  ]],

Cell["The pressure at the inlet and the outlet is", "Text",
 CellChangeTimes->{{3.815220986210059*^9, 
  3.8152210296110554`*^9}},ExpressionUUID->"cc398f7d-bba8-47bb-9e15-\
17e4f6232d7f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TextbookEq", "[", 
  RowBox[{"P1Inlet", "=", 
   RowBox[{
    RowBox[{"p1", "[", 
     RowBox[{"0", ",", "y"}], "]"}], "\[Equal]", "pin"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"TextbookEq", "[", 
  RowBox[{"P1Outlet", "=", 
   RowBox[{
    RowBox[{"p1", "[", 
     RowBox[{"l", ",", "y"}], "]"}], "\[Equal]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{
  3.815220916706301*^9, {3.8152210314130163`*^9, 3.815221045822689*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"da26abb9-25ff-42bb-b72c-99ccea1f41a2"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"p1", "\[LongEqual]", "pin"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007887023067`*^9},
 TextAlignment->Center,ExpressionUUID->"99f29d23-7cc6-4555-aa33-81c2afa5cfd1"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"p1", "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007887462816`*^9},
 TextAlignment->Center,ExpressionUUID->"1a6026cd-92f1-42ed-9c20-bd42627b3b88"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"MassConservationEq2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"{", "x", "}"}]], 
      RowBox[{"ux2", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"{", "y", "}"}]], 
      RowBox[{"uy2", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], "\[Equal]", "0"}]}], ";", 
  RowBox[{"XMomentumConservationEq2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"{", "x", "}"}]], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"{", "x", "}"}]], 
           RowBox[{"ux2", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"{", "y", "}"}]], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"{", "y", "}"}]], 
           RowBox[{"ux2", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"{", "x", "}"}]], 
      RowBox[{"p2", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], "\[Equal]", "0"}]}], ";", 
  RowBox[{"YMomentumConservationEq2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"{", "x", "}"}]], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"{", "x", "}"}]], 
           RowBox[{"uy2", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"{", "y", "}"}]], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"{", "y", "}"}]], 
           RowBox[{"uy2", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"{", "y", "}"}]], 
      RowBox[{"p2", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], "\[Equal]", "0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788840577769397*^9, 3.78884066399371*^9}, {
   3.788840723974203*^9, 3.7888408034336324`*^9}, {3.7888408635470223`*^9, 
   3.7888409099078436`*^9}, {3.788841187816532*^9, 3.7888412951846485`*^9}, {
   3.788841717642015*^9, 3.7888417250012474`*^9}, {3.788841859501815*^9, 
   3.7888418924368353`*^9}, {3.7890256441728363`*^9, 3.789025666361573*^9}, 
   3.7891047640846405`*^9, {3.789115037547179*^9, 3.7891150568262367`*^9}, {
   3.789119250798379*^9, 3.7891192615339994`*^9}, {3.7892032375936384`*^9, 
   3.789203256951635*^9}, 3.7892051385233088`*^9, 3.789205195039979*^9, 
   3.7892053110138273`*^9, 3.7892280856282797`*^9, {3.7892314262070274`*^9, 
   3.789231461004383*^9}, 3.790054306747078*^9, {3.790932848628825*^9, 
   3.7909328528343096`*^9}, 3.790932915313506*^9, {3.790933073432269*^9, 
   3.7909331070913773`*^9}, {3.7909331454143505`*^9, 3.79093321137868*^9}, 
   3.790933245535033*^9, {3.790933317655442*^9, 3.7909333219242225`*^9}, 
   3.7909346639788303`*^9, {3.7909363435461807`*^9, 3.7909363558629627`*^9}, {
   3.791001135544993*^9, 3.7910011543102665`*^9}, {3.791002201858511*^9, 
   3.7910022034371977`*^9}, {3.791004833267272*^9, 3.791004835502043*^9}, {
   3.7910145709245105`*^9, 3.7910145773397603`*^9}, 3.7910146983157167`*^9, {
   3.7940487272537556`*^9, 3.7940487288285584`*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"46f9be2b-ed06-421d-854c-ca4ac5ba05d9"],

Cell["\<\
The governing equations for region 2 are derived in a similar fashion, with \
the following boundary conditions\
\>", "Text",
 CellChangeTimes->{{3.815221153614061*^9, 3.8152211536170406`*^9}, 
   3.8152211865007286`*^9},ExpressionUUID->"66e6827b-d5f7-4337-acf9-\
f0c087e7979b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"NoSlipUP2", "=", 
   RowBox[{
    RowBox[{"ux2", "[", 
     RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", "0"}]}], ";", 
  RowBox[{"NoSlipDN2", "=", 
   RowBox[{
    RowBox[{"ux2", "[", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", " ", "h2"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", " ", "+", 
         RowBox[{"a1", " ", 
          RowBox[{"(", 
           RowBox[{"x", "/", "l"}], ")"}]}], "+", 
         RowBox[{"a2", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x", "/", "l"}], ")"}], "^", "2"}]}], "+", 
         RowBox[{"a3", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x", "/", "l"}], ")"}], "^", "3"}]}]}], ")"}]}]}], "]"}], 
    "\[Equal]", "0"}]}], ";", 
  RowBox[{"NoPenetrationDN2", "=", 
   RowBox[{
    RowBox[{"uy2", "[", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", " ", "h2"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", " ", "+", 
         RowBox[{"a1", " ", 
          RowBox[{"(", 
           RowBox[{"x", "/", "l"}], ")"}]}], "+", 
         RowBox[{"a2", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x", "/", "l"}], ")"}], "^", "2"}]}], "+", 
         RowBox[{"a3", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x", "/", "l"}], ")"}], "^", "3"}]}]}], ")"}]}]}], "]"}], 
    "\[Equal]", "0"}]}], ";", 
  RowBox[{"FluxUP2", "=", 
   RowBox[{
    RowBox[{"uy2", "[", 
     RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", 
    RowBox[{"k", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"p2", "[", 
        RowBox[{"x", ",", "0"}], "]"}], "-", 
       RowBox[{"p1", "[", 
        RowBox[{"x", ",", "0"}], "]"}]}], ")"}]}]}]}], ";", 
  RowBox[{"TextbookEq", "[", 
   RowBox[{"P2Inlet", "=", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"p2", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", "x"}], "]"}], "\[Equal]", 
     "0"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"TextbookEq", "[", 
  RowBox[{"P2Inlet", "=", 
   RowBox[{"P2Inlet", "//.", 
    RowBox[{"x", "\[Rule]", "0"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TextbookEq", "[", 
  RowBox[{"P2Outlet", "=", 
   RowBox[{
    RowBox[{"p2", "[", 
     RowBox[{"l", ",", "y"}], "]"}], "\[Equal]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.789451240090927*^9, 3.7894512820656805`*^9}, {
   3.789451315205353*^9, 3.7894513153379507`*^9}, 3.789453658616474*^9, {
   3.7909364912669744`*^9, 3.79093658316774*^9}, {3.7909378149025574`*^9, 
   3.7909378821626835`*^9}, {3.790999251317236*^9, 3.7909992922084274`*^9}, {
   3.7909995687363997`*^9, 3.7909996405757284`*^9}, {3.7909997781056423`*^9, 
   3.7909998966919403`*^9}, {3.7910001821919174`*^9, 
   3.7910001840127106`*^9}, {3.791000319364208*^9, 3.7910003513744955`*^9}, {
   3.791000489696292*^9, 3.791000490798891*^9}, {3.7910005890283337`*^9, 
   3.791000608763603*^9}, {3.7910012314330044`*^9, 3.791001236465436*^9}, {
   3.791014714691279*^9, 3.791014720050495*^9}, {3.802534899648225*^9, 
   3.8025349491927004`*^9}, {3.802593354254349*^9, 3.80259339608427*^9}, {
   3.8025981241544476`*^9, 3.802598133966798*^9}, {3.8035582798455763`*^9, 
   3.8035583198003407`*^9}, {3.803741186704715*^9, 3.8037412846768703`*^9}, {
   3.8037413353409176`*^9, 3.8037413723007154`*^9}, {3.803741451552035*^9, 
   3.8037414638452997`*^9}, {3.803741513140025*^9, 3.803741549769147*^9}, 
   3.803741671290572*^9, {3.8040007134497557`*^9, 3.8040007273087807`*^9}, {
   3.8152212188210955`*^9, 3.8152212297088003`*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"edad039b-2b17-4f52-a7db-fa51050b015b"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", "p2"}], 
      RowBox[{"\[PartialD]", "x"}],
      MultilineFunction->None], "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007889291754`*^9},
 TextAlignment->Center,ExpressionUUID->"8b004586-c0fb-4747-966d-6556eb1d29c0"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", "p2"}], 
      RowBox[{"\[PartialD]", "0"}],
      MultilineFunction->None], "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900788977148*^9},
 TextAlignment->Center,ExpressionUUID->"74c6ef2d-0e9e-42e4-83c1-b695a57783bd"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"p2", "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007890950813`*^9},
 TextAlignment->Center,ExpressionUUID->"8bef38a2-bf82-4c44-83f8-632a7cc5481d"]
}, Open  ]],

Cell["\<\
The full list of equations, initial conditions and boundary conditions, for \
regions 1 and 2 are thus\
\>", "Text",
 CellChangeTimes->{{3.789024908641591*^9, 3.789024919408763*^9}, {
  3.7900924552298946`*^9, 3.7900924557314014`*^9}, {3.790092758160754*^9, 
  3.7900927750668645`*^9}, {3.791014734918002*^9, 
  3.791014743591265*^9}},ExpressionUUID->"64871c31-e99d-4e13-a331-\
6c457155e3c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"EquationList1", "=", 
   RowBox[{"List", "[", 
    RowBox[{
     FormBox[
      FormBox["MassConservationEq1",
       TraditionalForm],
      TraditionalForm], ",", 
     FormBox["XMomentumConservationEq1",
      TraditionalForm], ",", "YMomentumConservationEq1", ",", "NoSlipUP1", 
     ",", "NoSlipDN1", ",", "NoPenetrationUP1", ",", "FluxDN1", ",", 
     "P1Inlet", ",", "P1Outlet"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.789024927372452*^9, 3.7890249685728717`*^9}, {
   3.789025005265811*^9, 3.789025006743664*^9}, {3.789025554107891*^9, 
   3.7890255552176404`*^9}, {3.789025689162074*^9, 3.7890256895421023`*^9}, {
   3.7890257914501123`*^9, 3.789025792759365*^9}, {3.789035913200107*^9, 
   3.7890359290744634`*^9}, {3.7891060152184625`*^9, 
   3.7891060175855484`*^9}, {3.789106145667101*^9, 3.7891061578817024`*^9}, {
   3.7894530805561695`*^9, 3.7894530986772947`*^9}, 3.7894536835466337`*^9, {
   3.789454941879286*^9, 3.789454946493154*^9}, {3.7894720319648457`*^9, 
   3.789472032447427*^9}, {3.790092539892213*^9, 3.7900925583799334`*^9}, {
   3.7910003971673927`*^9, 3.791000486975058*^9}, {3.791001306294716*^9, 
   3.791001331561081*^9}, 3.7910021380365*^9, {3.791002214529441*^9, 
   3.7910023085604796`*^9}, {3.8145308538302875`*^9, 3.8145308604669466`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"ad39bf18-392d-4ef4-ae96-f82f209225f8"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "ux1"}], 
           RowBox[{"\[PartialD]", "x"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "uy1"}], 
           RowBox[{"\[PartialD]", "y"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[PartialD]", "p1"}], 
            RowBox[{"\[PartialD]", "x"}],
            MultilineFunction->None]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "ux1"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["x", "2"]}],
              MultilineFunction->None], "+", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "ux1"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["y", "2"]}],
              MultilineFunction->None]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[PartialD]", "p1"}], 
            RowBox[{"\[PartialD]", "y"}],
            MultilineFunction->None]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "uy1"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["x", "2"]}],
              MultilineFunction->None], "+", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "uy1"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["y", "2"]}],
              MultilineFunction->None]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{"ux1", "\[LongEqual]", "0"}]},
       {
        RowBox[{"ux1", "\[LongEqual]", "0"}]},
       {
        RowBox[{"uy1", "\[LongEqual]", "0"}]},
       {
        RowBox[{"uy1", "\[LongEqual]", 
         FractionBox[
          RowBox[{"k", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "p1"}], "+", "p2"}], ")"}]}], 
          RowBox[{"w", " ", "\[Mu]"}]]}]},
       {
        RowBox[{"p1", "\[LongEqual]", "pin"}]},
       {
        RowBox[{"p1", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007892339993`*^9},
 TextAlignment->Center,ExpressionUUID->"6ce6a48a-31a3-43e6-bbcc-36fc52cb5f7b"]
}, Open  ]],

Cell["and", "Text",
 CellChangeTimes->{{3.791014746744605*^9, 
  3.791014746989946*^9}},ExpressionUUID->"fa1f6b4f-36cb-4cd1-9ebd-\
ad46c86ac027"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"EquationList2", "=", 
   RowBox[{"List", "[", 
    RowBox[{
     FormBox[
      FormBox["MassConservationEq2",
       TraditionalForm],
      TraditionalForm], ",", 
     FormBox["XMomentumConservationEq2",
      TraditionalForm], ",", "YMomentumConservationEq2", ",", "NoSlipUP2", 
     ",", "NoSlipDN2", ",", "NoPenetrationDN2", ",", "FluxUP2", ",", 
     "P2Inlet", ",", "P2Outlet"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.791001304703985*^9, 3.791001337796867*^9, {3.7910017322440767`*^9, 
   3.7910017555652194`*^9}, {3.8152212636530704`*^9, 3.8152212659523087`*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"00f4efd1-acba-49c7-a713-989dd98bb6b2"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "ux2"}], 
           RowBox[{"\[PartialD]", "x"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "uy2"}], 
           RowBox[{"\[PartialD]", "y"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[PartialD]", "p2"}], 
            RowBox[{"\[PartialD]", "x"}],
            MultilineFunction->None]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "ux2"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["x", "2"]}],
              MultilineFunction->None], "+", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "ux2"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["y", "2"]}],
              MultilineFunction->None]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[PartialD]", "p2"}], 
            RowBox[{"\[PartialD]", "y"}],
            MultilineFunction->None]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "uy2"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["x", "2"]}],
              MultilineFunction->None], "+", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "uy2"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["y", "2"]}],
              MultilineFunction->None]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{"ux2", "\[LongEqual]", "0"}]},
       {
        RowBox[{"ux2", "\[LongEqual]", "0"}]},
       {
        RowBox[{"uy2", "\[LongEqual]", "0"}]},
       {
        RowBox[{"uy2", "\[LongEqual]", 
         RowBox[{"k", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "p1"}], "+", "p2"}], ")"}]}]}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "p2"}], 
          RowBox[{"\[PartialD]", "0"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"p2", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007894338846`*^9},
 TextAlignment->Center,ExpressionUUID->"f4f072e6-5e9c-48fd-95df-032777ee05bb"]
}, Open  ]],

Cell["\<\
We proceed to perform order-of-magnitude analysis of these equations and \
boundary conditions.\
\>", "Text",
 CellChangeTimes->{{3.790092885794816*^9, 3.790092931779222*^9}, {
   3.7901771505318055`*^9, 3.790177167147109*^9}, 3.7910147542056465`*^9, {
   3.8025978290661373`*^9, 
   3.8025978359671564`*^9}},ExpressionUUID->"01349695-7b32-4096-be8d-\
3078a46cc797"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
B.Scaling analysis and normalization of the governing equations\
\>", "Subsection",
 CellChangeTimes->{{3.815221318934757*^9, 3.815221333235408*^9}, {
  3.815221434387226*^9, 
  3.815221442188117*^9}},ExpressionUUID->"a1fa3bf7-51e7-4029-9914-\
41a3892024a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AssumptionOnScaling", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"l", ">", "0"}], ",", 
     RowBox[{"h1", ">", "0"}], ",", 
     RowBox[{"h2", ">", "0"}], ",", 
     RowBox[{"pC1", ">", "0"}], ",", 
     RowBox[{"uxC", ">", "0"}], ",", 
     RowBox[{"uyC", ">", "0"}], ",", 
     RowBox[{"\[Epsilon]1", ">", "0"}], ",", 
     RowBox[{"\[Epsilon]2", ">", "0"}], ",", 
     RowBox[{"\[Mu]", ">", "0"}], ",", 
     RowBox[{"K1", ">", "0"}], ",", 
     RowBox[{"K2", ">", "0"}], ",", 
     RowBox[{"a1", ">", "0"}], ",", 
     RowBox[{"Pin", ">", "0"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[26]:=",ExpressionUUID->"9e564af6-03b9-4ef2-8b62-b5324b210c99"],

Cell["\<\
In order to simplify the governing equations, the following geometrical and \
physical parameters were assumed to be positive:\
\>", "Text",
 CellChangeTimes->{{3.7892281110031214`*^9, 3.7892281425241566`*^9}, {
  3.8152216516385975`*^9, 3.815221691885394*^9}, {3.815221746902283*^9, 
  3.8152217779876957`*^9}, {3.815222814443434*^9, 
  3.815222840690302*^9}},ExpressionUUID->"eaf4c3e4-c048-4e27-8bca-\
ccfe5ce06079"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"l", ">", "0"}], ",", 
    RowBox[{"h1", ">", "0"}], ",", 
    RowBox[{"h2", ">", "0"}], ",", 
    RowBox[{"\[Mu]", ">", "0"}], ",", 
    RowBox[{"K", ">", "0"}], ",", 
    RowBox[{"a1", ">", "0"}], ",", 
    RowBox[{"Pin", ">", "0"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{
  3.789111657702815*^9, {3.7891139701614404`*^9, 3.7891139721531115`*^9}, {
   3.7891140422660055`*^9, 3.789114043794038*^9}, {3.789114417017325*^9, 
   3.7891144173804035`*^9}, {3.789205439080191*^9, 3.789205441992399*^9}, 
   3.7892281511723566`*^9, {3.7900936429591656`*^9, 3.7900936453750324`*^9}, {
   3.7910006554789524`*^9, 3.791000684457801*^9}, 3.7910023286409283`*^9, {
   3.7910147673160467`*^9, 3.79101478155385*^9}, {3.791018942200173*^9, 
   3.7910189471967864`*^9}, {3.7911807964509296`*^9, 3.7911807987927203`*^9}, 
   3.791180859170185*^9, {3.79118220045881*^9, 3.791182200611384*^9}, {
   3.8025949278107166`*^9, 3.802594931954332*^9}, 3.802598185263276*^9, {
   3.8037422277196417`*^9, 3.8037422279781547`*^9}, {3.804000638251034*^9, 
   3.8040006489408836`*^9}, {3.8040006981195803`*^9, 
   3.8040007081458178`*^9}, {3.804000815835553*^9, 3.8040008384515357`*^9}, {
   3.804002631798581*^9, 3.804002641088237*^9}, {3.804003118129128*^9, 
   3.8040031183509655`*^9}, {3.804090167780367*^9, 3.8040901694643908`*^9}, {
   3.8040918298808804`*^9, 3.8040918315868897`*^9}, {3.8152216295762987`*^9, 
   3.815221632138839*^9}, {3.815222874764638*^9, 3.815222895879484*^9}, {
   3.8152229354146724`*^9, 3.815222946415457*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"59d1522a-de6a-425f-88c3-4ee1d09653b9"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{"l", ">", "0"}]},
       {
        RowBox[{"h1", ">", "0"}]},
       {
        RowBox[{"h2", ">", "0"}]},
       {
        RowBox[{"\[Mu]", ">", "0"}]},
       {
        RowBox[{"K", ">", "0"}]},
       {
        RowBox[{"a1", ">", "0"}]},
       {
        RowBox[{"Pin", ">", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007895987887`*^9},
 TextAlignment->Center,ExpressionUUID->"08a27d3f-3fb4-4d5f-9be5-3321c72825ce"]
}, Open  ]],

Cell["\<\
Scaling by the characteristic dimensions, which are assumed to be positive\
\>", "Text",
 CellChangeTimes->{{3.8152234378361177`*^9, 3.8152234565363507`*^9}, 
   3.815223487515731*^9},ExpressionUUID->"e6055883-f811-4ef1-9d50-\
6d5e5b8cf6dd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"uxC", ">", "0"}], ",", 
    RowBox[{"uyC", ">", "0"}], ",", 
    RowBox[{"pC1", ">", "0"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.8152234694868917`*^9, 3.8152234791842995`*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"4618f8ea-7bf9-4bae-8ed2-66686d1953bb"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{"uxC", ">", "0"}]},
       {
        RowBox[{"uyC", ">", "0"}]},
       {
        RowBox[{"pC1", ">", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007898586397`*^9},
 TextAlignment->Center,ExpressionUUID->"490324af-4537-41e9-abe9-69ce2dcac526"]
}, Open  ]],

Cell["we introduce the non-dimensional variables", "Text",
 CellChangeTimes->{{3.8152235002304015`*^9, 
  3.8152235126982117`*^9}},ExpressionUUID->"971c2982-1cef-4edd-89b8-\
9458602e6491"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "x_", "]"}], "=", 
     RowBox[{"x", " ", "/", "l"}]}], ";", 
    RowBox[{
     RowBox[{"Y1", "[", "y_", "]"}], "=", 
     RowBox[{"y", "/", "h1"}]}], ";", 
    RowBox[{
     RowBox[{"Y2", "[", "y_", "]"}], "=", 
     RowBox[{"y", " ", "/", "h2"}]}], ";"}], " "}],
  Background->GrayLevel[0.85]]], "Input",
 CellLabel->"In[29]:=",ExpressionUUID->"c3c0168b-cc94-417b-813f-9828e56ff8d9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"X", "==", 
     RowBox[{"x", " ", "/", "l"}]}], ",", 
    RowBox[{"Y1", "==", 
     RowBox[{"y", "/", "h1"}]}], ",", 
    RowBox[{"Y2", "==", 
     RowBox[{"y", " ", "/", "h2"}]}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.8152235906971064`*^9, 3.8152236408032007`*^9}, {
  3.815233079257622*^9, 3.815233083223355*^9}, {3.8152331154765253`*^9, 
  3.815233148140684*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"6cb53f5e-6f2e-4ae2-b644-09d2b31d7474"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{"X", "\[LongEqual]", 
         FractionBox["x", "l"]}]},
       {
        RowBox[{"Y1", "\[LongEqual]", 
         FractionBox["y", "h1"]}]},
       {
        RowBox[{"Y2", "\[LongEqual]", 
         FractionBox["y", "h2"]}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007900125504`*^9},
 TextAlignment->Center,ExpressionUUID->"eae2d127-82b6-4169-b4c4-f76383a7aba9"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.788846657367217*^9, 3.7888467044023857`*^9}, 
   3.7888487503074193`*^9, {3.788848800186204*^9, 3.7888488007418056`*^9}, 
   3.7888492849848967`*^9, 3.788850189022811*^9, {3.790092949153773*^9, 
   3.7900929539801188`*^9}, {3.79100068813951*^9, 3.791000705142762*^9}, {
   3.791000776326029*^9, 3.7910007842866535`*^9}, {3.7910010916398907`*^9, 
   3.791001109907282*^9}, 3.79100180637293*^9, {3.7910048039875607`*^9, 
   3.791004805777854*^9}, {3.8025351634533796`*^9, 3.802535168726352*^9}, {
   3.8025949051707683`*^9, 3.8025949052776833`*^9}, {3.804002756244924*^9, 
   3.804002758214821*^9}, {3.8152235181011143`*^9, 3.8152235234150333`*^9}, {
   3.815223659738302*^9, 3.815223660501848*^9}, 3.815223713686186*^9, 
   3.815223864450287*^9},
 CellLabel->"In[31]:=",ExpressionUUID->"b314aedf-407f-40cf-af6c-aae2c3426688"],

Cell["and define the slenderness ratio", "Text",
 CellChangeTimes->{{3.789228259291774*^9, 3.789228269562768*^9}, {
  3.789228589709876*^9, 
  3.7892285900900803`*^9}},ExpressionUUID->"f98e4fd0-c439-4781-b174-\
f5663c3118b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ShallowRelation1", "=", 
   RowBox[{"\[Epsilon]1", "\[Equal]", 
    RowBox[{"h1", "/", "l"}]}]}], ";", 
  RowBox[{"ShallowRelation2", "=", 
   RowBox[{"\[Epsilon]2", "\[Equal]", 
    RowBox[{"h2", "/", "l"}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.7892282936102285`*^9, {3.7892285988810368`*^9, 3.789228605366165*^9}, {
   3.7910007940814633`*^9, 3.791000795902013*^9}, {3.7910017843474164`*^9, 
   3.7910017972028437`*^9}, {3.8025352731500053`*^9, 3.802535273436858*^9}, {
   3.8025363995619593`*^9, 3.802536400877221*^9}, {3.802594949999945*^9, 
   3.802594950133899*^9}, {3.8040027635866985`*^9, 3.8040027646750717`*^9}, {
   3.8152237598305426`*^9, 3.8152237653114*^9}, 3.815223941005667*^9},
 CellLabel->"In[32]:=",ExpressionUUID->"ce892f4b-78d2-4ef8-958b-f92095d74a4d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"{", 
   RowBox[{"ShallowRelation1", ",", "ShallowRelation2"}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.815223958304696*^9, 3.8152239667368135`*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"98ffed9d-46b6-4cb0-8e23-09c221466b17"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{"\[Epsilon]1", "\[LongEqual]", 
         FractionBox["h1", "l"]}]},
       {
        RowBox[{"\[Epsilon]2", "\[LongEqual]", 
         FractionBox["h2", "l"]}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900790205441*^9},
 TextAlignment->Center,ExpressionUUID->"e9590aa7-cb56-4eb3-b399-c8a3abaaa894"]
}, Open  ]],

Cell["\<\
Substituting the above scaled coordinates as well as \[Epsilon]1 and \
\[Epsilon]2, to get the normalized set of equations as follows\
\>", "Text",
 CellChangeTimes->{{3.789109758321767*^9, 3.789109823044464*^9}, {
  3.791015184375188*^9, 3.7910151866694846`*^9}, {3.8152324066297092`*^9, 
  3.8152324416043787`*^9}},ExpressionUUID->"a48f4b84-356b-4398-b5bd-\
9523aeaeabc3"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"EquationList1", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"EquationList1", "//.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ux1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ux1C", " ", 
             RowBox[{"UX1", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          " ", ",", 
         RowBox[{"uy1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"uyC", " ", 
             RowBox[{"UY1", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"p1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"pC1", " ", 
             RowBox[{"P1", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"p2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"pC1", " ", 
             RowBox[{"P2", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", "0"}], "]"}]}], " ", "&"}],
            ")"}]}], ",", 
         RowBox[{"pin", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"Pin", "  ", "pC1"}], " ", ")"}]}], ",", 
         RowBox[{"x", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"X", " ", "l"}], ")"}]}], ",", 
         RowBox[{"y", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"Y1", " ", "h1"}], ")"}]}]}], "}"}]}], ",", 
      "AssumptionOnScaling"}], "]"}]}], ";"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7888445894916573`*^9, 3.7888446479472165`*^9}, {
   3.7888447101568155`*^9, 3.7888447204716997`*^9}, {3.788844751762835*^9, 
   3.7888449019211626`*^9}, {3.7888450870952635`*^9, 
   3.7888451099753227`*^9}, {3.7888451415959606`*^9, 3.7888452002821493`*^9}, 
   3.788845273282175*^9, {3.7888454218270035`*^9, 3.7888454247483144`*^9}, {
   3.788846575290144*^9, 3.7888466057618513`*^9}, 3.788846646051941*^9, {
   3.7888467345465603`*^9, 3.7888467370169544`*^9}, {3.7888488922325754`*^9, 
   3.7888488988477764`*^9}, {3.788849048778751*^9, 3.7888490722936373`*^9}, {
   3.7888491152830257`*^9, 3.788849123944197*^9}, {3.7888492597314353`*^9, 
   3.7888492677625074`*^9}, {3.7888493618279023`*^9, 3.788849372013519*^9}, {
   3.7888494052368917`*^9, 3.788849412557126*^9}, {3.78884967541287*^9, 
   3.788849743946454*^9}, 3.788850166304041*^9, {3.7889576675073824`*^9, 
   3.788957667922283*^9}, {3.788958663763878*^9, 3.7889586677905226`*^9}, {
   3.788958705577075*^9, 3.788958710668492*^9}, {3.7889590856200905`*^9, 
   3.788959089819852*^9}, {3.7889591210143833`*^9, 3.788959126220434*^9}, {
   3.788959157291351*^9, 3.7889591861944485`*^9}, {3.7889592968761415`*^9, 
   3.788959299327213*^9}, {3.7889595075150747`*^9, 3.7889595114714937`*^9}, {
   3.788959550820706*^9, 3.788959588190008*^9}, {3.788959625794365*^9, 
   3.788959632004291*^9}, {3.7889596621604395`*^9, 3.788959668585457*^9}, {
   3.788959701986768*^9, 3.7889597080924597`*^9}, {3.788959789519207*^9, 
   3.788959819907319*^9}, {3.7889599720992517`*^9, 3.7889599764912195`*^9}, 
   3.788960007799838*^9, {3.788960190229639*^9, 3.788960270324862*^9}, {
   3.7889605010426836`*^9, 3.7889606089090605`*^9}, {3.7890250271799774`*^9, 
   3.7890250289892054`*^9}, {3.7890254317536716`*^9, 
   3.7890254456817493`*^9}, {3.789025485407466*^9, 3.789025494967655*^9}, {
   3.789106200290019*^9, 3.7891062239846625`*^9}, 3.7891062559891224`*^9, {
   3.789106291066717*^9, 3.7891063229804716`*^9}, {3.7891064467052774`*^9, 
   3.789106448957025*^9}, 3.789106496696083*^9, 3.7891098401548815`*^9, {
   3.7892043017135563`*^9, 3.789204312086053*^9}, {3.789204705817875*^9, 
   3.7892047061848707`*^9}, {3.790093411651821*^9, 3.7900934371031055`*^9}, {
   3.7900939931988544`*^9, 3.7900940992847986`*^9}, {3.790094287254275*^9, 
   3.7900943459059343`*^9}, {3.7900953873631916`*^9, 
   3.7900953971336803`*^9}, {3.7910008117556276`*^9, 
   3.7910010179996605`*^9}, {3.7910018301060266`*^9, 
   3.7910019006625433`*^9}, {3.7910019997081823`*^9, 3.791002000027186*^9}, {
   3.7910025773997664`*^9, 3.7910025782804136`*^9}, 3.7910026439415684`*^9, {
   3.7910046884629674`*^9, 3.7910046899422617`*^9}, {3.7910148386291475`*^9, 
   3.791014847362551*^9}, 3.7910174425949774`*^9, {3.791019764311965*^9, 
   3.7910197775812845`*^9}, {3.7910198196143427`*^9, 3.791019822309923*^9}, {
   3.791020481583454*^9, 3.791020567662266*^9}, {3.7910921471468225`*^9, 
   3.7910921494801135`*^9}, {3.791180790055011*^9, 3.791180811866476*^9}, {
   3.7911808471762114`*^9, 3.7911808536997633`*^9}, 3.815232348210045*^9, {
   3.815232825091321*^9, 3.815232830803014*^9}, {3.815232947960027*^9, 
   3.81523295097727*^9}, {3.8152329890833187`*^9, 3.815233007876485*^9}, 
   3.815233215194027*^9},
 CellLabel->"In[34]:=",ExpressionUUID->"190406fd-3dff-4c32-a55e-bc5a6da89551"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList1", "]"}]], "Input",
 CellChangeTimes->{
  3.802536448980519*^9, {3.814531178651952*^9, 3.8145311840664744`*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"a99acee6-8fd9-4287-a043-7bac2bd48b61"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          RowBox[{"h1", " ", "ux1C", " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UX1"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          RowBox[{"l", " ", "uyC", " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UY1"}], 
            RowBox[{"\[PartialD]", "Y1"}],
            MultilineFunction->None]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"ux1C", " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["h1", "2"], " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UX1"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["X", "2"]}],
              MultilineFunction->None]}], "+", 
            RowBox[{
             SuperscriptBox["l", "2"], " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UX1"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["Y1", "2"]}],
              MultilineFunction->None]}]}], ")"}]}], "\[LongEqual]", 
         RowBox[{
          SuperscriptBox["h1", "2"], " ", "l", " ", "pC1", " ", 
          FractionBox[
           RowBox[{"\[PartialD]", "P1"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None]}]}]},
       {
        RowBox[{
         RowBox[{"uyC", " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["h1", "2"], " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UY1"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["X", "2"]}],
              MultilineFunction->None]}], "+", 
            RowBox[{
             SuperscriptBox["l", "2"], " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UY1"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["Y1", "2"]}],
              MultilineFunction->None]}]}], ")"}]}], "\[LongEqual]", 
         RowBox[{"h1", " ", 
          SuperscriptBox["l", "2"], " ", "pC1", " ", 
          FractionBox[
           RowBox[{"\[PartialD]", "P1"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None]}]}]},
       {
        RowBox[{
         RowBox[{"ux1C", " ", "UX1"}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"ux1C", " ", "UX1"}], "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY1", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"uyC", " ", "UY1"}], "\[LongEqual]", 
         FractionBox[
          RowBox[{"k", " ", "pC1", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "P1"}], "+", "P2"}], ")"}]}], 
          RowBox[{"w", " ", "\[Mu]"}]]}]},
       {
        RowBox[{"Pin", "\[LongEqual]", "P1"}]},
       {
        RowBox[{"P1", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900790890043*^9},
 TextAlignment->Center,ExpressionUUID->"fe029edb-b966-4bd8-b548-b2ef394c2292"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"EquationList1", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"EquationList1", "//.", 
         RowBox[{"{", 
          RowBox[{"Solve", "[", 
           RowBox[{
            FormBox["ShallowRelation1",
             TraditionalForm], ",", "h1"}], "]"}], "}"}]}], ",", 
        "AssumptionOnScaling"}], "]"}], ",", "6"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.7910169060122185`*^9, 3.791016963795545*^9}, 
   3.815232447745837*^9, {3.815232816892037*^9, 3.815232835280435*^9}, 
   3.8152330095625114`*^9, 3.8152364006170983`*^9},
 CellLabel->"In[36]:=",ExpressionUUID->"7dcb0647-8e53-41ed-8e8e-f07f6bf92f78"],

Cell[TextData[{
 "Examining the scales of the terms of the continuity equation and assuming \
that ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", "UX1"}], 
      RowBox[{"\[PartialD]", "X"}],
      MultilineFunction->None], " ", "is", " ", "of", " ", "the", " ", "same",
      " ", "order", " ", "as", " ", 
     FractionBox[
      RowBox[{"\[PartialD]", "UY1"}], 
      RowBox[{"\[PartialD]", "Y1"}],
      MultilineFunction->None]}],
    FontWeight->"Plain"], TraditionalForm]],ExpressionUUID->
  "9e80db9e-362b-49b2-8f8f-b77caf500e86"]
}], "Text",
 CellChangeTimes->{{3.8152378809042263`*^9, 3.8152379584597807`*^9}, {
  3.8152379991982756`*^9, 3.81523805850209*^9}, {3.8152380951689644`*^9, 
  3.815238098235197*^9}},ExpressionUUID->"2ee65efb-0100-4946-aaf9-\
b8b66527253d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"EquationList1", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7892284397529497`*^9, 3.7892284419841557`*^9}, 
   3.7910049152968674`*^9, {3.815236488439413*^9, 3.815236489922577*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"e681f2ee-ae44-42d5-90ed-2fbcb1a0b10b"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     RowBox[{
      RowBox[{"ux1C", " ", "\[Epsilon]1", " ", 
       FractionBox[
        RowBox[{"\[PartialD]", "UX1"}], 
        RowBox[{"\[PartialD]", "X"}],
        MultilineFunction->None]}], "+", 
      RowBox[{"uyC", " ", 
       FractionBox[
        RowBox[{"\[PartialD]", "UY1"}], 
        RowBox[{"\[PartialD]", "Y1"}],
        MultilineFunction->None]}]}], "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900791386757*^9},
 TextAlignment->Center,ExpressionUUID->"de211820-6f2f-4020-b8d6-065e21614273"]
}, Open  ]],

Cell["yields the first scaling relation", "Text",
 CellChangeTimes->{{3.78896033839715*^9, 3.788960362854823*^9}, 
   3.7889607061938057`*^9, {3.788960990361854*^9, 3.7889610006592665`*^9}, {
   3.789228624785879*^9, 3.7892286299250693`*^9}, {3.7892286819216104`*^9, 
   3.7892286829129844`*^9}, 3.7911808896527624`*^9, 
   3.8034731990553427`*^9},ExpressionUUID->"61f67a67-f981-4d7a-af57-\
49d4c9bb5c34"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"FirstScalingRelation1", "=", 
   RowBox[{
    FractionBox["uyC", "ux1C"], "\[Equal]", "\[Epsilon]1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7890305605282617`*^9, 3.7890306012077565`*^9}, {
   3.7891073921360946`*^9, 3.7891074477738047`*^9}, {3.7891077894743443`*^9, 
   3.789107793533653*^9}, {3.789109885768797*^9, 3.789109910073144*^9}, {
   3.7891116682884665`*^9, 3.7891116709850187`*^9}, {3.789112453293788*^9, 
   3.7891124849826307`*^9}, 3.7892033087264247`*^9, {3.78920472858747*^9, 
   3.789204728770942*^9}, 3.789228280640132*^9, 3.789228481024803*^9, 
   3.7892286494671597`*^9, 3.79100492547932*^9, {3.7910152901223593`*^9, 
   3.791015303726268*^9}, 3.791017011530769*^9, 3.7940320377744303`*^9, {
   3.815238131982723*^9, 3.8152381419309874`*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"c77d6c5a-30e3-456e-a347-c6356a38936a"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["uyC", "ux1C"], "\[LongEqual]", "\[Epsilon]1"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007916096272`*^9},
 TextAlignment->Center,ExpressionUUID->"5ba3a3ba-0208-4582-aa08-7be7014883da"]
}, Open  ]],

Cell["\<\
The relation is used to express uyC using the following parameters\
\>", "Text",
 CellChangeTimes->{{3.815238762131646*^9, 
  3.815238857005045*^9}},ExpressionUUID->"5a0f047e-7939-4e4a-8c4e-\
f0498f999c9b"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       FormBox["FirstScalingRelation1",
        TraditionalForm], ",", "uyC"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.815238747014344*^9, 3.8152387554125204`*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"ef5df8bb-4ff1-43fa-ae54-d8b148c9ea00"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"uyC", "\[Rule]", 
     RowBox[{"ux1C", " ", "\[Epsilon]1"}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900791986417*^9},
 TextAlignment->Center,ExpressionUUID->"07b39fba-d3d0-4cbd-acf0-564a731b8f13"]
}, Open  ]],

Cell["which is then substituted into the governing equations", "Text",
 CellChangeTimes->{{3.789109961158434*^9, 3.789109981894738*^9}, {
  3.7892288132563643`*^9, 3.7892288336465178`*^9}, {3.81523645338264*^9, 
  3.815236460054403*^9}, {3.8152388460221786`*^9, 
  3.815238846551874*^9}},ExpressionUUID->"aec21126-7f62-4af7-8e2d-\
cb97690c3a35"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"EquationList1", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"EquationList1", "//.", 
         RowBox[{"{", 
          RowBox[{"Solve", "[", 
           RowBox[{
            FormBox["FirstScalingRelation1",
             TraditionalForm], ",", "uyC"}], "]"}], "}"}]}], ",", 
        "AssumptionOnScaling"}], "]"}], ",", "6"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.788960384651573*^9, 3.788960426200202*^9}, {
   3.788961086058696*^9, 3.7889611468369102`*^9}, {3.7890235361137257`*^9, 
   3.7890235598617325`*^9}, {3.7891099929809065`*^9, 
   3.7891100699568233`*^9}, {3.789111677739606*^9, 3.78911168071181*^9}, 
   3.789203315052771*^9, 3.7892286456906853`*^9, {3.7910153593781548`*^9, 
   3.7910154226334486`*^9}, 3.7910168262764525`*^9, {3.791017022529649*^9, 
   3.791017030224433*^9}, 3.7911809571518*^9, {3.8152367729403267`*^9, 
   3.8152367752050023`*^9}, 3.815236845589553*^9},
 CellLabel->"In[40]:=",ExpressionUUID->"f22187e6-26f6-4eb1-beab-f478c1e8a1b3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList1", "]"}]], "Input",
 CellChangeTimes->{{3.8152368000367794`*^9, 3.8152368373253174`*^9}, {
  3.8152369098585196`*^9, 3.8152369130147*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"4ac8c04b-33b6-47bb-8db4-7370c5175df9"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{"ux1C", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"\[PartialD]", "UX1"}], 
             RowBox[{"\[PartialD]", "X"}],
             MultilineFunction->None], "+", 
            FractionBox[
             RowBox[{"\[PartialD]", "UY1"}], 
             RowBox[{"\[PartialD]", "Y1"}],
             MultilineFunction->None]}], ")"}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Epsilon]1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l", " ", "pC1", " ", 
             FractionBox[
              RowBox[{"\[PartialD]", "P1"}], 
              RowBox[{"\[PartialD]", "X"}],
              MultilineFunction->None]}], "-", 
            RowBox[{"ux1C", " ", "\[Mu]", " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UX1"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["X", "2"]}],
              MultilineFunction->None]}]}], ")"}]}], "\[LongEqual]", 
         RowBox[{"ux1C", " ", "\[Mu]", " ", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX1"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y1", "2"]}],
           MultilineFunction->None]}]}]},
       {
        RowBox[{
         RowBox[{"l", " ", "pC1", " ", 
          FractionBox[
           RowBox[{"\[PartialD]", "P1"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None]}], "\[LongEqual]", 
         RowBox[{"ux1C", " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Epsilon]1", "2"], " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UY1"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["X", "2"]}],
              MultilineFunction->None]}], "+", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[PartialD]", "2"], "UY1"}], 
             RowBox[{"\[PartialD]", 
              SuperscriptBox["Y1", "2"]}],
             MultilineFunction->None]}], ")"}]}]}]},
       {
        RowBox[{
         RowBox[{"ux1C", " ", "UX1"}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"ux1C", " ", "UX1"}], "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY1", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"ux1C", " ", "\[Epsilon]1", " ", "UY1"}], "\[LongEqual]", 
         FractionBox[
          RowBox[{"k", " ", "pC1", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "P1"}], "+", "P2"}], ")"}]}], 
          RowBox[{"w", " ", "\[Mu]"}]]}]},
       {
        RowBox[{"Pin", "\[LongEqual]", "P1"}]},
       {
        RowBox[{"P1", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900792340205*^9},
 TextAlignment->Center,ExpressionUUID->"123d7c94-e4c7-424e-8804-d2af436ade8a"]
}, Open  ]],

Cell["\<\
By examining the scales of the streamwise momentum equation, given by\
\>", "Text",
 CellChangeTimes->{{3.789110785285885*^9, 3.789110834628291*^9}, {
  3.7892288622872267`*^9, 3.789228871728592*^9}, {3.7910168093750706`*^9, 
  3.7910168132173033`*^9}, {3.815236934460337*^9, 3.8152369374646034`*^9}, {
  3.815238242273514*^9, 
  3.815238248148262*^9}},ExpressionUUID->"cc24846d-6c4b-405c-a0a6-\
eeee58512196"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"EquationList1", "[", 
   RowBox[{"[", "2", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.789228890762924*^9, 3.789228899281889*^9}, 
   3.791017060880043*^9, {3.7910186924190702`*^9, 3.791018692551461*^9}, {
   3.8152369593240023`*^9, 3.815236960435361*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"1a281b84-2ad3-4914-b4b9-fdea94f5d69e"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Epsilon]1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"l", " ", "pC1", " ", 
         FractionBox[
          RowBox[{"\[PartialD]", "P1"}], 
          RowBox[{"\[PartialD]", "X"}],
          MultilineFunction->None]}], "-", 
        RowBox[{"ux1C", " ", "\[Mu]", " ", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "UX1"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["X", "2"]}],
          MultilineFunction->None]}]}], ")"}]}], "\[LongEqual]", 
     RowBox[{"ux1C", " ", "\[Mu]", " ", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[PartialD]", "2"], "UX1"}], 
       RowBox[{"\[PartialD]", 
        SuperscriptBox["Y1", "2"]}],
       MultilineFunction->None]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007925041113`*^9},
 TextAlignment->Center,ExpressionUUID->"d6e33d6f-67f1-434c-ae5e-b14b52ed32a1"]
}, Open  ]],

Cell["\<\
by expecting a balance between the viscous terms and pressure related terms, \
a pressure-dissipation scaling relation is obtained\
\>", "Text",
 CellChangeTimes->{{3.789110785285885*^9, 3.789110834628291*^9}, {
   3.7892288622872267`*^9, 3.7892288706148233`*^9}, {3.789231689151945*^9, 
   3.7892317386669884`*^9}, {3.8152369814384985`*^9, 3.815236984374824*^9}, {
   3.815237051183876*^9, 3.8152370695329947`*^9}, {3.815238197646883*^9, 
   3.815238200486247*^9}, {3.8152382593284445`*^9, 3.8152382960772495`*^9}, {
   3.815238329957876*^9, 3.815238356741434*^9}, {3.815238399516774*^9, 
   3.815238479619859*^9}, {3.8152385150404572`*^9, 3.815238519906652*^9}, {
   3.815238585905879*^9, 3.8152386364850683`*^9}, 3.815238899417591*^9, {
   3.817748929858671*^9, 3.8177489353947697`*^9}, 
   3.817803840527486*^9},ExpressionUUID->"e5634736-b3aa-4ff4-b5bb-\
3b2e29961a7d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"PressureScale1", "=", " ", 
   RowBox[{
    RowBox[{"pC1", " ", "/", "l"}], " ", "==", 
    RowBox[{"ux1C", " ", 
     RowBox[{"\[Mu]", "/", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]1", " ", "\[Epsilon]1", " ", "l", " ", "l"}], 
       ")"}]}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.789231754590742*^9, {3.7910170842424793`*^9, 3.7910171235751085`*^9}, {
   3.7910182732907157`*^9, 3.791018299731946*^9}, {3.7910187105132475`*^9, 
   3.791018737870178*^9}, {3.7910188607632766`*^9, 3.7910188698056517`*^9}, 
   3.7911809057422976`*^9, {3.791181039247755*^9, 3.791181044716346*^9}, {
   3.8152369948577633`*^9, 3.815236996765664*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"45ea8fc0-a81c-4b63-af53-52c1e499ff66"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["pC1", "l"], "\[LongEqual]", 
     FractionBox[
      RowBox[{"ux1C", " ", "\[Mu]"}], 
      RowBox[{
       SuperscriptBox["l", "2"], " ", 
       SuperscriptBox["\[Epsilon]1", "2"]}]]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007927089925`*^9},
 TextAlignment->Center,ExpressionUUID->"c241ec0c-d482-41ff-856b-2bb5c0049d71"]
}, Open  ]],

Cell["Using this relation to express ux1C as follows", "Text",
 CellChangeTimes->{{3.8152387010998325`*^9, 3.8152387269709167`*^9}, {
  3.8152389092209225`*^9, 
  3.815238933182126*^9}},ExpressionUUID->"133fddf8-4a6e-43a4-9c42-\
58552ec5b7c2"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       FormBox["PressureScale1",
        TraditionalForm], ",", "ux1C"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.815238663198683*^9, 3.815238681367208*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"0d596993-f6c1-464c-835b-024f49365ca9"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"ux1C", "\[Rule]", 
     FractionBox[
      RowBox[{"l", " ", "pC1", " ", 
       SuperscriptBox["\[Epsilon]1", "2"]}], "\[Mu]"]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007930338097`*^9},
 TextAlignment->Center,ExpressionUUID->"0ee57908-e1b4-45f5-baa1-87e1be77f59a"]
}, Open  ]],

Cell[" and  substitute it into the governing equations", "Text",
 CellChangeTimes->{{3.8152382983679175`*^9, 3.815238299778124*^9}, {
  3.8152389363942747`*^9, 
  3.8152389456159415`*^9}},ExpressionUUID->"67136dcf-f19d-4d0f-a448-\
24bd8ecd1952"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"EquationList1", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"EquationList1", "//.", 
         RowBox[{"{", 
          RowBox[{"Solve", "[", 
           RowBox[{
            FormBox["PressureScale1",
             TraditionalForm], ",", "ux1C"}], "]"}], "}"}]}], ",", 
        "AssumptionOnScaling"}], "]"}], ",", "6"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.7890295892200003`*^9, 3.7890295900794897`*^9}, {
   3.789029629080496*^9, 3.7890296640233755`*^9}, {3.789111292931563*^9, 
   3.789111379136862*^9}, {3.789111461803974*^9, 3.7891114818431177`*^9}, {
   3.7891115590491247`*^9, 3.789111575055559*^9}, 3.7892035458268013`*^9, {
   3.7892047400596485`*^9, 3.7892047401992593`*^9}, 3.7892315284481783`*^9, 
   3.7892316012073593`*^9, 3.7892317523967323`*^9, {3.791018311540884*^9, 
   3.7910183183207426`*^9}, {3.7910183526998253`*^9, 
   3.7910183606250677`*^9}, {3.7911809212748146`*^9, 3.791180929779458*^9}, 
   3.8152371263182755`*^9},
 CellLabel->"In[45]:=",ExpressionUUID->"37d7cc37-f424-4d87-adbf-830230511a1e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList1", "]"}]], "Input",
 CellChangeTimes->{{3.8152371375287933`*^9, 3.815237138330352*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"37feefd9-71a7-429c-b972-2b1a0d29f7b3"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX1"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY1"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UX1"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["X", "2"]}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX1"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y1", "2"]}],
           MultilineFunction->None]}], "\[LongEqual]", 
         FractionBox[
          RowBox[{"\[PartialD]", "P1"}], 
          RowBox[{"\[PartialD]", "X"}],
          MultilineFunction->None]}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P1"}], 
          RowBox[{"\[PartialD]", "Y1"}],
          MultilineFunction->None], "\[LongEqual]", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "4"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UY1"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["X", "2"]}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UY1"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["Y1", "2"]}],
            MultilineFunction->None]}]}]}]},
       {
        RowBox[{"UX1", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX1", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY1", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"k", " ", "P1"}], "-", 
           RowBox[{"k", " ", "P2"}], "+", 
           RowBox[{"l", " ", "w", " ", 
            SuperscriptBox["\[Epsilon]1", "3"], " ", "UY1"}]}], "w"], 
         "\[LongEqual]", "0"}]},
       {
        RowBox[{"Pin", "\[LongEqual]", "P1"}]},
       {
        RowBox[{"P1", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900793372609*^9},
 TextAlignment->Center,ExpressionUUID->"3574661d-1fa7-4e7c-b345-13e642ad58b6"]
}, Open  ]],

Cell["\<\
From the boundary condition expressing the flux at the separator layer, i.e.\
\>", "Text",
 CellChangeTimes->{{3.7910199617635384`*^9, 3.7910199699416404`*^9}, {
  3.8152371470293365`*^9, 3.8152371481476717`*^9}, {3.815238997723526*^9, 
  3.815239017370025*^9}},ExpressionUUID->"20ed17a1-b65d-46c5-a405-\
88703bcd1fcc"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"EquationList1", "[", 
    RowBox[{"[", "7", "]"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.791019980571164*^9, 3.791019990553692*^9}, {
  3.8152371536555157`*^9, 3.8152371551316643`*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"d739b1b2-67de-4495-b8c0-edb124caceb7"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"k", " ", "P1"}], "-", 
       RowBox[{"k", " ", "P2"}], "+", 
       RowBox[{"l", " ", "w", " ", 
        SuperscriptBox["\[Epsilon]1", "3"], " ", "UY1"}]}], "w"], 
     "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007935215235`*^9},
 TextAlignment->Center,ExpressionUUID->"8ecbda1d-9d1c-43f0-b153-42f01db4a230"]
}, Open  ]],

Cell["an additional dimensional parameter can be extracted", "Text",
 CellChangeTimes->{{3.79101999316571*^9, 3.791020035479834*^9}, {
  3.8152371602696905`*^9, 
  3.815237180223791*^9}},ExpressionUUID->"5b9b9201-9805-431c-a638-\
f12536c867ce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"Kparameter1", "=", 
   RowBox[{"K1", "\[Equal]", 
    RowBox[{"k", " ", "/", 
     RowBox[{"(", 
      RowBox[{"w", " ", "l", " ", 
       SuperscriptBox["\[Epsilon]1", "3"]}], ")"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.791020050578171*^9, 3.7910201285569024`*^9}, {
   3.7910202771668572`*^9, 3.7910202775181117`*^9}, {3.7910203502341237`*^9, 
   3.791020379224369*^9}, 3.79109267110328*^9, 3.7910928333587723`*^9, {
   3.815237186640081*^9, 3.8152371877684307`*^9}, {3.8266907510756125`*^9, 
   3.8266907568579254`*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"8923c9c0-f0e7-404c-8aa2-baca5f507bdc"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"K1", "\[LongEqual]", 
     FractionBox["k", 
      RowBox[{"l", " ", "w", " ", 
       SuperscriptBox["\[Epsilon]1", "3"]}]]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007936724358`*^9},
 TextAlignment->Center,ExpressionUUID->"f0d95bdc-883f-4471-bc68-3f756417b23a"]
}, Open  ]],

Cell["resulting in an expression for the permeability K", "Text",
 CellChangeTimes->{{3.815239065041542*^9, 
  3.815239092298827*^9}},ExpressionUUID->"a60a4e9e-8434-4558-b351-\
6a8292ab215a"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       FormBox["Kparameter1",
        TraditionalForm], ",", "k"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.8152390514173765`*^9, 3.8152390592099047`*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"6a80786f-9b8b-471b-9408-1a741db78e35"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"k", "\[Rule]", 
     RowBox[{"K1", " ", "l", " ", "w", " ", 
      SuperscriptBox["\[Epsilon]1", "3"]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900793825348*^9},
 TextAlignment->Center,ExpressionUUID->"25a519b3-8982-47f9-95fc-7ae3ca6628a4"]
}, Open  ]],

Cell["which again is substituted to the governing equations", "Text",
 CellChangeTimes->{{3.79101999316571*^9, 3.79102003052488*^9}, {
  3.791020188430789*^9, 3.791020209849537*^9}, {3.8152371974748907`*^9, 
  3.815237214887043*^9}},ExpressionUUID->"2272036c-fd27-4bfb-9fbf-\
00eb8fcf0005"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"EquationList1", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"EquationList1", "//.", 
         RowBox[{"{", 
          RowBox[{"Solve", "[", 
           RowBox[{
            FormBox["Kparameter1",
             TraditionalForm], ",", "k"}], "]"}], "}"}]}], ",", 
        "AssumptionOnScaling"}], "]"}], ",", "6"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.791020219612568*^9, 3.791020227896762*^9}, 
   3.7910926727353787`*^9, {3.79109275661226*^9, 3.791092759259745*^9}, {
   3.791092894370928*^9, 3.7910928971152983`*^9}, 3.815237221145418*^9},
 CellLabel->"In[50]:=",ExpressionUUID->"c9e65873-10f6-4e19-8fd4-e5a855c1b60a"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", "EquationList1", "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{3.815237229781456*^9},
 CellLabel->"In[51]:=",ExpressionUUID->"d0d99d76-1f28-4f76-ba1b-9d78fa1f4b9a"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX1"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY1"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UX1"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["X", "2"]}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX1"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y1", "2"]}],
           MultilineFunction->None]}], "\[LongEqual]", 
         FractionBox[
          RowBox[{"\[PartialD]", "P1"}], 
          RowBox[{"\[PartialD]", "X"}],
          MultilineFunction->None]}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P1"}], 
          RowBox[{"\[PartialD]", "Y1"}],
          MultilineFunction->None], "\[LongEqual]", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "4"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UY1"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["X", "2"]}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UY1"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["Y1", "2"]}],
            MultilineFunction->None]}]}]}]},
       {
        RowBox[{"UX1", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX1", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY1", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"K1", " ", "P1"}], "+", "UY1"}], "\[LongEqual]", 
         RowBox[{"K1", " ", "P2"}]}]},
       {
        RowBox[{"Pin", "\[LongEqual]", "P1"}]},
       {
        RowBox[{"P1", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007941761456`*^9},
 TextAlignment->Center,ExpressionUUID->"f9a3f854-3455-43e6-9916-53a6dae597d2"]
}, Open  ]],

Cell["Similar scaling is performed for region 2", "Text",
 CellChangeTimes->{{3.79101999316571*^9, 3.79102003052488*^9}, {
  3.791020188430789*^9, 3.791020206004116*^9}, {3.7910921599318686`*^9, 
  3.7910921726523886`*^9}, {3.814531212010744*^9, 
  3.814531213473875*^9}},ExpressionUUID->"32e5d6b6-96a5-437b-b1b4-\
e8e46fd4670e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EquationList2", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"EquationList2", "//.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ux2", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ux2C", " ", 
            RowBox[{"UX2", "[", 
             RowBox[{
              RowBox[{"X", "[", "#1", "]"}], ",", 
              RowBox[{"Y2", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}], 
        " ", ",", 
        RowBox[{"uy2", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"uyC", " ", 
            RowBox[{"UY2", "[", 
             RowBox[{
              RowBox[{"X", "[", "#1", "]"}], ",", 
              RowBox[{"Y2", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}], 
        ",", 
        RowBox[{"p2", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"pC2", " ", 
            RowBox[{"P2", "[", 
             RowBox[{
              RowBox[{"X", "[", "#1", "]"}], ",", 
              RowBox[{"Y2", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}], 
        ",", 
        RowBox[{"p1", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"pC2", " ", 
            RowBox[{"P1", "[", 
             RowBox[{
              RowBox[{"X", "[", "#1", "]"}], ",", "0"}], "]"}]}], " ", "&"}], 
          ")"}]}], ",", 
        RowBox[{"pin", "\[Rule]", " ", 
         RowBox[{"(", 
          RowBox[{"Pin", "  ", "pC2"}], " ", ")"}]}], ",", 
        RowBox[{"x", "\[Rule]", " ", 
         RowBox[{"(", 
          RowBox[{"X", " ", "l"}], ")"}]}], ",", 
        RowBox[{"y", "\[Rule]", " ", 
         RowBox[{"(", 
          RowBox[{"Y2", " ", "h2"}], ")"}]}]}], "}"}]}], ",", 
     "AssumptionOnScaling"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.79109217911166*^9, 3.7910927020031753`*^9, {3.7911810864644637`*^9, 
   3.7911810912197485`*^9}, {3.802595817777977*^9, 3.802595818296712*^9}, 
   3.8025959294966917`*^9, 3.8025959675267887`*^9, {3.8040028276591964`*^9, 
   3.8040028287355595`*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"4e80c94b-bbfa-407c-9b5e-db80fd02a3d1"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"EquationList2", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"EquationList2", "//.", 
         RowBox[{"{", 
          RowBox[{"Solve", "[", 
           RowBox[{
            FormBox["ShallowRelation2",
             TraditionalForm], ",", "h2"}], "]"}], "}"}]}], ",", 
        "AssumptionOnScaling"}], "]"}], ",", "6"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.7910922099047556`*^9, 3.7910922213076277`*^9}, {
   3.7910927040982213`*^9, 3.791092707071684*^9}, 3.802595845071268*^9, 
   3.8025959742929106`*^9, {3.8040028554931583`*^9, 3.8040028576898947`*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"ade8582a-8789-4bfd-8a7e-926fc3cd373e"],

Cell["similarly, scaling relations for the second region result in", "Text",
 CellChangeTimes->{{3.7910922607872066`*^9, 3.791092283000944*^9}, {
  3.8152372450316467`*^9, 3.8152372578612504`*^9}, {3.815237315990757*^9, 
  3.8152373181435137`*^9}, {3.815239118248866*^9, 
  3.8152391246232204`*^9}},ExpressionUUID->"a760c1da-f019-42b3-af2d-\
a135c8d23e7b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"FirstScalingRelation2", "=", 
   RowBox[{
    FractionBox["uyC", "ux2C"], "\[Equal]", "\[Epsilon]2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7910922707058797`*^9, 3.7910922781368914`*^9}, {
  3.815237304240511*^9, 3.815237305754639*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"536c18a4-f566-4f3a-b22a-f926113115ee"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["uyC", "ux2C"], "\[LongEqual]", "\[Epsilon]2"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900794860751*^9},
 TextAlignment->Center,ExpressionUUID->"18ca7f88-be68-47c7-9ef4-8103d096a78f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"Kparameter2", "=", 
   RowBox[{"K2", "\[Equal]", 
    RowBox[{"k", " ", "/", 
     RowBox[{"(", 
      RowBox[{"w", " ", "l", " ", 
       SuperscriptBox["\[Epsilon]2", "3"]}], ")"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.791092687319867*^9, 3.7910926930277586`*^9}, {
  3.791092805854146*^9, 3.791092825734249*^9}, {3.815237322183166*^9, 
  3.815237323459449*^9}, {3.8266907896316714`*^9, 3.826690793169217*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"851cc1c0-1e87-4a8d-bfab-279266360abc"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"K2", "\[LongEqual]", 
     FractionBox["k", 
      RowBox[{"l", " ", "w", " ", 
       SuperscriptBox["\[Epsilon]2", "3"]}]]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007951066074`*^9},
 TextAlignment->Center,ExpressionUUID->"49f7886d-40e5-4c38-983c-30ee974b1b94"]
}, Open  ]],

Cell["and", "Text",
 CellChangeTimes->{{3.791092359240821*^9, 
  3.7910923603488607`*^9}},ExpressionUUID->"6a3cc3be-8bdc-4681-8101-\
1aab249a01f9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"PressureScale2", "=", " ", 
   RowBox[{
    RowBox[{"pC2", "/", "l"}], " ", "==", 
    RowBox[{"uyC", " ", 
     RowBox[{"\[Mu]", "/", 
      RowBox[{"(", 
       RowBox[{
       "\[Epsilon]2", " ", "\[Epsilon]2", " ", "\[Epsilon]2", " ", "l", " ", 
        "l"}], ")"}]}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.791092365380623*^9, 3.7910923746754475`*^9}, {
  3.791181248904684*^9, 3.7911812531034565`*^9}, {3.81523733263416*^9, 
  3.8152373337775*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"da3f8af1-da2f-4358-b371-6dcf6becb70a"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["pC2", "l"], "\[LongEqual]", 
     FractionBox[
      RowBox[{"uyC", " ", "\[Mu]"}], 
      RowBox[{
       SuperscriptBox["l", "2"], " ", 
       SuperscriptBox["\[Epsilon]2", "3"]}]]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900795320486*^9},
 TextAlignment->Center,ExpressionUUID->"86377428-4eb8-4f97-8678-501a083e5793"]
}, Open  ]],

Cell["\<\
These scaling relations are substituted to the governing equations of region \
2 as follows\
\>", "Text",
 CellChangeTimes->{{3.815237339517172*^9, 
  3.8152373665243607`*^9}},ExpressionUUID->"705147f4-d5a9-423e-b330-\
fa522e695ae0"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       FormBox["FirstScalingRelation2",
        TraditionalForm], ",", "ux2C"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.815239184891305*^9, 3.8152391965275965`*^9}},
 CellLabel->"In[57]:=",ExpressionUUID->"4bc36af4-3d6b-46db-8e05-f4ad9ba9f304"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"ux2C", "\[Rule]", 
     FractionBox["uyC", "\[Epsilon]2"]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007955423574`*^9},
 TextAlignment->Center,ExpressionUUID->"7081f613-ed68-483c-ae41-cd44ea99a9d6"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"EquationList2", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"EquationList2", "//.", 
         RowBox[{"{", 
          RowBox[{"Solve", "[", 
           RowBox[{
            FormBox["FirstScalingRelation2",
             TraditionalForm], ",", "ux2C"}], "]"}], "}"}]}], ",", 
        "AssumptionOnScaling"}], "]"}], ",", "6"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.79109254747971*^9, 3.7910925616238365`*^9}, 
   3.791092711458001*^9},
 CellLabel->"In[58]:=",ExpressionUUID->"36a17b40-7d8c-476d-8e06-c4b511da782a"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       FormBox["PressureScale2",
        TraditionalForm], ",", "pC2"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.8152392079519944`*^9, 3.815239211061219*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"b359a1b8-1885-4fa3-95c4-8f687403f2de"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"pC2", "\[Rule]", 
     FractionBox[
      RowBox[{"uyC", " ", "\[Mu]"}], 
      RowBox[{"l", " ", 
       SuperscriptBox["\[Epsilon]2", "3"]}]]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007958831596`*^9},
 TextAlignment->Center,ExpressionUUID->"76fd4318-eb18-427b-9047-bf4c4cc8cfbc"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"EquationList2", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"EquationList2", "//.", 
         RowBox[{"{", 
          RowBox[{"Solve", "[", 
           RowBox[{
            FormBox["PressureScale2",
             TraditionalForm], ",", "pC2"}], "]"}], "}"}]}], ",", 
        "AssumptionOnScaling"}], "]"}], ",", "6"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.7910925763876743`*^9, 3.79109261452746*^9}, {
   3.791092713210267*^9, 3.7910927148633204`*^9}, 3.7911812657067966`*^9},
 CellLabel->"In[60]:=",ExpressionUUID->"47584517-9be2-41f7-8002-56a0c4eebc20"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       FormBox["Kparameter2",
        TraditionalForm], ",", "k"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.81523922420564*^9, 3.815239227145929*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"f7578cc8-9b63-4c13-afd8-6d6741b41e88"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"k", "\[Rule]", 
     RowBox[{"K2", " ", "l", " ", "w", " ", 
      SuperscriptBox["\[Epsilon]2", "3"]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900796304917*^9},
 TextAlignment->Center,ExpressionUUID->"200d790c-8562-4739-879b-3f31fa435a1b"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"EquationList2", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"EquationList2", "//.", 
         RowBox[{"{", 
          RowBox[{"Solve", "[", 
           RowBox[{
            FormBox["Kparameter2",
             TraditionalForm], ",", "k"}], "]"}], "}"}]}], ",", 
        "AssumptionOnScaling"}], "]"}], ",", "6"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.791092736072259*^9, 3.791092750548814*^9}, {
   3.8037418764293737`*^9, 3.8037419195621004`*^9}, 3.815239142600484*^9, {
   3.815239237858751*^9, 3.8152392416765485`*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"1ee65923-4215-4006-b7d5-6ac8286ee643"],

Cell["\<\
Using the scaling relation for region 2 and replacing h2\[Rule]l \[Epsilon]2 \
gives\
\>", "Text",
 CellChangeTimes->{{3.815239254652087*^9, 
  3.8152392883136616`*^9}},ExpressionUUID->"30a8f1bd-bf71-43a2-92b3-\
1f8ba609503b"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"h2", "\[Rule]", 
    RowBox[{"\[Epsilon]2", " ", "l"}]}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.8152392480868735`*^9, 3.8152392493261585`*^9}},
 CellLabel->"In[63]:=",ExpressionUUID->"25640066-8433-4386-bc58-678012431c0f"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"h2", "\[Rule]", 
     RowBox[{"l", " ", "\[Epsilon]2"}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007965907507`*^9},
 TextAlignment->Center,ExpressionUUID->"97b469ba-eb8e-4989-a3c5-3d1d85b8e867"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"EquationList2", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"EquationList2", "//.", 
         RowBox[{"h2", "\[Rule]", 
          RowBox[{"\[Epsilon]2", " ", "l"}]}]}], ",", "AssumptionOnScaling"}],
        "]"}], ",", "6"}], "]"}]}], ";"}], TraditionalForm]], "Input",
 CellLabel->"In[64]:=",ExpressionUUID->"0077fcce-05b2-4f00-95c5-68963e6d791f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList2", "]"}]], "Input",
 CellLabel->"In[65]:=",ExpressionUUID->"05da49d3-04a2-4f74-8288-94e01d85faa1"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX2"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY2"}], 
           RowBox[{"\[PartialD]", "Y2"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Epsilon]2", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UX2"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["X", "2"]}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX2"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y2", "2"]}],
           MultilineFunction->None]}], "\[LongEqual]", 
         FractionBox[
          RowBox[{"\[PartialD]", "P2"}], 
          RowBox[{"\[PartialD]", "X"}],
          MultilineFunction->None]}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P2"}], 
          RowBox[{"\[PartialD]", "Y2"}],
          MultilineFunction->None], "\[LongEqual]", 
         RowBox[{
          SuperscriptBox["\[Epsilon]2", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Epsilon]2", "2"], " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UY2"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["X", "2"]}],
              MultilineFunction->None]}], "+", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[PartialD]", "2"], "UY2"}], 
             RowBox[{"\[PartialD]", 
              SuperscriptBox["Y2", "2"]}],
             MultilineFunction->None]}], ")"}]}]}]},
       {
        RowBox[{"UX2", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX2", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY2", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", "P1"}], "+", "UY2"}], 
         "\[LongEqual]", 
         RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", "P2"}]}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P2"}], 
          RowBox[{"\[PartialD]", "0"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"P2", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900796873587*^9},
 TextAlignment->Center,ExpressionUUID->"a337ef2d-b65c-4c93-ad28-0dcf9b6d92d6"]
}, Open  ]],

Cell["\<\
To summarize, the normalized system of equations are given by\
\>", "Text",
 CellChangeTimes->{{3.815237456208654*^9, 
  3.8152374722773914`*^9}},ExpressionUUID->"e3c95c90-50d4-4f18-a9a4-\
02d20b8ff300"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TextbookEq", "[", "EquationList1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"TextbookEq", "[", "EquationList2", "]"}]}], "Input",
 CellChangeTimes->{
  3.815237477937129*^9, {3.815239340597538*^9, 3.8152393408134136`*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"b458403a-5e97-407a-bb54-7649dde513d4"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX1"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY1"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UX1"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["X", "2"]}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX1"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y1", "2"]}],
           MultilineFunction->None]}], "\[LongEqual]", 
         FractionBox[
          RowBox[{"\[PartialD]", "P1"}], 
          RowBox[{"\[PartialD]", "X"}],
          MultilineFunction->None]}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P1"}], 
          RowBox[{"\[PartialD]", "Y1"}],
          MultilineFunction->None], "\[LongEqual]", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "4"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UY1"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["X", "2"]}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UY1"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["Y1", "2"]}],
            MultilineFunction->None]}]}]}]},
       {
        RowBox[{"UX1", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX1", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY1", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"K1", " ", "P1"}], "+", "UY1"}], "\[LongEqual]", 
         RowBox[{"K1", " ", "P2"}]}]},
       {
        RowBox[{"Pin", "\[LongEqual]", "P1"}]},
       {
        RowBox[{"P1", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007970614786`*^9},
 TextAlignment->Center,ExpressionUUID->"51f46910-f03d-4772-9488-bfb1cf09f913"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX2"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY2"}], 
           RowBox[{"\[PartialD]", "Y2"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Epsilon]2", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UX2"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["X", "2"]}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX2"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y2", "2"]}],
           MultilineFunction->None]}], "\[LongEqual]", 
         FractionBox[
          RowBox[{"\[PartialD]", "P2"}], 
          RowBox[{"\[PartialD]", "X"}],
          MultilineFunction->None]}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P2"}], 
          RowBox[{"\[PartialD]", "Y2"}],
          MultilineFunction->None], "\[LongEqual]", 
         RowBox[{
          SuperscriptBox["\[Epsilon]2", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Epsilon]2", "2"], " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UY2"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["X", "2"]}],
              MultilineFunction->None]}], "+", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[PartialD]", "2"], "UY2"}], 
             RowBox[{"\[PartialD]", 
              SuperscriptBox["Y2", "2"]}],
             MultilineFunction->None]}], ")"}]}]}]},
       {
        RowBox[{"UX2", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX2", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY2", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", "P1"}], "+", "UY2"}], 
         "\[LongEqual]", 
         RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", "P2"}]}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P2"}], 
          RowBox[{"\[PartialD]", "0"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"P2", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900797183408*^9},
 TextAlignment->Center,ExpressionUUID->"b331ac63-af40-4870-9ceb-378bf00fe696"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Asymptotic Scheme", "Subsection",
 CellChangeTimes->{{3.7891168263735065`*^9, 3.789116834913035*^9}, {
   3.789447817272208*^9, 3.7894478558935223`*^9}, {3.7894508974687843`*^9, 
   3.7894509051807976`*^9}, {3.7901775451686*^9, 3.7901775456363325`*^9}, {
   3.791171293140665*^9, 3.791171294163178*^9}, {3.791171678822258*^9, 
   3.7911717011653657`*^9}, 3.7911938307481413`*^9, {3.8145312966821547`*^9, 
   3.8145312974258156`*^9}},ExpressionUUID->"bb4e20bd-020e-4381-915a-\
2211d2dfc9b8"],

Cell["\<\
Expanding a regular asymptotic series for velocity and pressure expression \
with regard to the permeability parameter K1, i.e. :
UX1\[Rule](UX10[X,Y1]+K1 UX11[X,Y1]+K1^2 UX12[X,Y1]
UY1\[Rule](UY10[X,Y1]+K1 UY11[X,Y1]+K1^2 UY12[X,Y1]
P1\[Rule](P10[X,Y1]+K1 P11[X,Y1]+K1^2 P12[X,Y1]
P2\[Rule](P20[X,Y2]+K1 P21[X,Y2]+K1^2 P22[X,Y2]\
\>", "Text",
 CellChangeTimes->{{3.8152397517675047`*^9, 3.8152399133791704`*^9}, {
  3.8152399603452406`*^9, 
  3.81523997933573*^9}},ExpressionUUID->"e38586bd-0914-4402-ad26-\
b46d35acd240"],

Cell["and substituting into the governing equations gives", "Text",
 CellChangeTimes->{{3.815239805203029*^9, 3.815239806398339*^9}, {
  3.8152399856400967`*^9, 
  3.8152399875929885`*^9}},ExpressionUUID->"dae63973-c5dd-4fd5-9fac-\
5a14400cded7"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"EquationList1", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"EquationList1", "//.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"UX1", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"UX10", "[", 
             RowBox[{"#1", ",", "#2"}], "]"}], "+", 
            RowBox[{"K1", " ", 
             RowBox[{"UX11", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"K1", "^", "2"}], " ", 
             RowBox[{"UX12", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}]}]}], " ", "&"}], ")"}]}], ",", 
        RowBox[{"UY1", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"UY10", "[", 
             RowBox[{"#1", ",", "#2"}], "]"}], "+", 
            RowBox[{"K1", " ", 
             RowBox[{"UY11", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"K1", "^", "2"}], " ", 
             RowBox[{"UY12", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}]}]}], " ", "&"}], ")"}]}], ",", 
        RowBox[{"P1", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"P10", "[", 
             RowBox[{"#1", ",", "#2"}], "]"}], "+", 
            RowBox[{"K1", " ", 
             RowBox[{"P11", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"K1", "^", "2"}], " ", 
             RowBox[{"P12", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}]}]}], " ", "&"}], ")"}]}], ",", 
        RowBox[{"P2", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"P20", "[", 
             RowBox[{"#1", ",", "#2"}], "]"}], "+", 
            RowBox[{"K1", " ", 
             RowBox[{"P21", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"K1", "^", "2"}], " ", 
             RowBox[{"P22", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}]}]}], " ", "&"}], ")"}]}]}], 
       "}"}]}], "]"}]}], ";"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7891448147002707`*^9, 3.7891448228665676`*^9}, {
   3.7891448704536104`*^9, 3.7891449804155216`*^9}, 3.7891451607088976`*^9, 
   3.7891452028115706`*^9, {3.789145244542981*^9, 3.78914532371476*^9}, {
   3.7900956706026154`*^9, 3.7900957992379084`*^9}, 3.791019531236205*^9, {
   3.791019570469985*^9, 3.79101958390722*^9}, {3.791019619816754*^9, 
   3.79101962234905*^9}, {3.7910930555843163`*^9, 3.791093146295594*^9}, {
   3.791093480007223*^9, 3.7910935549258966`*^9}, {3.791188055693555*^9, 
   3.7911880660857506`*^9}, 3.7911902879911165`*^9, {3.791190656520606*^9, 
   3.7911906755741277`*^9}, 3.815239991234889*^9, {3.8179213360515776`*^9, 
   3.817921336561266*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"17f07bba-4111-400b-9415-b99fe21e7791"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList1", "]"}]], "Input",
 CellLabel->"In[69]:=",ExpressionUUID->"7433ace4-4c3a-41f1-95e0-42fc7724c07c"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX10"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UX11"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["K1", "2"], " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UX12"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY10"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UY11"}], 
            RowBox[{"\[PartialD]", "Y1"}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["K1", "2"], " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UY12"}], 
            RowBox[{"\[PartialD]", "Y1"}],
            MultilineFunction->None]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX10"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y1", "2"]}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UX11"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["Y1", "2"]}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UX10"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["X", "2"]}],
              MultilineFunction->None], "+", 
             RowBox[{"K1", " ", 
              RowBox[{"(", 
               RowBox[{
                FractionBox[
                 RowBox[{
                  SuperscriptBox["\[PartialD]", "2"], "UX11"}], 
                 RowBox[{"\[PartialD]", 
                  SuperscriptBox["X", "2"]}],
                 MultilineFunction->None], "+", 
                RowBox[{"K1", " ", 
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["\[PartialD]", "2"], "UX12"}], 
                  RowBox[{"\[PartialD]", 
                   SuperscriptBox["X", "2"]}],
                  MultilineFunction->None]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["K1", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UX12"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["Y1", "2"]}],
            MultilineFunction->None]}]}], "\[LongEqual]", 
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "P10"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"\[PartialD]", "P11"}], 
              RowBox[{"\[PartialD]", "X"}],
              MultilineFunction->None], "+", 
             RowBox[{"K1", " ", 
              FractionBox[
               RowBox[{"\[PartialD]", "P12"}], 
               RowBox[{"\[PartialD]", "X"}],
               MultilineFunction->None]}]}], ")"}]}]}]}]},
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "P10"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"\[PartialD]", "P11"}], 
              RowBox[{"\[PartialD]", "Y1"}],
              MultilineFunction->None], "+", 
             RowBox[{"K1", " ", 
              FractionBox[
               RowBox[{"\[PartialD]", "P12"}], 
               RowBox[{"\[PartialD]", "Y1"}],
               MultilineFunction->None]}]}], ")"}]}]}], "\[LongEqual]", 
         RowBox[{
          SuperscriptBox["\[Epsilon]1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{
              SuperscriptBox["\[PartialD]", "2"], "UY10"}], 
             RowBox[{"\[PartialD]", 
              SuperscriptBox["Y1", "2"]}],
             MultilineFunction->None], "+", 
            RowBox[{"K1", " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UY11"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["Y1", "2"]}],
              MultilineFunction->None]}], "+", 
            RowBox[{
             SuperscriptBox["\[Epsilon]1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{
                 SuperscriptBox["\[PartialD]", "2"], "UY10"}], 
                RowBox[{"\[PartialD]", 
                 SuperscriptBox["X", "2"]}],
                MultilineFunction->None], "+", 
               RowBox[{"K1", " ", 
                RowBox[{"(", 
                 RowBox[{
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["\[PartialD]", "2"], "UY11"}], 
                   RowBox[{"\[PartialD]", 
                    SuperscriptBox["X", "2"]}],
                   MultilineFunction->None], "+", 
                  RowBox[{"K1", " ", 
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["\[PartialD]", "2"], "UY12"}], 
                    RowBox[{"\[PartialD]", 
                    SuperscriptBox["X", "2"]}],
                    MultilineFunction->None]}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["K1", "2"], " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UY12"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["Y1", "2"]}],
              MultilineFunction->None]}]}], ")"}]}]}]},
       {
        RowBox[{
         RowBox[{"UX10", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"UX11", "+", 
             RowBox[{"K1", " ", "UX12"}]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"UX10", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"UX11", "+", 
             RowBox[{"K1", " ", "UX12"}]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"UY10", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"UY11", "+", 
             RowBox[{"K1", " ", "UY12"}]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"P10", "+", 
             RowBox[{"K1", " ", 
              RowBox[{"(", 
               RowBox[{"P11", "+", 
                RowBox[{"K1", " ", "P12"}]}], ")"}]}]}], ")"}]}], "+", "UY10",
           "+", 
          RowBox[{"K1", " ", "UY11"}], "+", 
          RowBox[{
           SuperscriptBox["K1", "2"], " ", "UY12"}]}], "\[LongEqual]", 
         RowBox[{"K1", " ", 
          RowBox[{"(", 
           RowBox[{"P20", "+", 
            RowBox[{"K1", " ", 
             RowBox[{"(", 
              RowBox[{"P21", "+", 
               RowBox[{"K1", " ", "P22"}]}], ")"}]}]}], ")"}]}]}]},
       {
        RowBox[{"Pin", "\[LongEqual]", 
         RowBox[{"P10", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"P11", "+", 
             RowBox[{"K1", " ", "P12"}]}], ")"}]}]}]}]},
       {
        RowBox[{
         RowBox[{"P10", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"P11", "+", 
             RowBox[{"K1", " ", "P12"}]}], ")"}]}]}], "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900797551196*^9},
 TextAlignment->Center,ExpressionUUID->"d3f255b6-a7db-4c95-97ea-1c89b1d2a5aa"]
}, Open  ]],

Cell["The leading order is given by", "Text",
 CellChangeTimes->{{3.789446954728057*^9, 3.789446955645482*^9}, {
  3.789450696632596*^9, 3.7894507062572412`*^9}, {3.7906994495886283`*^9, 
  3.7906994575099297`*^9}, {3.81524002250984*^9, 
  3.8152400383457108`*^9}},ExpressionUUID->"e3ac506a-d998-4b29-9e47-\
b936d563d738"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EquationList1LeadingOrder", "=", 
   RowBox[{"GetEquationListOrder", "[", 
    RowBox[{"EquationList1", ",", "0", ",", "\[Epsilon]1"}], "]"}]}], ";", 
  RowBox[{"EquationList1LeadingOrder", "=", 
   RowBox[{"GetEquationListOrder", "[", 
    RowBox[{"EquationList1LeadingOrder", ",", "0", ",", "K1"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.789444247495654*^9, {3.7894502422609854`*^9, 3.789450258518073*^9}, {
   3.789450358964265*^9, 3.789450398497295*^9}, {3.7894507283373594`*^9, 
   3.789450785070256*^9}, {3.791019538660824*^9, 3.7910195419680963`*^9}, {
   3.7910196299141746`*^9, 3.7910196336717386`*^9}, {3.7910988569743867`*^9, 
   3.7910988872208514`*^9}, {3.7910996221368213`*^9, 3.791099627673304*^9}, {
   3.7911000689863367`*^9, 3.791100101268182*^9}, {3.791100200401701*^9, 
   3.7911002228036737`*^9}, {3.791101332251273*^9, 3.7911013374375052`*^9}, 
   3.791101369848112*^9, {3.791171722255144*^9, 3.7911717269678073`*^9}, {
   3.791172418497492*^9, 3.791172420189741*^9}, {3.791190333471808*^9, 
   3.7911903367514343`*^9}, 3.8035586590317984`*^9, {3.815240044440145*^9, 
   3.8152400514320965`*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"c7856e43-bc16-4475-a848-9181031a270d"],

Cell[CellGroupData[{

Cell[BoxData["EquationList1LeadingOrder"], "Input",
 CellLabel->"In[71]:=",ExpressionUUID->"b2d785a0-ac2e-46b1-b304-eaded5a27660"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UY10", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["UX10", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UX10", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "-", 
     RowBox[{
      SuperscriptBox["P10", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["P10", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"X", ",", "Y1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX10", "[", 
     RowBox[{"X", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX10", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY10", "[", 
     RowBox[{"X", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY10", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"Pin", "-", 
     RowBox[{"P10", "[", 
      RowBox[{"0", ",", "Y1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"P10", "[", 
     RowBox[{"1", ",", "Y1"}], "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.81814865530413*^9, 3.8182505261734457`*^9, 
  3.818523527563468*^9, 3.8185236832288303`*^9, 3.818524185900059*^9, 
  3.818730739385973*^9, 3.8187630771412077`*^9, 3.8188345337006354`*^9, 
  3.8188433466769247`*^9, 3.8189050495709724`*^9, 3.8192998069760895`*^9, 
  3.8405169645845985`*^9, 3.8405214060996337`*^9, 3.840525979130382*^9, 
  3.8405564104998713`*^9, 3.840556611276226*^9, 3.841070362835232*^9, 
  3.841072391800934*^9, 3.8410724256255627`*^9, 3.8419006695497637`*^9, 
  3.8419007977151012`*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"afeb99b1-aa05-41ca-9ab7-82d31aefa58e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList1LeadingOrder", "]"}]], "Input",
 CellChangeTimes->{3.8152400550276694`*^9},
 CellLabel->"In[72]:=",ExpressionUUID->"06130d8c-8662-4083-850a-1863209dfa93"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX10"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY10"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[PartialD]", "P10"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX10"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y1", "2"]}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P10"}], 
          RowBox[{"\[PartialD]", "Y1"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX10", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX10", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY10", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY10", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"Pin", "-", "P10"}], "\[LongEqual]", "0"}]},
       {
        RowBox[{"P10", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900797816044*^9},
 TextAlignment->Center,ExpressionUUID->"274936a5-3e85-4959-9ae5-bf298a563e48"]
}, Open  ]],

Cell["\<\
Similarly for region 2:
UX2\[Rule](UX20[X,Y2]+K1 UX21[X,Y2]+K1^2 UX22[X,Y2] 
UY2\[Rule](UY20[X,Y2] +K1 UY21[X,Y2] +K1^2 UY22[X,Y2] 
P2\[Rule](P20[X,Y2] +K1 P21[X,Y2] +K1^2 P22[X,Y2] \
\>", "Text",
 CellChangeTimes->{{3.791101919823447*^9, 3.791101923562196*^9}, {
  3.815240073798296*^9, 
  3.815240126100143*^9}},ExpressionUUID->"2652e43c-10aa-4552-bb59-\
e3988851d90a"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"EquationList2", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"EquationList2", "//.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"UX2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"UX20", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}], "+", 
             RowBox[{"K1", " ", 
              RowBox[{"UX21", "[", 
               RowBox[{"#1", ",", "#2"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"K1", "^", "2"}], " ", 
              RowBox[{"UX22", "[", 
               RowBox[{"#1", ",", "#2"}], "]"}]}]}], " ", "&"}], ")"}]}], ",", 
         RowBox[{"UY2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"UY20", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}], "+", 
             RowBox[{"K1", " ", 
              RowBox[{"UY21", "[", 
               RowBox[{"#1", ",", "#2"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"K1", "^", "2"}], " ", 
              RowBox[{"UY22", "[", 
               RowBox[{"#1", ",", "#2"}], "]"}]}]}], " ", "&"}], ")"}]}], ",", 
         RowBox[{"P2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"P20", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}], "+", 
             RowBox[{"K1", " ", 
              RowBox[{"P21", "[", 
               RowBox[{"#1", ",", "#2"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"K1", "^", "2"}], " ", 
              RowBox[{"P22", "[", 
               RowBox[{"#1", ",", "#2"}], "]"}]}]}], " ", "&"}], ")"}]}]}], 
        "}"}]}], ",", "AssumptionOnScaling"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.791182312521583*^9, 3.7911823514030485`*^9}, {
   3.7911828892424507`*^9, 3.791182891800645*^9}, {3.791183175051201*^9, 
   3.7911831798826303`*^9}, 3.81524006274267*^9},
 CellLabel->"In[73]:=",ExpressionUUID->"3d019723-8623-48a1-8209-b16f3fe3515b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList2", "]"}]], "Input",
 CellChangeTimes->{
  3.815240139972126*^9, {3.818149113794957*^9, 3.8181491210607634`*^9}, {
   3.8181553549217644`*^9, 3.8181553848810587`*^9}},
 CellLabel->"In[74]:=",ExpressionUUID->"1b7ba417-e87e-4eff-90b4-0b8c7a63f2c7"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX20"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UX21"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["K1", "2"], " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UX22"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY20"}], 
           RowBox[{"\[PartialD]", "Y2"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UY21"}], 
            RowBox[{"\[PartialD]", "Y2"}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["K1", "2"], " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UY22"}], 
            RowBox[{"\[PartialD]", "Y2"}],
            MultilineFunction->None]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX20"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y2", "2"]}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UX21"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["Y2", "2"]}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UX20"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["X", "2"]}],
              MultilineFunction->None], "+", 
             RowBox[{"K1", " ", 
              RowBox[{"(", 
               RowBox[{
                FractionBox[
                 RowBox[{
                  SuperscriptBox["\[PartialD]", "2"], "UX21"}], 
                 RowBox[{"\[PartialD]", 
                  SuperscriptBox["X", "2"]}],
                 MultilineFunction->None], "+", 
                RowBox[{"K1", " ", 
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["\[PartialD]", "2"], "UX22"}], 
                  RowBox[{"\[PartialD]", 
                   SuperscriptBox["X", "2"]}],
                  MultilineFunction->None]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["K1", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UX22"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["Y2", "2"]}],
            MultilineFunction->None]}]}], "\[LongEqual]", 
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "P20"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"\[PartialD]", "P21"}], 
              RowBox[{"\[PartialD]", "X"}],
              MultilineFunction->None], "+", 
             RowBox[{"K1", " ", 
              FractionBox[
               RowBox[{"\[PartialD]", "P22"}], 
               RowBox[{"\[PartialD]", "X"}],
               MultilineFunction->None]}]}], ")"}]}]}]}]},
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "P20"}], 
           RowBox[{"\[PartialD]", "Y2"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"\[PartialD]", "P21"}], 
              RowBox[{"\[PartialD]", "Y2"}],
              MultilineFunction->None], "+", 
             RowBox[{"K1", " ", 
              FractionBox[
               RowBox[{"\[PartialD]", "P22"}], 
               RowBox[{"\[PartialD]", "Y2"}],
               MultilineFunction->None]}]}], ")"}]}]}], "\[LongEqual]", 
         RowBox[{
          SuperscriptBox["\[Epsilon]2", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{
              SuperscriptBox["\[PartialD]", "2"], "UY20"}], 
             RowBox[{"\[PartialD]", 
              SuperscriptBox["Y2", "2"]}],
             MultilineFunction->None], "+", 
            RowBox[{"K1", " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UY21"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["Y2", "2"]}],
              MultilineFunction->None]}], "+", 
            RowBox[{
             SuperscriptBox["\[Epsilon]2", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{
                 SuperscriptBox["\[PartialD]", "2"], "UY20"}], 
                RowBox[{"\[PartialD]", 
                 SuperscriptBox["X", "2"]}],
                MultilineFunction->None], "+", 
               RowBox[{"K1", " ", 
                RowBox[{"(", 
                 RowBox[{
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["\[PartialD]", "2"], "UY21"}], 
                   RowBox[{"\[PartialD]", 
                    SuperscriptBox["X", "2"]}],
                   MultilineFunction->None], "+", 
                  RowBox[{"K1", " ", 
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["\[PartialD]", "2"], "UY22"}], 
                    RowBox[{"\[PartialD]", 
                    SuperscriptBox["X", "2"]}],
                    MultilineFunction->None]}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["K1", "2"], " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UY22"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["Y2", "2"]}],
              MultilineFunction->None]}]}], ")"}]}]}]},
       {
        RowBox[{
         RowBox[{"UX20", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"UX21", "+", 
             RowBox[{"K1", " ", "UX22"}]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"UX20", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"UX21", "+", 
             RowBox[{"K1", " ", "UX22"}]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"UY20", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"UY21", "+", 
             RowBox[{"K1", " ", "UY22"}]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", "P1"}], "+", "UY20", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"UY21", "+", 
             RowBox[{"K1", " ", "UY22"}]}], ")"}]}]}], "\[LongEqual]", 
         RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{"P20", "+", 
            RowBox[{"K1", " ", 
             RowBox[{"(", 
              RowBox[{"P21", "+", 
               RowBox[{"K1", " ", "P22"}]}], ")"}]}]}], ")"}]}]}]},
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "P20"}], 
           RowBox[{"\[PartialD]", "0"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"\[PartialD]", "P21"}], 
              RowBox[{"\[PartialD]", "0"}],
              MultilineFunction->None], "+", 
             RowBox[{"K1", " ", 
              FractionBox[
               RowBox[{"\[PartialD]", "P22"}], 
               RowBox[{"\[PartialD]", "0"}],
               MultilineFunction->None]}]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"P20", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"P21", "+", 
             RowBox[{"K1", " ", "P22"}]}], ")"}]}]}], "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900798251792*^9},
 TextAlignment->Center,ExpressionUUID->"9c633b11-e59f-41f3-9f69-9d51c2506e8e"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Note",
  FontVariations->{"Underline"->True},
  Background->GrayLevel[0.85]],
 StyleBox[": GetEquationListOrder[EquationList2,1,\[Epsilon]2] gives the \
multiplier in EquationList2 of term having \[Epsilon]2 of the 1st order.",
  Background->GrayLevel[0.85]]
}], "Text",
 CellChangeTimes->{{3.803461758640258*^9, 3.8034617990340376`*^9}, {
  3.8034618798025265`*^9, 
  3.803461906641079*^9}},ExpressionUUID->"ef692396-d5cd-430f-bb9c-\
cdc751befad6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EquationList2LeadingOrder", "=", 
   RowBox[{"GetEquationListOrder", "[", 
    RowBox[{"EquationList2", ",", "1", ",", "\[Epsilon]2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.803402819854469*^9, 3.803402849631325*^9}},
 CellLabel->"In[75]:=",ExpressionUUID->"9e2148c3-f5e1-45f7-bac8-da727ff96d1a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EquationList2LeadingOrder", "=", 
   RowBox[{"GetEquationListOrder", "[", 
    RowBox[{"EquationList2", ",", "2", ",", "\[Epsilon]2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.803402870654228*^9, 3.8034028729808855`*^9}, {
  3.8034030611811457`*^9, 3.8034030795726624`*^9}, {3.8034031217004166`*^9, 
  3.803403130395434*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"3f5913d9-251f-49c9-99ec-a9023552eb3d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EquationList2LeadingOrder", "=", 
   RowBox[{"GetEquationListOrder", "[", 
    RowBox[{"EquationList2", ",", "0", ",", "\[Epsilon]2"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EquationList2LeadingOrder", "=", 
   RowBox[{"GetEquationListOrder", "[", 
    RowBox[{"EquationList2LeadingOrder", ",", "0", ",", "K1"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7911019765617323`*^9, 3.7911019978262105`*^9}, 
   3.7911823743786583`*^9, {3.791182823878044*^9, 3.7911828452528267`*^9}, {
   3.7911831338510113`*^9, 3.7911831359868565`*^9}, {3.7911832086580725`*^9, 
   3.791183223134178*^9}, {3.7911904478763037`*^9, 3.791190451458236*^9}, 
   3.8152402755559597`*^9},
 CellLabel->"In[77]:=",ExpressionUUID->"fef299ca-2d76-42a6-ad27-5a1d354c3b28"],

Cell["The leading order of region 2 is given by", "Text",
 CellChangeTimes->{{3.815240283163577*^9, 
  3.8152402876500063`*^9}},ExpressionUUID->"0bc4dc38-de76-4a0a-8ed2-\
b4c4ace4f69b"],

Cell[CellGroupData[{

Cell[BoxData["EquationList2LeadingOrder"], "Input",
 CellLabel->"In[79]:=",ExpressionUUID->"28dac6cd-12b6-4f8d-800d-f9a43c5717a1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UY20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["UX20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UX20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}], "-", 
     RowBox[{
      SuperscriptBox["P20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["P20", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"X", ",", "Y2"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX20", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX20", "[", 
     RowBox[{"X", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"a1", " ", "X"}], "-", 
       RowBox[{"a2", " ", 
        SuperscriptBox["X", "2"]}], "-", 
       RowBox[{"a3", " ", 
        SuperscriptBox["X", "3"]}]}]}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY20", "[", 
     RowBox[{"X", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"a1", " ", "X"}], "-", 
       RowBox[{"a2", " ", 
        SuperscriptBox["X", "2"]}], "-", 
       RowBox[{"a3", " ", 
        SuperscriptBox["X", "3"]}]}]}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
      RowBox[{"P1", "[", 
       RowBox[{"X", ",", "0"}], "]"}]}], "-", 
     RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
      RowBox[{"P20", "[", 
       RowBox[{"X", ",", "0"}], "]"}]}], "+", 
     RowBox[{"UY20", "[", 
      RowBox[{"X", ",", "0"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["P20", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"0", ",", "Y2"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"P20", "[", 
     RowBox[{"1", ",", "Y2"}], "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.818148647521643*^9, 3.818250526525244*^9, 
  3.818523527849284*^9, 3.8185236836385946`*^9, 3.8185241862417326`*^9, 
  3.818730739688799*^9, 3.818763077631922*^9, 3.8188345340684032`*^9, 
  3.8188433470876865`*^9, 3.8189050500370445`*^9, 3.819299807488282*^9, 
  3.840516965054837*^9, 3.84052140664542*^9, 3.8405259795421457`*^9, 
  3.84055641098419*^9, 3.8405566116980734`*^9, 3.8410703635147953`*^9, 
  3.8410723923009005`*^9, 3.8410724264254017`*^9, 3.841900670262353*^9, 
  3.84190079861758*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"ff8bb090-320a-49cb-8876-c2ae1211d0c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList2LeadingOrder", "]"}]], "Input",
 CellChangeTimes->{3.815240294734923*^9},
 CellLabel->"In[80]:=",ExpressionUUID->"2881d241-6546-4299-a8ec-3da66c209a66"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX20"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY20"}], 
           RowBox[{"\[PartialD]", "Y2"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[PartialD]", "P20"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX20"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y2", "2"]}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P20"}], 
          RowBox[{"\[PartialD]", "Y2"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX20", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX20", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY20", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", "P1"}], "-", 
          RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", "P20"}], "+", "UY20"}], 
         "\[LongEqual]", "0"}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P20"}], 
          RowBox[{"\[PartialD]", "0"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"P20", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419007987285166`*^9},
 TextAlignment->Center,ExpressionUUID->"0967c961-b72a-49b8-9804-98662004ec0a"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Solving the leading order of region 1", "Section",
 CellChangeTimes->{{3.789453018454837*^9, 3.7894530392871237`*^9}, {
   3.7901773265714464`*^9, 3.7901773453322277`*^9}, {3.7901775486648755`*^9, 
   3.7901775489051976`*^9}, {3.7911713018688803`*^9, 
   3.7911713021395645`*^9}, {3.791172436972288*^9, 3.7911724401547766`*^9}, {
   3.7911817122635975`*^9, 3.791181712982674*^9}, {3.803482623167575*^9, 
   3.803482624092075*^9}, 3.8410686186350217`*^9, {3.8410721771121716`*^9, 
   3.8410721773777943`*^9}},ExpressionUUID->"84d588b2-01dd-4452-9a47-\
59c0848e04fc"],

Cell["The leading order for region 1 is given by:", "Text",
 CellChangeTimes->{{3.8145281144072933`*^9, 3.814528120897705*^9}, 
   3.8153067705904007`*^9},ExpressionUUID->"8ce6210a-5fa1-478e-a27c-\
2eba3c3c5cdb"],

Cell[CellGroupData[{

Cell[BoxData["EquationList1LeadingOrder"], "Input",
 CellChangeTimes->{3.8035585582560854`*^9},
 CellLabel->"In[81]:=",ExpressionUUID->"4fac735b-cac9-4266-b61f-5a105b063869"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UY10", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["UX10", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UX10", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "-", 
     RowBox[{
      SuperscriptBox["P10", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["P10", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"X", ",", "Y1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX10", "[", 
     RowBox[{"X", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX10", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY10", "[", 
     RowBox[{"X", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY10", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"Pin", "-", 
     RowBox[{"P10", "[", 
      RowBox[{"0", ",", "Y1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"P10", "[", 
     RowBox[{"1", ",", "Y1"}], "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0WtIE2AYhuGt1KKTuajULLWMkgRHljOL8NPSmEtwweYhN5PczEWabjKb
CoYZlc6awpbukKTrqBLK8LApWJkpqaRZbZqHqMxepEYE5rTe78fD9fvhDszI
4WcyGQxGMm61rU5mEQARO7LVVE07q5F6sM2b8w3tVfQPUQca7amLaBSrT0K1
yHVV1AHV0R1LqNtMZrynEMhha8EANXLL8idqQsTERjX6lq1LqEInhnaJqJZI
rpQa7VNaYUbtrdskFpRvm7jaga49GTxPbbtd2tWJNoub5sRJQBj+eYVpyUB0
HaPj61OAWFXHHFSJ0hCWlApkOS5guvYsEJ9biVo9Gishdups99QrA5qRLqwz
onNOQacJre4bybWh1osiRzf60DD8R5cGRG8ScSczgXT8XPRYQeVFMSzqccVd
L3cJEPbehQRqurKM6YH6Vr/o8UJFrkqHEJ0N4qxiS4FwP/sWnEaZ7xdKhGhX
itlUnAXE5Rx9TQV/baXqApCXeoOeOqzWOMvRlX8htuto+p3W+x7Z2CFszqVC
e4r5Mj3qJnj65gEaudOhbUa541MZLegG87Mb1HJm1aZe9EQqPBHIgKxjeRlM
aGJ+yI96dOF7W2ADqglt+hJ0CQhvPridlwOkIMr1i5MLZPrAZZ0mD8jItZnd
1ejXmrE9VjSAs5JL8oG8u1lYRr13Lv451c+hNJrRK4PtWRZ0O/TxPqKPCqW1
k2hZaGzXEvp3/rfKKgfiDOfmHDIA2b/Prg1HTw0qRiPQipLzLXGofLyon8p3
z3scbcQ/Is/6GLTf70wjdeuRhs0fTEC8x9YEUP8DILp2ng==
  "],
 CellLabel->"Out[81]=",ExpressionUUID->"1adee59c-8839-491a-b4d0-8962e190c7ff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList1LeadingOrder", "]"}]], "Input",
 CellChangeTimes->{{3.8181654379962993`*^9, 3.8181654388098297`*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"f3794549-0188-44a5-afda-0b7219fbaddc"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX10"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY10"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[PartialD]", "P10"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX10"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y1", "2"]}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P10"}], 
          RowBox[{"\[PartialD]", "Y1"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX10", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX10", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY10", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY10", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"Pin", "-", "P10"}], "\[LongEqual]", "0"}]},
       {
        RowBox[{"P10", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900800489498*^9},
 TextAlignment->Center,ExpressionUUID->"3f4309a5-a953-468d-a742-2cf9d966509d"]
}, Open  ]],

Cell["Momentum in the Y direction gives", "Text",
 CellChangeTimes->{{3.7894701233752136`*^9, 3.7894701302389164`*^9}, {
  3.7900556780863547`*^9, 3.790055678901177*^9}, {3.7901773542536745`*^9, 
  3.7901773699846573`*^9}, {3.791103141119598*^9, 
  3.7911031523833413`*^9}},ExpressionUUID->"079c44b5-5a52-4062-9090-\
cafc8f2f7f21"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EquationList1LeadingOrder", "[", 
  RowBox[{"[", "3", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.790012069636074*^9, 3.790012071609027*^9}, {
  3.7900556882122326`*^9, 3.7900556943067355`*^9}, {3.791103160317979*^9, 
  3.7911031738214774`*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"10278591-8261-4868-ae0d-57a3e38a7512"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["P10", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0n0sFHAYB/BT67a8VehlseSlzZS0ZZhM/bTWDSHVeTnvG84RV25NDlNE
eblLrdR5OTdvpXS2YvJepFNR7TC5F6wXb78aJht31PP88eyz56/n+zx7bGJT
g+IMGAxGGtQm65B68iIlQVL1FPry9YNfKHtQ/RetSjMvnwJvi2c3UCuZ2fbe
S5SMh9dx0Plhp2Q0P6qIj1rslQTMgOzKEdEs2G7vvh7PpmTLkOdNLujlaDyQ
CDbHRCnvgorPT76Vgsa5ggWUn1fDuAcKtFSEOr85MYKW/JlToYa5SpP7IMsy
KALt89x6A70XkT6MZoyuebeC1Rlfk1CVw2URqt2wqEM9Uva7zYDeHoPDKNde
w1kDU58q4tFDsY/FKO+Kp6UO8xUl+O4IpqSOmfEBjY76p0U/6tUmIjD9n9Zf
DGYWWUeiikmfBFQ9nFdcD4ZkJsW3gnkszc3XoNL/yDxq7Jjb0Q4uDMlno0Io
eS4QXI8IpSR3ZWzMKIySW6ZEhfZKqo+HcCgJZNlOScIp2Wp0oawCXJWdnkAn
uqffV4KBZqHlVdgvh7ZLQY+jY/wu8FVytKob5PV/WX0UQYmTMtpHE0eJfFHH
3ASL9GfMUE+hZNe2eErCTi75o7yYAgMmyDBX9OwCe8zEqmBwqtZty7EE2CfT
6to5UM9ezA4G8/kN0iwu9LWjg+iEtaREmAjzrWQVaA774XI+uCfHuasADCtt
qWHyKJlcn9cLwR9ZF5IqwJ7ppqEGULVPU/YCFL2bjpWDp4xb7qAHtGLTtyCL
8/sZOwn+TWdeKQX99U4LMtBrpsOmFnTuaP5pn0KJ7erhNr9USlYMN5fc+JCH
M2d7/yol/T7jdp1guIPBFZIGd96fnYfqmAF9qLpQWFUPfv/SxW0FC30/+X0D
7djJEg3oI/ft0IFtduvCTgElQ67nU10qYb+GyTJX0LYtQ+kOupTz5GfBcPYN
BTpgIGz0rqKkONJCdhpstAqtQzs3mnaOS+Eeq7sPov8BGsLpdA==
  "],
 CellLabel->"Out[83]=",ExpressionUUID->"8af7d750-4fe2-4fed-93e8-2573e935a173"]
}, Open  ]],

Cell["\<\
we thus see that P10 is not a function of Y1, only X, and thus\
\>", "Text",
 CellChangeTimes->{{3.7900556996719666`*^9, 3.790055724113824*^9}, {
  3.7911031784675937`*^9, 3.7911031873150883`*^9}, {3.8152403719713736`*^9, 
  3.8152403740581884`*^9}},ExpressionUUID->"76671568-6484-4424-a8ad-\
13357343eb15"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList1LeadingOrder", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"EquationList1LeadingOrder", "//.", 
     RowBox[{"{", 
      RowBox[{"P10", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"G10", "[", "#1", "]"}], " ", "&"}], ")"}]}], "}"}]}], 
    "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7894701450985317`*^9, 3.7894701489668627`*^9}, 
   3.7894701838457813`*^9, {3.7894702166031375`*^9, 3.7894702364053183`*^9}, {
   3.789470542467842*^9, 3.789470546312563*^9}, {3.7900138687409487`*^9, 
   3.7900138773806005`*^9}, {3.7900172849666862`*^9, 3.790017295488431*^9}, {
   3.790017331820891*^9, 3.7900173358427134`*^9}, {3.790055784311367*^9, 
   3.7900558575948343`*^9}, {3.7900559443803797`*^9, 
   3.7900559741448545`*^9}, {3.7900560213777304`*^9, 3.790056066259585*^9}, {
   3.79005627911252*^9, 3.790056281682166*^9}, {3.790096278047047*^9, 
   3.7900962957908754`*^9}, {3.7901799439957743`*^9, 3.790179961629985*^9}, 
   3.7901803290836124`*^9, {3.791103193493278*^9, 3.791103213575675*^9}, {
   3.79117245003325*^9, 3.791172450392829*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"c91c492a-89d4-4582-b229-09f29b8b1f8c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UY10", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["UX10", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["G10", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}], "\[Equal]", 
    RowBox[{
     SuperscriptBox["UX10", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"X", ",", "Y1"}], "]"}]}], ",", "True", ",", 
   RowBox[{
    RowBox[{"UX10", "[", 
     RowBox[{"X", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX10", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY10", "[", 
     RowBox[{"X", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY10", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{"Pin", "\[Equal]", 
    RowBox[{"G10", "[", "0", "]"}]}], ",", 
   RowBox[{
    RowBox[{"G10", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0nssFHAcAPBj8kherZRVi1xba2usDDXZfliEJO+3XHMe53FheWdMVBOH
FZ1zF3nkKuIPhDtKUxib2A3nWUT8NLs8Joe+3z++++z73X6//b7f39eEFe8R
rsJgMLgQlu85U7NelAgrLeZRqWnvL9R1aX4TzTgIq5gDW7ghWj3elPQ5LXBR
oYbSewns8nAqWgbHZ67+Y/tQwufb5kSCTD2dviiw+dPdUR54WdIwUQyet09e
RXXTahgloMPUWiFa02gzhhZsrMjRIJsxnVKwXdMzGL2hopaNLhilDqMC5oFd
K6hn4RCDvrgdV4gauhvWoheMT1stgW4nBobR7LDZwB2s+w+y0fVQfhE6mH/9
1C644xHloudLCUclcwBl7DBm0ZT+aZ1C0LJhzq0IrIs2DkENBS4RqL5ZXkEd
2Fdey24Ff8incz6CGWKzFXR4NLezA9TUblkO9aNE41hyarA/JUrHSZl2ACXu
Jx3k6P6j6it+gZSsODLn+EGUbB32LhOAU1VOk+iQ7cLXSlC5EFAhxDwhqEME
Jp6d4ErAd5Qll4I+f0e2yoMpcQpkOU+HU1LN3VffB1lKx6OoTXaFwSE2zDNt
ww1Ncn6qog6ulwx2G4BiwpP7gmq11qrmETCHL2ce3AIVMsVDX1CL90aUGQnv
rZf1o99FgmfpUbA3yioBmuTzUpEHLmeZS/JB1+K21+rRlLxKX1Omg9t7XhwB
aMNpGqoHmfKZskaw58NPVhOo6Gx7goaIebqfwWvyP299OJSES45XikC6bbZa
BcaoSk1qwBFp8yIzjpK8kEvtrvFwjy5DYcWlJPbx6rnSBPhvOmHaBR5JUb1P
EmFvNrNyUbXYO71o7mSGsA6sTuuObAVlvGHXCbDkZhx/GrQ1c+vcBQl7L70r
Cfpq9Yy3qITz9fNllqB4KmPUGrxYEdPkCPrJcr6hvTqZYjshJfdmDKvsweeC
4Fq0L6pZf1xEye9FI2P0Pw0T3Dw=
  "],
 CellLabel->"Out[84]=",ExpressionUUID->"1dd532fe-61c3-45f7-97b7-6dabf4efeb7e"]
}, Open  ]],

Cell["We now solve the X momentum conservation equation, given by", "Text",
 CellChangeTimes->{{3.790097708845484*^9, 3.790097710431308*^9}, {
   3.790227493059335*^9, 3.790227494898937*^9}, 
   3.791174151413954*^9},ExpressionUUID->"6fd881af-0b02-4aed-b3fb-\
3795fdeea9fa"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList1LeadingOrder", "[", 
   RowBox[{"[", "2", "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.790178532164506*^9, 3.790178546112544*^9}, {
  3.7901801224389467`*^9, 3.790180128965833*^9}, {3.7911035018845186`*^9, 
  3.7911035035854087`*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"fa72849e-9775-4e61-950c-f6129b46dc87"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["G10", "\[Prime]",
    MultilineFunction->None], "[", "X", "]"}], "\[Equal]", 
  RowBox[{
   SuperscriptBox["UX10", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "2"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"X", ",", "Y1"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.802595045779521*^9, 3.802595084109269*^9}, 
   3.80259512902042*^9, 3.802595247082472*^9, {3.802596573179217*^9, 
   3.8025965748282704`*^9}, 3.803054158779054*^9, 3.8030549850707684`*^9, 
   3.803134641127211*^9, 3.803137160245574*^9, 3.803396049834436*^9, 
   3.803399185980357*^9, 3.8034017764311023`*^9, 3.8034817550643682`*^9, 
   3.8034838533313303`*^9, 3.803483995751932*^9, 3.8034841651641183`*^9, 
   3.8034853034621205`*^9, 3.8034858579242997`*^9, 3.8034859193697457`*^9, 
   3.80348631865139*^9, 3.803486954625599*^9, 3.803487240144143*^9, 
   3.803487859805398*^9, 3.8035584239972057`*^9, 3.8035587561481943`*^9, 
   3.8035590274791975`*^9, 3.8035592087258406`*^9, 3.8036586809339004`*^9, 
   3.8036598943403316`*^9, 3.803695839160549*^9, 3.8036959264385853`*^9, 
   3.8036962528521957`*^9, 3.803699417953806*^9, 3.8037407633413982`*^9, 
   3.8037417799986267`*^9, 3.803741944091322*^9, 3.8040003669530635`*^9, 
   3.804002935038646*^9, 3.8040030570372515`*^9, 3.8040031303847923`*^9, 
   3.8040505322451963`*^9, 3.804088644008869*^9, 3.8040893669490824`*^9, 
   3.804090193589503*^9, 3.804091868213818*^9, 3.8044301496308064`*^9, 
   3.804949451789136*^9, 3.8053065509322243`*^9, 3.8053065862249174`*^9, 
   3.805987229137803*^9, 3.806648065165045*^9, 3.80665157870446*^9, 
   3.8066521143478765`*^9, 3.806654015210785*^9, 3.8066557068964205`*^9, 
   3.8066580029827576`*^9, 3.8067188548560486`*^9, 3.806721755153883*^9, 
   3.8071684385979476`*^9, 3.811502675110585*^9, 3.8115697200449924`*^9, 
   3.8115698102964287`*^9, 3.8115841408905077`*^9, 3.811584631737881*^9, 
   3.8115860604305253`*^9, 3.8116101104554296`*^9, 3.811753692537999*^9, 
   3.8121963698170147`*^9, 3.8122566889711704`*^9, 3.8122772396043606`*^9, 
   3.8128796133220773`*^9, 3.812879950751217*^9, 3.813399660972626*^9, 
   3.8133997811402197`*^9, 3.8134229968855467`*^9, 3.8134246175624876`*^9, 
   3.81368450978336*^9, 3.813924839512788*^9, 3.8139912586715927`*^9, 
   3.814014573532331*^9, 3.814028479037208*^9, 3.8140301031652966`*^9, 
   3.8140304138455715`*^9, 3.814068340541741*^9, 3.814372703511133*^9, 
   3.8145220887273397`*^9, 3.814526809561977*^9, 3.81453134198866*^9, 
   3.8158436295955353`*^9, 3.816449473467741*^9, 3.816931216057769*^9, 
   3.8181665514313636`*^9, 3.8182505268590536`*^9, 3.8185235281171317`*^9, 
   3.818523684054699*^9, 3.81852418659553*^9, 3.8187307399356546`*^9, 
   3.8187630780596743`*^9, 3.8188345345141582`*^9, 3.818843347513442*^9, 
   3.8189050505057573`*^9, 3.8192998079793987`*^9, 3.840516986678554*^9, 
   3.8405214071141357`*^9, 3.8405259799669*^9, 3.840556411456436*^9, 
   3.8405566121511593`*^9, 3.8410704199628983`*^9, 3.8410723928063087`*^9, 
   3.841072427019107*^9, 3.841900677681083*^9, 3.8419008008832707`*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"4b9ef22c-f739-4df1-b20c-850b9d98fb03"]
}, Open  ]],

Cell["\<\
The solution for Ux along with the no-slip boundary condition is\
\>", "Text",
 CellChangeTimes->{{3.7901845160615387`*^9, 3.7901845337595663`*^9}, {
  3.814528503423097*^9, 
  3.8145285197812004`*^9}},ExpressionUUID->"8cd62ae8-a8f9-459d-b6fe-\
063513ccd953"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"UX10Func", "[", 
    RowBox[{"X_", ",", "Y1_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"EquationList1LeadingOrder", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{"EquationList1LeadingOrder", "[", 
          RowBox[{"[", "4", "]"}], "]"}], ",", 
         RowBox[{"EquationList1LeadingOrder", "[", 
          RowBox[{"[", "5", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"UX10", "[", 
        RowBox[{"X", ",", "Y1"}], "]"}], ",", 
       RowBox[{"{", "Y1", "}"}]}], "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.790097828472739*^9, 3.7900978824815903`*^9}, {
   3.7900990252955146`*^9, 3.7900990256641006`*^9}, {3.7900991077519226`*^9, 
   3.7900991539680495`*^9}, {3.790099614657666*^9, 3.790099617252245*^9}, {
   3.790183940717039*^9, 3.7901840454273524`*^9}, 3.7901845384438567`*^9, {
   3.7901851115955524`*^9, 3.7901851154436474`*^9}, 3.790239686648344*^9, {
   3.7911035152287345`*^9, 3.7911035555712748`*^9}, {3.791103589895382*^9, 
   3.79110362027931*^9}, {3.791174669166896*^9, 3.791174672123004*^9}, 
   3.813990144641215*^9},
 CellLabel->"In[86]:=",ExpressionUUID->"0b194382-db4d-4174-8e4d-fd85717b99c7"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "Y1"}], " ", 
     RowBox[{
      SuperscriptBox["G10", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["Y1", "2"], " ", 
     RowBox[{
      SuperscriptBox["G10", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVzn0s1HEcB3DsaOUhetga1jwV/VFpGla69WVpCX/YOS5Pm+ach3XnmGkO
kVHydIh2nN8Up9H4w0MeQw+ewgy74efhYh7Kd4m6azm1Pp8/3ntt7z8+n7d9
tDgoxtDAwCAR8oz7e2mVR8nRtC0tGt7zxW4wmJLqEMdkVO0skG+DU7obB0I+
Jc8vkBwRyBuzGI4DN/Uxs6XgWknzghzMX0rbQXmnVQZl4G7LbjEaHcqdQz/O
UBY9W6A2Lwc/rQZHoFFck2y0eD99Ck25aOrTCc7PDiWi39mkYnQ60boB/Vzk
4LEF6hMnplAzhob9Abmvp4VoxhFlCRrP3rTRgwfV4rvHQ+AeP28cDZIYr6Ja
wzXzYpDjuh5YAo62Okai0uuBseix8YJCFShLqXfpBt9saHLQihz3b6hP05Pe
HlDh1L0dFUpJh1nmwwgBJWKvdbXpPUrc1+6w6KZS5RYaRsnCiLNGEU6JpkBQ
VQNOLAYsom+5X0eUYGVcZHUtWCsV9jBgl2xV0g8WUhH7DlxxVOteRMCuwVi/
5RhK8iScI/9A/qHfCXTOmLEyFlLiZa8PRNuvlRqagMNlcwNWoEVAJRsC7tV7
GbnGUtKns0sNADVqbWYIKPNtYTJElNA1dgztYOqK0uMoYWSNNWgkn9nPAxez
3PrzQU957yuTeEqW/v48TAfrMwQJNeClhbbJRuxPrle1gMKSrehWcPz8wFPU
1rLC4j14itU28xMoaZZbKxlQt+m2UwcqREP29aB3YeeG0wNKVK1XuvzF8Fdj
vO8hoeTc5J5DuZQSB86KYx/4o5+TRJIpyW17nItqpnkf0JeKrFoV+Kt9WNQJ
Zoln/BdAgUCqWAZdLgf16kFpg5GsLwX2uYeKryop2VdtVLmDqfTRrCd4plrS
ehvk8vNH0TTf7CbvWkrcJm3qfECZ7f0GVHWrx3KeoaRAYG+H/gem1s+4
  "],
 CellLabel->"Out[86]=",ExpressionUUID->"b2df21db-52a4-4441-a02d-7f26b9921605"]
}, Open  ]],

Cell["\<\
Substituting the solution for Ux into the leading order equations\
\>", "Text",
 CellChangeTimes->{{3.7902382573230495`*^9, 3.790238280219982*^9}, {
  3.790241470949983*^9, 3.7902414909630194`*^9}, {3.7902453157466516`*^9, 
  3.7902453340846643`*^9}, {3.81452852710198*^9, 3.814528535312138*^9}, {
  3.8145286343009157`*^9, 
  3.8145286345518875`*^9}},ExpressionUUID->"957c1881-02b6-45ac-a667-\
7a2130a35235"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList1LeadingOrder", "=", 
   RowBox[{"EquationList1LeadingOrder", "/.", 
    RowBox[{"{", 
     RowBox[{"UX10", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"X", ",", "Y1"}], "}"}], ",", 
        RowBox[{"UX10Func", "[", 
         RowBox[{"X", ",", "Y1"}], "]"}]}], "]"}]}], "}"}]}]}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.790238287887574*^9, 3.790238304447383*^9}, {
   3.790238434119712*^9, 3.790238443907172*^9}, {3.7902388164964666`*^9, 
   3.7902388340482163`*^9}, {3.790238887396888*^9, 3.790238887609825*^9}, {
   3.7902399694240355`*^9, 3.790239981044535*^9}, {3.7902406380093126`*^9, 
   3.790240640509712*^9}, {3.7902406843504505`*^9, 3.7902407395060787`*^9}, 
   3.79024150851947*^9, {3.7902416104975424`*^9, 3.7902416312561703`*^9}, {
   3.7902416929054084`*^9, 3.790241725296995*^9}, {3.7902455701310835`*^9, 
   3.7902455984355917`*^9}, {3.7907031546546607`*^9, 3.790703155852154*^9}, {
   3.7911040602692003`*^9, 3.791104087957878*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"358f36b3-8ad3-4f90-9488-2802393ea193"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "Y1"}], " ", 
         RowBox[{
          SuperscriptBox["G10", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["Y1", "2"], " ", 
         RowBox[{
          SuperscriptBox["G10", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["UY10", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}]}], "\[Equal]", "0"}], ",", "True", ",", 
   "True", ",", "True", ",", "True", ",", 
   RowBox[{
    RowBox[{"UY10", "[", 
     RowBox[{"X", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY10", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{"Pin", "\[Equal]", 
    RowBox[{"G10", "[", "0", "]"}]}], ",", 
   RowBox[{
    RowBox[{"G10", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0XlIE3AUB3DtmJKZB5WRoVmaBiFiy1mQ9kvQmEckNs15MVLnkceUSDxa
2uGVx7SU6Ta0aTFlIzAx5ywP1ARN0sw5xCNT019LjMxjSO/98fj88b7vj/ee
Ay81ONbYyMiID8XdjhCt3KZE0+i1E8eh5O4IyeeDQqXFQAJo+Zk/XgHqk1u1
ldh/m7WGuq02G4lAsXy9DD3s5D2B9k790qGeg1PmVaChnxOJUi3jEZrjnDeK
+q4zfdrBCpej91BX24wyNIVn24TWshxZy6Di8sgo+tL3N3cbXBOOx6GKY9Jy
dG6M2O6CbcfT/S1CKWG3FA6j8h3GLKo3XzQvA9sM34PKQdMXjlGo+2xQPBpy
pbS0GXS9oHd5DyYUzeej8pmrq+iWf7G6E1yk6pXoMEoKecKsyDuUDEctTZqF
w3xjgA6N9n5zMYxLyRe/83PiCEqmD3Fr6kH19M1pVNW9NigBMwZj6qSgaIPf
KQP7F+bTNGDMTrKuGxSzv23WRsJerAT2TCwlQ/YmJnsgxxBgjQp2ZVYH4yg5
F7EXhIr4VcYMsFWk/WAFDpTU6ULBbrnXPrd4SlheZ+4HglrOVl4oyD6hkuXy
4Z6WM59Qpb38eXYCJdU5inqUzWnceAqOPbykeQZ6VmpeMRIpefB105ANinPD
k+pBs7Z3I6/B4qXFGiVYKfjJU4F+kz1FqFJdfaQXtOb+a+EkUWJjOCmRgcH7
PdYawCGHPgc5GHer44djCiV/9e4dAamUTFCTDVYaJeUf/5ypElAyEj1/tgv0
FJmkkwxKeqRPHqNMHqcPtVsQSpvBxJJhfjtIeRMBWnDUNlM8A95Qhah3wXrF
gZyuTEokHtxUpgRyzcs1HqC0oGDcE7SoE6j8wGucoiF0yLRAcV1KiXOgXYMP
mHkqtglVMrstp2TwBxun0+h/WUC4yA==
  "],
 CellLabel->"Out[87]=",ExpressionUUID->"a775b8b1-5b9f-4fe1-80b7-6836da85728b"]
}, Open  ]],

Cell["We now solve the mass conservation equation, given by", "Text",
 CellChangeTimes->{{3.7902382573230495`*^9, 3.7902382588519773`*^9}, {
  3.790703583170168*^9, 3.7907035993627357`*^9}, {3.791172641110285*^9, 
  3.791172645535569*^9}},ExpressionUUID->"ca36b454-430c-48ed-835e-\
177994c73620"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList1LeadingOrder", "[", 
   RowBox[{"[", "1", "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911726386205177`*^9, 3.7911726489155407`*^9}},
 CellLabel->"In[88]:=",ExpressionUUID->"5ead9c04-81ff-463d-917a-ed91285054ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Y1"}], " ", 
       RowBox[{
        SuperscriptBox["G10", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["Y1", "2"], " ", 
       RowBox[{
        SuperscriptBox["G10", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["UY10", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"X", ",", "Y1"}], "]"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0XlIE3AUB/BppVZoTkKkBK/sInSQTAlMfhMySl2IbqauY+ScWk1tFp7V
Ms2j6Rwe6A5nHmTY6J9lnmTilQppDW0eZdPM/RCUlHRSvffH48N7fP94j+cl
lEQl2jAYDDHUANtFuRJDibUoZEfEo+SHgiMTg345zoPJYH5p8lQF9lHtMwpQ
V51tQRcMrYxKcKx4XY52rYd8Rm9OrJnQEeGMoxK0qPkC1LXS/jF65WP+BBr9
kBtqAJvCa++g0Q1SOSqPcm9GB4d9A3+Cz5wmJtBAznr8NuZZRhHqvkdbjkb2
co5awcawjMuH+LBvROko6r3psIDmvjQ7ysFHO+bIctCc7HsNrcjgJqHLTWVl
LWDJObdT78Daw4sy1DmOrKJ7/cu6OsFJTc/K9VhKPsXIsgRXKUkPtRgPxlFy
5gnXhOpt2s7GxlMyOnT6W10C5A8IalSgPi7qK3rhxtqQGrRKb9VrQNlGaqcW
PM8yp/WA4f4SUy8Ymz69VSug5LY25dJcIiWJHHv7v+DF3QgXdJKpY+4TUTLP
tOWirJRqGztQOjrbxwSX+lUmPtjRFGLLSoL7M33uR4CTxj/5fHBtVa/NE1Oy
9WZ+BNV5tDzPSaakILddhQbzmjcKwd//2D1F4HFF3wu7FEqyS7Z3c0BlXkKq
CnQKfjveCp5YXK55DS4KLEI9OGweKEZrH1Q59YN28duveKmUZFW5q7Wgh32Q
RQc2jg54NYFO7M6lY3cpCfUL6AiXUCKU798ITKNEUb/prcygxH970acbNPAc
0sk9ShqyigrQCiv/AzrrINO04Fw7JjaA30XG8Blw5Utm3Rx4RM/rsoKMarvc
biklVWyBJEAN/239VcMGx9SFU0Gga71UHwbyjCXDqLfv0zaOhhK3cU9dKChS
JTWj9ZL3ztNaSkzKk57of6ExtFU=
  "],
 CellLabel->"Out[88]=",ExpressionUUID->"b4f86cfc-66b5-4f2d-b7eb-01bdc5680c15"]
}, Open  ]],

Cell["\<\
The expression for Uy is given when solving the mass conservation equation \
and by using the no penetration boundary condition at the top of region 1, \
i.e. UY10[X,1]\[Equal]0:\
\>", "Text",
 CellChangeTimes->{{3.8145282087937975`*^9, 3.8145282288472567`*^9}, {
  3.8145284340704784`*^9, 3.8145284649046264`*^9}, {3.814528559237461*^9, 
  3.8145285966685514`*^9}},ExpressionUUID->"99a02fb0-ed38-4b0d-86ef-\
ee18e86d3ec1"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"UY10Func", "[", 
    RowBox[{"X_", ",", "Y1_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"EquationList1LeadingOrder", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"EquationList1LeadingOrder", "[", 
          RowBox[{"[", "6", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"UY10", "[", 
        RowBox[{"X", ",", "Y1"}], "]"}], ",", 
       RowBox[{"{", "Y1", "}"}]}], "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911047746971445`*^9, 3.79110483142216*^9}, {
  3.791174784430597*^9, 3.791174798611549*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"a15ac0be-71c8-4dfd-8dd4-790329323a2e"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "12"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      SuperscriptBox["G10", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["Y1", "2"], " ", 
     RowBox[{
      SuperscriptBox["G10", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Y1", "3"], " ", 
     RowBox[{
      SuperscriptBox["G10", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwd0X0sFHAYB/DTRl4mtNbIMmS1ZCWFpj/yc41ImF3u5G1dnNe8nIs4argR
cd6aK29HIqW8/HN5L69djdtKGXfhat7W/aipqbzV8/THs8+e549nz7OvFTfB
P0KLwWBEQY1us8qXL1Nia0Y2eAGUlKUxs6NARprJaDQot4mdKAGrzrVOl4Jq
oVCDhgmbGWXglmRNjLrIXD+gO0PfVKjpMaVhOdjC54Sg67l6WWhd3m0FKuuq
ZcpwT87sdfSV6oYY7eJZNKLXqo44L4EVGoUCNTr4I+gPKGz6xENTzOqKUZ9h
pvkm+NlJcNGITclvV/FblG9qMIeu6C0aisFZ40WfYvCe0+FQVP+4X+T//mdR
YRPo1hFytAtkxcxnoy6C81/RneWinm60f2A5jEPJ2FVRWkggJZXKlUmDK5R4
Mv1VqO1YyylOECXDHnbqymBKRvXDJNXgQyVLiR5Y+v66Bgwo5VXVggJ+fLcU
HGMtJvaBIxlJqn7Qo256/X4IJSWcOK+ZCErcB/V274AuW7570VWfBhNtHiXv
s3V90XSHB1o6YI3X3EsTsP9JnYoNquzILvtISrgfbVIugWMBG7fY4IWeDmlm
FCVf1Oo3aLm0uUgYTUlqRns1ajvZvJYLyv869+WBlqUDDToxkF/41pYQLMgM
ja0GJbOd449xvrAsaQVfGK1w20A/XXk+yi2q2DMI7ig3WgJiKRliW9RIQfnC
WU09mJ48avUItK/uWbCJp0RU4djpnUBJ/Kr+mnMi5NL2y7qcTwmnYP5QL+jo
pZ9Ekil5FpwvQhdHAofQLL+c2iZQsK2IkoHud6e8p8GG9tTKGdD2RGDPJiia
0M3oFcD9srCE0zWUTDdpJE6gU+mdiTPgfvObbR6gw2ShHH3umffUrZaSfePW
9UzQKzyuEWW+GzGeksKf2ict0X89ebtN
  "],
 CellLabel->"Out[89]=",ExpressionUUID->"aa2ef3db-cf85-465a-87d4-c05ed6870e10"]
}, Open  ]],

Cell["\<\
Substituting the expression for Uy10 into the equation list for the leading \
order gives:\
\>", "Text",
 CellChangeTimes->{{3.814528236007127*^9, 
  3.8145282810261745`*^9}},ExpressionUUID->"f1f89611-8999-4a53-992f-\
402d6f244bdf"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList1LeadingOrder", "=", 
   RowBox[{"EquationList1LeadingOrder", "/.", 
    RowBox[{"{", 
     RowBox[{"UY10", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"X", ",", "Y1"}], "}"}], ",", 
        RowBox[{"UY10Func", "[", 
         RowBox[{"X", ",", "Y1"}], "]"}]}], "]"}]}], "}"}]}]}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.791174876573489*^9, 3.791174885545476*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"89c62589-580a-456d-8528-fe5297abb6f5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "12"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", "Y1", " ", 
         RowBox[{
          SuperscriptBox["G10", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["Y1", "2"], " ", 
         RowBox[{
          SuperscriptBox["G10", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "Y1"}], " ", 
         RowBox[{
          SuperscriptBox["G10", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["Y1", "2"], " ", 
         RowBox[{
          SuperscriptBox["G10", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}]}], 
    "\[Equal]", "0"}], ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "12"]}], " ", 
     RowBox[{
      SuperscriptBox["G10", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{"Pin", "\[Equal]", 
    RowBox[{"G10", "[", "0", "]"}]}], ",", 
   RowBox[{
    RowBox[{"G10", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0WtI02EYBXA1mmHrokQRVtO0gSV0sdIioncJhmmi0bacGkrTlTZ1ymK5
TGwtN8pZiX+ZuzjatLwkKFmps5iFU1CXxTSHaOKN+Wq5pNDp6Hk/HH5fD+cE
Z+Qm8b29vLy4kGXjFmE7G6MTa+JyoriEYSKunwuLnAPttqFBYnX8P94q+Jaa
yCSOHjWoiEGW6EA3+J0mvryDg5EooaKf6DNFnyC+ap7dVg4eH5i9ogJbncw0
Yn1IYhaxO0L1pA78fUoZ9gFs2JguJV59F+MkppSqOjtAX0bP/A0uRnS9XJJ6
HSPr0i/71mSMVgKvOYimquYILg8jS2/4pDoFoy6/dEoDUsmcMeLkH1evFrxZ
KKjRgUJRfoce5Erm88yg7HWBoxsUjIz9rU6FHsV3Ysf5GEWz6L4e8Kw0MYDY
HWf035yJkeY5PYEYxdd400BZ/8+P/qDUZnBwQHsTy+dYFkYju5jiePCz3V3M
AWudrfr7Aoy0e6b6iGWMxqdFtzDiS9s0xPCkJpcc/PTgjPkxuPtZz0vabYzk
C571IvDhRlq2Bhzu6xioBxeXndQbsNK5lNECHp52KYgrUdR2CxjCczeyszG6
tMzQ6sHKnPMLBnB4kzXYCJoumGdChRgt0SLfx+XC3vvprsg8jJRtqwdfiDB6
FDgb0gWGDvjlowKMYocUMuLaXV4PcVAl09WBtr1fBe0gv2os7gdYNiNRj4O1
CamdbvCex0/aVYhRSXt67kktRg7mInUaDMhRfosCnWpJSwx4wF5uJSbvUzSw
dBgdiT9kuAhWzIlMRLa2f+eoHn76EhFE/A80f3kn
  "],
 CellLabel->"Out[90]=",ExpressionUUID->"15464433-c80b-456e-a9a2-9f847eb9140b"]
}, Open  ]],

Cell["\<\
The pressure of the leading order for region 1 is a pressure driven channel \
flow:\
\>", "Text",
 CellChangeTimes->{{3.8145281664071145`*^9, 3.8145281978211603`*^9}, 
   3.8145286068506813`*^9},ExpressionUUID->"2260178e-a17c-4804-adf0-\
19f1ddeba3da"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"G10Func", "[", "X_", "]"}], "=", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"EquationList1LeadingOrder", "[", 
          RowBox[{"[", "7", "]"}], "]"}], ",", 
         RowBox[{"EquationList1LeadingOrder", "[", 
          RowBox[{"[", "8", "]"}], "]"}], ",", 
         RowBox[{"EquationList1LeadingOrder", "[", 
          RowBox[{"[", "9", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"G10", "[", "X", "]"}], ",", 
       RowBox[{"{", "X", "}"}]}], "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911750940037284`*^9, 3.791175144939642*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"dfc3b429-1199-4fb6-9181-7b671e447884"],

Cell[BoxData[
 RowBox[{"Pin", "-", 
  RowBox[{"Pin", " ", "X"}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0n0sFHAYwPHToo0OydaSlbfRbJRenNXa/E5mXVJJztu5pjgvzZES4VaW
VF6P6oRz83a1K/RixjmnVRyFtalb7oiUMfer1tVZctLz/PHb55/v82zP9nNN
EIYnWjAYDAG8JaGyeuE0JfIR9t+kSEqsDwcXJoOcg5sHU8CetvPjlWC+05MJ
MegsKDCglRsVjCowUmkqRyMy2O/REc1PPbo6qWdWg/c9YnhovsnmGlo0fXUM
3cVnp3eBexg55aj2nksrGqr1Zs1jJ303hmoDlmOXwVnf2SS02aepAjX0B29b
Ad1SLx+141KS87TqDVphsp1G/Y/MM8tBhXg+rAJck3vFowLNSQFaZysulYOq
3lPePeCHm3OF6KfPnEW05m11rxJskbxe4EdR8t25LJcXTYlObtTaxMCdZq4e
HTjRsTcqlpJejc9MbRwlndZnJfVgqS5ah2qzTBop+Mw/ta4BjDdmKWXgV+li
Rh9oP3ZJrwZNJv1SDY8S3y1CzlQiJX5s2w3/wEhzuANq9mvdZJkEXafdcTTs
oczCCgzlzPVvAq9om/RccOxx0LrdAko8I7yyj4Fq7aqIC4oPdcoKkikpL/4y
jIpkbWV5KZREmbvq0R3hHcYbYPfagb5ikCkeaLZKpeS30WI1DxSt8tPqwSaO
avQBqNj+TdIOprv9SugA6dqfW+hzKrF9iXM686PINEqyC12lMtBFHGhoBD3v
DLu2gBqWes4jnZKp/QHdoUJK2uOYRlYGJY4vVtyqL8D+lnl3FWgMsckkWfA/
DSXX0TNbea9QpbqoQQ46Wo4nd4GBmZOhE9jJ8mqnwLu5/N4V0MGdma+6SInU
/5xwn5SSQc8fEn9QxC8dDwBnnPI7QkBHbeUQOlRVomA3ULJ+dGdjEHhbkN2K
zmpG7T/KoK9juaD/AWbcuzA=
  "],
 CellLabel->"Out[91]=",ExpressionUUID->"fb2a5b37-ff3f-4a23-9747-23cbc1e98df7"]
}, Open  ]],

Cell["\<\
Substituting the solution for P1 into the leading order equations shows that \
all the equations are satisfied.\
\>", "Text",
 CellChangeTimes->{{3.81452861211129*^9, 
  3.8145286562820854`*^9}},ExpressionUUID->"68572aca-2e3b-458e-9a56-\
64358968f141"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FormBox["EquationList1LeadingOrder",
   TraditionalForm], "=", 
  RowBox[{
   FormBox["EquationList1LeadingOrder",
    TraditionalForm], "//.", 
   FormBox[
    RowBox[{"{", 
     RowBox[{"G10", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", "X", "}"}], ",", 
        RowBox[{
         FormBox["G10Func",
          TraditionalForm], "[", "X", "]"}]}], "]"}]}], "}"}],
    TraditionalForm]}]}]], "Input",
 CellChangeTimes->{3.7911743681560593`*^9},
 CellLabel->"In[92]:=",ExpressionUUID->"e545a2d3-8a38-4998-89c6-14e816b62a6e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0mssG2AUBuAyI3G/ZdlsyZTFRCRbWNiGxFeXJRSbGNa6hETdQjudhimK
ZbKFFkXNrcF0WSWUmGwUG8FmI5tK474lcyn9tkgXhNLsfD9Onr/vOe+hprKj
04woFEo6jKvTvljzEKPf/UEnrFiM/lwMLc8AD80cpzNB/7wcVQ3IdRtYrgWF
MSVaYsuunFIHeokOhURFVfAiUVCvWyVSa9esxKDciJlIHPC3KiMGV5TNE82O
BnKHwOoLhULiwRy1m2gu8PTdAQ2NqnmiW4meeQyuBG6xiIt+XSKidir0sh78
1FwQbhOH0enH+lkir9zuJ7FxbcdKCM6GaCJFYC/XPYkYy41OJyoC6qpkoFd8
p8cH8Jzjdjkx0zJyj5ha3DAyDAbbTmuS4zF6hUSFiY8w2rY8UFswMLp+lblK
tHfo945nwn4zN341J2D01jxN0gqWMhJWiN//Hc20gfP72S3tYJSONywFx/SY
MwqeGhesjoGKK+uHTYkYeUs4YetpGLlM2JoZwGR+jD1xw1Rmd56F0X2GQxTx
QU6nkSkYEKYZtwPlm12rcaA4KMT4ZjpGT1vceRGgXE0pjQM9Je+kxRnQD3vr
C5EjVVQXZWJ0l69sJZosDOqeg+pS/9FKkFI702WaBX/QYXJWBPLOUrJbwcDJ
0bk34NTSX0kvaHPpILUP9NSevCD6+TRZT4BHDENPbDZGg5vUNilI76ZpO0BK
wFfqa1DQML51LRcjj/w77+lsyF1hrfPlYCR6eeYizsOIFrnrqgSdVRaPERfu
HlH1jCiUJ00SadaV7TLQMLSYMQTWJGzQl8HwrOLmdVBwnDKiB4vCbPjKJxhl
+bDYt9owUsr2JT5gD1eoug0uOJX03QMt1HWfier8ajmtHaO9bx4dQSB7p7Cb
yKf/sF2SYlTg5u9M/A/kdbAt
  "],
 CellLabel->"Out[92]=",ExpressionUUID->"bee830c4-2f13-4f75-833c-84eb6cce0d6b"]
}, Open  ]],

Cell["\<\
As expected for a pressure driven channel flow, Uy in the leading order is \
zero\
\>", "Text",
 CellChangeTimes->{{3.814528661671075*^9, 
  3.814528697412016*^9}},ExpressionUUID->"e40b5ebd-99a0-4dc6-80c6-\
630cd01f7c6d"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"UY10Func", "[", 
    RowBox[{"X_", ",", "Y1_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"UY10Func", "[", 
     RowBox[{"X", ",", "Y1"}], "]"}], "//.", 
    FormBox[
     RowBox[{"{", 
      RowBox[{"G10", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", "X", "}"}], ",", 
         RowBox[{
          FormBox["G10Func",
           TraditionalForm], "[", "X", "]"}]}], "]"}]}], "}"}],
     TraditionalForm]}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911767398809586`*^9, 3.791176782879835*^9}, {
  3.791177116815175*^9, 3.791177118773944*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"d3ff29c8-2732-48c9-8185-e131713c553b"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0X0sFHAYB/DTC6u8JM0fYhIWtnaJURT3k2i6sjTn5bh04shynLchjpsJ
0yHWmbibda5NRtgur6fRTkq25ogO6Q8Sv6XRyGs9zx/PPvv++f0+dnxhSJwB
g8EQwPlo3WqWQikJUfhvx3MoKTcNlCSAvPmT2kRwxiN5vBJ0XO+YrgKdg8Qr
6LakhfEU9MzelKIxEdd0aFnquh69HzZrUg0Wr3Kj0b9K00LUnSkZQ30l35PV
4P7BHClqYWvfhKbvMj1/gPJY3RiaX7fH3QKdjizFoyJXZQWqHgo8tQO2ZOXc
MAuj5N2fZx9QF1eLb6iufMlECrKP/rxVAfJYzjx0wfSOAL2QUV2uAjV5Opdu
zIpFCcpvvL2MFnjKenvAlZLhpbvhlAwWV2VHR1BSwt+cPBZJieWXaD3Knehw
C+dSMjbsOl8XRUl9mUBWDzrpeV/R12l7ww2gyczD53KQtZbdowCNyWpKP9jF
zNFrQB/vuY3aaEramaKg2ThKbPwsjPZB693QE6i2Q2V+OJ6SRCvLYLStosnA
EHQPWhkwBw13lPowcEYScOC8gJJ7g86ZN0EV54A4DPRtVyvyEig5NLE4gsbb
dj7JTYTeu5p6tCDpzVox2CT26X8MblSOvDB8AH8QG+3lgsI9flI9eIU98Okl
OCr4LWsFL2s3+G3g2c3dUjTzc63pILgZuf+Kk0RJd4Z9gwLM6vZfaQSnFkbt
lCD719sFh2RKeqq9uthCSoKbzdY8UyipjPt3plpESatm2b4PLGIZp5I0Shwu
SYtQa3bMEOroXSpXodcnE9QgiznPnga9OgvrZsH8rdjeHTDS1/xRXzolUeoE
oXsDJdOqNZkHGLQoHb8IfrQqaAsEGZya96gotaLZT07JHPtc41UwRCBuQgOm
dcenFLC7Des0+h9efa70
  "],
 CellLabel->"Out[93]=",ExpressionUUID->"a136a473-0fd8-4fba-a770-754d9ffaae3d"]
}, Open  ]],

Cell[TextData[{
 "UY10, the leading order of the velocity in the direction perpendicular to \
the channel is ",
 StyleBox["zero",
  FontVariations->{"Underline"->True}],
 " since it is a pressure driven channel flow."
}], "Text",
 CellChangeTimes->{{3.8139901648671956`*^9, 
  3.8139902219131584`*^9}},ExpressionUUID->"12853a1d-7cb5-4a59-ad36-\
8b55e79e536e"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"UX10Func", "[", 
    RowBox[{"X_", ",", "Y1_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"UX10Func", "[", 
     RowBox[{"X", ",", "Y1"}], "]"}], "//.", 
    FormBox[
     RowBox[{"{", 
      RowBox[{"G10", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", "X", "}"}], ",", 
         RowBox[{
          FormBox["G10Func",
           TraditionalForm], "[", "X", "]"}]}], "]"}]}], "}"}],
     TraditionalForm]}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.791176793204914*^9, 3.791176810863175*^9}, {
  3.7911768988424354`*^9, 3.791176977234475*^9}, {3.7911771255345592`*^9, 
  3.7911771629570475`*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"abd920f9-3051-4c0c-8676-9c880a887bb5"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Pin", " ", "Y1"}], "-", 
    RowBox[{"Pin", " ", 
     SuperscriptBox["Y1", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0n0wE3AYB/Bh6RRCXB2OvNR1+4PExaWjnzCH1EkbeUliGGdKp2Qq68Vx
GiIkttQ2br34w0tshLkTYndohSVdV9n4daclp4n1/P547nPPP89973kelxRO
dJoRhUJJh9J3JtRozmL0JD5Ez2JgZDZN52WAuXZ7hjPBDBPOdCX49HX7bBXI
8ry1TAwNfEl5AEpY63yiISr0PdE/YFVNdN2Yt6gGqR0JiUQ23lVMrFbwlETp
lBmnCwzUXucTqeHuYqKxwMt3EXQ6qFISzfsN8X9Bm8ElFjHHV1xB/DEZ5rAB
1moKI3YxMSo1bRojluhsF4gaB60FH6wf1kZVgJ+ptCQidehMOrHW8mG5BOyR
Gmg9YDJtkUfMLotZIlZq6+UyMMpkVHM+FqPfDdUFiXEYrZnpP+w8B/M4F9XE
HM9279h4jERvD39pSMCovIxd1wjaq5PniJI8ykgTyBBwHgtA0TuuTAjWpP3K
7QOnsrnqN+B43MJafSJGrTfywufTMLJU2G3fAo9xmTbE0Kst1ttY0DvtPUU8
Kms1MgUjxn72W4PiFbGaCXaP0Y0PpWP0yYeWfxKUMIxvMsHR4m5hUQZG3kWa
UWKsc+f9wky407/BRmLOskx3D3xhCOgrAbHVxDNTNkZBwTs2C0HWZmpWIxii
GphoAeUuurpXoM6wntIGruq3Sok0t0eWCnBpzvCckYVRvvP+JiFo60dfbgZn
0pQuInBdpfjungN/J/PvjuRgZDFppfPNhRxKilv1Zch7Dbv1gqfl5pdQHkYe
jpV3iMdVF4aIHXFlAgkospnJ6AKlrl8jZ8HxmNsN8yC/gCXfAAu8dnN7r2AU
3cXm+DTBPg78qTsCfkutmvYDB+x5bXTQkVE7Qmy4WyUNEmCkj/RsPgEm2fLE
xBWPj1YzQozCWoP3Ef8D9J2xPQ==
  "],
 CellLabel->"Out[94]=",ExpressionUUID->"f4d28606-228a-4038-8ecc-c84ff99974a1"]
}, Open  ]],

Cell["In summary, the pressure, Ux, uy:", "Text",
 CellChangeTimes->{{3.8145287121175194`*^9, 
  3.814528732542182*^9}},ExpressionUUID->"efa3b393-c8ff-4065-9c81-\
8606ce7ec5de"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{
   FormBox["G10Func",
    TraditionalForm], "[", "X", "]"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"UX10Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"UY10Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.791177050401232*^9, 3.791177093466646*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"7ddca807-fa98-4de0-84a6-0ff77968c666"],

Cell[BoxData[
 RowBox[{"Pin", "-", 
  RowBox[{"Pin", " ", "X"}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0H0sFHAYB/C7o0vs5K7VbbJ5zVa2UoStLL+0pETzdheujDl3MecwKRG6
1FSkw+XtbianyZBQXk7D1XSVmvd3EsPdj0yrxkk9vz+effbs+eN5nq91hMg/
ikqhUKKhYhbyC5aCMFpjn93kB2O0VH0uSwBazbHfC8Fd/aKBx+DLgqaxfHDQ
IlNHVBvUUZ6ATZ4buUR3Z69B4oLxrwnirHyaIQVfZfB4REMTZibRn3+nj3hd
eULUAhotpuYSG04dqCI6cp1cF8HtraE+oncNNWwD7I9f4RPdjyvziPMj3vv1
YFhG2oXdHJh3KjTEvuV9M8Qz9cuMXFBZqfXNA/G3Q1eIvZGB0US6b9FDJTiu
dnBoBfOaF7OIKYkcLdHCtLS9Dayy/Lh0lYtReG7hDd5l+GNFP2wSglGRJX+C
KDRuduKGwh4v59mSMIwkObGyMpAVGjlOLEqk9ZaDBmJxqRycHElvU4BBQ4fF
KrBBkz7RCYakzP5+yoO/p5LOT0XBnm72zm2QtcVlEQMCnzN38DGyCTD3I64L
X1DpoK1m7S0TjGRXT3BARqE3zTEa7o91SL4IHks2vM0B1TmtijQB5DW8/IEY
pHj9KFWIEXtLXUYM16nWs8FJOw/VPXDO7Esl/RpGnVrTv6mgOC0qpgwsjuv+
XE163U9ZHchr3IyoBxPeUXKIwTPFpt3g93FKbXAM5NJgX64AmWe8dRVgNv2r
9TNQ86NnwS4OI0Gs+xsfEUYHjVjrrvEY0bpottIEuJe6atsBWrkwxCgRo5P/
8iVErV9ED/Hm/QdyJUipHRO0gNMu8z5j4Kjr3ZIpMGND0K4H3Wz23upIwsij
RSRyLseoxP6PzAUMb5QOuIGt5pJ6L3DPsKyXyD0irTktx2j109EKT/BSgaSK
uKIaMxtVYNSl97Ii/gdol64y
  "],
 CellLabel->"Out[95]=",ExpressionUUID->"38e32e68-4427-4777-b34c-b0091d708ee7"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Pin", " ", "Y1"}], "-", 
    RowBox[{"Pin", " ", 
     SuperscriptBox["Y1", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0H0sFHAYB/A7JLGTu1a3yeY1W9lKEbay/NLiSjRvd+HKmHMXcw6TEqFL
TXXS4fJ2N5PTZEgoL6fF1aRS837OW2K4+5Fp1byknt8fzz579vzxPM/XNkoY
GEOlUCixUHHzBYWLIRitMs9u8EIxWqzxzeGDNrPM9wJw14Bw8BH4orBZUwAO
WWXriWrDespjsNl7XUL0dPUZIs6b/tISZ+RTNCn4MovLJRqZ0bOJgbzb/cRr
yhPCVtBkIV1CbDx1oJrozHFxXwC3t4b7iaxaasQ6OJC4zCN6HlfmE+dGWfs3
wYisjPO72TDvUvQR+5f2TRPPNCzRJKCySuefD+Jvhy4Te6ODY4nG/sUPlOC4
2smpDcxvWcghpiWzdUQr87KOdrDa+uPiFQ5GkZKi69xL8Mfy5ohZGEbF1jwt
UWDa4sIJhz0+rjOlERiJ8+Jl5SAjPHqcWJxs0FsBGopEZXJwYjSzXQGGDB8W
qcDGvkxtFxiWNvP7CRf+nkw5NxkDe7qZO7dBxhaHQQwKfkbfwcPILsgygLgm
eE41Bu37Vt/QwWhmjZYN0opYBs6xcH+8U+oF8Fiq0S02qM5rU2TwIa+RpQ/E
EMWrh+kCjJhb6nJipF61lgtOOHip7oKzFl+qjK9i1KUz/5sOijJi4srBkoTu
zzWk1/+U1YPcpo2oBjDpHSWPGDpdYt4Nfh+n1IXGQS6NjhUKkH6Gpa8Ec42/
2j4F+370zDskYMSP93ztJ8TooAljzT0RI4O3BvbSJLiXumLfCdq40UQoGaOT
/wrERF1AVA/xxr37ciVIqdPwW8Eptzk/DTjmfqd0Esxa53dsgh52e292pmDk
1SoUulZgVOr4R+YGRjZJBz3ANktxgw+4Z0TWS+QckdaelmO08ulopTd4sVBc
TVxWaSzGFBghT18b4n9fa6z1
  "],
 CellLabel->"Out[96]=",ExpressionUUID->"86fd9c1c-3955-4814-839b-1b8ef8181697"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0H0sFHAYB/C7o0vs5K7VbbJ5zVa2UoStLL+0UKJ5uwtXxpy7mHOYlAhd
airS4fJ2N5PTZEgory2upqvUvJ/zlhjufmRaNS+p5/fHs8+ePX88z/O1jhQF
RFMpFEoMVOx8QeFiMEar7LMb/BCMFmu8swWg1Sz7vRDcNSAafAS+KGzWFIBD
Fll6osqgnvIYbPZczyO6O3sNEeeNf2mJM/IphhR8mcnjEQ1NmFnEAP7tfuI1
5QlRK2i0kJZHbDx1oJroyHVyXQC3t4b7iT611PB1cCBhmU90P67MJ86N+uzf
BMMz08/v5sC8W6Em9i/tmyaeaVhi5IHKKp1fPoi/HbpM7IsKiiHS/YofKMFx
lYNDG5jfspBNTE3i6IgWpmUd7WC15cfFK1yMIvKKrvMuwR/LmyMmoRgVW/K1
RKFxixM3DPZ4Oc+UhmMkyY2TlYOssKhxYnESra8CNBCLy+TgxGhGuwIMHj4s
7gIb1RnabjA0deb3Ex78PZl8bjIa9vSwd26DrC0uixgY9Iy5g4+RTaC5P3FN
+JxKB23Vq2+YYBS7RssBGUU+NMcYuD/OIeUCeCzF8BYHVOW2KdIFkNfI0gdi
sOLVwzQhRuwtVTkxQt+1lgNO2Hl03QVnzb5U0a9i1K0z/ZsGitOjY8vBkvie
zzWk1/+U1YO8po3IBjDxHSWXGDJdYtoDfh+n1IXEQi6N9hUKkHnGR18J5tC/
Wj8F1T965+3iMRLEub/2FWF00Ii15pqAEe0tzVaaCPdSV2w7QSsXhhglYXTy
X4GEqPOP7CXeuHdfrgQpdRpBKzjlMuerAcdc75ROgpnrgo5N0M1m783OZIw8
WkUi5wqMSu3/yFzAiCbpoBvYZi5p8AL3jMj6iNwj0trTcoxWPh2t9AQvFkqq
ictdGrMxBeTJ97Yi/gdgEq0P
  "],
 CellLabel->"Out[97]=",ExpressionUUID->"13618c23-a559-4988-8c54-50f297c8a289"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Solving the leading order of region 2", "Section",
 CellChangeTimes->{{3.7907038121677666`*^9, 3.7907038260644007`*^9}, {
   3.7911741986584024`*^9, 3.7911742063438106`*^9}, {3.791181319802334*^9, 
   3.7911813569837055`*^9}, {3.791181702348116*^9, 3.7911817056592326`*^9}, 
   3.8410686206856256`*^9, {3.8410721788776984`*^9, 
   3.8410721792682943`*^9}},ExpressionUUID->"0b43a310-b976-478a-a27c-\
7c1f599d04c2"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{
  Inherited, 3},ExpressionUUID->"c773358c-9293-4a6d-b584-25a53252e164"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Polynomial h2 case:",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.803482814211673*^9, 3.803482828378482*^9}, 
   3.8066515928029904`*^9, {3.8066518314998446`*^9, 3.8066518320674486`*^9}, 
   3.813390785273641*^9},ExpressionUUID->"26d74ae5-523d-4290-8a7a-\
40549ba33886"],

Cell["The set of equations for the leading order of region 2:", "Text",
 CellChangeTimes->{{3.814529345968212*^9, 
  3.814529360567794*^9}},ExpressionUUID->"1ebf9900-1328-4c02-b75a-\
77e7f922af98"],

Cell[CellGroupData[{

Cell[BoxData["EquationList2LeadingOrder"], "Input",
 CellChangeTimes->{3.806653963712391*^9},
 CellLabel->"In[98]:=",ExpressionUUID->"befcf539-b00c-4e50-b3a1-3e92f2c01b94"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UY20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["UX20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UX20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}], "-", 
     RowBox[{
      SuperscriptBox["P20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["P20", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"X", ",", "Y2"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX20", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX20", "[", 
     RowBox[{"X", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"a1", " ", "X"}], "-", 
       RowBox[{"a2", " ", 
        SuperscriptBox["X", "2"]}], "-", 
       RowBox[{"a3", " ", 
        SuperscriptBox["X", "3"]}]}]}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY20", "[", 
     RowBox[{"X", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"a1", " ", "X"}], "-", 
       RowBox[{"a2", " ", 
        SuperscriptBox["X", "2"]}], "-", 
       RowBox[{"a3", " ", 
        SuperscriptBox["X", "3"]}]}]}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
      RowBox[{"P1", "[", 
       RowBox[{"X", ",", "0"}], "]"}]}], "-", 
     RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
      RowBox[{"P20", "[", 
       RowBox[{"X", ",", "0"}], "]"}]}], "+", 
     RowBox[{"UY20", "[", 
      RowBox[{"X", ",", "0"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["P20", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"0", ",", "Y2"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"P20", "[", 
     RowBox[{"1", ",", "Y2"}], "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.806652204768029*^9, 3.8066522092296753`*^9}, {
   3.8066540183099403`*^9, 3.806654024629481*^9}, 3.8066580049557543`*^9, 
   3.8067188749664307`*^9, 3.8067217988367825`*^9, 3.8071684459017353`*^9, 
   3.8115026802921233`*^9, 3.811571485110295*^9, 3.8115846367475357`*^9, 
   3.8115860043539624`*^9, 3.811586062013319*^9, 3.811610120826947*^9, 
   3.8117537078202095`*^9, 3.8121963852677994`*^9, 3.8122566947678223`*^9, 
   3.812277241545579*^9, 3.8128798822566385`*^9, 3.812879965564709*^9, 
   3.8133996619881783`*^9, 3.8133997935175424`*^9, 3.8134229981693387`*^9, 
   3.813424618151111*^9, 3.813684510673918*^9, 3.813924898082757*^9, 
   3.8139912592496758`*^9, 3.814014574167966*^9, 3.814028479777223*^9, 
   3.8140301039663305`*^9, 3.8140304161040564`*^9, 3.814068343020567*^9, 
   3.814372704120465*^9, 3.8145220892840195`*^9, 3.814526810394498*^9, 
   3.814531345563607*^9, 3.8158436310821733`*^9, 3.816449474002434*^9, 
   3.8169312166254435`*^9, 3.8181665541205535`*^9, 3.818250533349566*^9, 
   3.818523528432847*^9, 3.8185236846613483`*^9, 3.8185241871291766`*^9, 
   3.8187307404213743`*^9, 3.8187630788782024`*^9, 3.818834535217689*^9, 
   3.818843348224049*^9, 3.8189050513742013`*^9, 3.819299808769384*^9, 
   3.8405214102389135`*^9, 3.840525980687483*^9, 3.840556412190756*^9, 
   3.840556584941793*^9, 3.8405566175310245`*^9, 3.841070420694474*^9, 
   3.841072393634384*^9, 3.84107242828372*^9, 3.8419006855175557`*^9, 
   3.841900809334389*^9},
 CellLabel->"Out[98]=",ExpressionUUID->"f7ed4918-5631-4c30-b143-aacc2462317a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList2LeadingOrder", "]"}]], "Input",
 CellChangeTimes->{3.8182505317604837`*^9},
 CellLabel->"In[99]:=",ExpressionUUID->"c9937e46-7532-4e98-a929-a51b260fdbe8"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX20"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY20"}], 
           RowBox[{"\[PartialD]", "Y2"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[PartialD]", "P20"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX20"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y2", "2"]}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P20"}], 
          RowBox[{"\[PartialD]", "Y2"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX20", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX20", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY20", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", "P1"}], "-", 
          RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", "P20"}], "+", "UY20"}], 
         "\[LongEqual]", "0"}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P20"}], 
          RowBox[{"\[PartialD]", "0"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"P20", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900809494299*^9},
 TextAlignment->Center,ExpressionUUID->"f0e00484-8482-42a9-a2da-fe480cdbfe1e"]
}, Open  ]],

Cell["\<\
Referring to the simplified case where the bottom wall of region 2 expands \
linearly downstream\
\>", "Text",
 CellChangeTimes->{{3.814529397448696*^9, 
  3.8145294540772653`*^9}},ExpressionUUID->"aa97664a-a666-4669-8a98-\
52cd1e31a647"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2", " ", "=", " ", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a3", " ", "=", " ", "0"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.8040893716214294`*^9, {3.806653956364318*^9, 3.8066539570919666`*^9}},
 CellLabel->
  "In[100]:=",ExpressionUUID->"1c0ce236-e692-4239-90b8-ec079b7f5ee1"],

Cell["\<\
The simplified set of equations for the leading order of region 2 :\
\>", "Text",
 CellChangeTimes->{{3.814529470894585*^9, 
  3.8145294755998745`*^9}},ExpressionUUID->"c4b7dc5a-039e-4bc4-b568-\
5e9d59d13bcb"],

Cell[CellGroupData[{

Cell[BoxData["EquationList2LeadingOrder"], "Input",
 CellChangeTimes->{3.7911818013448772`*^9},
 CellLabel->
  "In[102]:=",ExpressionUUID->"f46afe60-9947-41c3-add7-93fee742fd15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UY20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["UX20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UX20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}], "-", 
     RowBox[{
      SuperscriptBox["P20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["P20", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"X", ",", "Y2"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX20", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX20", "[", 
     RowBox[{"X", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"a1", " ", "X"}]}]}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY20", "[", 
     RowBox[{"X", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"a1", " ", "X"}]}]}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
      RowBox[{"P1", "[", 
       RowBox[{"X", ",", "0"}], "]"}]}], "-", 
     RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
      RowBox[{"P20", "[", 
       RowBox[{"X", ",", "0"}], "]"}]}], "+", 
     RowBox[{"UY20", "[", 
      RowBox[{"X", ",", "0"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["P20", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"0", ",", "Y2"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"P20", "[", 
     RowBox[{"1", ",", "Y2"}], "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8031372060801735`*^9, 3.8033995739922857`*^9, 3.803402001166058*^9, 
   3.803481721126326*^9, 3.8034817557202573`*^9, 3.803483809430957*^9, 
   3.8034840304130487`*^9, {3.8034840978339305`*^9, 3.803484137058371*^9}, 
   3.803484175589134*^9, {3.8034852878102317`*^9, 3.80348532047991*^9}, {
   3.803485860211985*^9, 3.8034858772831583`*^9}, 3.8034859218013477`*^9, 
   3.803486336286763*^9, 3.803486958754969*^9, 3.8034872426433754`*^9, 
   3.803487861607379*^9, 3.803558792387001*^9, 3.803559035715905*^9, 
   3.803559228217436*^9, 3.8036586834644375`*^9, 3.8036599116763725`*^9, 
   3.803695849014877*^9, 3.803695939001354*^9, 3.803696259071617*^9, 
   3.803699420809165*^9, 3.803740784537133*^9, 3.803741788345344*^9, 
   3.8037419534132175`*^9, 3.8040004990601425`*^9, 3.8040030755795794`*^9, 
   3.804003140658413*^9, 3.8040505412730865`*^9, 3.804088675773099*^9, 
   3.8040893785144267`*^9, 3.8040902135700035`*^9, 3.80409187686484*^9, 
   3.804430169653504*^9, 3.8049494573629475`*^9, 3.8053065527321863`*^9, 
   3.8053066078314943`*^9, 3.805987236329673*^9, 3.8066480738204756`*^9, 
   3.8066522094406805`*^9, 3.80665402475439*^9, 3.806658005115739*^9, 
   3.8067188751003537`*^9, 3.8067217989377255`*^9, 3.807168446016654*^9, 
   3.8115026803948483`*^9, 3.811571485265937*^9, 3.811584636883458*^9, 
   3.811586004476891*^9, 3.8115860621142464`*^9, 3.8116101210456667`*^9, 
   3.811753707992095*^9, 3.8121963854187117`*^9, 3.8122566949237127`*^9, 
   3.8122772416549444`*^9, 3.812879882454219*^9, 3.8128799656398096`*^9, 
   3.8133996620662966`*^9, 3.8133997936475053`*^9, 3.8134229982943325`*^9, 
   3.8134246182136087`*^9, 3.813684510752039*^9, 3.813924898173798*^9, 
   3.813991259312172*^9, 3.8140145742908845`*^9, 3.8140284798549447`*^9, 
   3.814030104061923*^9, 3.814030416194003*^9, 3.8140683430544767`*^9, 
   3.814372704167334*^9, 3.814522089348983*^9, 3.814526810484452*^9, 
   3.814531345706758*^9, 3.8158436311380663`*^9, 3.8164494740673957`*^9, 
   3.8169312167024174`*^9, 3.818166554211499*^9, 3.8182514637128525`*^9, 
   3.818523528483817*^9, 3.8185236848012295`*^9, 3.818524187256809*^9, 
   3.818730740544305*^9, 3.8187630790191207`*^9, 3.818834535361906*^9, 
   3.8188433483799405`*^9, 3.818905051561669*^9, 3.8192998090061555`*^9, 
   3.840521410473277*^9, 3.840525980858387*^9, 3.840556412378243*^9, 
   3.840556585238637*^9, 3.8405566179216375`*^9, 3.8410704208343935`*^9, 
   3.841072393806247*^9, 3.841072428513894*^9, 3.8419006858163834`*^9, 
   3.8419008096132283`*^9},
 CellLabel->
  "Out[102]=",ExpressionUUID->"89260425-79af-4141-bb00-f17f8970d049"]
}, Open  ]],

Cell[TextData[StyleBox["Assuming pC=pin, which is the most interesting limit",
 FontWeight->"Bold",
 FontSlant->"Italic",
 Background->RGBColor[0.94, 0.91, 0.88]]], "Text",
 CellChangeTimes->{{3.7911819583411875`*^9, 3.791181981965021*^9}, {
  3.7911880978509665`*^9, 3.791188116133806*^9}, {3.8033996575431995`*^9, 
  3.8033996594600945`*^9}, {3.8034625183667545`*^9, 3.8034625202326775`*^9}, {
  3.814529483805177*^9, 
  3.814529486572547*^9}},ExpressionUUID->"a4dd170b-55f4-4b60-8d66-\
c2075f3ebe61"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EquationList2LeadingOrder", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"EquationList2LeadingOrder", "//.", 
       FormBox[
        RowBox[{"{", 
         RowBox[{"P1", "\[Rule]", 
          RowBox[{"Function", "[", 
           RowBox[{
            RowBox[{"{", "X", "}"}], ",", 
            RowBox[{
             FormBox["G10Func",
              TraditionalForm], "[", "X", "]"}]}], "]"}]}], "}"}],
        TraditionalForm]}], "}"}], ",", "AssumptionOnScaling"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7911818121498265`*^9, 3.7911818803852153`*^9}, {
  3.7911821666008615`*^9, 3.7911821823409424`*^9}, {3.7911822198670764`*^9, 
  3.7911822349679394`*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"6d0c22ef-17d2-41ae-bdc2-6fe29e2cd847"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UY20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["UX20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["UX20", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"X", ",", "Y2"}], "]"}], "\[Equal]", 
    RowBox[{
     SuperscriptBox["P20", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"X", ",", "Y2"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["P20", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"X", ",", "Y2"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX20", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX20", "[", 
     RowBox[{"X", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"a1", " ", "X"}]}]}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY20", "[", 
     RowBox[{"X", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"a1", " ", "X"}]}]}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY20", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", 
    RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Pin", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
       RowBox[{"P20", "[", 
        RowBox[{"X", ",", "0"}], "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["P20", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"0", ",", "Y2"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"P20", "[", 
     RowBox[{"1", ",", "Y2"}], "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0nlIE3AUB/B5JmjmINAyzOmIEkUhm8OK+GnW1JVsoS5LLd10amhekReV
LBPBeSzQdG5YOmlNLYNhbhpag7wyMssib90Mf1BJ5WoZvffH4/PHgy+8g5WW
J5TYMRiMy1CPo3yb1uMpefV8YlCaQEmWOm05C+yts001gOLV1e/ozlKdFR3o
vmvfCBolpxrQmFLbe9TmW/wZ1RRrPRTg0YNOKaimSXYL7dIuvEadAyPz9aAq
+F8dqot+0oVaBCVhFnCfyvoGDTl+KPk3OMuwu4L2kO561NMw420DDyvX4nYl
UtKX5rCEek2pfeSgmN9/qQ4UVX+Roiln/9ZqwIfjxsBn4LzF9TY65NlPUev1
UeMAGCAI30gVQR5llCWfp8Qw5f3BNYmSmpPceZStnwwVXaBklZO60nKREseW
ELMSjDDvGW0DXew1A2rwHEtSOAgqHi0sDoG5zJGt5mTob7nHzkko4XVqV/6B
XtGqOKcMSoLqG/6g4gKTnTNIfvkPM8G3RyrnEsERQ7BjSCYlsaUL186AMT85
NxJBo7dwuEJKybtm/TjK3G+qLcuCPW1xVOjujYnNKnB6hjd4B+zz+PTAORvm
juc5loOiipwcJdhsHZvsAi0F2009oMzskN4LCltdalBR5bL7CDietEOXkEMJ
3yeoTQ3e5Ao32kFBJtevA1wqMq+xcynJqI/s5+dR4ubgtRl2lZIENc9fUQD3
1h24ZwTZYmY+KaTkx3qrDI2wz36BylcaVRrwW8qyVA+6pH/lfwRlrvKWOZBV
UmSwgaFRfuXGIkrW2IJmThslpo62aS5Yt1feexp8eT/AhC5unxhF3aqU2ggV
JeG6Y+2R4NN8RSdaLRpizqrh38Y4LPQ/lUiT5w==
  "],
 CellLabel->
  "Out[103]=",ExpressionUUID->"b19528c4-8a34-4d9c-b081-0a1cd5547b84"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList2LeadingOrder", "]"}]], "Input",
 CellChangeTimes->{{3.818251457886489*^9, 3.818251458659886*^9}},
 CellLabel->
  "In[104]:=",ExpressionUUID->"c98717b8-f076-4357-9e03-2125eb632e4b"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX20"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY20"}], 
           RowBox[{"\[PartialD]", "Y2"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "UX20"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["Y2", "2"]}],
          MultilineFunction->None], "\[LongEqual]", 
         FractionBox[
          RowBox[{"\[PartialD]", "P20"}], 
          RowBox[{"\[PartialD]", "X"}],
          MultilineFunction->None]}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P20"}], 
          RowBox[{"\[PartialD]", "Y2"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX20", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX20", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY20", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY20", "\[LongEqual]", 
         RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Pin", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", "P20"}], 
           ")"}]}]}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P20"}], 
          RowBox[{"\[PartialD]", "0"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"P20", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008098480935`*^9},
 TextAlignment->Center,ExpressionUUID->"f140206e-cbb1-445d-b62d-03601695c413"]
}, Open  ]],

Cell["Momentum in the Y direction gives", "Text",
 CellChangeTimes->{
  3.7911820971127615`*^9},ExpressionUUID->"6a0c501a-2fa9-4873-9121-\
dc7a77520536"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"EquationList2LeadingOrder", "[", 
   RowBox[{"[", "3", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.791182107704914*^9, 3.791182113670505*^9}, {
  3.818251477807835*^9, 3.818251483510101*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"4f94b34d-db0a-49c5-a68c-6c46d170f18c"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", "P20"}], 
      RowBox[{"\[PartialD]", "Y2"}],
      MultilineFunction->None], "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008099750204`*^9},
 TextAlignment->Center,ExpressionUUID->"8252f780-29c4-4e4e-901c-803d86fe74a7"]
}, Open  ]],

Cell["we thus see that P20 is not a function of Y2, and thus", "Text",
 CellChangeTimes->{{3.818251419701066*^9, 
  3.8182514288572493`*^9}},ExpressionUUID->"97cf4d11-f993-4240-9e32-\
110611e7af94"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList2LeadingOrder", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"EquationList2LeadingOrder", "//.", 
     RowBox[{"{", 
      RowBox[{"P20", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"G20", "[", "#1", "]"}], " ", "&"}], ")"}]}], "}"}]}], 
    "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911835439999123`*^9, 3.791183558865034*^9}, 
   3.8044291416561956`*^9},
 CellLabel->
  "In[106]:=",ExpressionUUID->"97d3386e-b582-4242-8077-2de063b4e397"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UY20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["UX20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["G20", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}], "\[Equal]", 
    RowBox[{
     SuperscriptBox["UX20", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"X", ",", "Y2"}], "]"}]}], ",", "True", ",", 
   RowBox[{
    RowBox[{"UX20", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX20", "[", 
     RowBox[{"X", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"a1", " ", "X"}]}]}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY20", "[", 
     RowBox[{"X", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"a1", " ", "X"}]}]}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY20", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", 
    RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Pin", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
       RowBox[{"G20", "[", "X", "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["G20", "\[Prime]",
      MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"G20", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0H0sFHAYB/DTvFTiSPlDrLx0liKWt7xtv7xknUo2zrutohN5V1Ynawtl
43Dk0r3MOZfJstYmnLNO5OVWkenq2ll5CXe/9YdRYqrn+ePZ55/vsz3fx/ly
flymCYPByICpOXhOuBJPycvlLA03gZLdVz/NZ4P7Q32mG8AL9Ssb6N2ycNNG
0HpV3YCe1MRrUSsPph59WOpgKwAVcWXpKLdFcw9dk7E/oIt1dkW94GxuZz3a
zXfsRFnhvIBlcLxgawp98NMr7Q/owTLkoiLFs0b0+HS84zY4tRp0icmh5IDy
0Txq6co8XAfaj2dm80FGoZKvAN1DWZ79IKtGUIl2pqso6nXbRTWAOWWYMSOR
ks1/nry0JErM5Ue0lsmUvD40PIcOMyv9ElMoiR2NWmxNpWTsse8PEXjC2WlC
DBpTugakoJWWW6wC+ar5b0Og4fvIb2EaJT4Vdmx9JiW+R3sW/oKpTu0XzbJg
L7J5Cw2RjpmYg+ulx9S2IDO4Ws8BgxpPmXpfgz4WCzfPg4Ebpys4oI0gSV3O
pcRtaUCDrksma+9kU1JWGCxBGTnTa1Xg21m2qhpss5lrN79OSb1VjCkPzNu5
kSMC+2rfv3sKGkJNhM/BIb3FlR7wa/S+GjRh16L1MPhKt6c7IYeSBZm3WAr6
3+IY28AXe0Nc5OCKn2HJLY+Sptiovph8SqpmHNYCCigJ07FdBUVwp9ZGMgjS
fvtCUgx/XpXdR0vMCt6gghShRAFOBRm5vSDP/VfMF3Ayr7lVD25vliu3wQiJ
B2+whBKdnCP0F1NCnnTMBILJDi09Z0GZzGcUHdqJnEA/urV3nZFQYtcd2RYO
NhF5B+qvnrT9LKVkJDDCGf0PKQ+Ivg==
  "],
 CellLabel->
  "Out[106]=",ExpressionUUID->"f2d68575-4bf1-45c9-9145-182200bf7cf8"]
}, Open  ]],

Cell["We now solve the X momentum conservation equation, given by", "Text",ExpressionUUID->"85086c89-05cc-41b7-81ff-e8b1dc966e70"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"EquationList2LeadingOrder", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911836293514347`*^9, 3.791183632316931*^9}, {
  3.8182515216671605`*^9, 3.818251523688264*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"68f15e40-b74b-49a8-ae35-c0214019dc93"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", "G20"}], 
      RowBox[{"\[PartialD]", "X"}],
      MultilineFunction->None], "\[LongEqual]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[PartialD]", "2"], "UX20"}], 
      RowBox[{"\[PartialD]", 
       SuperscriptBox["Y2", "2"]}],
      MultilineFunction->None]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900810208886*^9},
 TextAlignment->Center,ExpressionUUID->"94eca0d5-ea78-4a92-a155-93fdf26c47d8"]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{
  Inherited, 3},ExpressionUUID->"15c6807f-e195-45b5-bd76-58269cf7a18c"],

Cell["\<\
Solving the equation for Ux while implementing the no slip boundary \
conditions at the top and bottom walls of region 2:\
\>", "Text",
 CellChangeTimes->{{3.8145295304592905`*^9, 3.814529583244874*^9}, {
  3.8145296344568267`*^9, 
  3.8145296509089165`*^9}},ExpressionUUID->"ab428f61-6b0b-4fd0-8b8b-\
e395559f0293"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{
  Inherited, 3},ExpressionUUID->"71db7268-0c09-4b6c-9c60-d79c0474c896"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    RowBox[{"UX20Func", "[", 
     RowBox[{"X_", ",", "Y2_"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"DSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EquationList2LeadingOrder", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"EquationList2LeadingOrder", "[", 
           RowBox[{"[", "4", "]"}], "]"}], ",", 
          RowBox[{"EquationList2LeadingOrder", "[", 
           RowBox[{"[", "5", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"UX20", "[", 
         RowBox[{"X", ",", "Y2"}], "]"}], ",", 
        RowBox[{"{", "Y2", "}"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.791183717590526*^9, 3.7911837587653675`*^9}, {
  3.806657099351883*^9, 3.80665709976163*^9}, {3.8182524747545114`*^9, 
  3.818252476430546*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"9b6cdbd9-a803-4b69-9f70-acd9e43af96d"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y2", " ", 
        FractionBox[
         RowBox[{"\[PartialD]", "G20"}], 
         RowBox[{"\[PartialD]", "X"}],
         MultilineFunction->None]}], "+", 
       RowBox[{"a1", " ", "X", " ", "Y2", " ", 
        FractionBox[
         RowBox[{"\[PartialD]", "G20"}], 
         RowBox[{"\[PartialD]", "X"}],
         MultilineFunction->None]}], "+", 
       RowBox[{
        SuperscriptBox["Y2", "2"], " ", 
        FractionBox[
         RowBox[{"\[PartialD]", "G20"}], 
         RowBox[{"\[PartialD]", "X"}],
         MultilineFunction->None]}]}], ")"}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008103777876`*^9},
 TextAlignment->Center,ExpressionUUID->"a91325fa-e5a7-40d4-a381-e9cb43ffc331"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList2LeadingOrder", "=", 
   RowBox[{"EquationList2LeadingOrder", "/.", 
    RowBox[{"{", 
     RowBox[{"UX20", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"X", ",", "Y2"}], "}"}], ",", 
        RowBox[{"UX20Func", "[", 
         RowBox[{"X", ",", "Y2"}], "]"}]}], "]"}]}], "}"}]}]}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911837922427173`*^9, 3.7911838084158707`*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"566e27d6-b7a1-490a-a12e-4280f309362b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", "Y2", " ", 
         RowBox[{
          SuperscriptBox["G20", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{"Y2", " ", 
         RowBox[{
          SuperscriptBox["G20", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{"a1", " ", "X", " ", "Y2", " ", 
         RowBox[{
          SuperscriptBox["G20", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["Y2", "2"], " ", 
         RowBox[{
          SuperscriptBox["G20", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["UY20", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y2"}], "]"}]}], "\[Equal]", "0"}], ",", "True", ",", 
   "True", ",", "True", ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"a1", " ", "X"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{"a1", " ", "X", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"a1", " ", "X"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"a1", " ", "X"}]}], ")"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "\[Equal]", 
    "0"}], ",", 
   RowBox[{
    RowBox[{"UY20", "[", 
     RowBox[{"X", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"a1", " ", "X"}]}]}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY20", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", 
    RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Pin", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
       RowBox[{"G20", "[", "X", "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["G20", "\[Prime]",
      MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"G20", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwdz1tIE3AUBnANnQ+VN4KwVeYSBSOQArdKiFNhobZUzM15mZW3TXLquoxS
zFqmolYTaZrbmKm5krYeNDVX8xaYJWtWzGq00s1R/zKGVrqSzr+Hw4/v6ftO
2ElJSp63l5eXAC+fF9HiOk5AtFA7K0ojYK1ffHUTHTtt8lOgvf3dCuqlGl8r
VZ8Za6e+c+4IbkJlz4YU1L3cdDOVN2WW9qFhVaEKqsTE01H9C7/tmUe/c2tf
U8sOVWQvo4r8hDkqK5u5xYM6ZJOpATwCU8tX5qidns+hjWhQU5b4Ovr2luRG
F/rD8GjnAGofjaumrn4ZI/9zlcs4iP5k8YmQT8DP5C7PSse+jc0f1woI9LNy
YvgZBI4MhThbMwl0t+xztqHKCNaECuWOGAY1aE1MsdSIyqrm7U/Q1aiJX8os
AuwTzARbHoGkzt7ZVdQ/UHfMN5/AOri9Qv298tybgZqXooeD0A1PG208dMDE
8YkuIJD9yXXuKMpc2l/JQ8e25Q5XFOLeAtMk1bLV0nBRRGBZDmqqXWx1V6OG
N8nGa2hD4NwdhphAfHiqTzlaUldW1IZGtUy/vIvGeRjKB6hFv/6UHh12BtdR
FfVO/xG0QxDQk1ZE4L2Wo9KgK0zhVy3aGgmsDjSlcsERXkwgmhHfnyjB/Wmh
bnYJAXdz0vamMgJyS2SIERW7mKUgxX9kOjm1Juf8KFVeqlJ3oRL2YmEfmnHh
b+IMzcK2VhvqSLr62IPmfthdPnSGgHZQqIxREeCM90xz0F2bNPrD6GUWZ5z6
oiJhgmpp1907oCbw536y9iDqffZhJ3XNjC3IqiEQuzk5jPoPbap+qQ==
  "],
 CellLabel->
  "Out[109]=",ExpressionUUID->"78dc940f-1423-4168-99a5-84c5050f068f"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList2LeadingOrder", ";"}], TraditionalForm]], "Input",
 CellChangeTimes->{
  3.803401996736851*^9, {3.818252493330884*^9, 3.8182524946329765`*^9}, 
   3.818262356544171*^9},
 CellLabel->
  "In[110]:=",ExpressionUUID->"60a492af-e94f-4101-aa53-3a0efa4af9fd"],

Cell["We now solve the mass conservation equation, given by", "Text",
 CellChangeTimes->{{3.8034019761197147`*^9, 
  3.8034019806711264`*^9}},ExpressionUUID->"1d394573-cbea-4660-bb23-\
78fbd111af61"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"EquationList2LeadingOrder", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.791183852729454*^9, 3.791183857160372*^9}, {
  3.8182525067210073`*^9, 3.8182525082355394`*^9}},
 CellLabel->
  "In[111]:=",ExpressionUUID->"ed3872db-af3f-4d45-abce-8f71d5e1f8f7"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a1", " ", "Y2", " ", 
          FractionBox[
           RowBox[{"\[PartialD]", "G20"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None]}], "+", 
         RowBox[{"Y2", " ", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "G20"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["X", "2"]}],
           MultilineFunction->None]}], "+", 
         RowBox[{"a1", " ", "X", " ", "Y2", " ", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "G20"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["X", "2"]}],
           MultilineFunction->None]}], "+", 
         RowBox[{
          SuperscriptBox["Y2", "2"], " ", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "G20"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["X", "2"]}],
           MultilineFunction->None]}]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{"\[PartialD]", "UY20"}], 
       RowBox[{"\[PartialD]", "Y2"}],
       MultilineFunction->None]}], "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900810661624*^9},
 TextAlignment->Center,ExpressionUUID->"98549ece-7baf-4869-a53c-a7d8ccebd50b"]
}, Open  ]],

Cell["To obtain a solution for UY20", "Text",
 CellChangeTimes->{{3.818262470836269*^9, 
  3.818262483557145*^9}},ExpressionUUID->"4e3de867-0a34-43ff-aee1-\
3ab310617ffb"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    RowBox[{"UY20Func", "[", 
     RowBox[{"X_", ",", "Y2_"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"DSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EquationList2LeadingOrder", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"EquationList2LeadingOrder", "[", 
           RowBox[{"[", "6", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"UY20", "[", 
         RowBox[{"X", ",", "Y2"}], "]"}], ",", 
        RowBox[{"{", "Y2", "}"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.791183873715396*^9, 3.7911839002388463`*^9}, {
  3.818252515568037*^9, 3.8182525170441875`*^9}},
 CellLabel->
  "In[112]:=",ExpressionUUID->"a7639073-6a95-4485-a1d5-696424eabc06"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "a1", " ", 
        FractionBox[
         RowBox[{"\[PartialD]", "G20"}], 
         RowBox[{"\[PartialD]", "X"}],
         MultilineFunction->None]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["a1", "2"], " ", "X", " ", 
        FractionBox[
         RowBox[{"\[PartialD]", "G20"}], 
         RowBox[{"\[PartialD]", "X"}],
         MultilineFunction->None]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["a1", "3"], " ", 
        SuperscriptBox["X", "2"], " ", 
        FractionBox[
         RowBox[{"\[PartialD]", "G20"}], 
         RowBox[{"\[PartialD]", "X"}],
         MultilineFunction->None]}], "-", 
       RowBox[{"3", " ", "a1", " ", 
        SuperscriptBox["Y2", "2"], " ", 
        FractionBox[
         RowBox[{"\[PartialD]", "G20"}], 
         RowBox[{"\[PartialD]", "X"}],
         MultilineFunction->None]}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[PartialD]", "2"], "G20"}], 
        RowBox[{"\[PartialD]", 
         SuperscriptBox["X", "2"]}],
        MultilineFunction->None], "+", 
       RowBox[{"3", " ", "a1", " ", "X", " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G20"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["a1", "2"], " ", 
        SuperscriptBox["X", "2"], " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G20"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None]}], "+", 
       RowBox[{
        SuperscriptBox["a1", "3"], " ", 
        SuperscriptBox["X", "3"], " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G20"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["Y2", "2"], " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G20"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None]}], "-", 
       RowBox[{"3", " ", "a1", " ", "X", " ", 
        SuperscriptBox["Y2", "2"], " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G20"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["Y2", "3"], " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G20"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None]}]}], ")"}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008108165336`*^9},
 TextAlignment->Center,ExpressionUUID->"909165f9-475e-45fc-9d93-03c191f2475a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList2LeadingOrder", "=", 
   RowBox[{"EquationList2LeadingOrder", "/.", 
    RowBox[{"{", 
     RowBox[{"UY20", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"X", ",", "Y2"}], "}"}], ",", 
        RowBox[{"UY20Func", "[", 
         RowBox[{"X", ",", "Y2"}], "]"}]}], "]"}]}], "}"}]}]}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911839554587975`*^9, 3.791183972429577*^9}, {
  3.818262370510453*^9, 3.8182623778258*^9}},
 CellLabel->
  "In[113]:=",ExpressionUUID->"eb4866f8-5ccc-4ccd-8372-c7fdaf8712e5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "12"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "6"}], " ", "a1", " ", "Y2", " ", 
         RowBox[{
          SuperscriptBox["G20", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "-", 
        RowBox[{"6", " ", "Y2", " ", 
         RowBox[{
          SuperscriptBox["G20", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "-", 
        RowBox[{"6", " ", "a1", " ", "X", " ", "Y2", " ", 
         RowBox[{
          SuperscriptBox["G20", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["Y2", "2"], " ", 
         RowBox[{
          SuperscriptBox["G20", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", "Y2", " ", 
         RowBox[{
          SuperscriptBox["G20", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{"Y2", " ", 
         RowBox[{
          SuperscriptBox["G20", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{"a1", " ", "X", " ", "Y2", " ", 
         RowBox[{
          SuperscriptBox["G20", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["Y2", "2"], " ", 
         RowBox[{
          SuperscriptBox["G20", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}]}], 
    "\[Equal]", "0"}], ",", "True", ",", "True", ",", "True", ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"a1", " ", "X"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{"a1", " ", "X", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"a1", " ", "X"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"a1", " ", "X"}]}], ")"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "\[Equal]", 
    "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "a1", " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["a1", "2"], " ", "X", " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["a1", "3"], " ", 
        SuperscriptBox["X", "2"], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "-", 
       RowBox[{"3", " ", "a1", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"a1", " ", "X"}]}], ")"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["G20", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}], "+", 
       RowBox[{"3", " ", "a1", " ", "X", " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["a1", "2"], " ", 
        SuperscriptBox["X", "2"], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["a1", "3"], " ", 
        SuperscriptBox["X", "3"], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"a1", " ", "X"}]}], ")"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "-", 
       RowBox[{"3", " ", "a1", " ", "X", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"a1", " ", "X"}]}], ")"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"a1", " ", "X"}]}], ")"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "\[Equal]", 
    "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "a1", " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["a1", "2"], " ", "X", " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["a1", "3"], " ", 
        SuperscriptBox["X", "2"], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["G20", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}], "+", 
       RowBox[{"3", " ", "a1", " ", "X", " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["a1", "2"], " ", 
        SuperscriptBox["X", "2"], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["a1", "3"], " ", 
        SuperscriptBox["X", "3"], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "\[Equal]", 
    RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Pin", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
       RowBox[{"G20", "[", "X", "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["G20", "\[Prime]",
      MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"G20", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0n0s1HEABvCf5i6VXLeltbLfuIRGV7OizKxvWmecSMsddRntuItITmOp
rs3SrrBQw7jLSzRESiY687rImppqsm6oeSnfrKwYQs/3j2eff5/teZxiksLU
VhzHRSD6IUvJ9GlK/CXCIU04Jb5G07QWvnk+bpMH9amiAubuJ1YF+TAjcfw9
08Y8qGuGRSHqAqarg6CWOV8/d3gKfrqf84Ep97h9bhGu08ROMDlvwi/D3jSZ
UqSg5ETM8CRT6P7dMQequjk3ppc8LD4XXtysvlcFNx68KX0J10a1WcwOfpAy
XXS0vRVyhmgapaTE1tHluiqCEnFC19imSEp69tV4K89QEn2gY6r4LCWZRccm
SyC3fk9/KayRtrSa4N701BQzHBHNjrXDBMHgQqGKktUA1yCLmpIfle3fVqE0
uTFEEEvJ6w3lS8ymiXdWQvjwr0+nGG6vLrIo4FeOWO+PoyRQ/PtKMPz35/gN
BYyp03Ve01CyNa9vgGnkv2Rf1VLC+wYamXrp2NwtaPioNGfB8C0/K4QX0Esf
ZZ0BFYa0+BK4lj7ythpW+IkK62HvqP35BiiXOBiYKX3Tdl0wN9K+Ljwee0Ud
KTXBuG3amTLoXC6TVMLsnfMTzomU3Lkb2iJPosTTy2XO+xIlCw8Uu/IvU9I1
6cybYeNS0GwnDIiVJJMUStr4pkzmL7m+m2njXmGsguPuK5pmODwjCP4MZT1V
xRb4LDSnbRm62fplvNJRcspHU+hVir/xL4YOQY8djxtkUCfx72XWrZzsZ9ot
Pq05aqSkuFZV5g/TPAceMVv4GfGwCa6pnJj/AYD6bBc=
  "],
 CellLabel->
  "Out[113]=",ExpressionUUID->"c1181d7d-5914-4366-a911-9fded6550bab"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"EquationList2LeadingOrder", "[", 
    RowBox[{"[", "7", "]"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.8182638442577257`*^9, 3.8182638525747213`*^9}},
 CellLabel->
  "In[114]:=",ExpressionUUID->"83beb837-c36c-4ce0-8d78-c0646b4ab702"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     RowBox[{"12", " ", "K2", " ", "w", " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Pin", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", "G20"}], ")"}]}], 
     "\[LongEqual]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"a1", " ", "X"}]}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "a1", " ", 
         FractionBox[
          RowBox[{"\[PartialD]", "G20"}], 
          RowBox[{"\[PartialD]", "X"}],
          MultilineFunction->None]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"a1", " ", "X"}]}], ")"}], " ", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "G20"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["X", "2"]}],
          MultilineFunction->None]}]}], ")"}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008115671005`*^9},
 TextAlignment->Center,ExpressionUUID->"451ef112-d7a3-4213-886f-899f186787cb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TextbookEq", "[", 
  RowBox[{"EquationList2LeadingOrder", "[", 
   RowBox[{"[", "7", "]"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TextbookEq", "[", 
  RowBox[{"EquationList2LeadingOrder", "[", 
   RowBox[{"[", "8", "]"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TextbookEq", "[", 
  RowBox[{"EquationList2LeadingOrder", "[", 
   RowBox[{"[", "9", "]"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.8035588514494047`*^9, {3.818252533235853*^9, 3.8182525437910604`*^9}},
 CellLabel->
  "In[115]:=",ExpressionUUID->"cf7bb550-2d57-4478-8c0e-a89dd2fa07c2"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     RowBox[{
      FractionBox["1", "12"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "a1", " ", 
         FractionBox[
          RowBox[{"\[PartialD]", "G20"}], 
          RowBox[{"\[PartialD]", "X"}],
          MultilineFunction->None]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a1", "2"], " ", "X", " ", 
         FractionBox[
          RowBox[{"\[PartialD]", "G20"}], 
          RowBox[{"\[PartialD]", "X"}],
          MultilineFunction->None]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a1", "3"], " ", 
         SuperscriptBox["X", "2"], " ", 
         FractionBox[
          RowBox[{"\[PartialD]", "G20"}], 
          RowBox[{"\[PartialD]", "X"}],
          MultilineFunction->None]}], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G20"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None], "+", 
        RowBox[{"3", " ", "a1", " ", "X", " ", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "G20"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["X", "2"]}],
          MultilineFunction->None]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a1", "2"], " ", 
         SuperscriptBox["X", "2"], " ", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "G20"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["X", "2"]}],
          MultilineFunction->None]}], "+", 
        RowBox[{
         SuperscriptBox["a1", "3"], " ", 
         SuperscriptBox["X", "3"], " ", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "G20"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["X", "2"]}],
          MultilineFunction->None]}]}], ")"}]}], "\[LongEqual]", 
     RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Pin", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", "G20"}], ")"}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008118389435`*^9},
 TextAlignment->Center,ExpressionUUID->"7bc5a02f-e133-4721-b03f-66d9f03a9c57"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", "G20"}], 
      RowBox[{"\[PartialD]", "0"}],
      MultilineFunction->None], "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900811936888*^9},
 TextAlignment->Center,ExpressionUUID->"b96ccf0c-bdf7-4944-88d4-0c75c76cbef4"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"G20", "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008121087875`*^9},
 TextAlignment->Center,ExpressionUUID->"2fd8730b-95b4-4552-8098-14be7261cc6a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["G(x) Asymptotic expansion",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.811438476164263*^9, 3.8114385007261796`*^9}, {
  3.813990864477583*^9, 
  3.8139908868453174`*^9}},ExpressionUUID->"ec909af3-0310-4c64-9858-\
95483af8d41d"],

Cell[TextData[StyleBox["Assuming a1<<1",
 Background->RGBColor[0.94, 0.91, 0.88]]], "Text",
 CellChangeTimes->{{3.8139908736536207`*^9, 
  3.813990880592843*^9}},ExpressionUUID->"e8fb048f-df9d-4185-afc0-\
c064007cbbf7"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Expression for G (x)~G0 + a1 G1",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.8115697520787587`*^9, 
  3.8115697747616577`*^9}},ExpressionUUID->"7125cbb1-7824-4858-8c57-\
585bda00b262"],

Cell["The assumptions on scaling, as mentioned before are:", "Text",
 CellChangeTimes->{{3.814529236620761*^9, 
  3.8145292507366405`*^9}},ExpressionUUID->"9ceec09a-6e1b-4a73-9f04-\
cd5afcaa931a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AssumptionOnScaling", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"l", ">", "0"}], ",", 
     RowBox[{"h1", ">", "0"}], ",", 
     RowBox[{"h2", ">", "0"}], ",", 
     RowBox[{"pC1", ">", "0"}], ",", 
     RowBox[{"uxC", ">", "0"}], ",", 
     RowBox[{"uyC", ">", "0"}], ",", 
     RowBox[{"\[Epsilon]1", ">", "0"}], ",", 
     RowBox[{"\[Epsilon]2", ">", "0"}], ",", 
     RowBox[{"\[Mu]", ">", "0"}], ",", 
     RowBox[{"K1", ">", "0"}], ",", 
     RowBox[{"K2", ">", "0"}], ",", 
     RowBox[{"a1", ">", "0"}], ",", 
     RowBox[{"Pin", ">", "0"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[118]:=",ExpressionUUID->"a6a04698-4b8c-47b9-b3b0-f12f229b2e00"],

Cell["\<\
The equation representing the pressure for the leading order in region 2\
\>", "Text",
 CellChangeTimes->{{3.8145292548122725`*^9, 
  3.814529274879195*^9}},ExpressionUUID->"89b6776e-52f4-4805-8af1-\
b00b68195f33"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GOriginalEq", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", "a1", " ", 
       RowBox[{
        SuperscriptBox["G20", "\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["a1", "2"], " ", "X", " ", 
       RowBox[{
        SuperscriptBox["G20", "\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["X", "2"], " ", 
       RowBox[{
        SuperscriptBox["G20", "\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["G20", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "X", "]"}], "+", 
      RowBox[{"3", " ", "a1", " ", "X", " ", 
       RowBox[{
        SuperscriptBox["G20", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["X", "2"], " ", 
       RowBox[{
        SuperscriptBox["G20", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["X", "3"], " ", 
       RowBox[{
        SuperscriptBox["G20", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "\[Equal]", 
   RowBox[{"K2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Pin", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
      RowBox[{"G20", "[", "X", "]"}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8114388509100757`*^9, 3.811438871025342*^9}, {
  3.8114389015648518`*^9, 3.8114389022835493`*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"7a3742af-b6ea-46a5-825a-149ea6eafc4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "12"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", "a1", " ", 
      RowBox[{
       SuperscriptBox["G20", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["a1", "2"], " ", "X", " ", 
      RowBox[{
       SuperscriptBox["G20", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a1", "3"], " ", 
      SuperscriptBox["X", "2"], " ", 
      RowBox[{
       SuperscriptBox["G20", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["G20", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "+", 
     RowBox[{"3", " ", "a1", " ", "X", " ", 
      RowBox[{
       SuperscriptBox["G20", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a1", "2"], " ", 
      SuperscriptBox["X", "2"], " ", 
      RowBox[{
       SuperscriptBox["G20", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["a1", "3"], " ", 
      SuperscriptBox["X", "3"], " ", 
      RowBox[{
       SuperscriptBox["G20", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "\[Equal]", 
  RowBox[{"K2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Pin", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
     RowBox[{"G20", "[", "X", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.8114389206994724`*^9, 3.811502834775152*^9, 3.811569721976737*^9, 
   3.8115698213053837`*^9, 3.8115701446418962`*^9, {3.8115725057512913`*^9, 
   3.8115725193315415`*^9}, 3.8115725615931597`*^9, 3.8115841602055793`*^9, 
   3.8115846403855786`*^9, 3.8115860106931715`*^9, 3.811586071774399*^9, 
   3.811610133344036*^9, 3.811753738614122*^9, 3.81219640976266*^9, 
   3.8122566999488106`*^9, 3.812277303547418*^9, 3.812879629106055*^9, 
   3.8128799805186033`*^9, 3.8133996633943243`*^9, 3.8133998159858007`*^9, 
   3.81342299942752*^9, 3.8134246192447805`*^9, 3.8136845121113324`*^9, 
   3.813924899539282*^9, 3.813991260141862*^9, 3.8140145755329676`*^9, 
   3.814028481353382*^9, 3.814030105262234*^9, 3.814030417368849*^9, 
   3.814068343525797*^9, 3.8143727050738163`*^9, 3.814522090505315*^9, 
   3.814526811981602*^9, 3.814531346370191*^9, 3.8158436318323555`*^9, 
   3.8164494746500626`*^9, 3.816931217315048*^9, 3.818166554868102*^9, 
   3.8182646917566338`*^9, 3.8185235296023874`*^9, 3.8185236862226706`*^9, 
   3.8185241884911127`*^9, 3.8187307415847025`*^9, 3.818763080484274*^9, 
   3.8188345368432813`*^9, 3.8188433497691393`*^9, 3.818905053150426*^9, 
   3.8192998108193016`*^9, 3.8405214118664474`*^9, 3.8405259823275356`*^9, 
   3.8405564139718723`*^9, 3.8405565864104333`*^9, 3.8405566275484633`*^9, 
   3.841070422240447*^9, 3.8410723956146464`*^9, 3.8410724314422207`*^9, 
   3.8419006885248194`*^9, 3.8419008122946796`*^9},
 CellLabel->
  "Out[119]=",ExpressionUUID->"d8d20905-8f11-49ef-88d9-a7c3404a77cf"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"GOriginalEqList", "=", 
   RowBox[{"List", "[", "GOriginalEq", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.811438904166486*^9, 3.8114389122156057`*^9}, 
   3.811570155006544*^9},
 CellLabel->
  "In[120]:=",ExpressionUUID->"36251e6d-4f85-4749-a290-f70633e7451f"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"GAsymptoticExpList", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"GOriginalEqList", "//.", 
     RowBox[{"{", 
      RowBox[{"G20", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"G0", "[", "#1", "]"}], "+", 
          RowBox[{"a1", " ", 
           RowBox[{"G1", "[", "#1", "]"}]}], "+", 
          RowBox[{
           RowBox[{"a1", "^", "2"}], " ", 
           RowBox[{"G2", "[", "#1", "]"}]}]}], " ", "&"}], ")"}]}], "}"}]}], 
    "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.81143880750523*^9, 3.8114388633105125`*^9}, 
   3.8114389348704815`*^9, {3.811438972510415*^9, 3.811438976440713*^9}, {
   3.8114390201234217`*^9, 3.8114390352008076`*^9}},
 CellLabel->
  "In[121]:=",ExpressionUUID->"4eef1b5a-b13b-4fef-bfba-8f3674da88d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "12"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"a1", " ", "X"}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", "a1", " ", 
       RowBox[{
        SuperscriptBox["G0", "\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a1", "2"], " ", 
       RowBox[{
        SuperscriptBox["G1", "\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a1", "3"], " ", 
       RowBox[{
        SuperscriptBox["G2", "\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["G0", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "X", "]"}], "+", 
      RowBox[{"a1", " ", "X", " ", 
       RowBox[{
        SuperscriptBox["G0", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{"a1", " ", 
       RowBox[{
        SuperscriptBox["G1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["a1", "2"], " ", "X", " ", 
       RowBox[{
        SuperscriptBox["G1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["a1", "2"], " ", 
       RowBox[{
        SuperscriptBox["G2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["a1", "3"], " ", "X", " ", 
       RowBox[{
        SuperscriptBox["G2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "\[Equal]", 
   RowBox[{"K2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Pin", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
      RowBox[{"G0", "[", "X", "]"}], "+", 
      RowBox[{"a1", " ", 
       RowBox[{"G1", "[", "X", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["a1", "2"], " ", 
       RowBox[{"G2", "[", "X", "]"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.811438937298558*^9, 3.811438978211911*^9, 3.811439037616124*^9, 
   3.811502836790061*^9, 3.811569722132956*^9, 3.811569821477245*^9, 
   3.8115701487340946`*^9, {3.8115725059651675`*^9, 3.811572523850258*^9}, 
   3.811572565080134*^9, 3.8115841603514776`*^9, 3.811584640535492*^9, 
   3.8115860108330917`*^9, 3.8115860719183316`*^9, 3.8116101334846506`*^9, 
   3.8117537387490435`*^9, 3.8121964098720274`*^9, 3.8122567000507517`*^9, 
   3.8122773036724105`*^9, 3.8128796292789774`*^9, 3.8128799807223263`*^9, 
   3.8133996635193143`*^9, 3.813399816142023*^9, 3.813422999536886*^9, 
   3.813424619369775*^9, 3.813684512270091*^9, 3.8139248996832128`*^9, 
   3.8139912602199802`*^9, 3.8140145756409273`*^9, 3.8140284817780485`*^9, 
   3.814030105382163*^9, 3.8140304174796314`*^9, 3.814068343575663*^9, 
   3.8143727052355123`*^9, 3.8145220906352406`*^9, 3.814526812138584*^9, 
   3.814531346480895*^9, 3.8158436319321766`*^9, 3.816449474867936*^9, 
   3.816931217418989*^9, 3.8181665549620476`*^9, 3.8182646978205104`*^9, 
   3.8185235296973515`*^9, 3.818523686333588*^9, 3.8185241886190386`*^9, 
   3.81873074167765*^9, 3.8187630805802193`*^9, 3.818834536955236*^9, 
   3.8188433498760777`*^9, 3.8189050532910433`*^9, 3.819299810957508*^9, 
   3.840521411975814*^9, 3.840525982452465*^9, 3.8405564140812397`*^9, 
   3.840556586535407*^9, 3.8405566276890783`*^9, 3.8410704223583803`*^9, 
   3.841072395724016*^9, 3.841072431710894*^9, 3.841900688817651*^9, 
   3.841900812596508*^9},
 CellLabel->
  "Out[121]=",ExpressionUUID->"2e3eb959-6382-449e-9199-42cde9f5c7cc"]
}, Open  ]],

Cell["\<\
Dividing the orders of the solution by orders of a1. The leading order, i.e. \
O(a1=0):\
\>", "Text",
 CellChangeTimes->{{3.8114394860951257`*^9, 3.81143949536876*^9}, {
  3.814529303318799*^9, 
  3.81452932405183*^9}},ExpressionUUID->"496eccd0-a2b5-4433-b40c-\
dc24aa75b7ed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GEqLeadingOrder", "=", 
  RowBox[{"GetEquationListOrder", "[", 
   RowBox[{
    FormBox["GAsymptoticExpList",
     TraditionalForm], ",", "0", ",", "a1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.811439001069614*^9, 3.8114390065762935`*^9}, {
  3.8114390452180414`*^9, 3.811439047726551*^9}},
 CellLabel->
  "In[122]:=",ExpressionUUID->"60a71ef5-7ff1-4714-9deb-a91d1450eda9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "K2"}], " ", "Pin", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "-", 
    RowBox[{"K2", " ", 
     RowBox[{"G0", "[", "X", "]"}]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["G0", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "12"]}], "\[Equal]", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.8114390486466813`*^9, 3.811439069308934*^9}, 
   3.811502838910159*^9, 3.811569722179829*^9, 3.8115698215241156`*^9, 
   3.8115701631036186`*^9, {3.811572506069109*^9, 3.8115725267189436`*^9}, {
   3.8115725676184855`*^9, 3.8115725921081767`*^9}, 3.8115841604274406`*^9, 
   3.8115846406134477`*^9, 3.811586010919042*^9, 3.81158607199529*^9, 
   3.811610133562772*^9, 3.811753738833995*^9, 3.8121964099501457`*^9, 
   3.8122567001007247`*^9, 3.8122773037192817`*^9, 3.812879629379691*^9, 
   3.812879980844567*^9, 3.8133996635661955`*^9, 3.8133998162045164`*^9, 
   3.8134229996150293`*^9, 3.813424619432272*^9, 3.813684512348214*^9, 
   3.813924899774064*^9, 3.8139912602512274`*^9, 3.8140145756994576`*^9, 
   3.8140284819333878`*^9, 3.8140301054443026`*^9, 3.814030417550082*^9, 
   3.814068343596607*^9, 3.8143727052862244`*^9, 3.8145220907062016`*^9, 
   3.8145268122001762`*^9, 3.8145313465347505`*^9, 3.815843631987998*^9, 
   3.8164494749229054`*^9, 3.816931217463962*^9, 3.818166555007022*^9, 
   3.818264700273092*^9, 3.8185235297353344`*^9, 3.8185236863955708`*^9, 
   3.8185241886730075`*^9, 3.8187307417116294`*^9, 3.818763080639186*^9, 
   3.818834537012187*^9, 3.8188433499270487`*^9, 3.8189050533535337`*^9, 
   3.8192998110679374`*^9, 3.840521412022687*^9, 3.840525982514428*^9, 
   3.8405564141437545`*^9, 3.8405565865979023`*^9, 3.840556627751594*^9, 
   3.8410704224123507`*^9, 3.8410723957865286`*^9, 3.8410724318222523`*^9, 
   3.8419006889855537`*^9, 3.841900812760412*^9},
 CellLabel->
  "Out[122]=",ExpressionUUID->"3b4bffcc-62d0-47c4-b491-bd7430869007"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"FullSimplify", "[", "GEqLeadingOrder", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.8182647043613005`*^9, 3.818264716069271*^9}},
 CellLabel->
  "In[123]:=",ExpressionUUID->"c1b3225b-2b62-4dff-a259-cfe77e5225c8"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{"12", " ", "K2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Pin", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", "G0"}], ")"}]}], 
         "\[LongEqual]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "G0"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["X", "2"]}],
          MultilineFunction->None]}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008130542417`*^9},
 TextAlignment->Center,ExpressionUUID->"c84673dd-4e26-4b0a-96c0-0bee88d9bfbc"]
}, Open  ]],

Cell[TextData[{
 StyleBox["As expected, same as the case for a1=0:",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[0.87, 0.94, 1]],
 "\n\n",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["G20", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "X", "]"}], "12"], "\[Equal]", 
   RowBox[{"K2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Pin", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
      RowBox[{"G20", "[", "X", "]"}]}], ")"}]}]}]],ExpressionUUID->
  "83e8234a-c914-4e0a-9415-488c8659c4af"]
}], "Text",
 CellChangeTimes->{{3.8114390775485096`*^9, 3.8114390965457172`*^9}, 
   3.8182648899826984`*^9},ExpressionUUID->"e4010405-13f9-47d9-a530-\
92619386460c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GEq1stOrder", "=", 
  RowBox[{"GetEquationListOrder", "[", 
   RowBox[{
    FormBox["GAsymptoticExpList",
     TraditionalForm], ",", "1", ",", "a1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.811438772603104*^9, 3.8114387939448366`*^9}, {
  3.811439129331417*^9, 3.811439135843485*^9}},
 CellLabel->
  "In[124]:=",ExpressionUUID->"aed394fe-8f46-4749-88a8-2242db99fe37"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "K2"}], " ", 
     RowBox[{"G1", "[", "X", "]"}]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["G0", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "4"], "+", 
    RowBox[{
     FractionBox["1", "4"], " ", "X", " ", 
     RowBox[{
      SuperscriptBox["G0", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["G1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "12"]}], "\[Equal]", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.811439137579496*^9, 3.8115002660800457`*^9, 3.8115028515941267`*^9, 
   3.8115697222267027`*^9, 3.8115698215709867`*^9, 3.8115704061940236`*^9, {
   3.811572506173049*^9, 3.811572530062451*^9}, 3.8115725946700635`*^9, 
   3.8115841605153823`*^9, 3.8115846407093925`*^9, 3.8115860110060945`*^9, 
   3.811586072070263*^9, 3.811610133640914*^9, 3.8117537389389343`*^9, 
   3.812196410028286*^9, 3.8122567001477146`*^9, 3.8122773037817764`*^9, 
   3.8128796294674664`*^9, 3.8128799809564037`*^9, 3.8133996636286855`*^9, 
   3.8133998162826366`*^9, 3.813422999693127*^9, 3.8134246194947624`*^9, 
   3.8136845124575853`*^9, 3.8139248998573265`*^9, 3.813991260298098*^9, 
   3.814014575751151*^9, 3.814028481998114*^9, 3.814030105492273*^9, 
   3.814030417596405*^9, 3.8140683436205783`*^9, 3.8143727053195057`*^9, 
   3.81452209075917*^9, 3.8145268122538023`*^9, 3.8145313465866117`*^9, 
   3.815843632039996*^9, 3.8164494749628816`*^9, 3.816931217510954*^9, 
   3.8181665550550094`*^9, 3.818264927803576*^9, 3.8185235298472643`*^9, 
   3.8185236865474634`*^9, 3.818524188783929*^9, 3.8187307418235693`*^9, 
   3.818763080761115*^9, 3.818834537151187*^9, 3.818843350190895*^9, 
   3.8189050535097733`*^9, 3.8192998112287445`*^9, 3.8405214121523647`*^9, 
   3.8405259826563463`*^9, 3.8405564142999926`*^9, 3.840556589333725*^9, 
   3.840556627957698*^9, 3.8410704225772543`*^9, 3.841072395942747*^9, 
   3.8410724325064383`*^9, 3.841900689343348*^9, 3.8419008132211456`*^9},
 CellLabel->
  "Out[124]=",ExpressionUUID->"37785ca8-44b3-410e-a048-71fcd30398a9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"FullSimplify", "[", "GEq1stOrder", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.818264933756358*^9, 3.8182649444774437`*^9}},
 CellLabel->
  "In[125]:=",ExpressionUUID->"19b3f89e-1406-4d8b-a6b5-003fc6aeec62"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{"12", " ", "K2", " ", "G1"}], "\[LongEqual]", 
         RowBox[{
          RowBox[{"3", " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "G0"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          RowBox[{"3", " ", "X", " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "G0"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["X", "2"]}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "G1"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["X", "2"]}],
           MultilineFunction->None]}]}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900813336079*^9},
 TextAlignment->Center,ExpressionUUID->"022b485f-dccf-484c-97d0-4524f22d90b8"]
}, Open  ]],

Cell["\<\
Solving by orders.
First, leading order:\
\>", "Text",
 CellChangeTimes->{
  3.8114391540544834`*^9, {3.811439332357278*^9, 3.8114393873752427`*^9}, {
   3.8114395090408506`*^9, 3.811439581234185*^9}, 
   3.8114396243273487`*^9},ExpressionUUID->"9adc5520-632c-4d6a-8daf-\
04a09f11b4b0"],

Cell["Boundary conditions:", "Text",
 CellChangeTimes->{{3.8114395564298697`*^9, 
  3.811439586641179*^9}},ExpressionUUID->"501f3f7e-058d-4ef1-92d6-\
668bee51b880"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"G0BC1", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"G0", "[", "X", "]"}], ",", "X"}], "]"}], "\[Equal]", "0"}]}], 
  ";", 
  RowBox[{"G0BC1", "=", 
   RowBox[{"G0BC1", "//.", 
    RowBox[{"X", "\[Rule]", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G0BC2", "=", 
   RowBox[{
    RowBox[{"G0", "[", "1", "]"}], "\[Equal]", "0"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.811439187778887*^9, 3.811439190050357*^9}, {
   3.811439226958647*^9, 3.811439255806573*^9}, {3.811439286724909*^9, 
   3.8114393055401497`*^9}, {3.811503124699829*^9, 3.811503243955907*^9}, 
   3.8115663638292274`*^9, {3.811572804716675*^9, 3.8115728096396465`*^9}, {
   3.811578021926806*^9, 3.8115780265182943`*^9}},
 CellLabel->
  "In[126]:=",ExpressionUUID->"3e2d1db6-17f3-4005-9979-b23c0035991f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FuncG0", "[", "X_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"DSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"GEqLeadingOrder", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "G0BC1", ",", "G0BC2"}], 
         "}"}], ",", 
        RowBox[{"G0", "[", "X", "]"}], ",", 
        RowBox[{"{", "X", "}"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8114393951767406`*^9, 3.8114394503637342`*^9}, {
   3.8114396468194385`*^9, 3.8114396499851875`*^9}, {3.8114397638340435`*^9, 
   3.811439781230129*^9}, {3.8115029687284737`*^9, 3.8115030150142593`*^9}, 
   3.8115030488684945`*^9},
 CellLabel->
  "In[128]:=",ExpressionUUID->"9bab43ea-0633-4536-9b9a-3b0057a159f0"],

Cell[BoxData[
 FractionBox[
  RowBox[{"Pin", " ", 
   RowBox[{"(", 
    RowBox[{"6", "-", 
     FractionBox[
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "X"}], ")"}]}]]}], 
      SqrtBox["K2"]], "+", 
     FractionBox[
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", "X"}]]}], 
      SqrtBox["K2"]], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"4", " ", 
        SqrtBox["3"], " ", 
        SqrtBox["K2"]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "-", 
     RowBox[{"6", " ", "X"}]}], ")"}]}], 
  RowBox[{"6", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"4", " ", 
       SqrtBox["3"], " ", 
       SqrtBox["K2"]}]]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.8114394169303813`*^9, 3.8114394508976755`*^9}, {
   3.8114396317675195`*^9, 3.811439650988019*^9}, {3.8114397661217117`*^9, 
   3.8114397871379414`*^9}, 3.811502860468746*^9, {3.8115029802113085`*^9, 
   3.811503015559553*^9}, 3.8115030493644714`*^9, 3.811566403760577*^9, 
   3.8115697225860653`*^9, 3.811569821945959*^9, 3.811570415145503*^9, 
   3.8115725066208096`*^9, 3.8115726560145626`*^9, 3.8115779282138567`*^9, 
   3.8115779843564777`*^9, 3.8115841608691783`*^9, 3.811584641102165*^9, 
   3.811586022624236*^9, 3.8115860724260535`*^9, 3.8116101339846153`*^9, 
   3.811753739307723*^9, 3.812196410367813*^9, 3.8122567004665136`*^9, 
   3.812277304078647*^9, 3.812879629837989*^9, 3.812879981657755*^9, 
   3.8133996639724064`*^9, 3.813399816595111*^9, 3.813422999974354*^9, 
   3.8134246198201027`*^9, 3.813684512801303*^9, 3.8139249002493563`*^9, 
   3.8139912605793447`*^9, 3.814014576073715*^9, 3.814028482289137*^9, 
   3.8140301058300776`*^9, 3.8140304179219723`*^9, 3.8140683438205147`*^9, 
   3.814372705638543*^9, 3.814522091074986*^9, 3.8145268125353336`*^9, 
   3.81453134699851*^9, 3.815843632348184*^9, 3.8164494752827168`*^9, 
   3.816931217789774*^9, 3.818166555363815*^9, 3.8182651333175173`*^9, 
   3.818523530214053*^9, 3.8185236870321217`*^9, 3.8185241891829786`*^9, 
   3.8187307422213545`*^9, 3.8187630811549063`*^9, 3.818834537546172*^9, 
   3.8188433505836697`*^9, 3.8189050539441967`*^9, 3.8192998117558203`*^9, 
   3.840521412601019*^9, 3.840525983053135*^9, 3.840556414669612*^9, 
   3.8405566283951645`*^9, 3.841070423051978*^9, 3.8410723963646092`*^9, 
   3.841072433420947*^9, 3.841900690015959*^9, 3.84190081392074*^9},
 CellLabel->
  "Out[128]=",ExpressionUUID->"341ff39e-fc07-4008-b096-d07f9d282b5c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"FuncG0", "[", "X", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.818265147700923*^9, 3.818265165241325*^9}, {
  3.8182653259984255`*^9, 3.818265332730894*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"5070d449-6928-41e0-88a3-eb49f849ae18"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    FractionBox[
     RowBox[{"Pin", " ", 
      RowBox[{"(", 
       RowBox[{"6", "-", 
        FractionBox[
         RowBox[{
          SqrtBox["3"], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "X"}], ")"}]}]]}], 
         SqrtBox["K2"]], "+", 
        FractionBox[
         RowBox[{
          SqrtBox["3"], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]]}], 
         SqrtBox["K2"]], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "-", 
        RowBox[{"6", " ", "X"}]}], ")"}]}], 
     RowBox[{"6", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}]}]],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008156817255`*^9},
 TextAlignment->Center,ExpressionUUID->"40b7de70-a814-4871-b9ba-d18c51dd2621"]
}, Open  ]],

Cell["Checking BC for G0:", "Text",
 CellChangeTimes->{{3.811578041392433*^9, 3.811578045091173*^9}, {
  3.8115780801117315`*^9, 
  3.8115780828264284`*^9}},ExpressionUUID->"4d231278-2089-405e-b85e-\
6ac138c0d650"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FuncG0", "[", "X", "]"}], "/.", 
  RowBox[{"X", "\[Rule]", "1"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"FuncG0", "[", "X", "]"}], ",", "X"}], "]"}], "//.", 
  RowBox[{"X", "\[Rule]", "0"}]}]}], "Input",
 CellChangeTimes->{{3.8115779169670134`*^9, 3.811577920625531*^9}, {
  3.811577974239809*^9, 3.8115780357075634`*^9}, {3.8115780927937403`*^9, 
  3.8115780929896293`*^9}},
 CellLabel->
  "In[130]:=",ExpressionUUID->"f96244cf-58b0-4f95-bf55-cbcc80088932"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8115779212504225`*^9, 3.8115779303846827`*^9}, {
   3.8115779759714937`*^9, 3.8115780360723457`*^9}, 3.8115780933064446`*^9, 
   3.811584160951131*^9, 3.8115846411781216`*^9, 3.8115860229460325`*^9, 
   3.811586072514989*^9, 3.81161013407836*^9, 3.811753739413662*^9, 
   3.8121964104307785`*^9, 3.812256700513487*^9, 3.812277304141148*^9, 
   3.8128796298981853`*^9, 3.8128799818821487`*^9, 3.8133996640505285`*^9, 
   3.813399816673251*^9, 3.8134230000524845`*^9, 3.8134246198826013`*^9, 
   3.813684512863798*^9, 3.8139249003992963`*^9, 3.8139912606105947`*^9, 
   3.81401457615248*^9, 3.8140284823616357`*^9, 3.814030105876051*^9, 
   3.81403041797793*^9, 3.81406834384149*^9, 3.814372705701043*^9, 
   3.8145220911389503`*^9, 3.8145268125934105`*^9, 3.814531347050372*^9, 
   3.8158436324329233`*^9, 3.816449475320695*^9, 3.816931217827771*^9, 
   3.818166555444769*^9, 3.81826546233885*^9, 3.81852353119547*^9, 
   3.8185236880498753`*^9, 3.8185241901555347`*^9, 3.8187307431717887`*^9, 
   3.8187630821593266`*^9, 3.8188345385543284`*^9, 3.818843351634081*^9, 
   3.818905054912878*^9, 3.8192998130970826`*^9, 3.8405214135838842`*^9, 
   3.840525984060542*^9, 3.8405564156460314`*^9, 3.8405566293482394`*^9, 
   3.841070424150344*^9, 3.841072397348892*^9, 3.841072434604184*^9, 
   3.841900691842903*^9, 3.8419008158246417`*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"eb901842-9fe8-47c4-a872-0c8fca515de8"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8115779212504225`*^9, 3.8115779303846827`*^9}, {
   3.8115779759714937`*^9, 3.8115780360723457`*^9}, 3.8115780933064446`*^9, 
   3.811584160951131*^9, 3.8115846411781216`*^9, 3.8115860229460325`*^9, 
   3.811586072514989*^9, 3.81161013407836*^9, 3.811753739413662*^9, 
   3.8121964104307785`*^9, 3.812256700513487*^9, 3.812277304141148*^9, 
   3.8128796298981853`*^9, 3.8128799818821487`*^9, 3.8133996640505285`*^9, 
   3.813399816673251*^9, 3.8134230000524845`*^9, 3.8134246198826013`*^9, 
   3.813684512863798*^9, 3.8139249003992963`*^9, 3.8139912606105947`*^9, 
   3.81401457615248*^9, 3.8140284823616357`*^9, 3.814030105876051*^9, 
   3.81403041797793*^9, 3.81406834384149*^9, 3.814372705701043*^9, 
   3.8145220911389503`*^9, 3.8145268125934105`*^9, 3.814531347050372*^9, 
   3.8158436324329233`*^9, 3.816449475320695*^9, 3.816931217827771*^9, 
   3.818166555444769*^9, 3.81826546233885*^9, 3.81852353119547*^9, 
   3.8185236880498753`*^9, 3.8185241901555347`*^9, 3.8187307431717887`*^9, 
   3.8187630821593266`*^9, 3.8188345385543284`*^9, 3.818843351634081*^9, 
   3.818905054912878*^9, 3.8192998130970826`*^9, 3.8405214135838842`*^9, 
   3.840525984060542*^9, 3.8405564156460314`*^9, 3.8405566293482394`*^9, 
   3.841070424150344*^9, 3.841072397348892*^9, 3.841072434604184*^9, 
   3.841900691842903*^9, 3.8419008158346357`*^9},
 CellLabel->
  "Out[131]=",ExpressionUUID->"cb546211-5c8c-451b-bad9-dafa8d9c8e5d"]
}, Open  ]],

Cell["Next, solving the 1st order :", "Text",
 CellChangeTimes->{{3.8115782979636364`*^9, 3.8115783144963207`*^9}, {
  3.811578599221219*^9, 
  3.8115785999194345`*^9}},ExpressionUUID->"1af0b669-a63b-4b39-9542-\
02946527a5e5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"G1BC1", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"G1", "[", "X", "]"}], ",", "X"}], "]"}], "\[Equal]", "0"}]}], 
  ";", 
  RowBox[{"G1BC1", "=", 
   RowBox[{"G1BC1", "//.", 
    RowBox[{"X", "\[Rule]", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G1BC2", "=", 
   RowBox[{
    RowBox[{"G1", "[", "1", "]"}], "\[Equal]", "0"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.811578472243778*^9, {3.8137701417483397`*^9, 3.813770142748267*^9}},
 CellLabel->
  "In[132]:=",ExpressionUUID->"eb4c3a90-b9b5-441c-b414-d0658c458bc2"],

Cell["Substituting G0 into the exp. for the 1st order:", "Text",
 CellChangeTimes->{{3.8115784109933715`*^9, 3.8115784244068346`*^9}, {
  3.8115785922197847`*^9, 
  3.811578596136614*^9}},ExpressionUUID->"9e6f65df-5039-4d4a-93da-\
1ada59945b58"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GEq1stOrder1", "=", 
  RowBox[{"GEq1stOrder", "//.", 
   RowBox[{"G0", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"X", ",", 
      RowBox[{"FuncG0", "[", "X", "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8115029551550903`*^9, 3.81150298600288*^9}, {
  3.811503058091911*^9, 3.8115030665468287`*^9}, {3.811503284661544*^9, 
  3.81150329502614*^9}},
 CellLabel->
  "In[134]:=",ExpressionUUID->"484ba47c-5470-49eb-abea-de2f06249b06"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "6"}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "X"}], ")"}]}]]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]]}]}], ")"}], " ", "Pin"}], 
     RowBox[{"24", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "12"}], " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "X"}], ")"}]}]], " ", 
         SqrtBox["K2"]}], "+", 
        RowBox[{"12", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", 
         SqrtBox["K2"]}]}], ")"}], " ", "Pin", " ", "X"}], 
     RowBox[{"24", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}]}]], "-", 
    RowBox[{"K2", " ", 
     RowBox[{"G1", "[", "X", "]"}]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["G1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "12"]}], "\[Equal]", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.8115029864952316`*^9, 3.8115030699799547`*^9, {3.8115032866081505`*^9, 
   3.8115032955882006`*^9}, 3.8115664137428255`*^9, 3.811569722632944*^9, 
   3.811569821992834*^9, 3.8115704174607143`*^9, 3.8115725067137365`*^9, 
   3.8115726592982674`*^9, 3.8115781463179283`*^9, 3.8115786024332523`*^9, 
   3.8115841610470552`*^9, 3.8115846413126383`*^9, 3.8115860240663958`*^9, 
   3.8115860726010284`*^9, 3.811610134172102*^9, 3.8117537395625753`*^9, 
   3.8121964105127306`*^9, 3.8122567005794473`*^9, 3.81227730420364*^9, 
   3.8128796300071926`*^9, 3.8128799820428753`*^9, 3.8133996641286645`*^9, 
   3.813399816751356*^9, 3.8134230001149817`*^9, 3.81342461996072*^9, 
   3.8136845129887896`*^9, 3.8139249005052967`*^9, 3.813991260673089*^9, 
   3.814014576257183*^9, 3.8140284824336014`*^9, 3.814030105943031*^9, 
   3.8140304180693064`*^9, 3.8140683438793583`*^9, 3.8143727057479153`*^9, 
   3.814522091204911*^9, 3.814526812667473*^9, 3.814531347148117*^9, 
   3.815843632499153*^9, 3.8164494753796415`*^9, 3.816931217901728*^9, 
   3.8181665555057354`*^9, 3.818265466350698*^9, 3.8185235312634115`*^9, 
   3.8185236881428366`*^9, 3.818524190217517*^9, 3.8187307432347507`*^9, 
   3.8187630822452583`*^9, 3.8188345386702614`*^9, 3.8188433517190127`*^9, 
   3.8189050549910307`*^9, 3.8192998131870856`*^9, 3.840521413662022*^9, 
   3.84052598415648*^9, 3.840556415739791*^9, 3.840556629457588*^9, 
   3.841070424230316*^9, 3.8410723973801594`*^9, 3.8410724346666784`*^9, 
   3.841900692070772*^9, 3.8419008159385757`*^9},
 CellLabel->
  "Out[134]=",ExpressionUUID->"130e8f60-f2d7-4e81-9b39-50c0429df9ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"FullSimplify", "[", "GEq1stOrder1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.818265481536827*^9, 3.8182654914017954`*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"c9d082aa-8440-4285-914c-8f3c6e0a4cb8"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox["1", "12"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"4", " ", 
                  SqrtBox["3"], " ", 
                  SqrtBox["K2"]}]], "+", 
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  SqrtBox["3"], " ", 
                  SqrtBox["K2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "X"}], ")"}]}]], "+", 
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"2", " ", 
                  SqrtBox["3"], " ", 
                  SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", "Pin"}], 
             RowBox[{"1", "+", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox["K2"]}]]}]], "+", 
            FractionBox[
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                SqrtBox["3"], " ", 
                SqrtBox["K2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", "X"}], ")"}]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"4", " ", 
                  SqrtBox["3"], " ", 
                  SqrtBox["K2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "X"}], ")"}]}]]}], ")"}], " ", 
              SqrtBox["K2"], " ", "Pin", " ", "X"}], 
             RowBox[{"1", "+", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox["K2"]}]]}]], "+", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[PartialD]", "2"], "G1"}], 
             RowBox[{"\[PartialD]", 
              SuperscriptBox["X", "2"]}],
             MultilineFunction->None], "-", 
            RowBox[{"12", " ", "K2", " ", "G1"}]}], ")"}]}], "\[LongEqual]", 
         "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900824355212*^9},
 TextAlignment->Center,ExpressionUUID->"813b80c4-cb8d-4ef7-9653-99e1281d7b55"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FuncG1", "[", "X_", "]"}],
   FontWeight->"Bold"], 
  StyleBox["=",
   FontWeight->"Bold"], 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"DSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"GEq1stOrder1", ",", "G1BC1", ",", "G1BC2"}], "}"}], ",", 
         RowBox[{"G1", "[", "X", "]"}], ",", 
         RowBox[{"{", "X", "}"}]}], "]"}], ",", "AssumptionOnScaling"}], 
      "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8115028916415277`*^9, 3.811502930082323*^9}, 
   3.81150310116405*^9, {3.811503302137255*^9, 3.811503352289175*^9}, {
   3.811578519620288*^9, 3.8115785202209344`*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"69c9606b-b338-482e-94e3-d5a23b6d54c6"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"16", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}], "2"], " ", "K2"}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"2", " ", 
      SqrtBox["3"], " ", 
      SqrtBox["K2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "-", 
        RowBox[{"3", " ", "X"}]}], ")"}]}]], " ", "Pin", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"6", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", "X"}]]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"], " ", "X"}], "+", 
         RowBox[{"12", " ", "K2", " ", 
          SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"], " ", "X"}], "+", 
         RowBox[{"12", " ", "K2", " ", 
          SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", "X"}]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"], " ", "X"}], "+", 
         RowBox[{"12", " ", "K2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"8", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", "X"}]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"], " ", "X"}], "+", 
         RowBox[{"12", " ", "K2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwBuICLp7Zd1PfOLIu5V4Iop+0def8AdLTdd04/gHpDTdX
iIDoOVskEkG0/5Z9yf+BtNyc+nIQ/aK8QpUp7Y0jg9GVWBB9JVhdlBVIx7aa
BoLpyZ//gujNVWIsbEBaddnWw4JAupeh/lE4kK69nsphkP7GMer1jApfIL26
/ld7OJDWSJNeXJvxxnHJB9XzIPrY3T991ZlvHB9qcywC0bfNX39uA9L//Ir2
tQPpNh2JpWxZbxxFwqex1gDpfwL1OXOANJv3v3PLgfS2+oSZ64A0y7WAlPVA
em+iYzeINszewn8ISKeU6a8Ny37jGMKVNG8+kM5i636zEEj36jYqLwHSf9L+
P1PJe+N4TzFjp0/+G8dVj/w+mxcA7QnKUplc9Mbxe6Vl4WEgzaalU+xY/MZR
ds2mNhDtkZ91FEQ3zaxfsAxIr7j7KWsbkI6y+e13E0jr8T+dcxdI/zhbs/c3
kJbn/lK3pwTIXxQ2y2zuG0eFu0uuWgBpTqf6je5A+nGP9RkQff/bpjVO84Dh
dcd6hTOQ/qe2WfTG/DeOCUY7VEA0AA9I9Cs=
  "],
 CellLabel->
  "Out[136]=",ExpressionUUID->"1f66bcc6-47b0-4f3c-8ff6-a4539165e722"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"FullSimplify", "[", 
   StyleBox[
    RowBox[{"FuncG1", "[", "X", "]"}],
    FontWeight->"Bold"], 
   StyleBox["]",
    FontWeight->"Bold"]}], 
  StyleBox["]",
   FontWeight->"Bold"]}]], "Input",
 CellChangeTimes->{{3.818265552097291*^9, 3.8182655586159897`*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"badf32ce-57c4-478b-9e32-8495e0c0223b"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"16", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"]}]]}], ")"}], "2"], " ", "K2"}]], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           RowBox[{"3", " ", "X"}]}], ")"}]}]], " ", "Pin", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", 
              RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"8", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008423772974`*^9},
 TextAlignment->Center,ExpressionUUID->"fed567e7-82ab-4650-abfc-26711c602d7a"]
}, Open  ]],

Cell["Checking BC for G1 :", "Text",
 CellChangeTimes->{{3.8115799386441107`*^9, 
  3.8115799516164217`*^9}},ExpressionUUID->"db7e8bae-5db9-4da1-9c48-\
954c70aacda6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"FuncG1", "[", "X", "]"}], "/.", 
   RowBox[{"X", "\[Rule]", "1"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"FuncG1", "[", "X", "]"}], ",", "X"}], "]"}], "//.", 
   RowBox[{"X", "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.811579696165785*^9, 3.811579706421736*^9}},
 CellLabel->
  "In[138]:=",ExpressionUUID->"af88c069-fee0-4735-9c8c-8eb6e5503bc8"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA+J9d//3VWe+cbyszb0IRK/Z/u5zG5A+5Ve6rx1I5+nI
LWXLeuN4Z+Ys1hog/UGgMWcOkGa4zXR+OZAu802duQ5Ih2mGpKwH0jNk3bpB
9Pa2bfyHgDTHacO1YdlA/RdS580H0iHWvW8WAukXq9uVlwBpv7eMz1Xy3jhe
icva6ZP/xvHWt4DP5gVvHK+l5KpMLnrjmPxYbtYRIP3qdn2xY/EbxwknWNpB
tHvjvqMg+mvO+QXLgHRvu1v2NiCd4eHnfxNIL8rznnsXSGcfvrD3N5D+szWr
fk/JG0e5Tytmmc0F0i9/XLUA0suzLm50B9JrHLrOgGiXVPa1TvPeOP761L/C
GUj3//cTuzEf6M+GIFUQDQBwmqWo
  "],
 CellLabel->
  "Out[138]=",ExpressionUUID->"4e988f3c-b9e8-4096-8768-1f4972cacf8c"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA+J9d//3VWe+cbyszb0IRK/Z/u5zG5A+5Ve6rx1I5+nI
LWXLeuN4Z+Ys1hog/UGgMWcOkGa4zXR+OZAu802duQ5Ih2mGpKwH0jNk3bpB
9Pa2bfyHgDTHacO1YdlA/RdS580H0iHWvW8WAukXq9uVlwBpv7eMz1Xy3jhe
icva6ZP/xvHWt4DP5gVvHK+l5KpMLnrjmPxYbtYRIP3qdn2xY/EbxwknWNpB
tHvjvqMg+mvO+QXLgHRvu1v2NiCd4eHnfxNIL8rznnsXSGcfvrD3N5D+szWr
fk/JG0e5Tytmmc0F0i9/XLUA0suzLm50B9JrHLrOgGiXVPa1TvPeOP761L/C
GUj3//cTuzH/jeOxnUGqIBoAdKmmMQ==
  "],
 CellLabel->
  "Out[139]=",ExpressionUUID->"6b236e8c-ef27-4fbc-9652-6c0093aef468"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FuncG01", "[", "X_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"FuncG0", "[", "X", "]"}], "+", 
    RowBox[{"a1", " ", 
     StyleBox[
      RowBox[{"FuncG1", "[", "X", "]"}],
      FontWeight->"Bold"]}]}], 
   StyleBox["]",
    FontWeight->"Bold"]}]}]], "Input",
 CellChangeTimes->{{3.8128806923921213`*^9, 3.812880743857813*^9}, {
  3.8419007690377913`*^9, 3.8419007703900104`*^9}},
 CellLabel->
  "In[140]:=",ExpressionUUID->"78686682-2900-4218-a69a-d982ee236eac"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"48", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"]}]]}], ")"}], "2"]}]], 
  RowBox[{"Pin", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"6", "-", 
        FractionBox[
         RowBox[{
          SqrtBox["3"], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "X"}], ")"}]}]]}], 
         SqrtBox["K2"]], "+", 
        FractionBox[
         RowBox[{
          SqrtBox["3"], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]]}], 
         SqrtBox["K2"]], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "-", 
        RowBox[{"6", " ", "X"}]}], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "K2"], 
      RowBox[{"3", " ", "a1", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           RowBox[{"3", " ", "X"}]}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", 
              RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"8", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.8115781589480357`*^9, 3.8115786376344743`*^9, {3.811579700214159*^9, 
   3.8115797067618856`*^9}, 3.8115841694068813`*^9, 3.8115846498144464`*^9, 
   3.811586080896215*^9, 3.8116101418327513`*^9, 3.8117537481327415`*^9, 
   3.812196419288494*^9, 3.812256708878668*^9, 3.812277311968684*^9, 
   3.8128796411616645`*^9, 3.8128799935435457`*^9, 3.812880730775922*^9, 
   3.812880814452427*^9, 3.8133997061032176`*^9, 3.8133998566714735`*^9, 
   3.8134230395789747`*^9, 3.813424660462208*^9, 3.813684553839303*^9, 
   3.8139249454475975`*^9, 3.8139913003073573`*^9, 3.8140146175267653`*^9, 
   3.8140285263605785`*^9, 3.814030154984333*^9, 3.81403045996208*^9, 
   3.8140683756174507`*^9, 3.814372748371741*^9, 3.814522135225769*^9, 
   3.814526854844812*^9, 3.814531397834553*^9, 3.81584367244786*^9, 
   3.8164495177603016`*^9, 3.8169312633085756`*^9, 3.818166597677952*^9, 
   3.8182678946385603`*^9, 3.818523581295758*^9, 3.818523736552604*^9, 
   3.818524238877847*^9, 3.818730790838414*^9, 3.8187631302975235`*^9, 
   3.8188345866131105`*^9, 3.8188434049961805`*^9, 3.818905101695305*^9, 
   3.8192998824975176`*^9, 3.840521465151535*^9, 3.8405260322477226`*^9, 
   3.840556460813102*^9, 3.8405566745623474`*^9, 3.8410704741230106`*^9, 
   3.841072488623803*^9, 3.841900843536628*^9},
 CellLabel->
  "Out[140]=",ExpressionUUID->"d67f1be9-d987-47b1-b661-0a60707357d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FuncG201", "[", "X_", "]"}], "=", 
  RowBox[{"FuncG01", "[", "X", "]"}]}]], "Input",
 CellChangeTimes->{{3.8137703143092985`*^9, 3.813770323232106*^9}},
 CellLabel->
  "In[141]:=",ExpressionUUID->"5a94bb6c-4ec2-4451-8929-bdd467dec7a1"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"48", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"]}]]}], ")"}], "2"]}]], 
  RowBox[{"Pin", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"6", "-", 
        FractionBox[
         RowBox[{
          SqrtBox["3"], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "X"}], ")"}]}]]}], 
         SqrtBox["K2"]], "+", 
        FractionBox[
         RowBox[{
          SqrtBox["3"], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]]}], 
         SqrtBox["K2"]], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "-", 
        RowBox[{"6", " ", "X"}]}], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "K2"], 
      RowBox[{"3", " ", "a1", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           RowBox[{"3", " ", "X"}]}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", 
              RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"8", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.8137703255287504`*^9, 3.8139249455589604`*^9, 
  3.8139913003698554`*^9, 3.8140146176686845`*^9, 3.81402852648481*^9, 
  3.814030155059291*^9, 3.8140304600933704`*^9, 3.8140683756742983`*^9, 
  3.8143727484811068`*^9, 3.8145221353357077`*^9, 3.814526854929762*^9, 
  3.814531397958218*^9, 3.815843672538124*^9, 3.816449517845233*^9, 
  3.8169312634891195`*^9, 3.8181665977589045`*^9, 3.818267894759509*^9, 
  3.8185235813607197`*^9, 3.8185237366375556`*^9, 3.8185242389637985`*^9, 
  3.8187307908943825`*^9, 3.8187631303944674`*^9, 3.818834586709055*^9, 
  3.818843405096137*^9, 3.8189051018359013`*^9, 3.8192998826311703`*^9, 
  3.8405214652609215`*^9, 3.8405260323406515`*^9, 3.840556460922469*^9, 
  3.840556674671711*^9, 3.8410704742049646`*^9, 3.841072488698759*^9, 
  3.841900843773491*^9},
 CellLabel->
  "Out[141]=",ExpressionUUID->"88a9ff7e-e8f3-4925-8790-fb67d6e1cae7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"FuncG201", "[", "X", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.8182678847456455`*^9, 3.818267885726079*^9}},
 CellLabel->
  "In[142]:=",ExpressionUUID->"424dce56-ac77-43e3-a90c-9e5bd6fdde29"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"48", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]]}], ")"}], "2"]}]], 
     RowBox[{"Pin", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"8", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"6", "-", 
           FractionBox[
            RowBox[{
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "X"}], ")"}]}]]}], 
            SqrtBox["K2"]], "+", 
           FractionBox[
            RowBox[{
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}]]}], 
            SqrtBox["K2"]], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "-", 
           RowBox[{"6", " ", "X"}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["1", "K2"], 
         RowBox[{"3", " ", "a1", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"2", "-", 
              RowBox[{"3", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox["K2"], " ", "X"}], "+", 
               RowBox[{"12", " ", "K2", " ", 
                SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox["K2"], " ", "X"}], "+", 
               RowBox[{"12", " ", "K2", " ", 
                SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox["K2"], " ", "X"}], "+", 
               RowBox[{"12", " ", "K2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", 
                  SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"8", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox["K2"], " ", "X"}], "+", 
               RowBox[{"12", " ", "K2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", 
                  SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}]}], ")"}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008439134097`*^9},
 TextAlignment->Center,ExpressionUUID->"65988657-9657-457c-b627-0347010923a4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Back to analysis - First order 2nd region",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.8115696631858234`*^9, 3.8115696714741917`*^9}, {
  3.8122559831770115`*^9, 
  3.8122559889706707`*^9}},ExpressionUUID->"b7215235-202b-4966-80ad-\
15eb8082e06f"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList2LeadingOrder1", "=", 
   RowBox[{"FullSimplify", "[", "EquationList2LeadingOrder", "]"}]}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.812880328489509*^9, 3.812880339357357*^9}},
 CellLabel->
  "In[143]:=",ExpressionUUID->"590abef7-28f2-439a-ad69-91f7b209c4b1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", 
   RowBox[{
    RowBox[{"12", " ", "K2", " ", "w", " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Pin", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
       RowBox[{"G20", "[", "X", "]"}]}], ")"}]}], "\[Equal]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"a1", " ", "X"}]}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "a1", " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"a1", " ", "X"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["G20", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["G20", "\[Prime]",
      MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"G20", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB+Iry8p+1Wa8cVwWunRKdeYbx603nq0E0VOr6gprgPS7
q24/24D035gnh9uBNMPblavYst44Vq1y4qoB0kuuTimYA6Tzuu0uLwfSWQk3
5q4D0lcXZGWuB9LTarv6QbTcxD9Ch4D0idYZG8Oy3ziyyH9bNB9Iv2N49mEh
kI43O6mxBEh7LpV8rZL3xrFe8chen/w3jlaqv7+bF7xxlLl8QGNy0RvHH2fX
lTsWv3FsdpXoBtE9cx+dBNEC0g+WLAPSRdsD8rcBaa5t0cE3gXREyPKFd4H0
0v37D/4G0k2rolr3lLxxNL+pO99s7hvHSy8FblkA6X0ti7e6A+kLL14fBtEd
dTEXQHSGg89Gp3lvHLdZSK91BtJz4ppVb8x/4wgACjWrfA==
  "],
 CellLabel->
  "Out[143]=",ExpressionUUID->"ca62f61c-adb2-4d50-9e90-1419f2451f45"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"G20EqLead", "=", 
   RowBox[{
    RowBox[{"GetEquationListOrder", "[", 
     RowBox[{"EquationList2LeadingOrder", ",", "0", ",", "a1"}], "]"}], "[", 
    RowBox[{"[", "7", "]"}], "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.812880227139594*^9, 3.812880229963846*^9}, {
  3.8128802640595713`*^9, 3.8128803154695373`*^9}, {3.812880397690322*^9, 
  3.8128804196497226`*^9}},
 CellLabel->
  "In[144]:=",ExpressionUUID->"bba659d1-3da4-423b-a997-1864d73010f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "K2"}], " ", "w", " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Pin", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
      RowBox[{"G20", "[", "X", "]"}]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["G20", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "X", "]"}], "12"]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.8128802778380957`*^9, 3.812880316129716*^9}, 
   3.812880367821972*^9, {3.812880407858602*^9, 3.8128804200932455`*^9}, 
   3.8133997173229485`*^9, 3.8134014862477045`*^9, 3.813423050322983*^9, 
   3.8134246713099885`*^9, 3.8136845654820423`*^9, 3.813924946370984*^9, 
   3.8139913007604475`*^9, 3.8140146180834446`*^9, 3.8140285268946733`*^9, 
   3.81403015552602*^9, 3.814030460444106*^9, 3.8140683760123944`*^9, 
   3.814372749005625*^9, 3.8145221359431477`*^9, 3.8145268552865567`*^9, 
   3.8145313984085636`*^9, 3.815843672977194*^9, 3.816449518342947*^9, 
   3.8169312640552073`*^9, 3.8181665982146425`*^9, 3.818523581631545*^9, 
   3.8185237368664236`*^9, 3.8185242391866703`*^9, 3.8187307911951914`*^9, 
   3.818763130630331*^9, 3.8188345869769125`*^9, 3.8188434053349853`*^9, 
   3.818905102103151*^9, 3.81929988304545*^9, 3.8405214655265093`*^9, 
   3.8405260326834545`*^9, 3.8405564612036963`*^9, 3.840556575637782*^9, 
   3.8405566750310593`*^9, 3.8410704744808064`*^9, 3.8410724890285683`*^9, 
   3.8419008444281125`*^9},
 CellLabel->
  "Out[144]=",ExpressionUUID->"83f5c4e9-c7c3-4ef7-b669-bcbc6b02c255"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList2LeadingOrder1a1", "=", 
   RowBox[{
    RowBox[{"GetEquationListOrder", "[", 
     RowBox[{"EquationList2LeadingOrder", ",", "1", ",", "a1"}], "]"}], "[", 
    RowBox[{"[", "7", "]"}], "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.8128803788497977`*^9, 3.812880382240451*^9}, {
  3.8128804320119495`*^9, 3.8128804327098017`*^9}},
 CellLabel->
  "In[145]:=",ExpressionUUID->"b90bc767-ca52-49e0-b761-897a825b1041"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["G20", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}], "4"], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "X", " ", 
    RowBox[{
     SuperscriptBox["G20", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB+JNbTEMdRlvHLef02AD0XOurp1SnfnGsUiYtagGSL+7
6vuzDUhHvH5zuB1IX8zZvIot643jIsEArhogvS10VsEcIN231/XyciB9K+Th
3HVA2uVsUeZ6IL1r9cR+EK2rziR8CEiz6C3eGJb9xlHBhnHxfCDtsun1h4VA
mm3ZBY0lQLpsi+Jrlbw3jr7hZ/f65L9x3POU+Yd5wRvHLzEnNSYXvXGUat5W
7lj8xvFFgFw3iLZ59OIkiFaoebFkGZAu3RSWvw1IW6YmBd8E0nvi1y68C6Qv
nTly8DeI75fWuqfkjaP4TeP5ZnPfOKotl7hlAaRnsaze6g6kd7z4cRhEp9Sl
XADR/NpBG53mvXF8eUp5rTOQnv9ykuqN+W8cAXQ9pik=
  "],
 CellLabel->
  "Out[145]=",ExpressionUUID->"a84c60af-a8a5-4f2c-9447-96a9b41de419"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FuncG0", "[", "X", "]"}]], "Input",
 CellChangeTimes->{{3.812880094938512*^9, 3.8128801343404417`*^9}},
 CellLabel->
  "In[146]:=",ExpressionUUID->"95515546-5b22-4d1c-8fd6-e232d09520fb"],

Cell[BoxData[
 FractionBox[
  RowBox[{"Pin", " ", 
   RowBox[{"(", 
    RowBox[{"6", "-", 
     FractionBox[
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "X"}], ")"}]}]]}], 
      SqrtBox["K2"]], "+", 
     FractionBox[
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", "X"}]]}], 
      SqrtBox["K2"]], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"4", " ", 
        SqrtBox["3"], " ", 
        SqrtBox["K2"]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "-", 
     RowBox[{"6", " ", "X"}]}], ")"}]}], 
  RowBox[{"6", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"4", " ", 
       SqrtBox["3"], " ", 
       SqrtBox["K2"]}]]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.812880099311754*^9, 3.812880134857363*^9}, 
   3.813399717510458*^9, 3.8134015493168516`*^9, 3.8134230505104904`*^9, 
   3.8134246714818497`*^9, 3.813684565700783*^9, 3.8139249467107368`*^9, 
   3.813991300869815*^9, 3.814014618240354*^9, 3.8140285271205444`*^9, 
   3.8140301556672397`*^9, 3.8140304606161757`*^9, 3.814068376098165*^9, 
   3.8143727491462374`*^9, 3.8145221360945563`*^9, 3.8145268554145017`*^9, 
   3.8145313985990543`*^9, 3.815843673095579*^9, 3.816449518457882*^9, 
   3.816931264162485*^9, 3.8181665983445683`*^9, 3.8185235817434816`*^9, 
   3.8185237370003643`*^9, 3.818524239340581*^9, 3.8187307913121233`*^9, 
   3.8187631307702503`*^9, 3.818834587143257*^9, 3.8188434054709253`*^9, 
   3.8189051022125235`*^9, 3.8192998832783365`*^9, 3.840521465698372*^9, 
   3.840526032839365*^9, 3.840556461391183*^9, 3.8405565758565135`*^9, 
   3.8405566752497935`*^9, 3.841070474623741*^9, 3.8410724891664906`*^9, 
   3.8419008448258834`*^9},
 CellLabel->
  "Out[146]=",ExpressionUUID->"2d380311-7586-47d6-97e9-ba946517c80b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FormBox["EquationList2LeadingOrdersub",
   TraditionalForm], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    FormBox["EquationList2LeadingOrder",
     TraditionalForm], "//.", 
    FormBox[
     RowBox[{"{", 
      RowBox[{"G20", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", "X", "}"}], ",", 
         RowBox[{
          FormBox["G20Func",
           TraditionalForm], "[", "X", "]"}]}], "]"}]}], "}"}],
     TraditionalForm]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.811742633076439*^9, 3.8117426372665606`*^9}, {
  3.811754769790119*^9, 3.8117547915351286`*^9}, {3.812880069206297*^9, 
  3.81288007290617*^9}},
 CellLabel->
  "In[147]:=",ExpressionUUID->"715f0429-fe69-4979-b04f-c2ee37352235"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "12"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"a1", " ", "X"}]}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "a1", " ", 
        RowBox[{
         SuperscriptBox["G20Func", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"a1", " ", "X"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["G20Func", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "\[Equal]", 
    RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Pin", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
       RowBox[{"G20Func", "[", "X", "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["G20Func", "\[Prime]",
      MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"G20Func", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBmKW0w+6w9PfOGZGJy+tzXjjuId97XoQvfGDwC4QPe9L
9E0QXRS6aUp15htHmz1vK2uAdILSiU4QzWIU9LMNSDu8/ni4HUhvzdm5ii3r
jeOMw5FcNUC6PXRuwRwgvf2u5+XlQPrk4mdz1wHpBpXyzPVA+tCsqf0gusyJ
RfgQkP6mu2xjWPYbxwlcrIvnA+ljV959WAikD7Fd01gCpLmaVV6r5L1xnCp/
Ya9P/hvHD71sP8wL3jgu2XFGY3LRG8eWmp3ljsVvHB88VewG0VdfvjkJok+F
vF6yDEhfDI/K3wakexamBd8E0ksXbFx4F0gfOnPi4G8g/aQuu3VPyRtHtkiL
+WZz3zhWBcnesgDSnSzrt7oD6foXfw+D6Jy6rAsgOi04bKPTvDeOj+6orXUG
0i/3zVO9Mf+NIwAM0bzl
  "],
 CellLabel->
  "Out[147]=",ExpressionUUID->"dbb44765-b3b0-4d1f-9da5-badecb90516f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox["EquationList2LeadingOrdersub", TraditionalForm]], "Input",
 CellChangeTimes->{3.8122773539933453`*^9, 3.8128797505626564`*^9},
 CellLabel->
  "In[148]:=",ExpressionUUID->"f712775d-4925-42ad-80fa-74fa0d1c7104"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "12"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"a1", " ", "X"}]}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "a1", " ", 
        RowBox[{
         SuperscriptBox["G20Func", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"a1", " ", "X"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["G20Func", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "\[Equal]", 
    RowBox[{"K2", " ", "w", " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Pin", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
       RowBox[{"G20Func", "[", "X", "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["G20Func", "\[Prime]",
      MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"G20Func", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBOK4sscbajPeOBYUO+4C0TL2x0TqgHTi1S1TqjPfOF56
LFFVA6SXz5PvAtEMRiE/24C0+evPh9uB9LI3u1exZb1xXGMby1UDpOuuziuY
A6QvvfS+vBxIpym9nLsOSOddq8hcD6QXlE7vB9F7/VmFDwHpV7orNoZlv3HM
FGNfPB9Ic9t++LAQSIcZ3dBYAqSZ5dVeq+S9cczKv7jXJ/+No+Ap9h/mBW8c
7ymc05hc9MYx5cqucsfiN44BAUrdIPrI7HcnQTTL3jdLlgHp7OCY/G1AelFL
RvBNID0laPPCu0D66ZmTB38DaekVOa17St44/rlhOd9s7htHMT/5WxZAegXL
xq3uQLoog+EIiDapy70AogvNIjY6zXvj+M5GY60zkH5yYaHqjflvHAHxHaz1

  "],
 CellLabel->
  "Out[148]=",ExpressionUUID->"d96690ab-64f4-440d-acb0-ce99400ca1b7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"UY20Func", "[", 
   RowBox[{"X", ",", "Y2"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{
  3.8116100413063965`*^9, {3.8134016861314573`*^9, 3.813401687037616*^9}},
 CellLabel->
  "In[149]:=",ExpressionUUID->"9bcbc51a-b14b-461d-ac08-6485c15e0754"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "12"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", " ", "a1", " ", 
     RowBox[{
      SuperscriptBox["G20", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["a1", "2"], " ", "X", " ", 
     RowBox[{
      SuperscriptBox["G20", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a1", "3"], " ", 
     SuperscriptBox["X", "2"], " ", 
     RowBox[{
      SuperscriptBox["G20", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{"3", " ", "a1", " ", 
     SuperscriptBox["Y2", "2"], " ", 
     RowBox[{
      SuperscriptBox["G20", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["G20", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "X", "]"}], "+", 
    RowBox[{"3", " ", "a1", " ", "X", " ", 
     RowBox[{
      SuperscriptBox["G20", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["X", "2"], " ", 
     RowBox[{
      SuperscriptBox["G20", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["a1", "3"], " ", 
     SuperscriptBox["X", "3"], " ", 
     RowBox[{
      SuperscriptBox["G20", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["Y2", "2"], " ", 
     RowBox[{
      SuperscriptBox["G20", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{"3", " ", "a1", " ", "X", " ", 
     SuperscriptBox["Y2", "2"], " ", 
     RowBox[{
      SuperscriptBox["G20", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Y2", "3"], " ", 
     RowBox[{
      SuperscriptBox["G20", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.811610036146924*^9, 3.8116100421537747`*^9}, 
   3.8116101605407796`*^9, 3.8116978884525137`*^9, 3.8117426848678913`*^9, 
   3.8117548273924665`*^9, 3.8128796596759267`*^9, 3.81287983648491*^9, 
   3.8128805517206717`*^9, 3.813399717729184*^9, 3.813401555490923*^9, {
   3.813401682488018*^9, 3.813401687693807*^9}, 3.8134230506936026`*^9, 
   3.8134246717006083`*^9, 3.8136845660601463`*^9, 3.8139249470201483`*^9, 
   3.813991300994808*^9, 3.8140146184372425`*^9, 3.814028527366421*^9, 
   3.8140301558321447`*^9, 3.8140304607970905`*^9, 3.8140683761769543`*^9, 
   3.814372749318099*^9, 3.8145221362874475`*^9, 3.814526855551422*^9, 
   3.814531398819973*^9, 3.815843673253282*^9, 3.816449518594821*^9, 
   3.8169312642815914`*^9, 3.8181665984905024`*^9, 3.818523581890395*^9, 
   3.8185237371252737`*^9, 3.818524239508484*^9, 3.818730791437051*^9, 
   3.8187631309361534`*^9, 3.818834587331208*^9, 3.8188434056617975`*^9, 
   3.818905102368749*^9, 3.8192998834680448`*^9, 3.8405214658702526`*^9, 
   3.8405260330402465`*^9, 3.840556461594318*^9, 3.84055657610649*^9, 
   3.840556675499794*^9, 3.8410704748166113`*^9, 3.841072489305411*^9, 
   3.841900845161689*^9},
 CellLabel->
  "Out[149]=",ExpressionUUID->"91c4a5ce-a20d-45d1-ba13-84c2127a4575"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"UY20FuncSub", "[", 
    RowBox[{"X_", ",", "Y2_"}], "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"UY20Func", "[", 
      RowBox[{"X", ",", "Y2"}], "]"}], "//.", 
     FormBox[
      RowBox[{"{", 
       RowBox[{"G20", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", "X", "}"}], ",", 
          RowBox[{"FuncG201", "[", "X", "]"}]}], "]"}]}], "}"}],
      TraditionalForm]}], "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.811609437684334*^9, 3.811609459897601*^9}, {
   3.8116094937795076`*^9, 3.811609507594775*^9}, {3.811609561840171*^9, 
   3.8116095623557587`*^9}, {3.811610180125558*^9, 3.8116101806098967`*^9}, 
   3.8116102223121*^9, 3.811742693925968*^9, 3.8134012845063686`*^9, {
   3.8134016985877867`*^9, 3.813401699775201*^9}, {3.8137699710958977`*^9, 
   3.813769972752078*^9}, {3.8137703411811996`*^9, 3.8137703627815905`*^9}, {
   3.8137704440808077`*^9, 3.813770445065113*^9}, {3.8140302989329576`*^9, 
   3.814030301250805*^9}, 3.840556552091773*^9},
 CellLabel->
  "In[150]:=",ExpressionUUID->"bbb76d04-ff0b-42ca-bc3a-0d5fd89d90d9"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"48", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}], "2"], " ", 
     SqrtBox["K2"]}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SqrtBox["3"], " ", 
      SqrtBox["K2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "X"}], ")"}]}]], " ", "Pin", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"a1", " ", "X"}], "+", "Y2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["a1", "3"], " ", "X", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["3"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["K2"], " ", "X"}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["3"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["K2"], " ", "X"}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["3"], "+", 
            RowBox[{"2", " ", 
             SqrtBox["K2"], " ", "X"}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["3"], "+", 
            RowBox[{"2", " ", 
             SqrtBox["K2"], " ", "X"}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          SqrtBox["K2"], " ", "X", " ", 
          RowBox[{"(", 
           RowBox[{"3", "-", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"3", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          SqrtBox["K2"], " ", "X", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"3", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["3"], "-", 
            RowBox[{"14", " ", 
             SqrtBox["K2"], " ", "X"}], "-", 
            RowBox[{"12", " ", 
             SuperscriptBox["K2", 
              RowBox[{"3", "/", "2"}]], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}], "+", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["X", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["3"], "+", 
            RowBox[{"14", " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox["K2", 
              RowBox[{"3", "/", "2"}]], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}], "+", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["X", "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
      "-", 
      RowBox[{"8", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", "K2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "Y2", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Y2", "2"]}]}], ")"}]}], "-", 
      RowBox[{"a1", " ", 
       SqrtBox["K2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}], "+", 
         RowBox[{"24", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}], "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}], "-", 
         RowBox[{"12", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Y2", "2"]}]}], ")"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Y2", "2"]}]}], ")"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Y2", "2"]}]}], ")"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Y2", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{"3", "-", 
            RowBox[{"3", " ", "Y2"}], "+", 
            RowBox[{"18", " ", 
             SuperscriptBox["Y2", "2"]}], "+", 
            RowBox[{"36", " ", "K2", " ", 
             SuperscriptBox["X", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "7"}], "+", 
               RowBox[{"11", " ", "Y2"}], "+", 
               RowBox[{"30", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"36", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2", "+", 
               RowBox[{"10", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "7"}], "+", 
               RowBox[{"11", " ", "Y2"}], "+", 
               RowBox[{"30", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{"3", "-", 
            RowBox[{"3", " ", "Y2"}], "+", 
            RowBox[{"18", " ", 
             SuperscriptBox["Y2", "2"]}], "+", 
            RowBox[{"36", " ", "K2", " ", 
             SuperscriptBox["X", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "7"}], "+", 
               RowBox[{"11", " ", "Y2"}], "+", 
               RowBox[{"30", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"36", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2", "+", 
               RowBox[{"10", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "7"}], "+", 
               RowBox[{"11", " ", "Y2"}], "+", 
               RowBox[{"30", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox["a1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "X"}], ")"}]}]], " ", 
          SqrtBox["K2"], " ", "X"}], "+", 
         RowBox[{"24", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          SqrtBox["K2"], " ", "X"}], "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", "X"}], ")"}]}]], " ", 
          SqrtBox["K2"], " ", "X"}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["X", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"35", "-", 
                  RowBox[{"24", " ", "Y2"}]}], ")"}]}], "+", 
               RowBox[{"18", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{"45", "-", 
               RowBox[{"42", " ", "Y2"}]}], ")"}]}], "-", 
            RowBox[{"36", " ", 
             SuperscriptBox["K2", 
              RowBox[{"3", "/", "2"}]], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "-", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}]}], ")"}]}], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"12", " ", 
          SqrtBox["K2"], " ", "X", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "-", 
         RowBox[{"6", " ", 
          SqrtBox["3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          SqrtBox["K2"], " ", "X", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "33"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{"35", "-", 
               RowBox[{"24", " ", "Y2"}]}], ")"}]}], "+", 
            RowBox[{"36", " ", "K2", " ", 
             SuperscriptBox["X", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{"36", " ", "Y2"}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          SqrtBox["K2"], " ", "X", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "33"}], "+", 
            RowBox[{"36", " ", "K2", " ", 
             SuperscriptBox["X", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{"36", " ", "Y2"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "35"}], "+", 
               RowBox[{"24", " ", "Y2"}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{"45", "-", 
               RowBox[{"42", " ", "Y2"}]}], ")"}]}], "-", 
            RowBox[{"36", " ", 
             SuperscriptBox["K2", 
              RowBox[{"3", "/", "2"}]], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "18"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["X", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "35"}], "+", 
                  RowBox[{"24", " ", "Y2"}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.840556554609767*^9, 3.8405565761846204`*^9}, 
   3.840556680805402*^9, 3.8410704803064394`*^9, 3.8410724945714145`*^9, 
   3.8419008562462864`*^9},
 CellLabel->
  "Out[150]=",ExpressionUUID->"0e3088a0-d093-4550-acfe-ca9039b02384"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"UX20FuncSub", "[", 
    RowBox[{"X_", ",", "Y2_"}], "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"UX20Func", "[", 
      RowBox[{"X", ",", "Y2"}], "]"}], "//.", 
     FormBox[
      RowBox[{"{", 
       RowBox[{"G20", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", "X", "}"}], ",", 
          RowBox[{
           FormBox["FuncG201",
            TraditionalForm], "[", "X", "]"}]}], "]"}]}], "}"}],
      TraditionalForm]}], "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.8117427358316345`*^9, 3.811742745174638*^9}, {
   3.811742785521965*^9, 3.811742785928156*^9}, 3.8134012947754917`*^9, {
   3.813770448397527*^9, 3.813770450536265*^9}},
 CellLabel->
  "In[151]:=",ExpressionUUID->"cdd43519-09f3-4026-9f21-5fedcebfd63d"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"]}]]}], ")"}], "2"], " ", 
    SqrtBox["K2"]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SqrtBox["3"], " ", 
     SqrtBox["K2"], " ", "X"}]], " ", "Pin", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", 
      SqrtBox["K2"]}], "+", 
     RowBox[{"a1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            SqrtBox["K2"], " ", "X"}], "-", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", "K2", " ", 
            SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"8", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", "K2", " ", 
            SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SqrtBox["3"], "-", 
           RowBox[{"9", " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SqrtBox["3"], "+", 
           RowBox[{"9", " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}], " ", "Y2", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"a1", " ", "X"}], "+", "Y2"}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.811742742272886*^9, 3.8117427457271566`*^9}, 
   3.8117428086045647`*^9, 3.8117548437618256`*^9, 3.812879659844307*^9, 
   3.8128805695795994`*^9, 3.8133997227138023`*^9, {3.8134015602119846`*^9, 
   3.8134015671350856`*^9}, 3.8134017626101136`*^9, 3.813423055554285*^9, 
   3.8134246765622187`*^9, 3.8136845711847515`*^9, 3.81377045646181*^9, 
   3.8139249537971115`*^9, 3.8139913068720226`*^9, 3.814014624522832*^9, 
   3.8140285338702416`*^9, 3.8140301632607164`*^9, 3.814030466903047*^9, 
   3.814068380863126*^9, 3.81437275539334*^9, 3.8145221432373323`*^9, 
   3.814526861811311*^9, 3.814531405914112*^9, 3.8158436791348004`*^9, 
   3.8164495248652167`*^9, 3.8169312708697257`*^9, 3.818166604942934*^9, 
   3.8185235884642816`*^9, 3.8185237436811113`*^9, 3.818524246097022*^9, 
   3.8187307977174444`*^9, 3.818763137359465*^9, 3.818834593820913*^9, 
   3.81884341202814*^9, 3.8189051086831336`*^9, 3.81929989234546*^9, 
   3.840521472030239*^9, 3.8405260395395117`*^9, 3.8405564675660763`*^9, 
   3.8405565762627473`*^9, 3.8405566825766106`*^9, 3.841070481861455*^9, 
   3.8410724960505624`*^9, 3.8419008599681377`*^9},
 CellLabel->
  "Out[151]=",ExpressionUUID->"4e9dd41b-848d-472f-8295-c5b71ac67d08"]
}, Open  ]],

Cell["In summary, the pressure and velocities are given by:", "Text",
 CellChangeTimes->{{3.84107051108637*^9, 
  3.841070526374612*^9}},ExpressionUUID->"82378a2b-5631-42f7-9f32-\
9576a9a0cbc2"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{"FuncG201", "[", "X", "]"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"UY20FuncSub", "[", 
   RowBox[{"X", ",", "Y2"}], "]"}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"UX20FuncSub", "[", 
   RowBox[{"X", ",", "Y2"}], "]"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.813849508856*^9, 3.8138495121336603`*^9}, {
   3.813849741710698*^9, 3.8138497423377957`*^9}, 3.840554937914363*^9, 
   3.840556748805455*^9},
 CellLabel->
  "In[152]:=",ExpressionUUID->"1024d9e9-fdb6-4132-87a9-df8bb69f64d7"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"48", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"]}]]}], ")"}], "2"]}]], 
  RowBox[{"Pin", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"6", "-", 
        FractionBox[
         RowBox[{
          SqrtBox["3"], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "X"}], ")"}]}]]}], 
         SqrtBox["K2"]], "+", 
        FractionBox[
         RowBox[{
          SqrtBox["3"], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]]}], 
         SqrtBox["K2"]], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "-", 
        RowBox[{"6", " ", "X"}]}], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "K2"], 
      RowBox[{"3", " ", "a1", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           RowBox[{"3", " ", "X"}]}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", 
              RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"8", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.8138497432091513`*^9, 3.8139249539219093`*^9, 
  3.813991306934515*^9, 3.8140146246467586`*^9, 3.8140285339775925`*^9, 
  3.814030163348666*^9, 3.814030466990011*^9, 3.814068380923963*^9, 
  3.814372755471476*^9, 3.814522143324299*^9, 3.814526861896242*^9, 
  3.8145314060362654`*^9, 3.815843679215846*^9, 3.816449524940174*^9, 
  3.816931270930711*^9, 3.8181666050238886`*^9, 3.8185235885322404`*^9, 
  3.818523743749072*^9, 3.8185242461789746`*^9, 3.8187307977913837`*^9, 
  3.8187631374453983`*^9, 3.8188345939078627`*^9, 3.818843412122069*^9, 
  3.818905108792486*^9, 3.81929989247585*^9, 3.8405214721396055`*^9, 
  3.840526039635437*^9, 3.8405549387579985`*^9, 3.840556467675441*^9, 
  3.8405565763720956`*^9, 3.840556682717245*^9, 3.8405567515630627`*^9, 
  3.8410704819761486`*^9, 3.8410724961375294`*^9, 3.8419008601660233`*^9},
 CellLabel->
  "Out[152]=",ExpressionUUID->"809e0ec8-767c-4e9c-84cf-8bd3101857cc"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"48", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}], "2"], " ", 
     SqrtBox["K2"]}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SqrtBox["3"], " ", 
      SqrtBox["K2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "X"}], ")"}]}]], " ", "Pin", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"a1", " ", "X"}], "+", "Y2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["a1", "3"], " ", "X", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["3"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["K2"], " ", "X"}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["3"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["K2"], " ", "X"}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["3"], "+", 
            RowBox[{"2", " ", 
             SqrtBox["K2"], " ", "X"}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["3"], "+", 
            RowBox[{"2", " ", 
             SqrtBox["K2"], " ", "X"}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          SqrtBox["K2"], " ", "X", " ", 
          RowBox[{"(", 
           RowBox[{"3", "-", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"3", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          SqrtBox["K2"], " ", "X", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"3", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["3"], "-", 
            RowBox[{"14", " ", 
             SqrtBox["K2"], " ", "X"}], "-", 
            RowBox[{"12", " ", 
             SuperscriptBox["K2", 
              RowBox[{"3", "/", "2"}]], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}], "+", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["X", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["3"], "+", 
            RowBox[{"14", " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox["K2", 
              RowBox[{"3", "/", "2"}]], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}], "+", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["X", "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
      "-", 
      RowBox[{"8", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", "K2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "Y2", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Y2", "2"]}]}], ")"}]}], "-", 
      RowBox[{"a1", " ", 
       SqrtBox["K2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}], "+", 
         RowBox[{"24", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}], "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}], "-", 
         RowBox[{"12", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Y2", "2"]}]}], ")"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Y2", "2"]}]}], ")"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Y2", "2"]}]}], ")"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Y2", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{"3", "-", 
            RowBox[{"3", " ", "Y2"}], "+", 
            RowBox[{"18", " ", 
             SuperscriptBox["Y2", "2"]}], "+", 
            RowBox[{"36", " ", "K2", " ", 
             SuperscriptBox["X", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "7"}], "+", 
               RowBox[{"11", " ", "Y2"}], "+", 
               RowBox[{"30", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"36", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2", "+", 
               RowBox[{"10", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "7"}], "+", 
               RowBox[{"11", " ", "Y2"}], "+", 
               RowBox[{"30", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{"3", "-", 
            RowBox[{"3", " ", "Y2"}], "+", 
            RowBox[{"18", " ", 
             SuperscriptBox["Y2", "2"]}], "+", 
            RowBox[{"36", " ", "K2", " ", 
             SuperscriptBox["X", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "7"}], "+", 
               RowBox[{"11", " ", "Y2"}], "+", 
               RowBox[{"30", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"36", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2", "+", 
               RowBox[{"10", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "7"}], "+", 
               RowBox[{"11", " ", "Y2"}], "+", 
               RowBox[{"30", " ", 
                SuperscriptBox["Y2", "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox["a1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "X"}], ")"}]}]], " ", 
          SqrtBox["K2"], " ", "X"}], "+", 
         RowBox[{"24", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          SqrtBox["K2"], " ", "X"}], "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", "X"}], ")"}]}]], " ", 
          SqrtBox["K2"], " ", "X"}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["X", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"35", "-", 
                  RowBox[{"24", " ", "Y2"}]}], ")"}]}], "+", 
               RowBox[{"18", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{"45", "-", 
               RowBox[{"42", " ", "Y2"}]}], ")"}]}], "-", 
            RowBox[{"36", " ", 
             SuperscriptBox["K2", 
              RowBox[{"3", "/", "2"}]], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "-", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}]}], ")"}]}], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"12", " ", 
          SqrtBox["K2"], " ", "X", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "-", 
         RowBox[{"6", " ", 
          SqrtBox["3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          SqrtBox["K2"], " ", "X", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "33"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{"35", "-", 
               RowBox[{"24", " ", "Y2"}]}], ")"}]}], "+", 
            RowBox[{"36", " ", "K2", " ", 
             SuperscriptBox["X", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{"36", " ", "Y2"}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
          SqrtBox["K2"], " ", "X", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "33"}], "+", 
            RowBox[{"36", " ", "K2", " ", 
             SuperscriptBox["X", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{"36", " ", "Y2"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "35"}], "+", 
               RowBox[{"24", " ", "Y2"}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["K2"], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{"45", "-", 
               RowBox[{"42", " ", "Y2"}]}], ")"}]}], "-", 
            RowBox[{"36", " ", 
             SuperscriptBox["K2", 
              RowBox[{"3", "/", "2"}]], " ", "X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "18"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "Y2"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["X", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "35"}], "+", 
                  RowBox[{"24", " ", "Y2"}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.8138497432091513`*^9, 3.8139249539219093`*^9, 
  3.813991306934515*^9, 3.8140146246467586`*^9, 3.8140285339775925`*^9, 
  3.814030163348666*^9, 3.814030466990011*^9, 3.814068380923963*^9, 
  3.814372755471476*^9, 3.814522143324299*^9, 3.814526861896242*^9, 
  3.8145314060362654`*^9, 3.815843679215846*^9, 3.816449524940174*^9, 
  3.816931270930711*^9, 3.8181666050238886`*^9, 3.8185235885322404`*^9, 
  3.818523743749072*^9, 3.8185242461789746`*^9, 3.8187307977913837`*^9, 
  3.8187631374453983`*^9, 3.8188345939078627`*^9, 3.818843412122069*^9, 
  3.818905108792486*^9, 3.81929989247585*^9, 3.8405214721396055`*^9, 
  3.840526039635437*^9, 3.8405549387579985`*^9, 3.840556467675441*^9, 
  3.8405565763720956`*^9, 3.840556682717245*^9, 3.8405567515630627`*^9, 
  3.8410704819761486`*^9, 3.8410724961375294`*^9, 3.841900860205001*^9},
 CellLabel->
  "Out[153]=",ExpressionUUID->"449ca525-0972-4ea0-82c5-98a9e8d0dbdc"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"]}]]}], ")"}], "2"], " ", 
    SqrtBox["K2"]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SqrtBox["3"], " ", 
     SqrtBox["K2"], " ", "X"}]], " ", "Pin", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", 
      SqrtBox["K2"]}], "+", 
     RowBox[{"a1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            SqrtBox["K2"], " ", "X"}], "-", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", "K2", " ", 
            SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"8", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", "K2", " ", 
            SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SqrtBox["3"], "-", 
           RowBox[{"9", " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SqrtBox["3"], "+", 
           RowBox[{"9", " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}], " ", "Y2", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"a1", " ", "X"}], "+", "Y2"}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.8138497432091513`*^9, 3.8139249539219093`*^9, 
  3.813991306934515*^9, 3.8140146246467586`*^9, 3.8140285339775925`*^9, 
  3.814030163348666*^9, 3.814030466990011*^9, 3.814068380923963*^9, 
  3.814372755471476*^9, 3.814522143324299*^9, 3.814526861896242*^9, 
  3.8145314060362654`*^9, 3.815843679215846*^9, 3.816449524940174*^9, 
  3.816931270930711*^9, 3.8181666050238886`*^9, 3.8185235885322404`*^9, 
  3.818523743749072*^9, 3.8185242461789746`*^9, 3.8187307977913837`*^9, 
  3.8187631374453983`*^9, 3.8188345939078627`*^9, 3.818843412122069*^9, 
  3.818905108792486*^9, 3.81929989247585*^9, 3.8405214721396055`*^9, 
  3.840526039635437*^9, 3.8405549387579985`*^9, 3.840556467675441*^9, 
  3.8405565763720956`*^9, 3.840556682717245*^9, 3.8405567515630627`*^9, 
  3.8410704819761486`*^9, 3.8410724961375294`*^9, 3.8419008602259893`*^9},
 CellLabel->
  "Out[154]=",ExpressionUUID->"71b98ed9-cfc3-4cdf-8bfe-a2fd7f29d112"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Solving the first order region 1", "Section",
 CellChangeTimes->{{3.7911845990627584`*^9, 3.791184608580055*^9}, {
   3.79118492060427*^9, 3.7911849248951592`*^9}, 3.841068624124804*^9, {
   3.841072180588652*^9, 
   3.841072183740471*^9}},ExpressionUUID->"0a003d3b-4343-431c-bd38-\
8d096493f92e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList1", "]"}]], "Input",
 CellChangeTimes->{
  3.791185095054936*^9, {3.818523563918703*^9, 3.8185235708199587`*^9}},
 CellLabel->
  "In[155]:=",ExpressionUUID->"afaefb47-2f97-4fcf-af3d-a1c9f0786b8f"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX10"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UX11"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["K1", "2"], " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UX12"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY10"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UY11"}], 
            RowBox[{"\[PartialD]", "Y1"}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["K1", "2"], " ", 
           FractionBox[
            RowBox[{"\[PartialD]", "UY12"}], 
            RowBox[{"\[PartialD]", "Y1"}],
            MultilineFunction->None]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX10"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y1", "2"]}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UX11"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["Y1", "2"]}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UX10"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["X", "2"]}],
              MultilineFunction->None], "+", 
             RowBox[{"K1", " ", 
              RowBox[{"(", 
               RowBox[{
                FractionBox[
                 RowBox[{
                  SuperscriptBox["\[PartialD]", "2"], "UX11"}], 
                 RowBox[{"\[PartialD]", 
                  SuperscriptBox["X", "2"]}],
                 MultilineFunction->None], "+", 
                RowBox[{"K1", " ", 
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["\[PartialD]", "2"], "UX12"}], 
                  RowBox[{"\[PartialD]", 
                   SuperscriptBox["X", "2"]}],
                  MultilineFunction->None]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["K1", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UX12"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["Y1", "2"]}],
            MultilineFunction->None]}]}], "\[LongEqual]", 
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "P10"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"\[PartialD]", "P11"}], 
              RowBox[{"\[PartialD]", "X"}],
              MultilineFunction->None], "+", 
             RowBox[{"K1", " ", 
              FractionBox[
               RowBox[{"\[PartialD]", "P12"}], 
               RowBox[{"\[PartialD]", "X"}],
               MultilineFunction->None]}]}], ")"}]}]}]}]},
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "P10"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None], "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"\[PartialD]", "P11"}], 
              RowBox[{"\[PartialD]", "Y1"}],
              MultilineFunction->None], "+", 
             RowBox[{"K1", " ", 
              FractionBox[
               RowBox[{"\[PartialD]", "P12"}], 
               RowBox[{"\[PartialD]", "Y1"}],
               MultilineFunction->None]}]}], ")"}]}]}], "\[LongEqual]", 
         RowBox[{
          SuperscriptBox["\[Epsilon]1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{
              SuperscriptBox["\[PartialD]", "2"], "UY10"}], 
             RowBox[{"\[PartialD]", 
              SuperscriptBox["Y1", "2"]}],
             MultilineFunction->None], "+", 
            RowBox[{"K1", " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UY11"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["Y1", "2"]}],
              MultilineFunction->None]}], "+", 
            RowBox[{
             SuperscriptBox["\[Epsilon]1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{
                 SuperscriptBox["\[PartialD]", "2"], "UY10"}], 
                RowBox[{"\[PartialD]", 
                 SuperscriptBox["X", "2"]}],
                MultilineFunction->None], "+", 
               RowBox[{"K1", " ", 
                RowBox[{"(", 
                 RowBox[{
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["\[PartialD]", "2"], "UY11"}], 
                   RowBox[{"\[PartialD]", 
                    SuperscriptBox["X", "2"]}],
                   MultilineFunction->None], "+", 
                  RowBox[{"K1", " ", 
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["\[PartialD]", "2"], "UY12"}], 
                    RowBox[{"\[PartialD]", 
                    SuperscriptBox["X", "2"]}],
                    MultilineFunction->None]}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["K1", "2"], " ", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[PartialD]", "2"], "UY12"}], 
              RowBox[{"\[PartialD]", 
               SuperscriptBox["Y1", "2"]}],
              MultilineFunction->None]}]}], ")"}]}]}]},
       {
        RowBox[{
         RowBox[{"UX10", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"UX11", "+", 
             RowBox[{"K1", " ", "UX12"}]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"UX10", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"UX11", "+", 
             RowBox[{"K1", " ", "UX12"}]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"UY10", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"UY11", "+", 
             RowBox[{"K1", " ", "UY12"}]}], ")"}]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"P10", "+", 
             RowBox[{"K1", " ", 
              RowBox[{"(", 
               RowBox[{"P11", "+", 
                RowBox[{"K1", " ", "P12"}]}], ")"}]}]}], ")"}]}], "+", "UY10",
           "+", 
          RowBox[{"K1", " ", "UY11"}], "+", 
          RowBox[{
           SuperscriptBox["K1", "2"], " ", "UY12"}]}], "\[LongEqual]", 
         RowBox[{"K1", " ", 
          RowBox[{"(", 
           RowBox[{"P20", "+", 
            RowBox[{"K1", " ", 
             RowBox[{"(", 
              RowBox[{"P21", "+", 
               RowBox[{"K1", " ", "P22"}]}], ")"}]}]}], ")"}]}]}]},
       {
        RowBox[{"Pin", "\[LongEqual]", 
         RowBox[{"P10", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"P11", "+", 
             RowBox[{"K1", " ", "P12"}]}], ")"}]}]}]}]},
       {
        RowBox[{
         RowBox[{"P10", "+", 
          RowBox[{"K1", " ", 
           RowBox[{"(", 
            RowBox[{"P11", "+", 
             RowBox[{"K1", " ", "P12"}]}], ")"}]}]}], "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900864792351*^9},
 TextAlignment->Center,ExpressionUUID->"39e4f906-3eab-41ec-9d36-dbffd4712790"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"EquationList1FirstOrder", "=", 
   RowBox[{"GetEquationListOrder", "[", 
    RowBox[{"EquationList1", ",", "1", ",", "K1"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7911849656846094`*^9, 3.7911849910387487`*^9}, {
  3.7911850363528614`*^9, 3.791185039592205*^9}, {3.791185111566979*^9, 
  3.791185115082573*^9}, {3.791185211169927*^9, 3.791185215190137*^9}, {
  3.7911857518475943`*^9, 3.7911857521946135`*^9}, {3.7911859359695807`*^9, 
  3.791185951330229*^9}, {3.8185236854428577`*^9, 3.818523691115366*^9}},
 CellLabel->
  "In[156]:=",ExpressionUUID->"3bc3f73f-46bf-4e86-be01-8e1906c3a787"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX11"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY11"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[PartialD]", "P11"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UX11"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["X", "2"]}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX11"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y1", "2"]}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "P11"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "4"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UY11"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["X", "2"]}],
            MultilineFunction->None]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]1", "2"], " ", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], "UY11"}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["Y1", "2"]}],
            MultilineFunction->None]}]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX11", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX11", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY11", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"P10", "-", "P20", "+", "UY11"}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"-", "P11"}], "\[LongEqual]", "0"}]},
       {
        RowBox[{"P11", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900865007227*^9},
 TextAlignment->Center,ExpressionUUID->"1d6a009e-df9f-47fd-8564-901ea883d565"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"EquationList1FirstOrder", "=", 
   RowBox[{"GetEquationListOrder", "[", 
    RowBox[{"EquationList1FirstOrder", ",", "0", ",", "\[Epsilon]1"}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.791186088653308*^9, 3.7911861114840317`*^9}, {
  3.8185236947997637`*^9, 3.818523696958127*^9}},
 CellLabel->
  "In[157]:=",ExpressionUUID->"03ee8fb2-622c-4762-8662-b87275950b0e"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX11"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY11"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[PartialD]", "P11"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX11"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y1", "2"]}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P11"}], 
          RowBox[{"\[PartialD]", "Y1"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX11", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX11", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY11", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"P10", "-", "P20", "+", "UY11"}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"-", "P11"}], "\[LongEqual]", "0"}]},
       {
        RowBox[{"P11", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900865235095*^9},
 TextAlignment->Center,ExpressionUUID->"120b0c2c-534c-42e4-8f4e-c154d4c46c32"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", "EquationList1FirstOrder", "]"}]], "Input",
 CellChangeTimes->{{3.8185235526744995`*^9, 3.8185235538029485`*^9}},
 CellLabel->
  "In[158]:=",ExpressionUUID->"f92ea485-9668-415c-a2b9-3a15be251287"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX11"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY11"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[PartialD]", "P11"}], 
            RowBox[{"\[PartialD]", "X"}],
            MultilineFunction->None]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "UX11"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["Y1", "2"]}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "P11"}], 
          RowBox[{"\[PartialD]", "Y1"}],
          MultilineFunction->None], "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX11", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX11", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY11", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"P10", "-", "P20", "+", "UY11"}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"-", "P11"}], "\[LongEqual]", "0"}]},
       {
        RowBox[{"P11", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900865429983*^9},
 TextAlignment->Center,ExpressionUUID->"3443c4f6-7032-4645-bd0d-117fcd994f6b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"EquationList1FirstOrder", "[", 
   RowBox[{"[", "3", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7911874633642616`*^9, 3.791187473696618*^9}, {
  3.818523604364667*^9, 3.8185236058171253`*^9}},
 CellLabel->
  "In[159]:=",ExpressionUUID->"88b33826-0a57-4967-ae4e-bedd76d1c2cf"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", "P11"}], 
      RowBox[{"\[PartialD]", "Y1"}],
      MultilineFunction->None], "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008656028843`*^9},
 TextAlignment->Center,ExpressionUUID->"7084511e-1538-49aa-ab8a-89f1c78947c1"]
}, Open  ]],

Cell["we thus see that P11 is not a function of Y1, and thus", "Text",
 CellChangeTimes->{
  3.791187503528839*^9},ExpressionUUID->"99f9e484-64e1-49b8-8547-\
02e9091212be"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"EquationList1FirstOrder", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"EquationList1FirstOrder", "//.", 
      RowBox[{"{", 
       RowBox[{"P11", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"G11", "[", "#1", "]"}], " ", "&"}], ")"}]}], "}"}]}], 
     "]"}]}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911875524009*^9, 3.7911875667899747`*^9}, {
  3.8185237375978928`*^9, 3.8185237394784765`*^9}},
 CellLabel->
  "In[160]:=",ExpressionUUID->"8f08f563-cbb8-4196-aed1-c2f9e5f68744"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"\[PartialD]", "UX11"}], 
           RowBox[{"\[PartialD]", "X"}],
           MultilineFunction->None], "+", 
          FractionBox[
           RowBox[{"\[PartialD]", "UY11"}], 
           RowBox[{"\[PartialD]", "Y1"}],
           MultilineFunction->None]}], "\[LongEqual]", "0"}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", "G11"}], 
          RowBox[{"\[PartialD]", "X"}],
          MultilineFunction->None], "\[LongEqual]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "UX11"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["Y1", "2"]}],
          MultilineFunction->None]}]},
       {"True"},
       {
        RowBox[{"UX11", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UX11", "\[LongEqual]", "0"}]},
       {
        RowBox[{"UY11", "\[LongEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"P10", "+", "UY11"}], "\[LongEqual]", "P20"}]},
       {
        RowBox[{"G11", "\[LongEqual]", "0"}]},
       {
        RowBox[{"G11", "\[LongEqual]", "0"}]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008657148185`*^9},
 TextAlignment->Center,ExpressionUUID->"651f6da3-631e-4a09-8965-eacf0dd4202b"]
}, Open  ]],

Cell["Substituting P20 into the permeability boundary condition", "Text",
 CellChangeTimes->{{3.818523983602294*^9, 
  3.818524007619038*^9}},ExpressionUUID->"c6a65103-350f-4b02-a518-\
3bdfd21e60c4"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"EquationList1FirstOrder", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"EquationList1FirstOrder", "//.", 
      RowBox[{"{", 
       RowBox[{"P20", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", "X", "}"}], ",", 
          RowBox[{
           FormBox["FuncG01",
            TraditionalForm], "[", "X", "]"}]}], "]"}]}], "}"}]}], "]"}]}],
   FontColor->GrayLevel[0]], TraditionalForm]], "Input",
 CellChangeTimes->{{3.8121964909195065`*^9, 3.8121965353032093`*^9}, 
   3.8128809364259796`*^9, {3.818523801732633*^9, 3.818523803378738*^9}},
 CellLabel->
  "In[161]:=",ExpressionUUID->"08db2087-1133-41e5-88fb-1f6cea8847b5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UY11", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["UX11", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["G11", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}], "\[Equal]", 
    RowBox[{
     SuperscriptBox["UX11", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"X", ",", "Y1"}], "]"}]}], ",", "True", ",", 
   RowBox[{
    RowBox[{"UX11", "[", 
     RowBox[{"X", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX11", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY11", "[", 
     RowBox[{"X", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"P10", "[", 
      RowBox[{"X", ",", "0"}], "]"}], "+", 
     RowBox[{"UY11", "[", 
      RowBox[{"X", ",", "0"}], "]"}]}], "\[Equal]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"48", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]]}], ")"}], "2"]}]], 
     RowBox[{"Pin", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"8", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"6", "-", 
           FractionBox[
            RowBox[{
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "X"}], ")"}]}]]}], 
            SqrtBox["K2"]], "+", 
           FractionBox[
            RowBox[{
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}]]}], 
            SqrtBox["K2"]], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "-", 
           RowBox[{"6", " ", "X"}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["1", "K2"], 
         RowBox[{"3", " ", "a1", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"2", "-", 
              RowBox[{"3", " ", "X"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 RowBox[{"3", " ", "X"}]}], ")"}]}]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"4", " ", "X"}]}], ")"}]}]]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox["K2"], " ", "X"}], "+", 
               RowBox[{"12", " ", "K2", " ", 
                SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox["K2"], " ", "X"}], "+", 
               RowBox[{"12", " ", "K2", " ", 
                SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox["K2"], " ", "X"}], "+", 
               RowBox[{"12", " ", "K2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", 
                  SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"8", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox["K2"], " ", "X"}], "+", 
               RowBox[{"12", " ", "K2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", 
                  SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}]}], ")"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"G11", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"G11", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.812196524410982*^9, 3.812196538800187*^9}, 
   3.812196742970544*^9, 3.812256739618904*^9, 3.812277370460905*^9, 
   3.8128809455600586`*^9, {3.8134018025708957`*^9, 3.8134018027271357`*^9}, 
   3.8134230915344844`*^9, 3.813424681063593*^9, 3.8136845759671125`*^9, 
   3.8139251420300627`*^9, 3.8139913110148487`*^9, 3.8140146289793854`*^9, 
   3.8140285384689465`*^9, 3.8140301687462535`*^9, 3.8140304713683386`*^9, 
   3.8140683841180334`*^9, 3.8143727597818155`*^9, 3.8145221478486743`*^9, 
   3.8145268663217096`*^9, 3.814531416402157*^9, 3.8158436833729143`*^9, 
   3.816449529347623*^9, 3.8169312752849855`*^9, 3.8181666117708516`*^9, 
   3.8185236245941877`*^9, 3.8185238158312826`*^9, 3.818524250658211*^9, 
   3.818730802337777*^9, 3.8187631421686893`*^9, 3.8188345986974797`*^9, 
   3.818843416849265*^9, 3.818905113310216*^9, 3.8192998991107645`*^9, 
   3.8405214769794483`*^9, 3.840526044358729*^9, 3.8405564721777267`*^9, 
   3.8410704867198553`*^9, 3.8410725009347596`*^9, 3.8419008721870804`*^9},
 CellLabel->
  "Out[161]=",ExpressionUUID->"d4599f33-6128-4238-aac8-e6fafed881bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"EquationList1FirstOrder", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"EquationList1FirstOrder", "//.", 
      RowBox[{"{", 
       RowBox[{"P10", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", "X", "}"}], ",", 
          RowBox[{
           FormBox["G10Func",
            TraditionalForm], "[", "X", "]"}]}], "]"}]}], "}"}]}], "]"}]}],
   FontColor->GrayLevel[0]], TraditionalForm]], "Input",
 CellChangeTimes->{{3.812881209335841*^9, 3.8128812118274326`*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"2f8f1844-6c3f-47bc-8e74-33575f9b9d2d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["UY11", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["UX11", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["G11", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}], "\[Equal]", 
    RowBox[{
     SuperscriptBox["UX11", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"X", ",", "Y1"}], "]"}]}], ",", "True", ",", 
   RowBox[{
    RowBox[{"UX11", "[", 
     RowBox[{"X", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UX11", "[", 
     RowBox[{"X", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"UY11", "[", 
     RowBox[{"X", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"8", " ", 
     SqrtBox["3"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SqrtBox["3"], " ", 
       SqrtBox["K2"], " ", "X"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", "Pin"}], "\[Equal]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], ")"}], " ", 
       SqrtBox["K2"]}]], 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", "Pin", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]]}], "+", 
           RowBox[{"8", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", "X"}], ")"}]}]]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", "X"}], ")"}]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "-", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{"16", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]]}], ")"}], "2"], " ", "K2", " ", 
         RowBox[{"UY11", "[", 
          RowBox[{"X", ",", "0"}], "]"}]}]}], ")"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"G11", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"G11", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8128812149083385`*^9, 3.8134018065097227`*^9, 
  3.813423095877899*^9, 3.81342468325093*^9, 3.8136845781700945`*^9, 
  3.8139251666716967`*^9, 3.8139913131461487`*^9, 3.81401463118994*^9, 
  3.814028540829877*^9, 3.814030171180456*^9, 3.8140304736205716`*^9, 
  3.8140683857816677`*^9, 3.814372761988016*^9, 3.8145221501343546`*^9, 
  3.814526868603394*^9, 3.814531419000134*^9, 3.8158436854969187`*^9, 
  3.816449531641304*^9, 3.816931277628872*^9, 3.8181666140845346`*^9, 
  3.8185238736870685`*^9, 3.8185242529754524`*^9, 3.81873080462144*^9, 
  3.8187631445003242`*^9, 3.8188346010602636`*^9, 3.8188434191729045`*^9, 
  3.81890511552882*^9, 3.8192999024223723`*^9, 3.8405214793763905`*^9, 
  3.840526046688365*^9, 3.8405564743650827`*^9, 3.8410704890181117`*^9, 
  3.841072503568218*^9, 3.841900876975315*^9},
 CellLabel->
  "Out[162]=",ExpressionUUID->"bc3ec641-786f-448a-8df0-880e72dcdcba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"EquationList1FirstOrder", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911875920148973`*^9, 3.7911875983014584`*^9}, {
  3.818523879496127*^9, 3.818523880770569*^9}},
 CellLabel->
  "In[163]:=",ExpressionUUID->"5009ec76-9943-4a9d-b7a2-3cbc9b96de52"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", "G11"}], 
      RowBox[{"\[PartialD]", "X"}],
      MultilineFunction->None], "\[LongEqual]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[PartialD]", "2"], "UX11"}], 
      RowBox[{"\[PartialD]", 
       SuperscriptBox["Y1", "2"]}],
      MultilineFunction->None]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900877077256*^9},
 TextAlignment->Center,ExpressionUUID->"ffac1ce9-c898-4c59-a940-25cd5279982c"]
}, Open  ]],

Cell["The solution along with the no-slip boundary condition is", "Text",ExpressionUUID->"7df9a167-97b5-4293-bb64-4b5febacf720"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    RowBox[{"UX11Func", "[", 
     RowBox[{"X_", ",", "Y1_"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"DSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EquationList1FirstOrder", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"EquationList1FirstOrder", "[", 
           RowBox[{"[", "4", "]"}], "]"}], ",", 
          RowBox[{"EquationList1FirstOrder", "[", 
           RowBox[{"[", "5", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"UX11", "[", 
         RowBox[{"X", ",", "Y1"}], "]"}], ",", 
        RowBox[{"{", "Y1", "}"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911876416408596`*^9, 3.7911876592461915`*^9}, {
  3.818523890113459*^9, 3.818523892013479*^9}},
 CellLabel->
  "In[164]:=",ExpressionUUID->"ac04a579-6c35-492b-bbd1-cac92dd78010"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "Y1"}], " ", 
        FractionBox[
         RowBox[{"\[PartialD]", "G11"}], 
         RowBox[{"\[PartialD]", "X"}],
         MultilineFunction->None]}], "+", 
       RowBox[{
        SuperscriptBox["Y1", "2"], " ", 
        FractionBox[
         RowBox[{"\[PartialD]", "G11"}], 
         RowBox[{"\[PartialD]", "X"}],
         MultilineFunction->None]}]}], ")"}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900877196189*^9},
 TextAlignment->Center,ExpressionUUID->"30e77381-79d4-4e1b-a31c-e10c6898b8df"]
}, Open  ]],

Cell["Substituting into the leading order equations", "Text",ExpressionUUID->"51735f6f-cece-4832-864b-d0d0ab33da34"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList1FirstOrder", "=", 
   RowBox[{"EquationList1FirstOrder", "/.", 
    RowBox[{"{", 
     RowBox[{"UX11", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"X", ",", "Y1"}], "}"}], ",", 
        RowBox[{"UX11Func", "[", 
         RowBox[{"X", ",", "Y1"}], "]"}]}], "]"}]}], "}"}]}]}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.791187692183861*^9, 3.7911877067631283`*^9}},
 CellLabel->
  "In[165]:=",ExpressionUUID->"7f7d05d1-5529-4cc8-ad12-99eaad99e2e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "Y1"}], " ", 
         RowBox[{
          SuperscriptBox["G11", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["Y1", "2"], " ", 
         RowBox[{
          SuperscriptBox["G11", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["UY11", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"X", ",", "Y1"}], "]"}]}], "\[Equal]", "0"}], ",", "True", ",", 
   "True", ",", "True", ",", "True", ",", 
   RowBox[{
    RowBox[{"UY11", "[", 
     RowBox[{"X", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"8", " ", 
     SqrtBox["3"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SqrtBox["3"], " ", 
       SqrtBox["K2"], " ", "X"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", "Pin"}], "\[Equal]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], ")"}], " ", 
       SqrtBox["K2"]}]], 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", "Pin", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]]}], "+", 
           RowBox[{"8", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", "X"}], ")"}]}]]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", "X"}], ")"}]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "-", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{"16", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]]}], ")"}], "2"], " ", "K2", " ", 
         RowBox[{"UY11", "[", 
          RowBox[{"X", ",", "0"}], "]"}]}]}], ")"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"G11", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"G11", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB+I36iVLXoS+cZQ66Gc7L+aN4x3LtHvzgXSNm8akfUBa
YKPzWxDtkK/yf0bsG8eZFzl9hdLeOE6ZrDM1CEjvC2DPiwDSbcq5kgbpbxxl
3hwzBNGnBONqfYH0BcvWCeFA+tdWRY+6jDeOq6fIzanJBOq/mMXYDqQr2QuO
gmiHYp81bFlvHHeplevVAGmrtZpFc4D0hodvrywH0o8uLJ6/Dkjfi8nJXg+k
b2pZTQTRlZesRQ4B6bWPXDeHZb9x5Ft1asl8IB22YvqnhUA6UCZDewmQzlPd
9kYl740j69PK/T75QPcl7PhpXvDG8caj41qTi9445p/4vMCx+I3jTv1lp0G0
Ss/MZcuA9Jz14oXbgLTdbs3Qm0A6+GHu4rtA+sXrysO/gXTQxOvte0reOFp0
f11gNveNoy3fvdsWQJqrK2S7O5DmFdHe7DTvjePsgJ/rnIH05i8rNW/Mf+MI
ACkGxH4=
  "],
 CellLabel->
  "Out[165]=",ExpressionUUID->"00e38aba-9079-460c-9263-f3117384de5a"]
}, Open  ]],

Cell["We now solve the mass conservation equation, given by", "Text",ExpressionUUID->"9c95ff48-885a-4f71-9d42-1521f8c9b7d2"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"EquationList1FirstOrder", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911877376747613`*^9, 3.791187742584978*^9}, {
  3.81852391414106*^9, 3.818523915742159*^9}},
 CellLabel->
  "In[166]:=",ExpressionUUID->"eafa38aa-314c-4dc1-9397-844e12746517"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "Y1"}], " ", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "G11"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["X", "2"]}],
           MultilineFunction->None]}], "+", 
         RowBox[{
          SuperscriptBox["Y1", "2"], " ", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "G11"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["X", "2"]}],
           MultilineFunction->None]}]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{"\[PartialD]", "UY11"}], 
       RowBox[{"\[PartialD]", "Y1"}],
       MultilineFunction->None]}], "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008774290533`*^9},
 TextAlignment->Center,ExpressionUUID->"81074133-a202-4932-923a-1f5329fe3a3d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    RowBox[{"UY11Func", "[", 
     RowBox[{"X_", ",", "Y1_"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"DSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EquationList1FirstOrder", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"EquationList1FirstOrder", "[", 
           RowBox[{"[", "6", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"UY11", "[", 
         RowBox[{"X", ",", "Y1"}], "]"}], ",", 
        RowBox[{"{", "Y1", "}"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911877596410384`*^9, 3.791187774753732*^9}, {
  3.8185240403196087`*^9, 3.8185240417480273`*^9}},
 CellLabel->
  "In[167]:=",ExpressionUUID->"1cab1b1d-f40f-4163-b07a-e805f83ccfd4"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G11"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["Y1", "2"], " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G11"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["Y1", "3"], " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G11"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None]}]}], ")"}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008775779696`*^9},
 TextAlignment->Center,ExpressionUUID->"359c497d-56a7-4910-aacc-95b022e066f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EquationList1FirstOrder", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"EquationList1FirstOrder", "/.", 
     RowBox[{"{", 
      RowBox[{"UY11", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"X", ",", "Y1"}], "}"}], ",", 
         RowBox[{"UY11Func", "[", 
          RowBox[{"X", ",", "Y1"}], "]"}]}], "]"}]}], "}"}]}], "]"}]}], 
  TraditionalForm]], "Input",
 CellLabel->
  "In[168]:=",ExpressionUUID->"a93764b7-91b5-42f6-9adb-7d6445964ade"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{"8", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SqrtBox["3"], " ", 
        SqrtBox["K2"], " ", "X"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", "Pin"}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}], " ", 
      SqrtBox["K2"], " ", 
      RowBox[{
       SuperscriptBox["G11", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}]}], "\[Equal]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], ")"}], " ", 
       SqrtBox["K2"]}]], 
     RowBox[{"3", " ", "a1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SqrtBox["3"], " ", 
        SqrtBox["K2"], " ", "X"}]], " ", "Pin", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "X"}], ")"}]}]]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"4", "+", "X"}], ")"}]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"8", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"12", " ", "K2", " ", 
            SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"12", " ", "K2", " ", 
            SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"12", " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"12", " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}], 
   ",", 
   RowBox[{
    RowBox[{"G11", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"G11", "[", "1", "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8134018412732077`*^9, 3.8134231222811737`*^9, 
  3.81342468433068*^9, 3.8136845792171326`*^9, 3.8139252582315626`*^9, 
  3.813991314067957*^9, 3.8140146322388024`*^9, 3.8140285420953655`*^9, 
  3.814030172240633*^9, 3.814030474668643*^9, 3.8140683864793096`*^9, 
  3.8143727630116568`*^9, 3.814522151231982*^9, 3.814526869588807*^9, 
  3.8145314201948233`*^9, 3.815843686486577*^9, 3.8164495326237574`*^9, 
  3.816931278564181*^9, 3.8181666150899353`*^9, 3.8185240652684793`*^9, 
  3.8185242540949*^9, 3.8187308056666813`*^9, 3.8187631456306734`*^9, 
  3.818834602248964*^9, 3.818843420373214*^9, 3.8189051166710224`*^9, 
  3.8192999039568977`*^9, 3.84052148093316*^9, 3.8405260478876896`*^9, 
  3.8405564755324097`*^9, 3.841070490300846*^9, 3.841072504802508*^9, 
  3.8419008789401793`*^9},
 CellLabel->
  "Out[168]=",ExpressionUUID->"d17ffde7-9338-4eaf-848c-aec3b6157bc8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   FormBox[
    FormBox["EquationList1FirstOrder",
     TraditionalForm],
    TraditionalForm], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     FormBox[
      FormBox["EquationList1FirstOrder",
       TraditionalForm],
      TraditionalForm], "//.", 
     FormBox[
      RowBox[{"{", 
       RowBox[{"P10", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", "X", "}"}], ",", 
          RowBox[{
           FormBox["G10Func",
            TraditionalForm], "[", "X", "]"}]}], "]"}]}], "}"}],
      TraditionalForm]}], "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.7911934333974648`*^9, 3.7911934394857883`*^9}, 
   3.806721974591929*^9, 3.812197249832556*^9, 3.813991071186158*^9},
 CellLabel->
  "In[169]:=",ExpressionUUID->"124dfbbe-ffee-4de7-b836-119dea9613c2"],

Cell["Now solving the ODE for G11 with the existing BC", "Text",
 CellChangeTimes->{{3.79118786990961*^9, 3.791187884182527*^9}, 
   3.812256020942377*^9, {3.813991104077637*^9, 
   3.813991130735019*^9}},ExpressionUUID->"f156db73-a223-4ad4-b39a-\
726c59bd67c3"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"EquationList1FirstOrder", "[", 
    RowBox[{"[", "7", "]"}], "]"}], "]"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"EquationList1FirstOrder", "[", 
    RowBox[{"[", "8", "]"}], "]"}], "]"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"EquationList1FirstOrder", "[", 
    RowBox[{"[", "9", "]"}], "]"}], "]"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.8117549437131133`*^9, 3.8117549542747364`*^9}, {
  3.8185240809900656`*^9, 3.818524087938642*^9}},
 CellLabel->
  "In[170]:=",ExpressionUUID->"3cc3be6b-1f09-4921-a032-813a4933ef86"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     RowBox[{
      RowBox[{"8", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", "X"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]]}], "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", "Pin"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], ")"}], " ", 
       SqrtBox["K2"], " ", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[PartialD]", "2"], "G11"}], 
        RowBox[{"\[PartialD]", 
         SuperscriptBox["X", "2"]}],
        MultilineFunction->None]}]}], "\[LongEqual]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]]}], ")"}], " ", 
        SqrtBox["K2"]}]], 
      RowBox[{"3", " ", "a1", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", "X"}]], " ", "Pin", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]]}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "X"}], ")"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"4", "+", "X"}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"8", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}], "+", 
            RowBox[{"12", " ", "K2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008790651073`*^9},
 TextAlignment->Center,ExpressionUUID->"2ac837eb-31e2-4a04-8a3c-72684c34dcac"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"G11", "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900879142065*^9},
 TextAlignment->Center,ExpressionUUID->"58b01f37-b3fb-475c-8ce9-8dae8e0d7344"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"G11", "\[LongEqual]", "0"}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008792320113`*^9},
 TextAlignment->Center,ExpressionUUID->"6c4acb07-ba96-4590-bb3b-a9c37bc4128f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"G11Func", "[", "X_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"DSolve", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EquationList1FirstOrder", "[", 
             RowBox[{"[", "7", "]"}], "]"}], ",", 
            RowBox[{"EquationList1FirstOrder", "[", 
             RowBox[{"[", "8", "]"}], "]"}], ",", 
            RowBox[{"EquationList1FirstOrder", "[", 
             RowBox[{"[", "9", "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"G11", "[", "X", "]"}], ",", 
          RowBox[{"{", "X", "}"}]}], "]"}], ",", "AssumptionOnScaling"}], 
       "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.812197330852301*^9, 3.8121973345317907`*^9}, {
  3.812197387245631*^9, 3.8121973938960657`*^9}, {3.8122567793709774`*^9, 
  3.812256805244014*^9}, {3.8134231532174683`*^9, 3.813423161261259*^9}, {
  3.813423193666979*^9, 3.813423219290701*^9}, {3.813423260002576*^9, 
  3.8134232601431923`*^9}},
 CellLabel->
  "In[173]:=",ExpressionUUID->"625e88c8-10a5-44e0-a76b-7ae2fc3951fd"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"48", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"]}]]}], ")"}], "2"], " ", 
    SuperscriptBox["K2", "2"]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SqrtBox["3"], " ", 
     SqrtBox["K2"], " ", "X"}]], " ", "Pin", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"8", " ", 
      SqrtBox["3"], " ", 
      SqrtBox["K2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"8", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"], " ", "X"}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "X"}], ")"}]}]], "-", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"4", "+", "X"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "X"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"3", " ", "a1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"8", "-", 
           RowBox[{"16", " ", "X"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "X"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"8", "-", 
           RowBox[{"16", " ", "X"}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "X"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"24", " ", "K2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "X"}], ")"}], "2"]}], "+", 
           RowBox[{"9", " ", "X"}]}], ")"}]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"8", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"4", " ", "K2", " ", 
            SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", 
         RowBox[{"(", 
          RowBox[{"3", "-", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"12", " ", "K2", " ", 
            SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"7", "-", 
              RowBox[{"24", " ", "K2"}]}], ")"}], " ", "X"}], "+", 
           RowBox[{"24", " ", "K2", " ", 
            SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"4", "+", "X"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"7", "-", 
              RowBox[{"24", " ", "K2"}]}], ")"}], " ", "X"}], "+", 
           RowBox[{"24", " ", "K2", " ", 
            SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"5", "-", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"12", " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{"5", "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"12", " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAOIQ770tBulvHKfckGj0BdJcD9taQfQPyaZp4UB6cur3
4LbMN47OU7a/B9FfokRZ24G06YvP3CC6d/J2YRBtNUn5GIgOq2FZy5b1xnFf
31fLGiBttuNi0Rwg7ek37+pyIM1dHbdgHZDuClHJWQ+kLyx9NRFEn8g8IHII
SMe0f9kclv3G8Qhjw9L5QLqr2efzQiC9yVFfZwmQDi5MequSB7S/U/eAT/4b
x+wd2b/MC9441lg3a08ueuO4JPrtHsfiN46afslnQHSdWuDyZUDadMPVwm1A
2rztX+hNIG03Q3vJXSDdw2V65DeQrjrytGNPyRtHlcUHF5rNfePoNHn+HQsg
/XQ75w53IP1j5cvNTvOA7gzet94ZSNt3fNS6Mf+NIwCel6je
  "],
 CellLabel->
  "Out[173]=",ExpressionUUID->"5567a67c-10ca-481b-99ec-0f88a6519ac2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextbookEq", "[", 
  RowBox[{"UY11Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.818524101463795*^9, 3.818524103176914*^9}},
 CellLabel->
  "In[174]:=",ExpressionUUID->"8f832aeb-15f8-46c4-8c3c-4985c1e5a10e"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G11"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["Y1", "2"], " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G11"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["Y1", "3"], " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "G11"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["X", "2"]}],
         MultilineFunction->None]}]}], ")"}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900887699793*^9},
 TextAlignment->Center,ExpressionUUID->"ff0dc7b6-408e-405e-a87d-9226c4ceb30c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"UY11Func", "[", 
    RowBox[{"X_", ",", "Y1_"}], "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"UY11Func", "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "//.", 
     FormBox[
      RowBox[{"{", 
       RowBox[{"G11", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", "X", "}"}], ",", 
          RowBox[{
           FormBox["G11Func",
            TraditionalForm], "[", "X", "]"}]}], "]"}]}], "}"}],
      TraditionalForm]}], "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{3.813423331329009*^9},
 CellLabel->
  "In[175]:=",ExpressionUUID->"de30f588-6e85-41fe-8117-3e3e63d1a1bb"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"48", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"]}]]}], ")"}], "2"], " ", "K2"}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SqrtBox["3"], " ", 
     SqrtBox["K2"], " ", "X"}]], " ", "Pin", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SqrtBox["3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", 
      SqrtBox["K2"]}], "-", 
     RowBox[{"3", " ", "a1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "X"}], ")"}]}]]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"4", "+", "X"}], ")"}]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"8", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"12", " ", "K2", " ", 
            SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"12", " ", "K2", " ", 
            SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"12", " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"12", " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "Y1"}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"2", " ", "Y1"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.8134233343455048`*^9, 3.8134246897396183`*^9, 
  3.813684584858877*^9, 3.813991319116989*^9, 3.814014637553867*^9, 
  3.8140285475563602`*^9, 3.814030177777855*^9, 3.814030479903757*^9, 
  3.8140683904337873`*^9, 3.814372768230129*^9, 3.8145221565809813`*^9, 
  3.814526874973705*^9, 3.8145314261669316`*^9, 3.8158436916714087`*^9, 
  3.8164495380306325`*^9, 3.8169312839243326`*^9, 3.818166620794615*^9, 
  3.818524136105111*^9, 3.818524259749937*^9, 3.818730811138584*^9, 
  3.818763151363364*^9, 3.818834608637903*^9, 3.818843426019971*^9, 
  3.818905122395467*^9, 3.819299912154129*^9, 3.84052148672299*^9, 
  3.840526053671333*^9, 3.8405564809706287`*^9, 3.841070496020694*^9, 
  3.8410725105943346`*^9, 3.841900888885108*^9},
 CellLabel->
  "Out[175]=",ExpressionUUID->"d13662e6-1d2c-4d2a-9e40-81554f6160d2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"UX11Func", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.8185241068590856`*^9, 3.8185241080312138`*^9}},
 CellLabel->
  "In[176]:=",ExpressionUUID->"e6326985-bc7a-4616-9b0e-f6416da9108d"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "Y1"}], " ", 
        FractionBox[
         RowBox[{"\[PartialD]", "G11"}], 
         RowBox[{"\[PartialD]", "X"}],
         MultilineFunction->None]}], "+", 
       RowBox[{
        SuperscriptBox["Y1", "2"], " ", 
        FractionBox[
         RowBox[{"\[PartialD]", "G11"}], 
         RowBox[{"\[PartialD]", "X"}],
         MultilineFunction->None]}]}], ")"}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900889001042*^9},
 TextAlignment->Center,ExpressionUUID->"d0336ebe-e070-484f-ac81-ca6756a67f97"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"UX11Func", "[", 
    RowBox[{"X_", ",", "Y1_"}], "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"UX11Func", "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "//.", 
     FormBox[
      RowBox[{"{", 
       RowBox[{"G11", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", "X", "}"}], ",", 
          RowBox[{
           FormBox["G11Func",
            TraditionalForm], "[", "X", "]"}]}], "]"}]}], "}"}],
      TraditionalForm]}], "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.7911937229045353`*^9, 3.7911937525338836`*^9}, {
  3.8117430114466553`*^9, 3.811743012149707*^9}},
 CellLabel->
  "In[177]:=",ExpressionUUID->"86a7dc7a-8049-4cf1-9b67-696afc7bb52e"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"96", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"]}]]}], ")"}], "2"], " ", 
    SuperscriptBox["K2", "2"]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SqrtBox["3"], " ", 
     SqrtBox["K2"], " ", "X"}]], " ", "Pin", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", 
          SqrtBox["3"], " ", 
          SqrtBox["K2"]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]]}], "-", 
        RowBox[{
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "X"}], ")"}]}]]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         SqrtBox["K2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", 
         SqrtBox["K2"]}]}], ")"}], " ", 
      SqrtBox["K2"]}], "+", 
     RowBox[{"3", " ", "a1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "16"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "X"}], ")"}]}]]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "X"}], ")"}]}]]}], "+", 
        RowBox[{"8", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         SqrtBox["K2"]}], "+", 
        RowBox[{"8", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         SqrtBox["K2"]}], "-", 
        RowBox[{"8", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
         SqrtBox["K2"]}], "-", 
        RowBox[{"8", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
         SqrtBox["K2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "X"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"16", " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "X"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", "K2", " ", "X", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]}], ")"}]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"8", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", "K2", " ", "X", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"], " ", "X"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", "X"}]], " ", 
         RowBox[{"(", 
          RowBox[{"7", "+", 
           RowBox[{"24", " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"4", "+", "X"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"7", "+", 
           RowBox[{"24", " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "X"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SqrtBox["3"], "-", 
           RowBox[{"3", " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox["K2"]}]], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SqrtBox["3"], "+", 
           RowBox[{"3", " ", 
            SqrtBox["K2"], " ", "X"}], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", "K2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "Y1"}], ")"}], " ", "Y1"}]}]], "Output",
 CellChangeTimes->{3.803137316029645*^9, 3.8066549550297623`*^9, 
  3.811743020278055*^9, 3.8117549898561573`*^9, 3.813423402242174*^9, 
  3.8134246909426746`*^9, 3.8136845861556573`*^9, 3.8139913203044186`*^9, 
  3.8140146388375235`*^9, 3.8140285487307806`*^9, 3.8140301790264797`*^9, 
  3.814030481117836*^9, 3.8140683913389397`*^9, 3.8143727694901943`*^9, 
  3.814522157834625*^9, 3.8145268762319965`*^9, 3.8145314275753336`*^9, 
  3.8158436928872557`*^9, 3.816449539280914*^9, 3.816931285132557*^9, 
  3.8181666221700974`*^9, 3.8185241385236073`*^9, 3.818524261068691*^9, 
  3.8187308124148455`*^9, 3.8187631526776237`*^9, 3.81883461003074*^9, 
  3.818843427349204*^9, 3.8189051235985193`*^9, 3.8192999141186595`*^9, 
  3.840521488003648*^9, 3.840526055008577*^9, 3.840556482238637*^9, 
  3.84107049734872*^9, 3.841072511881734*^9, 3.841900891246744*^9},
 CellLabel->
  "Out[177]=",ExpressionUUID->"23b177b6-0966-4ffa-9df0-4286b52acdea"]
}, Open  ]],

Cell[TextData[StyleBox["Summary:",
 FontWeight->"Bold",
 Background->RGBColor[0.87, 0.94, 1]]], "Text",
 CellChangeTimes->{{3.813423411023903*^9, 
  3.81342343244118*^9}},ExpressionUUID->"40417323-f82a-480f-b7bf-\
599c9bca52db"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    FormBox["G11Func",
     TraditionalForm], "[", "X", "]"}], "]"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"UX11Func", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], "]"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"UY11Func", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], "]"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.791193770490223*^9, 3.791193780339069*^9}, {
  3.8185241121799936`*^9, 3.8185241180485554`*^9}, {3.8185243073980427`*^9, 
  3.8185243592918005`*^9}, {3.81852464831404*^9, 3.8185246497783422`*^9}},
 CellLabel->
  "In[178]:=",ExpressionUUID->"0324f1cf-18a3-4dce-bc01-f50aa4afdbaf"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"48", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]]}], ")"}], "2"], " ", 
       SuperscriptBox["K2", "2"]}]], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SqrtBox["3"], " ", 
        SqrtBox["K2"], " ", "X"}]], " ", "Pin", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"8", " ", 
         SqrtBox["3"], " ", 
         SqrtBox["K2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"]}]], "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"8", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"]}]], "-", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}]], "-", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "X"}], ")"}]}]], "-", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", "X"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "X"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"3", " ", "a1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"8", "-", 
              RowBox[{"16", " ", "X"}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", "X"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"8", "-", 
              RowBox[{"16", " ", "X"}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", "X"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], "+", 
              RowBox[{"24", " ", "K2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "X"}], ")"}], "2"]}], "+", 
              RowBox[{"9", " ", "X"}]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"4", " ", "K2", " ", 
               SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]], " ", 
            RowBox[{"(", 
             RowBox[{"3", "-", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"7", "-", 
                 RowBox[{"24", " ", "K2"}]}], ")"}], " ", "X"}], "+", 
              RowBox[{"24", " ", "K2", " ", 
               SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", "X"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"7", "-", 
                 RowBox[{"24", " ", "K2"}]}], ")"}], " ", "X"}], "+", 
              RowBox[{"24", " ", "K2", " ", 
               SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"5", "-", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            RowBox[{"(", 
             RowBox[{"5", "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419008913976583`*^9},
 TextAlignment->Center,ExpressionUUID->"03b6ea18-7f51-4bee-9291-c9bd8ec9bd0a"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"96", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]]}], ")"}], "2"], " ", 
       SuperscriptBox["K2", "2"]}]], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SqrtBox["3"], " ", 
        SqrtBox["K2"], " ", "X"}]], " ", "Pin", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SqrtBox["3"], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]]}], "-", 
           RowBox[{
            SqrtBox["3"], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", "X"}], ")"}]}]]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            SqrtBox["K2"]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]], " ", 
            SqrtBox["K2"]}]}], ")"}], " ", 
         SqrtBox["K2"]}], "+", 
        RowBox[{"3", " ", "a1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "16"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "X"}], ")"}]}]]}], "-", 
           RowBox[{"16", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", "X"}], ")"}]}]]}], "+", 
           RowBox[{"8", " ", 
            SqrtBox["3"], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            SqrtBox["K2"]}], "+", 
           RowBox[{"8", " ", 
            SqrtBox["3"], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            SqrtBox["K2"]}], "-", 
           RowBox[{"8", " ", 
            SqrtBox["3"], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
            SqrtBox["K2"]}], "-", 
           RowBox[{"8", " ", 
            SqrtBox["3"], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", " ", "X"}]}], ")"}]}]], " ", 
            SqrtBox["K2"]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", "X"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              RowBox[{"16", " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "X"}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"12", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]], " ", "K2", " ", "X", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}]}], ")"}]}], "-", 
           RowBox[{"12", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", "K2", " ", "X", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]], " ", 
            RowBox[{"(", 
             RowBox[{"7", "+", 
              RowBox[{"24", " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", " ", "X"}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", "X"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"7", "+", 
              RowBox[{"24", " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", " ", "X"}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SqrtBox["3"], "-", 
              RowBox[{"3", " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            SqrtBox["K2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SqrtBox["3"], "+", 
              RowBox[{"3", " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "Y1"}], ")"}], " ", "Y1"}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900891518587*^9},
 TextAlignment->Center,ExpressionUUID->"11daf75b-058b-4d64-985a-51f845ef1b9d"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"48", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox["K2"]}]]}], ")"}], "2"], " ", "K2"}]], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SqrtBox["3"], " ", 
        SqrtBox["K2"], " ", "X"}]], " ", "Pin", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", 
         SqrtBox["3"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"]}]], "-", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox["K2"], " ", "X"}]]}], ")"}], " ", 
         SqrtBox["K2"]}], "-", 
        RowBox[{"3", " ", "a1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]]}], "+", 
           RowBox[{"8", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", "X"}], ")"}]}]]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", "X"}], ")"}]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "-", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", "X"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"]}]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox["K2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox["K2"], " ", "X"}], "+", 
              RowBox[{"12", " ", "K2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "Y1"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "Y1"}]}], ")"}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900891633521*^9},
 TextAlignment->Center,ExpressionUUID->"7765ddb4-253b-4f3a-8342-996ec2bee2b5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Results", "Section",
 CellChangeTimes->{{3.794032724343643*^9, 3.7940327329434056`*^9}, 
   3.8410686250309877`*^9},ExpressionUUID->"666d5801-8dce-4738-ac85-\
618cbe9c801a"],

Cell[CellGroupData[{

Cell["Non-dimensional pressure and velocity functions", "Subsection",
 CellChangeTimes->{{3.813854003801598*^9, 3.813854004872179*^9}, {
  3.81399116126499*^9, 3.8139911662483273`*^9}, {3.841071466074975*^9, 
  3.8410714887048244`*^9}},ExpressionUUID->"fb3b0c20-0993-45a4-9d71-\
70bba5d441a9"],

Cell[CellGroupData[{

Cell["K1, K2 to K & ratio of h1/h2", "Subsubsection",
 CellChangeTimes->{{3.81400353708805*^9, 3.814003574073125*^9}, {
  3.814008167876248*^9, 
  3.8140081693681173`*^9}},ExpressionUUID->"3f744ea4-0e89-4fc8-9c4b-\
371dbcab8cdf"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ShallowRelation1", "=", 
   RowBox[{"\[Epsilon]1", "\[Equal]", 
    RowBox[{"h1", "/", "l"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ShallowRelation2", "=", 
   RowBox[{"\[Epsilon]2", "\[Equal]", 
    RowBox[{"h2", "/", "l"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{3.814003628218221*^9, 3.8140079261426935`*^9, 
  3.814015110325591*^9},
 CellLabel->
  "In[181]:=",ExpressionUUID->"4e301745-8b2b-43ba-8422-89492349c5b5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FirstScalingRelation1", "=", 
   RowBox[{
    FractionBox["uyC", "ux1C"], "\[Equal]", "\[Epsilon]1"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstScalingRelation2", "=", 
   RowBox[{
    FractionBox["uyC", "ux2C"], "\[Equal]", "\[Epsilon]2"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.814003632618823*^9, 3.81400363288443*^9}},
 CellLabel->
  "In[183]:=",ExpressionUUID->"a316e0a7-c2e6-4229-9631-572a8bf3c2dc"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Kparameter1", "=", 
   RowBox[{"K1", "\[Equal]", 
    RowBox[{"k", " ", 
     RowBox[{"\[Mu]", "/", 
      RowBox[{"(", 
       RowBox[{"l", " ", 
        SuperscriptBox["\[Epsilon]1", "3"]}], ")"}]}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Kparameter2", "=", 
   RowBox[{"K2", "\[Equal]", 
    RowBox[{"k", " ", 
     RowBox[{"\[Mu]", "/", 
      RowBox[{"(", 
       RowBox[{"l", " ", 
        SuperscriptBox["\[Epsilon]2", "3"]}], ")"}]}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8140036362766457`*^9, 3.814003639416251*^9}, {
  3.8140059430255036`*^9, 3.814005943150434*^9}, {3.814008302635632*^9, 
  3.814008322246358*^9}},
 CellLabel->
  "In[185]:=",ExpressionUUID->"a03fdd3d-4059-4614-970d-ba405de92ae5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AssumptionOnScaling", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"l", ">", "0"}], ",", 
     RowBox[{"h1", ">", "0"}], ",", 
     RowBox[{"h2", ">", "0"}], ",", 
     RowBox[{"pC1", ">", "0"}], ",", 
     RowBox[{"uxC", ">", "0"}], ",", 
     RowBox[{"uyC", ">", "0"}], ",", 
     RowBox[{"\[Epsilon]1", ">", "0"}], ",", 
     RowBox[{"\[Epsilon]2", ">", "0"}], ",", 
     RowBox[{"\[Mu]", ">", "0"}], ",", 
     RowBox[{"K1", ">", "0"}], ",", 
     RowBox[{"K2", ">", "0"}], ",", 
     RowBox[{"a1", ">", "0"}], ",", 
     RowBox[{"Pin", ">", "0"}], ",", 
     RowBox[{"R", ">", "0"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8140086812943993`*^9, 3.8140086869030704`*^9}, {
  3.814009060665785*^9, 3.8140091024735775`*^9}},
 CellLabel->
  "In[187]:=",ExpressionUUID->"5dfa33bd-c1e6-4fa5-ab2c-4a5c11308ba4"],

Cell["Substituting K1 and K2 (Only where K1 or K2 exist):", "Text",
 CellChangeTimes->{{3.8140069431658635`*^9, 3.814006952184856*^9}, {
  3.814012971626053*^9, 
  3.814013000588687*^9}},ExpressionUUID->"857d713c-06fa-4bae-be68-\
8c5e07621cb9"],

Cell[TextData[{
 StyleBox["Region 1",
  FontVariations->{"Underline"->True}],
 " :"
}], "Text",
 CellChangeTimes->{{3.814012886228238*^9, 
  3.8140128879984255`*^9}},ExpressionUUID->"d40154ea-c28c-4cc4-aa53-\
9b477bd5729b"],

Cell["Pressure", "Text",
 CellChangeTimes->{{3.814012851358394*^9, 
  3.8140128902193704`*^9}},ExpressionUUID->"08a84314-99a5-4fce-b946-\
a06a9fa74a27"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"G10Func", "[", "X", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G11Func", "[", "X", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"G11FuncR", "[", "X", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"G11Func", "[", "X", "]"}], "//.", 
     RowBox[{"K2", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Kp", "*", "R"}], "}"}]}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8140081203932056`*^9, 3.8140081210407047`*^9}, {
   3.814012813252533*^9, 3.814012829354537*^9}, 3.81406851178942*^9},
 CellLabel->
  "In[188]:=",ExpressionUUID->"11301b0f-845d-48eb-a172-59f3d08a21ac"],

Cell["UY", "Text",
 CellChangeTimes->{{3.8140128766982713`*^9, 3.8140128940909147`*^9}, {
  3.814013529505287*^9, 
  3.814013530180934*^9}},ExpressionUUID->"a43845bf-bc18-4ed8-a295-\
9fe818a0725d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"UX10Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UX11Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UX11FuncR", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"UX11Func", "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "//.", 
     RowBox[{"K2", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Kp", "*", "R"}], "}"}]}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.814012907133856*^9, 3.8140129493074956`*^9}, {
   3.8140130626056814`*^9, 3.814013071257039*^9}, 3.8140131191339197`*^9, {
   3.814013197041531*^9, 3.81401324815383*^9}, {3.814013521617198*^9, 
   3.8140135227483587`*^9}, {3.814068515384762*^9, 3.814068516589048*^9}},
 CellLabel->
  "In[191]:=",ExpressionUUID->"4fda771d-762d-43f2-b896-e663650e39b2"],

Cell["UY", "Text",
 CellChangeTimes->{{3.814013525884781*^9, 
  3.8140135279797297`*^9}},ExpressionUUID->"5043f6f9-5ec8-443f-898e-\
f49fc5d1f220"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"UY10Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UY11Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UY11FuncR", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"UY11Func", "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "//.", 
     RowBox[{"K2", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Kp", "*", "R"}], "}"}]}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8140135364164715`*^9, 3.8140136776972704`*^9}, 
   3.8140685201706553`*^9},
 CellLabel->
  "In[194]:=",ExpressionUUID->"9fa24da1-47d8-4ea5-917b-3e2e96c8148c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Region 1", "Subsection",
 CellChangeTimes->{{3.813853950578466*^9, 
  3.81385395287887*^9}},ExpressionUUID->"69bd0bac-d683-4255-a931-\
0918bd45f894"],

Cell[CellGroupData[{

Cell["Pressure - definitions ", "Subsubsection",
 CellChangeTimes->{{3.8138539670917664`*^9, 3.8138539768442802`*^9}, {
   3.81385484244687*^9, 3.8138548675050707`*^9}, {3.814006230007923*^9, 
   3.8140062303357215`*^9}, {3.814006745498549*^9, 3.8140067520727515`*^9}, 
   3.8410715146637144`*^9, {3.841071838984377*^9, 
   3.8410718467390375`*^9}},ExpressionUUID->"1bafd2af-159c-4745-9502-\
56ad696e8e22"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G10Func", "[", "X", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"G11FuncR", "[", "X", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"GFuncAsy", "[", 
   RowBox[{"X_", ",", "Kp_", ",", "R_", ",", "Pin_", ",", "a1_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"G10Func", "[", "X", "]"}], "+", 
   RowBox[{"Kp", " ", 
    RowBox[{"G11FuncR", "[", "X", "]"}]}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GFuncAsyCorr", "[", 
    RowBox[{"X_", ",", "Kp_", ",", "R_", ",", "Pin_", ",", "a1_"}], "]"}], 
   "=", 
   RowBox[{"Kp", " ", 
    RowBox[{"G11FuncR", "[", "X", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.814006248508891*^9, 3.814006248518885*^9}, 
   3.814006374225153*^9, {3.814006774014435*^9, 3.814006784992659*^9}, {
   3.814008182010174*^9, 3.8140082154160137`*^9}, {3.814008248989914*^9, 
   3.814008254820907*^9}, {3.8140102750092425`*^9, 3.814010334354715*^9}, {
   3.8140104163382435`*^9, 3.8140104206713853`*^9}, {3.814012118966838*^9, 
   3.8140121238522615`*^9}, {3.8140684374693837`*^9, 3.8140684482361307`*^9}, 
   3.814068480753261*^9, {3.8143728053752985`*^9, 3.8143728271387672`*^9}, 
   3.814522190509121*^9, 3.814522280259774*^9},
 CellLabel->
  "In[197]:=",ExpressionUUID->"566108ee-a11b-4c0f-bf80-aa321bd8e768"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Pin", "-", 
   RowBox[{"Pin", " ", "X"}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"48", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"4", " ", 
           SqrtBox["3"], " ", 
           SqrtBox[
            RowBox[{"Kp", " ", "R"}]]}]]}], ")"}], "2"], " ", "Kp", " ", 
      SuperscriptBox["R", "2"]}]], 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SqrtBox["3"], " ", 
       SqrtBox[
        RowBox[{"Kp", " ", "R"}]], " ", "X"}]], " ", "Pin", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", " ", 
        SqrtBox["3"], " ", 
        SqrtBox[
         RowBox[{"Kp", " ", "R"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             RowBox[{"Kp", " ", "R"}]]}]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"8", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             RowBox[{"Kp", " ", "R"}]]}]], "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             RowBox[{"Kp", " ", "R"}]], " ", "X"}]], "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             RowBox[{"Kp", " ", "R"}]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "X"}], ")"}]}]], "-", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]], " ", "X"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "X"}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]], " ", 
             RowBox[{"(", 
              RowBox[{"4", "+", "X"}], ")"}]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "X"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"3", " ", "a1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]]}]]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"6", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]]}]]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]], " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"2", " ", "X"}]}], ")"}]}]]}], "+", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
           RowBox[{"(", 
            RowBox[{"8", "-", 
             RowBox[{"16", " ", "X"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]], " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", "X"}], ")"}]}]], " ", 
           RowBox[{"(", 
            RowBox[{"8", "-", 
             RowBox[{"16", " ", "X"}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]], " ", 
             RowBox[{"(", 
              RowBox[{"2", "+", "X"}], ")"}]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"24", " ", "Kp", " ", "R", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "X"}], ")"}], "2"]}], "+", 
             RowBox[{"9", " ", "X"}]}], ")"}]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"8", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]]}]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               RowBox[{"Kp", " ", "R"}]], " ", "X"}], "+", 
             RowBox[{"4", " ", "Kp", " ", "R", " ", 
              SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]], " ", "X"}]], " ", 
           RowBox[{"(", 
            RowBox[{"3", "-", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               RowBox[{"Kp", " ", "R"}]], " ", "X"}], "+", 
             RowBox[{"12", " ", "Kp", " ", "R", " ", 
              SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]], " ", "X"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"7", "-", 
                RowBox[{"24", " ", "Kp", " ", "R"}]}], ")"}], " ", "X"}], "+", 
             RowBox[{"24", " ", "Kp", " ", "R", " ", 
              SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]], " ", 
             RowBox[{"(", 
              RowBox[{"4", "+", "X"}], ")"}]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"7", "-", 
                RowBox[{"24", " ", "Kp", " ", "R"}]}], ")"}], " ", "X"}], "+", 
             RowBox[{"24", " ", "Kp", " ", "R", " ", 
              SuperscriptBox["X", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "X"}], ")"}]}]], " ", 
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               RowBox[{"Kp", " ", "R"}]], " ", "X"}], "+", 
             RowBox[{"12", " ", "Kp", " ", "R", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", 
                SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{"Kp", " ", "R"}]]}]], " ", 
           RowBox[{"(", 
            RowBox[{"5", "+", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               RowBox[{"Kp", " ", "R"}]], " ", "X"}], "+", 
             RowBox[{"12", " ", "Kp", " ", "R", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", 
                SuperscriptBox["X", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.814522280661542*^9, 3.8145268798024406`*^9, 
  3.8145316943320827`*^9, 3.815843773236042*^9, 3.816450116917392*^9, 
  3.8169312893806105`*^9, 3.8181666283289604`*^9, 3.818524419710314*^9, 
  3.8187308161906853`*^9, 3.81876315658535*^9, 3.8188346142316628`*^9, 
  3.81884343125594*^9, 3.8189051273820972`*^9, 3.819299920391467*^9, 
  3.840526058883322*^9, 3.8410705013825874`*^9, 3.84107251549272*^9, 
  3.8419009059154043`*^9},
 CellLabel->
  "Out[199]=",ExpressionUUID->"98f96892-1c65-4c94-a186-d30526f95a7a"]
}, Open  ]],

Cell[BoxData[{
 FormBox[
  RowBox[{
   FormBox[
    FormBox[
     RowBox[{"GFuncAsy", "[", 
      RowBox[{
      "0.5", ",", "0.50", ",", "0.3", ",", "0.1", ",", "1", ",", "0.2"}], 
      "]"}],
     TraditionalForm],
    TraditionalForm], ";"}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"GFuncAsyCorr", "[", 
    RowBox[{
    "0.5", ",", "0.50", ",", "0.3", ",", "0.1", ",", "1", ",", "0.2"}], "]"}],
    ";"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.8140082407811403`*^9, 3.8140082412148705`*^9}, {
   3.8140103442122364`*^9, 3.8140103877365093`*^9}, {3.814010428071245*^9, 
   3.814010428587209*^9}, 3.841071581606206*^9},
 CellLabel->
  "In[201]:=",ExpressionUUID->"d78bc078-395f-4a0c-bace-bd04c4cadfd7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pressure - total", "Subsubsection",
 CellChangeTimes->{{3.8410716019250064`*^9, 
  3.841071624238802*^9}},ExpressionUUID->"4e7a0de3-fd4f-4757-98f1-\
482feff78d74"],

Cell[TextData[StyleBox["The leading order is simple pressure driven channel \
flow.",
 Background->RGBColor[0.87, 0.94, 1]]], "Text",
 CellChangeTimes->{{3.81385537418635*^9, 3.8138553960150332`*^9}, {
  3.81385918048217*^9, 3.8138591827768383`*^9}, {3.813859282655939*^9, 
  3.81385928710841*^9}},ExpressionUUID->"98bf7274-ca44-484e-90ce-\
b6ea7d0b4f11"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     FormBox[
      FormBox[
       RowBox[{"GFuncAsy", "[", 
        RowBox[{"X", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], "]"}],
       TraditionalForm],
      TraditionalForm], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"X", ",", "Pressure"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1", " ", ",", "1000"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "0.1", " ", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.814012464971412*^9, {3.8143728393124323`*^9, 3.8143728440109625`*^9}, {
   3.816485615500132*^9, 3.8164856325403557`*^9}, 3.8164875324135256`*^9, {
   3.8164877507106514`*^9, 3.8164877518160334`*^9}},
 CellLabel->
  "In[203]:=",ExpressionUUID->"5ab15786-4758-4e05-84c7-f4d7cf9a9713"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.1, 1}}, Typeset`size$$ = {
    396.00000000000006`, {121., 125.97731425578988`}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[
        $CellContext`GFuncAsy[$CellContext`X, $CellContext`Kp$$, \
$CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], {$CellContext`X, 0, 
         1}, AxesLabel -> {$CellContext`X, $CellContext`Pressure}], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 1, 
         1000}, {$CellContext`Pin$$, 0.1, 5}, {$CellContext`a1$$, 0.1, 1}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{450., {201.125, 207.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.8140124658478975`*^9, {3.8140151111004066`*^9, 3.8140151351653423`*^9}, 
   3.8140285902480288`*^9, 3.8140302062427883`*^9, 3.814030525009837*^9, 
   3.814068394256189*^9, 3.814068452633366*^9, 3.8140685290922112`*^9, {
   3.814372834043706*^9, 3.814372848279012*^9}, {3.8144213856526423`*^9, 
   3.814421387414001*^9}, 3.814522058188694*^9, 3.8145221659918985`*^9, 
   3.814526879867404*^9, 3.8145316944327807`*^9, 3.815843773290866*^9, 
   3.816450117050335*^9, 3.8164856378562813`*^9, 3.8164875336917906`*^9, 
   3.816487849412436*^9, 3.816931289447559*^9, 3.8181666284838715`*^9, 
   3.8185244197802725`*^9, 3.818730816249633*^9, 3.8187631566623063`*^9, 
   3.8188346143146152`*^9, 3.8188434313648696`*^9, 3.818905127507084*^9, 
   3.8192999204953413`*^9, 3.840526058985262*^9, 3.8410705014837584`*^9, 
   3.841072515555216*^9, 3.8419009060423317`*^9},
 CellLabel->
  "Out[203]=",ExpressionUUID->"7726fd72-a8e2-4c04-ac65-174512e5f601"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P1Order0Fig", "=", 
  RowBox[{"DynamicModule", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a1", "=", "0.1`"}], ",", 
      RowBox[{"Kp", "=", "0.1`"}], ",", 
      RowBox[{"Pin", "=", "0.1`"}], ",", 
      RowBox[{"R", "=", "1"}]}], "}"}], ",", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"GFuncAsy", "[", 
       RowBox[{"X", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"X", ",", "Pressure"}], "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"FontSize", "\[Rule]", "12"}], ")"}]}]}], "]"}]}], 
   "]"}]}]], "Input",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.8164875067212906`*^9, 3.8164875365201817`*^9}, 
   3.8164878178905725`*^9, {3.8164885067071595`*^9, 3.8164885086540413`*^9}},
 CellLabel->
  "In[204]:=",ExpressionUUID->"d9d4288b-8341-4c07-9640-d242387ae3d3"],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
  0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVxXs00wsAB/CRslKESj/PJlZIr4vCbd+SWlmopaMHyxEldCNKHKWJnuRx
dtNCEWG5LI+plXDHpYcIFaLRWhLjVycyOtm994/P+dD8j7MD1SkUivt//t8t
cLCt7sseBsXV4xqfL4bGZsOwPsIOYbcCs9QzxPjt9o2sCsIVs/2CWkN4YrBe
dpZnE16Y6l+Sz0gRwztg4kk6EYCt/t81BxLEeL/q4uZkIhJZV1+InMPEyFno
eeEKkQB9VW2KOlMMLrVi2WWCh+AO76O/xh5i775c4ddv+aBpGDbqbXkILRXX
h2kqhJG+7QfzvAew3DU6WH+1Eu01/ufOznqAqBZH3BgTI3wPfbGMUwWDSl2p
mlotRhnzalIbRKiSbW5u/V0CNQXteIqZCJLgbKN9igb0ZES7SuIqMU7foFNy
rAkhRieb+YoKqE8WzzeyfA6eqt5Vy7MCDiq/qt2lzfjE1HZ48aQczQl2LY3W
raBPXeLprSmHWerwpGD0FcZbfdPsbpZheKJP+mZ1O8SG5iaLdMqQP/T4ufa1
DhyLLKdSY+5D26SQlMtfQ6c6jtHeLkTSUdHhHIu3qL15vn3m01L82FgsD4rr
hJdPiHu9oASRaxsqF9V3Ic2ypyYw9y/0lTZcbaO9Q85+83ufE4vxM/h1plVM
D9gn6aejTtyDzSbN6cOPe1Fk9M5aFSEA8w7tSJmBFN10io7IvwhRJgfNP/j0
weNF5tuBwEKsUOzR6nTvx6HqcsOVYQXQ1/lKbZjqR6z1IxfZkbvQqM0ULs36
gDxrZ/n2iHyE2D3uns2SgW6z0ZIdmofi7f45NT9kiAjZybMLvYPxYcP5A9c/
It1Hn5gflwvRbuYMnqscXowgo/K4HMRtS7xdOSBH1fLe/DeWt0F779aVl/gJ
nIvvXML3ZsNpXQKPWDsA4qfn2abDmfAxbZ1U6xhAM9FSuIjPx/jzZFkY9zO2
fhRt2FKYgRsanEi2xSA4w+xXkq4/oS8V3VFvGITjAr+dexfyMPMM18sx/AsM
m/YvbrJNB0XAEcr0hhBAiY6JD0rFiZvCZD3JEGJOsZ7RppPwxOYSVfePYRRw
eYTTxsvQdTuxIl5bgbn77A+Y/JOIXttXHdHVCugY0OpWqMXj/i1YyDkj0LOP
9zWYjoWv0EHXZHoE3p8tonrNTuFcYi63994ozEyPF9F9j6Fk0CRTeweJPHe/
IYGSg0vZiX5SDxKz3GzPSmI5CGCPWJbuIuEoU7J6KBwYV1ffd/cmcbpHmjZv
ti+upBxoTPInEaqwKokkDiDIgf9tTjSJNd1tu3c4ecM8YcE2zQISdpptMnul
B6bXx87rLCLhcmZsMpzige6Rj+0FxSTc56x3K6W6I9W7wndrGQnWTMm1ZQQL
Kmt2RGI1iUee7EhjJyZ621Juzegg0WwhsDJWMvDwwsShjjck7HO//82nbgDP
+aBVXheJyVnJaQaEM1h3V1a6SElc9Bpt0ndah0enXz7jfiFBzjjqZaxcieu2
9im7FCQELudsDAkbhMuyvGgkiR6Bo8Nip2VYviO0r26MxNI6y3QrpSk01F7n
p06QGJXJE+hOBugXOQf7TZGY29jCZCq1UR2ct2r1LxLbIsq455XTjAwzrXGV
ikTS6k1Py21MGf8CZl1JTg==
        "]]},
      Annotation[#, "Charting`Private`Tag$15054#1"]& ]}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox["X", HoldForm], TraditionalForm], 
     FormBox["Pressure", TraditionalForm]},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   LabelStyle->(FontSize -> 12),
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{0, 1}, {0., 0.0999999973703467}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  DynamicModuleValues:>{}]], "Output",
 CellChangeTimes->{{3.816487518077764*^9, 3.816487538025316*^9}, 
   3.8164878519889536`*^9, 3.8164885103510466`*^9, 3.8169312898403482`*^9, 
   3.8181666286627674`*^9, 3.8185244201432543`*^9, 3.8187308164365244`*^9, 
   3.8187631568542137`*^9, 3.8188346145145736`*^9, 3.818843431616722*^9, 
   3.818905127725817*^9, 3.819299920794928*^9, 3.8405260591901617`*^9, 
   3.841070501624394*^9, 3.8410725159547424`*^9, 3.8419009063141747`*^9},
 CellLabel->
  "Out[204]=",ExpressionUUID->"178718b8-5a10-4e0c-a7b5-542c860ac622"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pressure - asymptotic correction", "Subsubsection",
 CellChangeTimes->{{3.841071634283373*^9, 
  3.841071644315037*^9}},ExpressionUUID->"fbfc9927-1971-462b-bf5d-\
3d23496f73af"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    RowBox[{"GFuncAsyCorr", "[", 
     RowBox[{"X", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], "]"}],
    TraditionalForm], ";"}], TraditionalForm]], "Input",
 CellChangeTimes->{
  3.813855978664581*^9, {3.8140106477339582`*^9, 3.814010654356045*^9}, 
   3.8140121369383745`*^9, 3.814012442920513*^9, 3.814372861505535*^9},
 CellLabel->
  "In[205]:=",ExpressionUUID->"7839c868-6d4c-427a-bf7c-89f795a20f24"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     FormBox[
      FormBox[
       RowBox[{"GFuncAsyCorr", "[", 
        RowBox[{"X", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], "]"}],
       TraditionalForm],
      TraditionalForm], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"X", ",", "Pressure"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1", " ", ",", "1000"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "0.1", " ", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8140119462352304`*^9, 3.81401204754808*^9}, {
  3.814012078508111*^9, 3.8140121061494913`*^9}, {3.8143728592340117`*^9, 
  3.8143728642830515`*^9}},
 CellLabel->
  "In[206]:=",ExpressionUUID->"d46acc4b-064f-4337-afdd-2e86de1c6b47"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.1, 1}}, Typeset`size$$ = {
    396.00000000000006`, {114., 120.57221405149403`}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[
        $CellContext`GFuncAsyCorr[$CellContext`X, $CellContext`Kp$$, \
$CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], {$CellContext`X, 0, 
         1}, AxesLabel -> {$CellContext`X, $CellContext`Pressure}], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 1, 
         1000}, {$CellContext`Pin$$, 0.1, 5}, {$CellContext`a1$$, 0.1, 1}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{450., {195.125, 201.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.8140120479278526`*^9, 3.8140120806045313`*^9, 3.8140121429431567`*^9, 
   3.8140151114692087`*^9, 3.814015143739229*^9, 3.8140286021113296`*^9, 
   3.814030536844119*^9, 3.8140683943908615`*^9, 3.814068533513856*^9, 
   3.8143728342311897`*^9, 3.8143728724500628`*^9, {3.814421518444849*^9, 
   3.814421521866943*^9}, 3.814522166224763*^9, 3.8145268799603305`*^9, 
   3.8145316947180176`*^9, 3.815843773352461*^9, 3.816450117203227*^9, 
   3.81693129051374*^9, 3.8181666291954613`*^9, 3.81852442056509*^9, 
   3.818730816926248*^9, 3.818763157342913*^9, 3.8188346150558753`*^9, 
   3.8188434320664625`*^9, 3.818905128382021*^9, 3.8192999216253757`*^9, 
   3.8405260598167815`*^9, 3.841070502146577*^9, 3.841072516022684*^9, 
   3.8419009063981256`*^9},
 CellLabel->
  "Out[206]=",ExpressionUUID->"7c03033d-3608-422f-bc1d-6903b7f58ad2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ux1 - definitions", "Subsubsection",
 CellChangeTimes->{{3.8138548808912945`*^9, 3.8138548878221197`*^9}, {
   3.8138549228764143`*^9, 3.813854925123768*^9}, 3.8140062743559237`*^9, 
   3.841071516210474*^9, {3.8410718510537505`*^9, 
   3.841071851663081*^9}},ExpressionUUID->"ed6e60db-8330-4a8d-bb63-\
3c43974f56c3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"UX10Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UX11Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UXAsy", "[", 
    RowBox[{
    "X_", ",", "Y1_", ",", "Kp_", ",", "R_", ",", "Pin_", ",", "a1_"}], "]"}],
    "=", 
   RowBox[{
    RowBox[{"UX10Func", "[", 
     RowBox[{"X", ",", "Y1"}], "]"}], "+", 
    RowBox[{"Kp", " ", 
     RowBox[{"UX11FuncR", "[", 
      RowBox[{"X", ",", "Y1"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UXAsyCorr", "[", 
    RowBox[{
    "X_", ",", "Y1_", ",", "Kp_", ",", "R_", ",", "Pin_", ",", "a1_"}], "]"}],
    "=", 
   RowBox[{"Kp", "*", 
    RowBox[{"UX11FuncR", "[", 
     RowBox[{"X", ",", "Y1"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8140063946583614`*^9, 3.814006395048907*^9}, {
   3.8140127570801134`*^9, 3.814012758984371*^9}, {3.8140131280103707`*^9, 
   3.8140131318217707`*^9}, {3.8140131810108137`*^9, 
   3.8140131919157133`*^9}, {3.8140132588621063`*^9, 3.814013307916706*^9}, {
   3.8140298244347596`*^9, 3.8140298397111945`*^9}, {3.814030547234051*^9, 
   3.814030549542413*^9}, {3.8140310726246634`*^9, 3.814031077436*^9}, 
   3.814068390475707*^9, {3.8140685405830235`*^9, 3.8140685470741453`*^9}, 
   3.814522198613103*^9, 3.8145222487040405`*^9},
 CellLabel->
  "In[207]:=",ExpressionUUID->"9d585ca6-e665-4c30-a841-b1dd6452db08"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"UXAsy", "[", 
    RowBox[{
    "0.5", ",", "0.50", ",", "0.3", ",", "0.1", ",", "1", ",", "0.2"}], "]"}],
    ";"}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"UXAsyCorr", "[", 
    RowBox[{
    "0.5", ",", "0.50", ",", "0.3", ",", "0.1", ",", "1", ",", "0.2"}], "]"}],
    ";"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.814013140260376*^9, 3.814013166587414*^9}, {
  3.8140133156873646`*^9, 3.8140133162810555`*^9}, {3.814029847321669*^9, 
  3.8140298513633604`*^9}},
 CellLabel->
  "In[211]:=",ExpressionUUID->"2f143267-9eb1-4d57-8fea-482d1f9bffc8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"UX10Func", "[", 
    RowBox[{
    "X_", ",", "Y1_", ",", "Kp_", ",", "R_", ",", "Pin_", ",", "a1_"}], "]"}],
    "=", 
   RowBox[{"UX10Func", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.818166704178279*^9, 3.818166708845135*^9}},
 CellLabel->
  "In[213]:=",ExpressionUUID->"ff8f52ad-4fbc-4d01-90fc-3255159d305d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ux1 - leading order", "Subsubsection",
 CellChangeTimes->{{3.841071723694068*^9, 
  3.8410717345533867`*^9}},ExpressionUUID->"d84842bc-d64b-4dcd-9f4b-\
8cab847a91db"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     FormBox[
      FormBox[
       RowBox[{"UX10Func", "[", 
        RowBox[{"X", ",", "Y1", ",", 
         StyleBox["Kp",
          FontSlant->"Plain"], ",", 
         StyleBox["R",
          FontSlant->"Plain"], ",", "Pin", ",", "a1"}], "]"}],
       TraditionalForm],
      TraditionalForm], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Y1", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"X", ",", "Y1", ",", "UX"}], "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", "Automatic"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1", " ", ",", "1000"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "0.1", " ", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8181666649540915`*^9, 3.8181666817613225`*^9}},
 CellLabel->
  "In[214]:=",ExpressionUUID->"90eda0cd-9c76-42ae-b7e2-2c56a904a44b"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.1, 1}}, Typeset`size$$ = {
    474., {194., 200.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ContourPlot[
        $CellContext`UX10Func[$CellContext`X, $CellContext`Y1, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], \
{$CellContext`X, 0, 1}, {$CellContext`Y1, 0, 1}, 
        AxesLabel -> {$CellContext`X, $CellContext`Y1, $CellContext`UX}, 
        PlotLegends -> Automatic], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 1, 
         1000}, {$CellContext`Pin$$, 0.1, 5}, {$CellContext`a1$$, 0.1, 1}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{527., {275.125, 281.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.818166712911254*^9, 3.8185244257954917`*^9, 
  3.8187308218254147`*^9, 3.8187631620401993`*^9, 3.8188346198601866`*^9, 
  3.818843435152681*^9, 3.818905131306035*^9, 3.8192999262992735`*^9, 
  3.840526062997963*^9, 3.841070505679188*^9, 3.841072516203579*^9, 
  3.8419009066429844`*^9},
 CellLabel->
  "Out[214]=",ExpressionUUID->"38e6993e-2156-49ed-9fdb-8480d355463e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ux1 - asymptotic correction", "Subsubsection",
 CellChangeTimes->{{3.8410718011749897`*^9, 
  3.8410718046763773`*^9}},ExpressionUUID->"cb05614d-83a2-4792-b5bd-\
565907af956a"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"UXAsyCorr", "[", 
    RowBox[{"X", ",", "Y1", ",", 
     StyleBox["Kp",
      FontSlant->"Plain"], ",", 
     StyleBox["R",
      FontSlant->"Plain"], ",", "Pin", ",", " ", "a1"}], "]"}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.813742952452878*^9, 3.813742960018732*^9}, {
   3.814013440548716*^9, 3.814013446056755*^9}, 3.8140685612617064`*^9, 
   3.8144222373385997`*^9, 3.8144222751662955`*^9},
 CellLabel->
  "In[215]:=",ExpressionUUID->"9ac27044-a609-49b7-a22e-ee5e64c251c4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     FormBox[
      FormBox[
       RowBox[{"UXAsyCorr", "[", 
        RowBox[{"X", ",", "Y1", ",", 
         StyleBox["Kp",
          FontSlant->"Plain"], ",", 
         StyleBox["R",
          FontSlant->"Plain"], ",", "Pin", ",", "a1"}], "]"}],
       TraditionalForm],
      TraditionalForm], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Y1", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"X", ",", "Y1", ",", "UX"}], "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", "Automatic"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1", " ", ",", "1000"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "0.1", " ", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.8137428864345655`*^9, 3.813859715462668*^9, {3.8140134518649845`*^9, 
   3.8140134623084784`*^9}, {3.8140685677172365`*^9, 3.814068571841226*^9}},
 CellLabel->
  "In[216]:=",ExpressionUUID->"a7dea257-6cd6-4077-8a7e-32d6a8023358"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.1, 1}}, Typeset`size$$ = {
    481., {194., 200.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ContourPlot[
        $CellContext`UXAsyCorr[$CellContext`X, $CellContext`Y1, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], \
{$CellContext`X, 0, 1}, {$CellContext`Y1, 0, 1}, 
        AxesLabel -> {$CellContext`X, $CellContext`Y1, $CellContext`UX}, 
        PlotLegends -> Automatic], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 1, 
         1000}, {$CellContext`Pin$$, 0.1, 5}, {$CellContext`a1$$, 0.1, 1}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{534., {275.125, 281.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.8137428909207697`*^9, 3.813742894701749*^9}, {
   3.813743106128101*^9, 3.813743109599089*^9}, 3.8138597174415255`*^9, 
   3.8139987758824897`*^9, 3.814013463478958*^9, 3.8140151126092577`*^9, 
   3.81401515837096*^9, 3.8140286187015877`*^9, 3.8140305644384475`*^9, 
   3.8140683950979376`*^9, 3.814068572953206*^9, 3.8143729102165937`*^9, 
   3.814522166790457*^9, 3.8145268801722174`*^9, 3.814531695374034*^9, 
   3.8158437734958386`*^9, 3.816450117482067*^9, 3.816931297380698*^9, 
   3.8181666351256895`*^9, 3.818524426023429*^9, 3.8187308219533415`*^9, 
   3.8187631621971097`*^9, 3.8188346200240912`*^9, 3.818843435301596*^9, 
   3.8189051314466496`*^9, 3.819299926471174*^9, 3.840526063190834*^9, 
   3.841070505897902*^9, 3.8410725169471493`*^9, 3.8419009072376413`*^9},
 CellLabel->
  "Out[216]=",ExpressionUUID->"049598a4-6d5c-4fda-bc77-4a0ad2c714b2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ux1 - total flow", "Subsubsection",
 CellChangeTimes->{{3.841071759334439*^9, 
  3.841071789955845*^9}},ExpressionUUID->"fbbbd907-92e9-4b7d-8920-\
d16d0bc3bd2f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     FormBox[
      FormBox[
       RowBox[{"UXAsy", "[", 
        RowBox[{"X", ",", "Y1", ",", 
         StyleBox["Kp",
          FontSlant->"Plain"], ",", 
         StyleBox["R",
          FontSlant->"Plain"], ",", "Pin", ",", "a1"}], "]"}],
       TraditionalForm],
      TraditionalForm], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Y1", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"X", ",", "Y1", ",", "UX"}], "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", "Automatic"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1", " ", ",", "1000"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "0.1", " ", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.79403658079869*^9, 3.7940365975196805`*^9}, {
   3.7940491251448817`*^9, 3.794049127373955*^9}, {3.7940493749437895`*^9, 
   3.794049382835476*^9}, 3.8136848124107127`*^9, 3.813684867284356*^9, {
   3.813684913790927*^9, 3.81368493017105*^9}, {3.813684968593027*^9, 
   3.813684995435321*^9}, {3.8136850401189227`*^9, 3.813685068551732*^9}, {
   3.81368510456462*^9, 3.8136851305586224`*^9}, {3.8136851852472095`*^9, 
   3.813685187075199*^9}, {3.813742361173437*^9, 3.813742362251483*^9}, {
   3.8137424203210793`*^9, 3.8137424627156973`*^9}, {3.8138596825752726`*^9, 
   3.813859698276064*^9}, {3.8140133287142987`*^9, 3.814013349573474*^9}, {
   3.814372882826643*^9, 3.8143728872816467`*^9}},
 CellLabel->
  "In[217]:=",ExpressionUUID->"99ca54c8-d2b8-4886-b17b-58d899fd953c"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.1, 1}}, Typeset`size$$ = {
    474., {194., 200.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ContourPlot[
        $CellContext`UXAsy[$CellContext`X, $CellContext`Y1, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], \
{$CellContext`X, 0, 1}, {$CellContext`Y1, 0, 1}, 
        AxesLabel -> {$CellContext`X, $CellContext`Y1, $CellContext`UX}, 
        PlotLegends -> Automatic], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 1, 
         1000}, {$CellContext`Pin$$, 0.1, 5}, {$CellContext`a1$$, 0.1, 1}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{527., {275.125, 281.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.813684969311741*^9, 3.813684996044659*^9}, {
   3.8136850698953915`*^9, 3.8136851317459917`*^9}, 3.8136851912355366`*^9, {
   3.813742368253765*^9, 3.813742373021192*^9}, {3.8137424278232937`*^9, 
   3.8137424691872263`*^9}, {3.8138596902058764`*^9, 3.8138596987817535`*^9}, 
   3.8139987754450207`*^9, {3.814013351471443*^9, 3.814013369848548*^9}, 
   3.8140143541303797`*^9, 3.8140151116942596`*^9, 3.8140151552496595`*^9, 
   3.8140286095792007`*^9, 3.814030553760174*^9, 3.8140683945274634`*^9, 
   3.81406855478802*^9, 3.8143728962466345`*^9, {3.8144221241255026`*^9, 
   3.814422126759631*^9}, 3.8145221663986816`*^9, 3.814526880096253*^9, 
   3.8145316949411674`*^9, 3.815843773429247*^9, 3.8164501173611374`*^9, 
   3.8169312972947273`*^9, 3.818166634422331*^9, 3.8185244259414053`*^9, 
   3.8187308218693886`*^9, 3.8187631621051636`*^9, 3.8188346199351435`*^9, 
   3.8188434352216425`*^9, 3.8189051313685284`*^9, 3.8189549720725193`*^9, 
   3.819299926371232*^9, 3.840526063104882*^9, 3.841070505788539*^9, 
   3.8410725171820145`*^9, 3.841900907560455*^9},
 CellLabel->
  "Out[217]=",ExpressionUUID->"ffbe8fab-c367-460a-a7a8-0dc9b92fb467"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Uy1", "Subsubsection",
 CellChangeTimes->{{3.8138549168088474`*^9, 
  3.8138549342674117`*^9}},ExpressionUUID->"db66a2ac-78fc-45bb-9990-\
3cf8c8e388a9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"UY10Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UY11Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UYAsy", "[", 
    RowBox[{
    "X_", ",", "Y1_", ",", "Kp_", ",", "R_", ",", "Pin_", ",", " ", "a1_"}], 
    "]"}], "=", 
   RowBox[{
    RowBox[{"UY10Func", "[", 
     RowBox[{"X", ",", "Y1"}], "]"}], "+", 
    RowBox[{"Kp", "*", 
     RowBox[{"UY11FuncR", "[", 
      RowBox[{"X", ",", "Y1"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UYAsyCorr", "[", 
    RowBox[{
    "X_", ",", "Y1_", ",", "Kp_", ",", "R_", ",", "Pin_", ",", " ", "a1_"}], 
    "]"}], "=", 
   RowBox[{"Kp", "*", 
    RowBox[{"UY11FuncR", "[", 
     RowBox[{"X", ",", "Y1"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8140135083685923`*^9, 3.8140135103551564`*^9}, {
  3.814013690244449*^9, 3.814013710368442*^9}, {3.814013768496763*^9, 
  3.8140137806738787`*^9}, {3.8140152930220814`*^9, 3.814015300604828*^9}, {
  3.814031141909257*^9, 3.814031144716339*^9}, {3.814068578782124*^9, 
  3.81406858477116*^9}, {3.814522255082981*^9, 3.8145222749628806`*^9}},
 CellLabel->
  "In[218]:=",ExpressionUUID->"8abf5c0f-4ed6-4ac3-8703-7a2a03041eb7"],

Cell[TextData[StyleBox["Since the leading order is essentially zero, only the \
asymptotic exp. matters in this case.",
 Background->RGBColor[0.87, 0.94, 1]]], "Text",
 CellChangeTimes->{{3.8140137263538976`*^9, 
  3.8140137508121643`*^9}},ExpressionUUID->"4edb1769-f707-47b7-a88f-\
ec01a62a1641"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"UYAsy", "[", 
    RowBox[{
    "0.5", ",", "0.50", ",", "0.5", ",", "0.5", ",", "0.5", ",", "0.5"}], 
    "]"}], ";"}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"UYAsyCorr", "[", 
    RowBox[{
    "0.5", ",", "0.50", ",", "0.5", ",", "0.5", ",", "0.5", ",", "0.5"}], 
    "]"}], ";"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.8140137898320436`*^9, 3.814013799963191*^9}, {
  3.8140138331361046`*^9, 3.814013833690917*^9}},
 CellLabel->
  "In[222]:=",ExpressionUUID->"389b34a8-0d32-4894-91ae-160c20b538fc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Uy1 - total flow", "Subsubsection",
 CellChangeTimes->{{3.8410718677881536`*^9, 
  3.841071871343412*^9}},ExpressionUUID->"2e5ac9da-4fb9-47ba-8295-\
a090bc2b0ed5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     FormBox[
      FormBox[
       RowBox[{"UYAsy", "[", 
        RowBox[{"X", ",", "Y1", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
        "]"}],
       TraditionalForm],
      TraditionalForm], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Y1", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"X", ",", "Y1", ",", "UX"}], "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", "Automatic"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1", " ", ",", "1000"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "0.1", " ", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7940372388669147`*^9, 3.794037249389822*^9}, {
   3.7940490496828265`*^9, 3.794049049824814*^9}, {3.794049153068055*^9, 
   3.7940491543372316`*^9}, {3.8137425392529225`*^9, 3.8137426147689266`*^9}, 
   3.81374445375054*^9, {3.813860255707279*^9, 3.813860261020219*^9}, {
   3.814013842037058*^9, 3.8140138713651667`*^9}, {3.814068589581666*^9, 
   3.814068592576144*^9}},
 CellLabel->
  "In[224]:=",ExpressionUUID->"42c673b1-2eea-45ec-9a7c-b726e9ac5c3f"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.1, 1}}, Typeset`size$$ = {
    481., {194., 200.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ContourPlot[
        $CellContext`UYAsy[$CellContext`X, $CellContext`Y1, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], \
{$CellContext`X, 0, 1}, {$CellContext`Y1, 0, 1}, 
        AxesLabel -> {$CellContext`X, $CellContext`Y1, $CellContext`UX}, 
        PlotLegends -> Automatic], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 1, 
         1000}, {$CellContext`Pin$$, 0.1, 5}, {$CellContext`a1$$, 0.1, 1}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{534., {275.125, 281.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.819299926620087*^9, 3.840526063308766*^9, 
  3.841070506132262*^9, 3.8410725174658504`*^9, 3.8419009080521708`*^9},
 CellLabel->
  "Out[224]=",ExpressionUUID->"dfe0d4fb-03af-415d-a794-0e079a08383f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["UX and UY stream map - total flow fields", "Subsubsection",
 CellChangeTimes->{{3.8138549168088474`*^9, 3.8138549342674117`*^9}, {
  3.8140140756772366`*^9, 3.8140141045745835`*^9}, {3.8410719259825673`*^9, 
  3.8410719474255114`*^9}},ExpressionUUID->"7691fbaf-07dc-4005-8bee-\
9f0f23cd9077"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   FormBox[
    RowBox[{"UXAsy", "[", 
     RowBox[{"X", ",", "Y1", ",", 
      StyleBox["Kp",
       FontSlant->"Plain"], ",", 
      StyleBox["R",
       FontSlant->"Plain"], ",", "Pin", ",", "a1"}], "]"}],
    TraditionalForm], ";"}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   FormBox[
    RowBox[{"UYAsy", "[", 
     RowBox[{"X", ",", "Y1", ",", 
      StyleBox["Kp",
       FontSlant->"Plain"], ",", 
      StyleBox["R",
       FontSlant->"Plain"], ",", "Pin", ",", "a1"}], "]"}],
    TraditionalForm], ";"}], TraditionalForm]}], "Input",
 CellChangeTimes->{
  3.814015639073902*^9, 3.814015719135804*^9, {3.8140285186457744`*^9, 
   3.8140285212928715`*^9}, {3.814028747509917*^9, 3.8140287670391116`*^9}, {
   3.8140298810243454`*^9, 3.8140298879975576`*^9}, {3.814031036316656*^9, 
   3.814031036730607*^9}, 3.8140312871205416`*^9, 3.814031371027548*^9, {
   3.8140316764544945`*^9, 3.8140316914119797`*^9}, {3.8140317456348953`*^9, 
   3.814031746666806*^9}, {3.8140685989839315`*^9, 3.814068600041222*^9}, 
   3.8140686752503915`*^9, 3.814372928401904*^9},
 CellLabel->
  "In[225]:=",ExpressionUUID->"73ffec47-eb06-4950-b21e-973a4961c8cc"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"UXAsy", "[", 
    RowBox[{"1", ",", "0.5", ",", "0.1", ",", "10", ",", "1", ",", "0.1"}], 
    "]"}], ";"}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"UYAsy", "[", 
    RowBox[{"0.5", ",", "0.5", ",", "0.1", ",", "10", ",", "1", ",", "0.1"}], 
    "]"}], ";"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.814014421244696*^9, 3.814014450365838*^9}, {
  3.8140151964725695`*^9, 3.8140151973306336`*^9}, {3.8140156593397636`*^9, 
  3.8140156791748075`*^9}, {3.814028532494024*^9, 3.814028533042777*^9}, {
  3.8140317840250273`*^9, 3.8140317977131653`*^9}, {3.8140686885250072`*^9, 
  3.814068690937607*^9}, {3.8140687715820384`*^9, 3.814068805850108*^9}, {
  3.8143729331988506`*^9, 3.8143729360584507`*^9}},
 CellLabel->
  "In[227]:=",ExpressionUUID->"d250bd75-e569-43b9-8369-8251f00e790e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"VectorPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"X", ",", " ", "Y1"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"X", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"Y1", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"PlotLegends", " ", "->", " ", "Automatic"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8140689551905713`*^9, 3.8140689585884686`*^9}, 
   3.814522323749372*^9},
 CellLabel->
  "In[229]:=",ExpressionUUID->"fe3f626b-9366-4378-b0f9-d04c52e9af0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"UXAsy", "[", 
    RowBox[{
    "X", ",", " ", "Y1", ",", " ", "Kp", ",", " ", "R", ",", " ", "Pin", ",", 
     " ", "a1"}], "]"}], "*", "0"}], ";"}]], "Input",
 CellChangeTimes->{3.8145223276251373`*^9},
 CellLabel->
  "In[230]:=",ExpressionUUID->"5e88254d-4f48-42bb-947c-6f3914eb4262"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"VectorPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"UXAsy", "[", 
         RowBox[{
         "X", ",", " ", "Y1", ",", " ", "Kp", ",", " ", "R", ",", " ", "Pin", 
          ",", " ", "a1"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
       RowBox[{
        RowBox[{"UYAsy", "[", 
         RowBox[{
         "X", ",", " ", "Y1", ",", " ", "Kp", ",", " ", "R", ",", " ", "Pin", 
          ",", " ", "a1"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"X", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"Y1", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
     RowBox[{"PlotLegends", " ", "->", " ", "Automatic"}]}], "]"}], ",", " ", 
   "\n", "  ", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", " ", "0.1", ",", " ", "1"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"R", ",", " ", "10", ",", " ", "1000"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Pin", ",", " ", "1"}], "}"}], ",", " ", "0.1", ",", " ", "5"}],
     "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"a1", ",", " ", "0.1", ",", " ", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.814015437525648*^9, 3.814015439334367*^9}, {
   3.814015688262698*^9, 3.8140156902864447`*^9}, 3.814029930619461*^9, {
   3.814030737332802*^9, 3.814030756953063*^9}, {3.81403097364774*^9, 
   3.8140309962336006`*^9}, {3.814031581891168*^9, 3.81403159396013*^9}, {
   3.81403198496035*^9, 3.814031985478054*^9}, {3.8140686044424486`*^9, 
   3.814068608815686*^9}, {3.814068653992194*^9, 3.814068659218774*^9}, 
   3.8140687394969215`*^9, {3.8140688619751587`*^9, 3.814068933075082*^9}, {
   3.814068994903126*^9, 3.814069005547059*^9}},
 CellLabel->
  "In[231]:=",ExpressionUUID->"af8aed76-245e-44c2-91f7-cda295e93a2c"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 1, $CellContext`R$$ = 10, Typeset`show$$ = True,
     Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 10, 1000}, {{
       Hold[$CellContext`Pin$$], 1}, 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.1, 1}}, Typeset`size$$ = {
    474., {194., 200.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 1, $CellContext`R$$ = 10}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> VectorPlot[{
         Part[
          $CellContext`UXAsy[$CellContext`X, $CellContext`Y1, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], 
          1], 
         Part[
          $CellContext`UYAsy[$CellContext`X, $CellContext`Y1, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], 
          1]}, {$CellContext`X, 0, 1}, {$CellContext`Y1, 0, 1}, PlotLegends -> 
        Automatic], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 10,
          1000}, {{$CellContext`Pin$$, 1}, 0.1, 5}, {$CellContext`a1$$, 0.1, 
         1}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{527., {275.125, 281.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.8140156940835247`*^9, 3.8140286362484865`*^9, 3.8140287752619495`*^9, 
   3.814029904928379*^9, 3.8140299550525446`*^9, {3.8140300471342077`*^9, 
   3.814030049351364*^9}, 3.8140305793179626`*^9, {3.8140307398530455`*^9, 
   3.814030759481535*^9}, 3.814030807881463*^9, {3.8140309785252705`*^9, 
   3.8140309988532963`*^9}, 3.8140311109926367`*^9, {3.8140311911057253`*^9, 
   3.8140312090873523`*^9}, 3.8140313537590694`*^9, 3.8140313948018837`*^9, 
   3.814031463079157*^9, 3.81403159584052*^9, {3.814031834189248*^9, 
   3.8140318494704547`*^9}, 3.814031996743165*^9, 3.8140683955337734`*^9, 
   3.8140686099406753`*^9, {3.8140686403716846`*^9, 3.814068659918844*^9}, 
   3.814068808448118*^9, 3.8140688721197824`*^9, 3.8140689339497395`*^9, 
   3.8140690060805807`*^9, 3.8143729695111256`*^9, 3.814522167931781*^9, 
   3.814526880865925*^9, 3.8145316963536177`*^9, 3.8158437739328156`*^9, 
   3.8164501183535843`*^9, 3.8169312976891937`*^9, 3.8181666358112593`*^9, 
   3.8185244264236474`*^9, 3.8187308222381935`*^9, 3.8187631625908833`*^9, 
   3.8188346204868417`*^9, 3.818843435653392*^9, 3.8189051318216205`*^9, 
   3.8192999270088644`*^9, 3.84052606375051*^9, 3.8410705065853505`*^9, 
   3.8410725179365788`*^9, 3.841900908659819*^9},
 CellLabel->
  "Out[231]=",ExpressionUUID->"9d89e09c-01d7-4858-b99e-d53c8e83df27"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["UX and UY stream map - asymptotic correction", "Subsubsection",
 CellChangeTimes->{{3.8410719835182476`*^9, 
  3.8410719937236476`*^9}},ExpressionUUID->"8c40a79d-af9c-40f1-b941-\
f42080ec5ac2"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"UXAsyCorr", "[", 
    RowBox[{"X", ",", "Y1", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
    "]"}], ";"}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"UYAsyCorr", "[", 
    RowBox[{"X", ",", "Y1", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
    "]"}], ";"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.813744720713574*^9, 3.813744728871337*^9}, {
  3.8140285379284754`*^9, 3.8140285385908537`*^9}, {3.8143729910020533`*^9, 
  3.8143730072467203`*^9}},
 CellLabel->
  "In[232]:=",ExpressionUUID->"fc1ff0d7-b8f2-46f3-a53c-37b9d06e5108"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"VectorPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FormBox[
         FormBox[
          FormBox[
           FormBox[
            RowBox[{"UXAsyCorr", "[", 
             RowBox[{
             "X", ",", "Y1", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
             "]"}],
            TraditionalForm],
           TraditionalForm],
          TraditionalForm],
         TraditionalForm], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       FormBox[
        FormBox[
         FormBox[
          FormBox[
           RowBox[{
            RowBox[{"UYAsyCorr", "[", 
             RowBox[{
             "X", ",", "Y1", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
             "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}],
           TraditionalForm],
          TraditionalForm],
         TraditionalForm],
        TraditionalForm]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Y1", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", "Automatic"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1", " ", ",", "1000"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "0.1", " ", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.794115848256583*^9, {3.794115950039853*^9, 3.7941159539730573`*^9}, 
   3.813742577594711*^9, {3.813744672213298*^9, 3.8137446833235536`*^9}, 
   3.8138603315003414`*^9, {3.814028401595484*^9, 3.814028407744497*^9}, 
   3.814028561150572*^9, {3.814028870886176*^9, 3.814028877993495*^9}, {
   3.8140690629502907`*^9, 3.8140690705557413`*^9}, {3.8143730110738974`*^9, 
   3.8143730188273077`*^9}},
 CellLabel->
  "In[234]:=",ExpressionUUID->"7ede82c9-3f41-4477-a54e-46faa6ab54eb"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.1, 1}}, Typeset`size$$ = {
    474., {194., 200.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> VectorPlot[{
         Part[
          $CellContext`UXAsyCorr[$CellContext`X, $CellContext`Y1, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], 
          1], 
         Part[
          $CellContext`UYAsyCorr[$CellContext`X, $CellContext`Y1, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], 
          1]}, {$CellContext`X, 0, 1}, {$CellContext`Y1, 0, 1}, PlotLegends -> 
        Automatic], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 1, 
         1000}, {$CellContext`Pin$$, 0.1, 5}, {$CellContext`a1$$, 0.1, 1}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{527., {275.125, 281.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.813674167054277*^9, 3.81367417601151*^9}, {
   3.813744686452221*^9, 3.8137446896082287`*^9}, 3.8138603331863317`*^9, 
   3.8139987769789686`*^9, 3.8140151170135584`*^9, 3.8140284106087418`*^9, 
   3.814028670548808*^9, 3.81402887939902*^9, 3.814030596832859*^9, 
   3.814068400901519*^9, 3.814069071104231*^9, 3.814373019979863*^9, 
   3.8145221689002233`*^9, 3.8145268810518174`*^9, 3.814531697361167*^9, 
   3.8158437740400286`*^9, 3.8164501185354614`*^9, 3.8169312977913475`*^9, 
   3.818166636716403*^9, 3.8185244265475764`*^9, 3.8187308223551083`*^9, 
   3.8187631627478104`*^9, 3.8188346206997194`*^9, 3.818843435794312*^9, 
   3.818905131976837*^9, 3.8192999272912197`*^9, 3.8405260639504128`*^9, 
   3.841070506804092*^9, 3.841072518443306*^9, 3.8419009094863424`*^9},
 CellLabel->
  "Out[234]=",ExpressionUUID->"0f3aacf4-7583-45b2-b2c8-9e94d17ad1b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"StreamPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FormBox[
         FormBox[
          RowBox[{"UXAsyCorr", "[", 
           RowBox[{
           "X", ",", "Y1", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], "]"}],
          TraditionalForm],
         TraditionalForm], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        FormBox[
         FormBox[
          RowBox[{"UYAsyCorr", "[", 
           RowBox[{
           "X", ",", "Y1", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], "]"}],
          TraditionalForm],
         TraditionalForm], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Y1", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"StreamColorFunction", "\[Rule]", "Automatic"}], ",", " ", 
     RowBox[{"PlotLegends", " ", "->", " ", "Automatic"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1", " ", ",", "1000"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "0.1", " ", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.794115998527856*^9, 3.7941160075716457`*^9}, 
   3.813742580050398*^9, {3.8137447946151295`*^9, 3.813744813195383*^9}, {
   3.8138603474589224`*^9, 3.813860360456772*^9}, {3.8140284247755556`*^9, 
   3.8140284302451763`*^9}, 3.8140285553912125`*^9, {3.814069075457588*^9, 
   3.814069079479831*^9}, {3.8143730270133934`*^9, 3.8143730327083035`*^9}, {
   3.814523301822339*^9, 3.8145233020751934`*^9}},
 CellLabel->
  "In[235]:=",ExpressionUUID->"74855f6d-5c03-4d39-9922-b93f50b5da33"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.1, 1}}, Typeset`size$$ = {
    474., {194., 200.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> StreamPlot[{
         Part[
          $CellContext`UXAsyCorr[$CellContext`X, $CellContext`Y1, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], 
          1], 
         Part[
          $CellContext`UYAsyCorr[$CellContext`X, $CellContext`Y1, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], 
          1]}, {$CellContext`X, 0, 1}, {$CellContext`Y1, 0, 1}, 
        StreamColorFunction -> Automatic, PlotLegends -> Automatic], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 1, 
         1000}, {$CellContext`Pin$$, 0.1, 5}, {$CellContext`a1$$, 0.1, 1}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{527., {275.125, 281.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.8136741822785573`*^9, 3.8136741854158764`*^9}, {
   3.813744819493967*^9, 3.813744822745475*^9}, {3.8138603487191935`*^9, 
   3.8138603611173525`*^9}, 3.813998777261304*^9, 3.814015117637469*^9, 
   3.814028431893117*^9, 3.814028682245684*^9, 3.8140306383246593`*^9, 
   3.8140314992575207`*^9, 3.8140684035410013`*^9, 3.814069079879799*^9, 
   3.8143730335051036`*^9, 3.8145221694049296`*^9, 3.814523302584881*^9, 
   3.814526881241708*^9, 3.8145316978428564`*^9, 3.8158437740687294`*^9, 
   3.816450118605423*^9, 3.8169312978473887`*^9, 3.8181666371901283`*^9, 
   3.8185244266065407`*^9, 3.8187308223981023`*^9, 3.818763162811774*^9, 
   3.818834620776658*^9, 3.818843435854278*^9, 3.81890513203936*^9, 
   3.8192999273731785`*^9, 3.840526064041343*^9, 3.841070506897829*^9, 
   3.841072518933004*^9, 3.8419009102908773`*^9},
 CellLabel->
  "Out[235]=",ExpressionUUID->"5972f39e-a04e-4d62-9ff7-b8f97a4dc383"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Region 2", "Subsection",
 CellChangeTimes->{{3.813769717589635*^9, 3.8137697186685534`*^9}, {
  3.813769754277314*^9, 
  3.8137697561700935`*^9}},ExpressionUUID->"32a52a57-e0ed-446d-a549-\
4e6cd59f2ec9"],

Cell[CellGroupData[{

Cell["Pressure 2", "Subsubsection",
 CellChangeTimes->{{3.813854083380842*^9, 3.81385408644806*^9}, {
  3.8140065609038305`*^9, 3.814006562105959*^9}, {3.8140067469156723`*^9, 
  3.814006753463277*^9}},ExpressionUUID->"74d20dc6-65a5-43bc-aef5-\
8a64723cdab1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FuncG201", "[", "X", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FuncG201R", "[", "X", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"FuncG201", "[", "X", "]"}], "//.", 
     RowBox[{"K2", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Kp", "*", "R"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"G2FuncAsy", "[", 
    RowBox[{
    "X_", ",", "Y2_", ",", "Kp_", ",", "R_", ",", "Pin_", ",", " ", "a1_"}], 
    "]"}], "=", 
   RowBox[{"FuncG201R", "[", "X", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.814028972264475*^9, 3.8140290638989925`*^9}, {
   3.814029095292372*^9, 3.8140291281220245`*^9}, {3.8143730400316057`*^9, 
   3.814373043167411*^9}, 3.8145223452975645`*^9, 3.8145224087832737`*^9, {
   3.8194565420737276`*^9, 3.8194565587831073`*^9}},
 CellLabel->
  "In[236]:=",ExpressionUUID->"56878dea-604f-448b-9a6f-4bb628887137"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{
   "G2", " ", "is", " ", "not", " ", "a", " ", "function", " ", "of", " ", 
    "Y2", " ", "or", " ", "K"}], "Text",
   Background->RGBColor[0.94, 0.91, 0.88]], TraditionalForm]], "Input",
 CellChangeTimes->{{3.8138583850527077`*^9, 3.813858389419157*^9}, {
   3.8138584266517124`*^9, 3.8138584290483303`*^9}, {3.8138597340489445`*^9, 
   3.81385974890374*^9}, {3.81402907702118*^9, 3.8140290782257223`*^9}, 
   3.841071315255104*^9},
 CellLabel->
  "In[239]:=",ExpressionUUID->"5e25f4aa-f247-4d40-bbf6-9a8a403cf924"],

Cell[BoxData[
 RowBox[{"a", " ", "function", " ", "G2", " ", "is", " ", "K", " ", "not", 
  " ", "of", " ", "or", " ", "Y2"}]], "Output",
 CellChangeTimes->{3.8410725218173404`*^9, 3.8419009126105385`*^9},
 CellLabel->
  "Out[239]=",ExpressionUUID->"e66150a1-3c28-4c22-84c4-acc6ba99c380"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     FormBox[
      FormBox[
       RowBox[{"G2FuncAsy", "[", 
        RowBox[{
        "X", ",", "Y2", ",", "Kp", ",", "R", ",", "Pin", ",", " ", "a1"}], 
        "]"}],
       TraditionalForm],
      TraditionalForm], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"X", ",", "Pressure"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1", " ", ",", "1000"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "0.1", " ", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8140291880953665`*^9, 3.8140291960261326`*^9}, {
  3.814373048717436*^9, 3.8143730514167585`*^9}},
 CellLabel->
  "In[240]:=",ExpressionUUID->"ff3ef10b-2d25-419b-b816-20ebeff96aaf"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.1, 1}}, Typeset`size$$ = {
    396.00000000000006`, {119., 124.38262677020379`}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[
        $CellContext`G2FuncAsy[$CellContext`X, $CellContext`Y2, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], \
{$CellContext`X, 0, 1}, AxesLabel -> {$CellContext`X, $CellContext`Pressure}],
       "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 1,
          1000}, {$CellContext`Pin$$, 0.1, 5}, {$CellContext`a1$$, 0.1, 1}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{450., {200.125, 206.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.8140291991716166`*^9, 3.8140292178226676`*^9}, 
   3.814030651236455*^9, 3.814069094932993*^9, 3.81437305768388*^9, 
   3.814522172498148*^9, 3.814526883313526*^9, 3.8145317012891474`*^9, 
   3.8158437760246286`*^9, 3.81645012085213*^9, 3.816931299960533*^9, 
   3.818524428797306*^9, 3.8185244635123243`*^9, 3.8187308244289303`*^9, 
   3.8187631649195395`*^9, 3.8188346229879627`*^9, 3.818843438053007*^9, 
   3.8189051340079556`*^9, 3.8192999308551817`*^9, {3.8194564665323133`*^9, 
   3.8194564682883015`*^9}, 3.8405260662420893`*^9, 3.841070509080573*^9, 
   3.8410725218793025`*^9, 3.84190091274446*^9},
 CellLabel->
  "Out[240]=",ExpressionUUID->"aa892abc-008f-4e9c-b52b-c42b08fe7ec5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["UX2", "Subsubsection",
 CellChangeTimes->{{3.813854083380842*^9, 3.81385408644806*^9}, {
   3.8140065609038305`*^9, 3.8140065763829966`*^9}, 
   3.814006656927096*^9},ExpressionUUID->"83fb99ef-1aa3-4b3f-a339-\
38e163fa5b61"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"UX20FuncSub", "[", 
    RowBox[{"X", ",", "Y2"}], "]"}], ";"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"UX20FuncSubR", "[", 
     RowBox[{"X", ",", "Y2"}], "]"}], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"UX20FuncSub", "[", 
       RowBox[{"X", ",", "Y2"}], "]"}], "//.", 
      RowBox[{"K2", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"Kp", "*", "R"}], "}"}]}]}], "]"}]}], ";"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"UX20Asy", "[", 
     RowBox[{
     "X_", ",", "Y2_", ",", "Kp_", ",", "R_", ",", "Pin_", ",", " ", "a1_"}], 
     "]"}], "=", 
    RowBox[{"UX20FuncSubR", "[", 
     RowBox[{"X", ",", "Y2"}], "]"}]}], ";"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.81400661583683*^9, 3.814006626640919*^9}, {
   3.8140292780984287`*^9, 3.8140294198058834`*^9}, {3.8143730636854935`*^9, 
   3.814373067340294*^9}, {3.8144229024597187`*^9, 3.8144229032209754`*^9}, 
   3.814522439446176*^9},
 CellLabel->
  "In[241]:=",ExpressionUUID->"6b381e77-fb2c-4cc8-917c-8a4d3c763089"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ContourPlot", "[", 
       RowBox[{
        FormBox[
         FormBox[
          RowBox[{"UX20Asy", "[", 
           RowBox[{
           "X", ",", "Y2", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], "]"}],
          TraditionalForm],
         TraditionalForm], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Y2", ",", 
          RowBox[{"-", "1.25"}], ",", "0"}], "}"}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"X", ",", "Y2", ",", "UX"}], "}"}]}], ",", 
        RowBox[{"PlotLegends", "\[Rule]", "Automatic"}]}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Polygon", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "-", "a1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "-", 
             RowBox[{"5", " ", "a1"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "-", 
             RowBox[{"5", " ", "a1"}]}]}], "}"}]}], "}"}], "]"}], "]"}]}], 
     "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1", " ", ",", "1000"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "0.05", " ", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.8164510677998266`*^9, {3.816451098992505*^9, 3.816451123591358*^9}, {
   3.8164511590044627`*^9, 3.8164511932085495`*^9}},
 CellLabel->
  "In[244]:=",ExpressionUUID->"7773a70f-5441-4753-8063-f42d08b2e481"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.05, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.05, 1}}, Typeset`size$$ = {
    481., {191., 196.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.05, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[{
         ContourPlot[
          $CellContext`UX20Asy[$CellContext`X, $CellContext`Y2, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], \
{$CellContext`X, 0, 1}, {$CellContext`Y2, -1.25, 0}, 
          AxesLabel -> {$CellContext`X, $CellContext`Y2, $CellContext`UX}, 
          PlotLegends -> Automatic], 
         Graphics[
          
          Polygon[{{0, -1}, {1, -1 - $CellContext`a1$$}, {
            1, -1 - 5 $CellContext`a1$$}, {0, -1 - 5 $CellContext`a1$$}}]]}], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 1, 
         1000}, {$CellContext`Pin$$, 0.1, 5}, {$CellContext`a1$$, 0.05, 1}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{534., {271.125, 277.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.8164511265506754`*^9, {3.8164511622006235`*^9, 3.816451193641282*^9}, 
   3.816931300948786*^9, 3.8185244299163327`*^9, 3.8187308254223557`*^9, 
   3.818763165983925*^9, 3.8188346240447073`*^9, 3.818843439072419*^9, 
   3.8189051350078635`*^9, 3.8192999323839293`*^9, 3.8405260672644987`*^9, 
   3.8410705101186934`*^9, 3.841072522946685*^9, 3.8419009144584703`*^9},
 CellLabel->
  "Out[244]=",ExpressionUUID->"1189fc77-f511-4b2f-9189-afb7fe74e95a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["UY2", "Subsubsection",
 CellChangeTimes->{{3.813854083380842*^9, 3.81385408644806*^9}, {
  3.8140065609038305`*^9, 3.8140065763829966`*^9}, {3.8140066510096173`*^9, 
  3.8140066541729918`*^9}},ExpressionUUID->"ebde4574-8e95-49c0-86d1-\
2a383653e043"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"UY20FuncSub", "[", 
    RowBox[{"X", ",", "Y2"}], "]"}], ";"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"UY20FuncSubR", "[", 
     RowBox[{"X", ",", "Y2"}], "]"}], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"UY20FuncSub", "[", 
       RowBox[{"X", ",", "Y2"}], "]"}], "//.", 
      RowBox[{"K2", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"Kp", "*", "R"}], "}"}]}]}], "]"}]}], ";"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"UY20Asy", "[", 
     RowBox[{
     "X_", ",", "Y2_", ",", "Kp_", ",", "R_", ",", "Pin_", ",", " ", "a1_"}], 
     "]"}], "=", 
    RowBox[{"UY20FuncSubR", "[", 
     RowBox[{"X", ",", "Y2"}], "]"}]}], ";"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.814006661534518*^9, 3.81400666977567*^9}, {
   3.814029469783761*^9, 3.814029543831885*^9}, {3.8140296383866577`*^9, 
   3.8140296910797033`*^9}, {3.8143730903154325`*^9, 3.814373092941253*^9}, 
   3.814522444967988*^9, 3.8158438376106205`*^9},
 CellLabel->
  "In[245]:=",ExpressionUUID->"bae609df-4e63-4f86-8790-240f28453d8f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ContourPlot", "[", 
       RowBox[{
        RowBox[{"-", 
         FormBox[
          FormBox[
           RowBox[{"UY20Asy", "[", 
            RowBox[{
            "X", ",", "Y2", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
            "]"}],
           TraditionalForm],
          TraditionalForm]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Y2", ",", 
          RowBox[{"-", "1.25"}], ",", "0"}], "}"}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"X", ",", "Y2", ",", "UY"}], "}"}]}], ",", 
        RowBox[{"PlotLegends", "\[Rule]", "Automatic"}]}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Polygon", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "-", "a1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "-", 
             RowBox[{"5", " ", "a1"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "-", 
             RowBox[{"5", " ", "a1"}]}]}], "}"}]}], "}"}], "]"}], "]"}]}], 
     "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1", " ", ",", "1000"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "0.05", " ", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.8138509908890877`*^9, {3.8138510729949427`*^9, 3.813851086990679*^9}, 
   3.8138511538197336`*^9, 3.813851753253331*^9, 3.8138518327558737`*^9, 
   3.8138518638018293`*^9, 3.8138519723268766`*^9, {3.8138520579446073`*^9, 
   3.8138520582102385`*^9}, {3.8138525668866887`*^9, 
   3.8138525939736648`*^9}, {3.813854170935528*^9, 3.8138541781047277`*^9}, {
   3.813854237149849*^9, 3.8138542422033796`*^9}, 3.813854395414403*^9, 
   3.813859776385209*^9, {3.814029696993448*^9, 3.8140297086649237`*^9}, {
   3.8143730954135504`*^9, 3.8143730986347513`*^9}, 3.814526650666274*^9, {
   3.8145320904601107`*^9, 3.814532108042159*^9}, 3.816451218985733*^9},
 CellLabel->
  "In[248]:=",ExpressionUUID->"3569a15a-e811-49d6-97c8-cc364cef8823"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.05, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.05, 1}}, Typeset`size$$ = {
    474., {191., 196.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.05, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[{
         ContourPlot[-$CellContext`UY20Asy[$CellContext`X, $CellContext`Y2, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], \
{$CellContext`X, 0, 1}, {$CellContext`Y2, -1.25, 0}, 
          AxesLabel -> {$CellContext`X, $CellContext`Y2, $CellContext`UY}, 
          PlotLegends -> Automatic], 
         Graphics[
          
          Polygon[{{0, -1}, {1, -1 - $CellContext`a1$$}, {
            1, -1 - 5 $CellContext`a1$$}, {0, -1 - 5 $CellContext`a1$$}}]]}], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 1, 
         1000}, {$CellContext`Pin$$, 0.1, 5}, {$CellContext`a1$$, 0.05, 1}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{527., {271.125, 277.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.8138510879876814`*^9, 3.813851155073786*^9, {3.8138518405070095`*^9, 
   3.8138518668320475`*^9}, 3.8138519728267927`*^9, 3.8138520596966896`*^9, {
   3.813852567886555*^9, 3.8138526032634773`*^9}, 3.8138541793812485`*^9, 
   3.813854268985816*^9, 3.8138543959603033`*^9, 3.8138597781472125`*^9, 
   3.8139987792775483`*^9, 3.8140151186366234`*^9, 3.814029710499095*^9, 
   3.8140306678556013`*^9, 3.814069105163766*^9, 3.814373105244902*^9, 
   3.8145221762829666`*^9, {3.8145266348357077`*^9, 3.814526651123992*^9}, 
   3.8145268866495905`*^9, 3.81453170563029*^9, 3.814532108880536*^9, 
   3.815843779123724*^9, 3.816450125689349*^9, 3.8164512205388403`*^9, 
   3.8169313035676484`*^9, 3.8185244329773664`*^9, 3.818730827664867*^9, 
   3.818763168339565*^9, 3.8188346264388933`*^9, 3.818843441387085*^9, 
   3.81890513718112*^9, 3.8192999361629953`*^9, 3.840526069608128*^9, 
   3.8410705129889135`*^9, 3.8410725255302114`*^9, 3.841900919030633*^9},
 CellLabel->
  "Out[248]=",ExpressionUUID->"9d810847-506b-4be8-9333-b59d23e35e1a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["UX2, UY2 - total flow field", "Subsubsection",
 CellChangeTimes->{{3.841072032360097*^9, 
  3.8410720496463795`*^9}},ExpressionUUID->"26e5edac-764e-4739-87bc-\
5176e741659e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FormBox[
    FormBox[
     RowBox[{"UX20Asy", "[", 
      RowBox[{"X", ",", "Y2", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
      "]"}],
     TraditionalForm],
    TraditionalForm], "[", 
   RowBox[{"[", "1", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{3.814523023551474*^9},
 CellLabel->
  "In[249]:=",ExpressionUUID->"dfba8af0-c9e8-4ca6-9b46-3262ab8e5df1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FormBox[
    FormBox[
     RowBox[{"UY20Asy", "[", 
      RowBox[{"X", ",", "Y2", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
      "]"}],
     TraditionalForm],
    TraditionalForm], "[", 
   RowBox[{"[", "1", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{3.814523026447806*^9, 3.8145233429933214`*^9, 
  3.8145239723475304`*^9},
 CellLabel->
  "In[250]:=",ExpressionUUID->"4fa0ba0a-8d9c-43aa-9e2a-e6ffb548cc22"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"VectorPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FormBox[
            FormBox[
             RowBox[{"UX20Asy", "[", 
              RowBox[{
              "X", ",", "Y2", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
              "]"}],
             TraditionalForm],
            TraditionalForm], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
          RowBox[{
           FormBox[
            FormBox[
             RowBox[{"UY20Asy", "[", 
              RowBox[{
              "X", ",", "Y2", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
              "]"}],
             TraditionalForm],
            TraditionalForm], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Y2", ",", 
          RowBox[{"-", "1.25"}], ",", "0"}], "}"}], ",", " ", 
        RowBox[{"PlotLegends", " ", "->", " ", "Automatic"}]}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Polygon", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "-", "a1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "-", 
             RowBox[{"5", " ", "a1"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "-", 
             RowBox[{"5", " ", "a1"}]}]}], "}"}]}], "}"}], "]"}], "]"}]}], 
     "}"}], "]"}], ",", " ", "\n", "  ", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", " ", "0.1", ",", " ", "1"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"R", ",", " ", "10", ",", " ", "1000"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Pin", ",", " ", "1"}], "}"}], ",", " ", "0.1", ",", " ", "5"}],
     "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"a1", ",", " ", "0.05", " ", ",", " ", "1"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8145229608976464`*^9, 3.8145229719800386`*^9}, 
   3.814523096953354*^9, 3.814523137408846*^9, 3.8145233399708166`*^9, 
   3.8145234565474377`*^9, {3.814524269277402*^9, 3.814524273622896*^9}, {
   3.814532019037117*^9, 3.8145320330903883`*^9}, {3.816451226511407*^9, 
   3.816451233507386*^9}},
 CellLabel->
  "In[251]:=",ExpressionUUID->"715206f4-d183-45d7-bc8a-67b61f735d45"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.05, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 1, $CellContext`R$$ = 10, Typeset`show$$ = True,
     Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 10, 1000}, {{
       Hold[$CellContext`Pin$$], 1}, 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.05, 1}}, Typeset`size$$ = {
    468., {190., 197.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.05, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 1, $CellContext`R$$ = 10}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[{
         VectorPlot[{
           Part[
            $CellContext`UX20Asy[$CellContext`X, $CellContext`Y2, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], 
            1], 
           Part[
            $CellContext`UY20Asy[$CellContext`X, $CellContext`Y2, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], 
            1]}, {$CellContext`X, 0, 1}, {$CellContext`Y2, -1.25, 0}, 
          PlotLegends -> Automatic], 
         Graphics[
          
          Polygon[{{0, -1}, {1, -1 - $CellContext`a1$$}, {
            1, -1 - 5 $CellContext`a1$$}, {0, -1 - 5 $CellContext`a1$$}}]]}], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 10,
          1000}, {{$CellContext`Pin$$, 1}, 0.1, 5}, {$CellContext`a1$$, 0.05, 
         1}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{521., {271.125, 277.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.8145229733622437`*^9, 3.8145230045686407`*^9, 3.814523098028715*^9, 
   3.8145231378995647`*^9, 3.814523340440831*^9, 3.8145234579206614`*^9, 
   3.8145242804770613`*^9, 3.814526886721548*^9, 3.8145317059879313`*^9, 
   3.814532033757121*^9, 3.8158437791937575`*^9, 3.816450126027155*^9, {
   3.8164512273958807`*^9, 3.8164512409081163`*^9}, 3.8169313036256156`*^9, 
   3.818524433285987*^9, 3.8187308277448215`*^9, 3.8187631684395256`*^9, 
   3.8188346265298243`*^9, 3.8188434414910226`*^9, 3.818905137290489*^9, 
   3.8192999362919827`*^9, 3.8405260697250605`*^9, 3.841070513082657*^9, 
   3.841072525830041*^9, 3.841900919529696*^9},
 CellLabel->
  "Out[251]=",ExpressionUUID->"7cd95243-98e7-4783-80cd-f3a8d902ef7e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"Show", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"StreamPlot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FormBox[
             FormBox[
              RowBox[{"UX20Asy", "[", 
               RowBox[{
               "X", ",", "Y2", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
               "]"}],
              TraditionalForm],
             TraditionalForm], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
           RowBox[{
            FormBox[
             FormBox[
              RowBox[{"UY20Asy", "[", 
               RowBox[{
               "X", ",", "Y2", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
               "]"}],
              TraditionalForm],
             TraditionalForm], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Y2", ",", 
           RowBox[{"-", "1.25"}], ",", "0"}], "}"}], ",", 
         RowBox[{"StreamColorFunction", "\[Rule]", "Automatic"}], ",", " ", 
         RowBox[{"PlotLegends", " ", "->", " ", "Automatic"}]}], "]"}], ",", 
       RowBox[{"Graphics", "[", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{
              RowBox[{"-", "1"}], "-", "a1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{
              RowBox[{"-", "1"}], "-", 
              RowBox[{"5", " ", "a1"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{
              RowBox[{"-", "1"}], "-", 
              RowBox[{"5", " ", "a1"}]}]}], "}"}]}], "}"}], "]"}], "]"}]}], 
      "}"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"R", ",", "1", " ", ",", "1000"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a1", ",", "0.05", "  ", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.814523051155619*^9, {3.814523182157264*^9, 3.8145231879709234`*^9}, {
   3.8145232567236824`*^9, 3.814523279643545*^9}, 3.8145233265835605`*^9, {
   3.814523370914399*^9, 3.8145234119515653`*^9}, {3.8145237461909795`*^9, 
   3.8145237476501217`*^9}, {3.814524263550703*^9, 3.8145242781582813`*^9}, {
   3.814526170137236*^9, 3.814526226425186*^9}, {3.8145317906041317`*^9, 
   3.8145318918831215`*^9}, {3.814531924850821*^9, 3.8145319625473323`*^9}, 
   3.8145322051314554`*^9, 3.816451247420389*^9},
 CellLabel->
  "In[252]:=",ExpressionUUID->"9bbcc1e1-6894-4a12-a1c2-322cba42655f"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.05, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {
      Hold[$CellContext`R$$], 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.05, 1}}, Typeset`size$$ = {
    474., {191., 196.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.05, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[{
         StreamPlot[{
           Part[
            $CellContext`UX20Asy[$CellContext`X, $CellContext`Y2, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], 
            1], 
           Part[
            $CellContext`UY20Asy[$CellContext`X, $CellContext`Y2, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], 
            1]}, {$CellContext`X, 0, 1}, {$CellContext`Y2, -1.25, 0}, 
          StreamColorFunction -> Automatic, PlotLegends -> Automatic], 
         Graphics[
          
          Polygon[{{0, -1}, {1, -1 - $CellContext`a1$$}, {
            1, -1 - 5 $CellContext`a1$$}, {0, -1 - 5 $CellContext`a1$$}}]]}], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 1}, {$CellContext`R$$, 1, 
         1000}, {$CellContext`Pin$$, 0.1, 5}, {$CellContext`a1$$, 0.05, 1}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{527., {271.125, 277.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.81452305224401*^9, {3.814523183410535*^9, 3.814523188345688*^9}, {
   3.814523262200424*^9, 3.8145232809447927`*^9}, 3.814523327012295*^9, {
   3.81452337386368*^9, 3.8145234123833156`*^9}, 3.8145237486495504`*^9, 
   3.814524291920483*^9, 3.8145262274075994`*^9, 3.814526886771538*^9, 
   3.8145317066182814`*^9, 3.8145318937345047`*^9, {3.8145319263462677`*^9, 
   3.814531963127818*^9}, 3.814533255380221*^9, 3.8158437792316704`*^9, 
   3.816450126701768*^9, 3.816451248431794*^9, 3.816931304988572*^9, 
   3.8185244360739484`*^9, 3.818730829112032*^9, 3.8187631699396415`*^9, 
   3.818834628076288*^9, 3.818843442933191*^9, 3.818905138759266*^9, 
   3.8189081231320343`*^9, 3.819299938945021*^9, 3.8405260713861003`*^9, 
   3.841070515129382*^9, 3.841072526373725*^9, 3.8419009205771313`*^9},
 CellLabel->
  "Out[252]=",ExpressionUUID->"3c7502ac-a1a8-4779-bdce-b4df2d37ad77"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total flow field", "Subsection",
 CellChangeTimes->{{3.8410720954873066`*^9, 
  3.8410720978464603`*^9}},ExpressionUUID->"7c16043b-ec94-4db1-80d4-\
3c40c81f4ebf"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"H2Border", "[", 
    RowBox[{"X_", ",", "a1_"}], "]"}], "=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"a1", "*", "X"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"H2Border", "[", 
   RowBox[{"X", ",", "a1"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"H2Border", "[", 
   RowBox[{"0.5", ",", "0.5"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.814523876212494*^9, 3.8145239371879625`*^9}, {
   3.814523996326582*^9, 3.814523999157555*^9}, {3.814524042447709*^9, 
   3.8145240426275854`*^9}, {3.8145241528307853`*^9, 
   3.8145241555202465`*^9}, {3.8145242327095146`*^9, 
   3.8145242407598405`*^9}, {3.8145244833306575`*^9, 3.81452448758722*^9}, {
   3.814524997796385*^9, 3.814525017169568*^9}, {3.8145250587154036`*^9, 
   3.814525060506791*^9}, 3.814525102663512*^9, {3.814525710742237*^9, 
   3.8145257158882513`*^9}, {3.8145258640386257`*^9, 3.814525867669551*^9}, 
   3.8145259015593233`*^9, {3.814525946291609*^9, 3.814525950390246*^9}, 
   3.814526150406478*^9, 3.8145262409548244`*^9, {3.8145263050357857`*^9, 
   3.8145263058762817`*^9}, {3.8145263804889307`*^9, 3.8145264061408663`*^9}},
 CellLabel->
  "In[253]:=",ExpressionUUID->"a3feef87-8a54-439f-86f1-3a4e6fb85f38"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"StreamPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FormBox[
            FormBox[
             RowBox[{"UXAsy", "[", 
              RowBox[{
              "X", ",", "Y1", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
              "]"}],
             TraditionalForm],
            TraditionalForm], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
          RowBox[{
           FormBox[
            FormBox[
             RowBox[{"UYAsy", "[", 
              RowBox[{
              "X", ",", "Y1", ",", "Kp", ",", "R", ",", "Pin", ",", "a1"}], 
              "]"}],
             TraditionalForm],
            TraditionalForm], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Y1", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"StreamColorFunction", "\[Rule]", "Automatic"}], ",", " ", 
        RowBox[{"PlotLegends", " ", "->", " ", "Automatic"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}]}], "]"}], ",", 
      RowBox[{"StreamPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FormBox[
            FormBox[
             RowBox[{"UX20Asy", "[", 
              RowBox[{"X", ",", 
               RowBox[{"Y2", "/", 
                RowBox[{"(", 
                 RowBox[{"R", "^", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "/", "3"}], ")"}]}], ")"}]}], ",", 
               "Kp", ",", "R", ",", "Pin", ",", "a1"}], "]"}],
             TraditionalForm],
            TraditionalForm], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
          RowBox[{
           FormBox[
            FormBox[
             RowBox[{"UY20Asy", "[", 
              RowBox[{"X", ",", 
               RowBox[{"Y2", "/", 
                RowBox[{"(", 
                 RowBox[{"R", "^", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "/", "3"}], ")"}]}], ")"}]}], ",", 
               "Kp", ",", "R", ",", "Pin", ",", "a1"}], "]"}],
             TraditionalForm],
            TraditionalForm], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Y2", ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"R", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "/", "3"}], ")"}]}], ")"}]}], 
           RowBox[{"(", 
            RowBox[{"1", "+", "a1"}], ")"}]}], ",", "0"}], "}"}], ",", 
        RowBox[{"StreamColorFunction", "\[Rule]", "Automatic"}], ",", " ", 
        RowBox[{"PlotLegends", " ", "->", " ", "Automatic"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Polygon", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"-", "1"}], " ", 
             RowBox[{"(", 
              RowBox[{"R", "^", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "/", "3"}], ")"}]}], ")"}]}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"R", "^", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "/", "3"}], ")"}]}], ")"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "a1"}], ")"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"R", "^", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "/", "3"}], ")"}]}], ")"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"5", " ", "a1"}]}], ")"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"R", "^", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "/", "3"}], ")"}]}], ")"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"5", " ", "a1"}]}], ")"}]}]}], "}"}]}], "}"}], "]"}], 
       "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Kp", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"R", ",", "10"}], "}"}], ",", "1", " ", ",", "1000"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"Pin", ",", "0.1", " ", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "0.1", " ", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.814532293899*^9, 3.8145324412744875`*^9}, {
  3.814532513501112*^9, 3.8145326139077425`*^9}, {3.8145328744049263`*^9, 
  3.8145328960756283`*^9}, {3.8145329261521416`*^9, 3.814532928483067*^9}, {
  3.8145330575882053`*^9, 3.814533061666583*^9}},
 CellLabel->
  "In[256]:=",ExpressionUUID->"c9fb64c2-ff07-4ee9-bfdf-3ba85f2b2c3d"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
    0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 10, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`Kp$$], 0.1, 1}, {{
       Hold[$CellContext`R$$], 10}, 1, 1000}, {
      Hold[$CellContext`Pin$$], 0.1, 5}, {
      Hold[$CellContext`a1$$], 0.1, 1}}, Typeset`size$$ = {
    540., {190., 196.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.1, $CellContext`Kp$$ = 
        0.1, $CellContext`Pin$$ = 0.1, $CellContext`R$$ = 10}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[{
         StreamPlot[{
           Part[
            $CellContext`UXAsy[$CellContext`X, $CellContext`Y1, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], 
            1], 
           Part[
            $CellContext`UYAsy[$CellContext`X, $CellContext`Y1, \
$CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, $CellContext`a1$$], 
            1]}, {$CellContext`X, 0, 1}, {$CellContext`Y1, 0, 1}, 
          StreamColorFunction -> Automatic, PlotLegends -> Automatic, 
          PlotRange -> {{0, 1}, {-1, 1}}], 
         StreamPlot[{
           Part[
            $CellContext`UX20Asy[$CellContext`X, \
$CellContext`Y2/$CellContext`R$$^((-1)/
              3), $CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, \
$CellContext`a1$$], 1], 
           Part[
            $CellContext`UY20Asy[$CellContext`X, \
$CellContext`Y2/$CellContext`R$$^((-1)/
              3), $CellContext`Kp$$, $CellContext`R$$, $CellContext`Pin$$, \
$CellContext`a1$$], 1]}, {$CellContext`X, 0, 
           1}, {$CellContext`Y2, (-$CellContext`R$$^((-1)/3)) (
            1 + $CellContext`a1$$), 0}, StreamColorFunction -> Automatic, 
          PlotLegends -> Automatic, PlotRange -> All], 
         Graphics[
          
          Polygon[{{0, -$CellContext`R$$^((-1)/3)}, {
            1, $CellContext`R$$^((-1)/3) (-1 - $CellContext`a1$$)}, {
            1, $CellContext`R$$^((-1)/3) (-1 - 5 $CellContext`a1$$)}, {
            0, $CellContext`R$$^((-1)/3) (-1 - 5 $CellContext`a1$$)}}]]}], 
      "Specifications" :> {{$CellContext`Kp$$, 0.1, 
         1}, {{$CellContext`R$$, 10}, 1, 1000}, {$CellContext`Pin$$, 0.1, 
         5}, {$CellContext`a1$$, 0.1, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{593., {271.125, 277.875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.815844042678919*^9, 3.815844047596469*^9}, 
   3.81645012807098*^9, 3.8169313050505357`*^9, 3.818524437255001*^9, 
   3.8187308291739955`*^9, 3.818763170021594*^9, 3.818834628171234*^9, 
   3.818843443033145*^9, 3.8189051388530083`*^9, 3.8192999390501385`*^9, 
   3.840526071497036*^9, 3.8410705152074986`*^9, 3.841072527709934*^9, 
   3.8419009230118113`*^9},
 CellLabel->
  "Out[256]=",ExpressionUUID->"c391624e-2bfa-4e20-837b-b14e8f9fe4a8"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Dimensional velocity and pressure functions", "Section",
 CellChangeTimes->{{3.8405252471921253`*^9, 3.8405252869641237`*^9}, {
  3.8410686317765546`*^9, 
  3.84106863257051*^9}},ExpressionUUID->"84567c30-a94d-4a36-957d-\
c4caef31a459"],

Cell[CellGroupData[{

Cell["6.1 Top Region - Leading Order", "Subsection",
 CellChangeTimes->{{3.8405162710983624`*^9, 3.8405162732544003`*^9}, {
  3.840525319994708*^9, 3.8405253716662474`*^9}, {3.8410721399445314`*^9, 
  3.841072140991377*^9}},ExpressionUUID->"9023d7c1-4374-4f97-a577-\
26af84d1ed91"],

Cell[CellGroupData[{

Cell["P10", "Subsubsection",
 CellChangeTimes->{{3.841071410787815*^9, 
  3.841071413630278*^9}},ExpressionUUID->"ebe5f237-6980-4fe6-810e-\
4e013b8651ac"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{
    FormBox["G10Func",
     TraditionalForm], "[", "X", "]"}], ";"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     FormBox["G10FuncDim",
      TraditionalForm], "[", "X", "]"}], "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        FormBox["G10Func",
         TraditionalForm], "[", "X", "]"}], "//.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"UX1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ux1", "/", 
             RowBox[{"ux1C", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          " ", ",", 
         RowBox[{"UY1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"uy1", "/", 
             RowBox[{"uyC", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"P1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", "/", 
             RowBox[{"pC1", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"P2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p2", "/", 
             RowBox[{"pC1", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", "0"}], "]"}]}], " ", "&"}],
            ")"}]}], ",", 
         RowBox[{"Pin", " ", "\[Rule]", " ", 
          RowBox[{"(", " ", 
           RowBox[{"pin", "/", "pC1"}], " ", ")"}]}], ",", 
         RowBox[{"X", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"x", "/", " ", "l"}], ")"}]}], ",", 
         RowBox[{"Y1", " ", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"y", "/", "h1"}], ")"}]}]}], "}"}]}], ",", 
      "AssumptionOnScaling"}], "]"}]}], ";"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.840517330985919*^9, 3.8405173613895707`*^9}, {
  3.840517398500762*^9, 3.8405174921722307`*^9}, {3.8405261701830587`*^9, 
  3.840526212318722*^9}, {3.8405262893520365`*^9, 3.840526290786208*^9}},
 CellLabel->
  "In[257]:=",ExpressionUUID->"e14f081e-7cbf-4856-a29a-b575d3f5a37a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TextbookEq", "[", 
  RowBox[{
   FormBox["G10Func",
    TraditionalForm], "[", "X", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TextbookEq", "[", 
  RowBox[{
   FormBox["G10FuncDim",
    TraditionalForm], "[", "X", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8405262840830803`*^9, 3.8405263053288083`*^9}},
 CellLabel->
  "In[259]:=",ExpressionUUID->"e2e3c2c5-2c45-4612-be84-236c0fc52823"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"Pin", "-", 
     RowBox[{"Pin", " ", "X"}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419009411607523`*^9},
 TextAlignment->Center,ExpressionUUID->"5789bbaa-9b9e-42cf-ba3b-9ffd88892ba4"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    FractionBox[
     RowBox[{"pin", " ", 
      RowBox[{"(", 
       RowBox[{"l", "-", "x"}], ")"}]}], 
     RowBox[{"l", " ", "pC1"}]],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900941352936*^9},
 TextAlignment->Center,ExpressionUUID->"5f18ecdd-7e1c-4025-9c77-7e1ffcf315ac"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["U10", "Subsubsection",
 CellChangeTimes->{{3.841071419349802*^9, 
  3.841071423257555*^9}},ExpressionUUID->"84f80be7-35f5-4d96-940a-\
3db5dd514154"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{"UX10Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"UX10FuncDim", "[", 
     RowBox[{"X", ",", "Y1"}], "]"}], "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"UX10Func", "[", 
        RowBox[{"X", ",", "Y1"}], "]"}], "//.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"UX1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ux1", "/", 
             RowBox[{"ux1C", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          " ", ",", 
         RowBox[{"UY1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"uy1", "/", 
             RowBox[{"uyC", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"P1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", "/", 
             RowBox[{"pC1", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"P2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p2", "/", 
             RowBox[{"pC1", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", "0"}], "]"}]}], " ", "&"}],
            ")"}]}], ",", 
         RowBox[{"Pin", " ", "\[Rule]", " ", 
          RowBox[{"(", " ", 
           RowBox[{"pin", "/", "pC1"}], " ", ")"}]}], ",", 
         RowBox[{"X", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"x", "/", " ", "l"}], ")"}]}], ",", 
         RowBox[{"Y1", " ", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"y", "/", "h1"}], ")"}]}]}], "}"}]}], ",", 
      "AssumptionOnScaling"}], "]"}]}], ";"}], TraditionalForm]}], "Input",
 CellChangeTimes->{
  3.8405170650729494`*^9, {3.840517283182503*^9, 3.840517309136182*^9}, {
   3.8405263115432386`*^9, 3.8405263122838106`*^9}, 3.8405533037845325`*^9},
 CellLabel->
  "In[261]:=",ExpressionUUID->"852df4f3-ab0d-485a-b7c5-23c2042da0b2"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Pin", " ", "Y1"}], "-", 
    RowBox[{"Pin", " ", 
     SuperscriptBox["Y1", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8410725295778565`*^9, 3.8419009414886913`*^9},
 CellLabel->
  "Out[261]=",ExpressionUUID->"1f70ae8c-7e94-43ec-ae67-3ad9530a7bb1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TextbookEq", "[", 
  RowBox[{"UX10Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TextbookEq", "[", 
  RowBox[{"UX10FuncDim", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.840526326604529*^9, 3.840526332079359*^9}},
 CellLabel->
  "In[263]:=",ExpressionUUID->"776f83ce-746b-45a1-9423-f128294278c2"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Pin", " ", "Y1"}], "-", 
       RowBox[{"Pin", " ", 
        SuperscriptBox["Y1", "2"]}]}], ")"}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900941644928*^9},
 TextAlignment->Center,ExpressionUUID->"62c8d810-6f0a-4acc-8a85-161c72c34aae"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    FractionBox[
     RowBox[{"pin", " ", 
      RowBox[{"(", 
       RowBox[{"h1", "-", "y"}], ")"}], " ", "y"}], 
     RowBox[{"2", " ", 
      SuperscriptBox["h1", "2"], " ", "pC1"}]],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419009418011665`*^9},
 TextAlignment->Center,ExpressionUUID->"eea57954-bf8c-4304-bcd4-a0555aa7a83c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["V10", "Subsubsection",
 CellChangeTimes->{{3.8410714277727976`*^9, 
  3.841071429118194*^9}},ExpressionUUID->"d4edc9d1-6249-40ab-86df-\
ec64f795d7c7"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{"UY10Func", "[", 
   RowBox[{"X", ",", "Y1"}], "]"}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"UY10FuncDim", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], "=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"UY10Func", "[", 
       RowBox[{"X", ",", "Y1"}], "]"}], "//.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"UX1", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ux1", "/", 
            RowBox[{"ux1C", " ", "[", 
             RowBox[{
              RowBox[{"X", "[", "#1", "]"}], ",", 
              RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}], 
        " ", ",", 
        RowBox[{"UY1", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"uy1", "/", 
            RowBox[{"uyC", " ", "[", 
             RowBox[{
              RowBox[{"X", "[", "#1", "]"}], ",", 
              RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}], 
        ",", 
        RowBox[{"P1", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", "/", 
            RowBox[{"pC1", " ", "[", 
             RowBox[{
              RowBox[{"X", "[", "#1", "]"}], ",", 
              RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}], 
        ",", 
        RowBox[{"P2", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p2", "/", 
            RowBox[{"pC1", " ", "[", 
             RowBox[{
              RowBox[{"X", "[", "#1", "]"}], ",", "0"}], "]"}]}], " ", "&"}], 
          ")"}]}], ",", 
        RowBox[{"Pin", " ", "\[Rule]", " ", 
         RowBox[{"(", " ", 
          RowBox[{"pin", "/", "pC1"}], " ", ")"}]}], ",", 
        RowBox[{"X", "\[Rule]", " ", 
         RowBox[{"(", 
          RowBox[{"x", "/", " ", "l"}], ")"}]}], ",", 
        RowBox[{"Y1", " ", "\[Rule]", " ", 
         RowBox[{"(", 
          RowBox[{"y", "/", "h1"}], ")"}]}]}], "}"}]}], ",", 
     "AssumptionOnScaling"}], "]"}]}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.840517571426132*^9, 3.840517587978266*^9}},
 CellLabel->
  "In[265]:=",ExpressionUUID->"7bd5002c-244d-4071-81b2-4187be840eb0"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8405175752241397`*^9, 3.8405175889018803`*^9}, 
   3.840521408004692*^9, 3.8405547339589396`*^9, 3.8410725297087984`*^9, 
   3.841900941988685*^9},
 CellLabel->
  "Out[265]=",ExpressionUUID->"931a696c-18b4-4ea0-8c48-4d9e62ad5a8b"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8405175752241397`*^9, 3.8405175889018803`*^9}, 
   3.840521408004692*^9, 3.8405547339589396`*^9, 3.8410725297087984`*^9, 
   3.841900941990904*^9},
 CellLabel->
  "Out[266]=",ExpressionUUID->"5a53c61a-77f8-4bab-857c-b4aec5cffd44"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 Top Region - First Order", "Subsection",
 CellChangeTimes->{{3.8405253485425854`*^9, 3.8405253787641296`*^9}, {
  3.8410721440067153`*^9, 
  3.841072144866027*^9}},ExpressionUUID->"b430c486-1365-4ec2-813f-\
42e106a6f25f"],

Cell[CellGroupData[{

Cell["P11", "Subsubsection",
 CellChangeTimes->{{3.840552667040646*^9, 3.840552671449685*^9}, 
   3.8405546123343143`*^9},ExpressionUUID->"95c86445-d58b-42a3-84e2-\
f232d66a27da"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox["G11Func",
     TraditionalForm], "[", "X", "]"}], ";"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.840526363058467*^9, 3.8405263645006332`*^9}, 
   3.8405524173461266`*^9, {3.840552541986032*^9, 3.8405525834985456`*^9}},
 CellLabel->
  "In[267]:=",ExpressionUUID->"d6e2b506-b112-4a31-9553-722266475222"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox[
     RowBox[{"G11FuncDim", "[", "X", "]"}],
     TraditionalForm], "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        FormBox["G11Func",
         TraditionalForm], "[", "X", "]"}], "//.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"UX1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ux1", "/", 
             RowBox[{"ux1C", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          " ", ",", 
         RowBox[{"UY1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"uy1", "/", 
             RowBox[{"uyC", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"P1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", "/", 
             RowBox[{"pC1", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"P2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p2", "/", 
             RowBox[{"pC1", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", "0"}], "]"}]}], " ", "&"}],
            ")"}]}], ",", 
         RowBox[{"Pin", " ", "\[Rule]", " ", 
          RowBox[{"(", " ", 
           RowBox[{"pin", "/", "pC1"}], " ", ")"}]}], ",", 
         RowBox[{"X", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"x", "/", " ", "l"}], ")"}]}], ",", 
         RowBox[{"Y1", " ", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"y", "/", "h1"}], ")"}]}], ",", 
         RowBox[{"K2", " ", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"K", " ", 
             RowBox[{"(", 
              RowBox[{"h1", "/", "h2"}], ")"}]}], ")"}], "^", "3"}]}]}], 
        "}"}]}], ",", "AssumptionOnScaling"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.840552309853076*^9, 3.8405524041554537`*^9}, {
  3.8405524714512997`*^9, 3.84055255654138*^9}},
 CellLabel->
  "In[268]:=",ExpressionUUID->"0652d4d5-bb1d-4e26-8ea2-d5369d73ec52"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    FormBox["G11FuncDim",
     TraditionalForm], "[", "X", "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{3.84055242408*^9},
 CellLabel->
  "In[269]:=",ExpressionUUID->"fe39638a-b2bb-478d-9463-ca833e75f9da"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"48", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"]}], 
              SuperscriptBox["h2", "3"]]]}]]}], ")"}], "2"], " ", 
       SuperscriptBox["h1", "6"], " ", 
       SuperscriptBox["K", "6"], " ", 
       SuperscriptBox["l", "2"], " ", "pC1"}]], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["h1", "3"], " ", 
             SuperscriptBox["K", "3"]}], 
            SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]}]], " ", 
      SuperscriptBox["h2", "3"], " ", "pin", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"8", " ", 
         SqrtBox["3"], " ", "h1", " ", "h2", " ", 
         SqrtBox[
          RowBox[{"h1", " ", "h2", " ", 
           SuperscriptBox["K", "3"]}]], " ", "l", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]], " ", "l"}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]], " ", "l"}], "-", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", "l"}], 
           "-", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", "l"}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
            RowBox[{"(", 
             RowBox[{"l", "-", "x"}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", 
                FractionBox["x", "l"]}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "l"}], "+", "x"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"3", " ", "a1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]], " ", 
            SuperscriptBox["h2", "3"], " ", 
            SuperscriptBox["l", "2"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]], " ", 
            SuperscriptBox["h2", "3"], " ", 
            SuperscriptBox["l", "2"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"l", "+", 
                 RowBox[{"2", " ", "x"}]}], ")"}]}], "l"]], " ", 
            SuperscriptBox["h2", "3"], " ", 
            SuperscriptBox["l", "2"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", 
                FractionBox[
                 RowBox[{"2", " ", "x"}], "l"]}], ")"}]}]], " ", 
            SuperscriptBox["h2", "3"], " ", 
            SuperscriptBox["l", "2"]}], "+", 
           RowBox[{"8", " ", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
            SuperscriptBox["h2", "3"], " ", "l", " ", 
            RowBox[{"(", 
             RowBox[{"l", "-", 
              RowBox[{"2", " ", "x"}]}], ")"}]}], "+", 
           RowBox[{"8", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", 
                FractionBox["x", "l"]}], ")"}]}]], " ", 
            SuperscriptBox["h2", "3"], " ", "l", " ", 
            RowBox[{"(", 
             RowBox[{"l", "-", 
              RowBox[{"2", " ", "x"}]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["h2", "3"], " ", 
               SuperscriptBox["l", "2"]}], "-", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "h1", " ", "h2", " ", 
               SqrtBox[
                RowBox[{"h1", " ", "h2", " ", 
                 SuperscriptBox["K", "3"]}]], " ", "l", " ", "x"}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"], " ", 
               SuperscriptBox["x", "2"]}]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["h2", "3"], " ", 
               SuperscriptBox["l", "2"]}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "h1", " ", "h2", " ", 
               SqrtBox[
                RowBox[{"h1", " ", "h2", " ", 
                 SuperscriptBox["K", "3"]}]], " ", "l", " ", "x"}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"], " ", 
               SuperscriptBox["x", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"24", " ", 
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"], " ", "x", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "l"}], "+", "x"}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["h2", "3"], " ", "l", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], " ", "l"}], "+", 
                 RowBox[{"7", " ", "x"}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", 
                FractionBox["x", "l"]}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"24", " ", 
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"], " ", "x", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "l"}], "+", "x"}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["h2", "3"], " ", "l", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], " ", "l"}], "+", 
                 RowBox[{"7", " ", "x"}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", 
                FractionBox["x", "l"]}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"24", " ", 
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"l", "-", "x"}], ")"}], "2"]}], "+", 
              RowBox[{
               SuperscriptBox["h2", "3"], " ", "l", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "5"}], " ", "l"}], "+", 
                 RowBox[{"9", " ", "x"}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", " ", 
               SuperscriptBox["h2", "3"], " ", 
               SuperscriptBox["l", "2"]}], "-", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", "h1", " ", "h2", " ", 
               SqrtBox[
                RowBox[{"h1", " ", "h2", " ", 
                 SuperscriptBox["K", "3"]}]], " ", "l", " ", "x"}], "+", 
              RowBox[{"12", " ", 
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  SuperscriptBox["l", "2"]}], "+", 
                 SuperscriptBox["x", "2"]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", " ", 
               SuperscriptBox["h2", "3"], " ", 
               SuperscriptBox["l", "2"]}], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", "h1", " ", "h2", " ", 
               SqrtBox[
                RowBox[{"h1", " ", "h2", " ", 
                 SuperscriptBox["K", "3"]}]], " ", "l", " ", "x"}], "+", 
              RowBox[{"12", " ", 
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  SuperscriptBox["l", "2"]}], "+", 
                 SuperscriptBox["x", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900946424383*^9},
 TextAlignment->Center,ExpressionUUID->"396c8942-7d61-44dd-8a70-ed2a6602800f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["U11", "Subsubsection",
 CellChangeTimes->{{3.8405534190819006`*^9, 3.8405534258794007`*^9}, 
   3.84055461414668*^9},ExpressionUUID->"ecf483c2-1e3e-42ce-a7e3-\
b962acad28d3"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"UX11Func", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], ";"}], TraditionalForm]], "Input",
 CellChangeTimes->{
  3.840553393040099*^9, {3.8405536147411003`*^9, 3.840553618450126*^9}, {
   3.8405536810358596`*^9, 3.840553687166924*^9}},
 CellLabel->
  "In[270]:=",ExpressionUUID->"b74b75ea-c332-42dc-af16-a4c14483a0cb"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"UX11FuncDim", "[", 
     RowBox[{"X", ",", "Y1"}], "]"}], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"UX11Func", "[", 
        RowBox[{"X", ",", "Y1"}], "]"}], "//.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"UX1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ux1", "/", 
             RowBox[{"ux1C", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          " ", ",", 
         RowBox[{"UY1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"uy1", "/", 
             RowBox[{"uyC", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"P1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", "/", 
             RowBox[{"pC1", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"P2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p2", "/", 
             RowBox[{"pC1", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", "0"}], "]"}]}], " ", "&"}],
            ")"}]}], ",", 
         RowBox[{"Pin", " ", "\[Rule]", " ", 
          RowBox[{"(", " ", 
           RowBox[{"pin", "/", "pC1"}], " ", ")"}]}], ",", 
         RowBox[{"X", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"x", "/", " ", "l"}], ")"}]}], ",", 
         RowBox[{"Y1", " ", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"y", "/", "h1"}], ")"}]}], ",", 
         RowBox[{"K2", " ", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"K", " ", 
             RowBox[{"(", 
              RowBox[{"h1", "/", "h2"}], ")"}]}], ")"}], "^", "3"}]}]}], 
        "}"}]}], ",", "AssumptionOnScaling"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.840553327067656*^9, 3.8405533520807595`*^9}, {
  3.8405533964943438`*^9, 3.8405534100413527`*^9}, {3.840553672220066*^9, 
  3.8405536732981634`*^9}},
 CellLabel->
  "In[271]:=",ExpressionUUID->"4df7de5e-ccce-4976-a65e-08e2020fe1e4"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{
    FormBox["UX11FuncDim",
     TraditionalForm], "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellLabel->
  "In[272]:=",ExpressionUUID->"dc204fd2-6e1e-4099-8b5d-8cdabc4a6bdc"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"96", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"]}], 
              SuperscriptBox["h2", "3"]]]}]]}], ")"}], "2"], " ", 
       SuperscriptBox["h1", "7"], " ", 
       SuperscriptBox["K", "6"], " ", "pC1"}]], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["h1", "3"], " ", 
             SuperscriptBox["K", "3"]}], 
            SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]}]], " ", 
      SuperscriptBox["h2", "3"], " ", "pin", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"]}], 
               SuperscriptBox["h2", "3"]]]}]]}], ")"}], " ", "h1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]], " ", 
            SuperscriptBox["h1", "2"], " ", 
            SuperscriptBox["K", "3"]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
            SuperscriptBox["h1", "2"], " ", 
            SuperscriptBox["K", "3"]}], "+", 
           RowBox[{
            SqrtBox["3"], " ", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", "h2", 
            " ", 
            SqrtBox[
             RowBox[{"h1", " ", "h2", " ", 
              SuperscriptBox["K", "3"]}]]}], "-", 
           RowBox[{
            SqrtBox["3"], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", 
                FractionBox["x", "l"]}], ")"}]}]], " ", "h2", " ", 
            SqrtBox[
             RowBox[{"h1", " ", "h2", " ", 
              SuperscriptBox["K", "3"]}]]}]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["l", "2"]], 
         RowBox[{"3", " ", "a1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "16"}], " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
             SuperscriptBox["h2", "3"], " ", 
             SuperscriptBox["l", "2"]}], "-", 
            RowBox[{"16", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", 
                 FractionBox["x", "l"]}], ")"}]}]], " ", 
             SuperscriptBox["h2", "3"], " ", 
             SuperscriptBox["l", "2"]}], "+", 
            RowBox[{"8", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", "h1", " ", "h2", " ", 
             SqrtBox[
              RowBox[{"h1", " ", "h2", " ", 
               SuperscriptBox["K", "3"]}]], " ", 
             SuperscriptBox["l", "2"]}], "+", 
            RowBox[{"8", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", "h1", " ", "h2", " ", 
             SqrtBox[
              RowBox[{"h1", " ", "h2", " ", 
               SuperscriptBox["K", "3"]}]], " ", 
             SuperscriptBox["l", "2"]}], "-", 
            RowBox[{"8", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", 
                  RowBox[{"2", " ", "x"}]}], ")"}]}], "l"]], " ", "h1", " ", 
             "h2", " ", 
             SqrtBox[
              RowBox[{"h1", " ", "h2", " ", 
               SuperscriptBox["K", "3"]}]], " ", 
             SuperscriptBox["l", "2"]}], "-", 
            RowBox[{"8", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", 
                 FractionBox[
                  RowBox[{"2", " ", "x"}], "l"]}], ")"}]}]], " ", "h1", " ", 
             "h2", " ", 
             SqrtBox[
              RowBox[{"h1", " ", "h2", " ", 
               SuperscriptBox["K", "3"]}]], " ", 
             SuperscriptBox["l", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", "l", 
             " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"7", " ", 
                SuperscriptBox["h2", "3"], " ", "l"}], "-", 
               RowBox[{"24", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "-", 
                  RowBox[{"2", " ", "x"}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"4", "+", 
                 FractionBox["x", "l"]}], ")"}]}]], " ", "l", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"7", " ", 
                SuperscriptBox["h2", "3"], " ", "l"}], "-", 
               RowBox[{"24", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "-", 
                  RowBox[{"2", " ", "x"}]}], ")"}]}]}], ")"}]}], "-", 
            RowBox[{"12", " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
             SuperscriptBox["h1", "3"], " ", 
             SuperscriptBox["K", "3"], " ", "x", " ", 
             RowBox[{"(", 
              RowBox[{"l", "-", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}]}], ")"}]}], "-", 
            RowBox[{"12", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"8", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", 
             SuperscriptBox["h1", "3"], " ", 
             SuperscriptBox["K", "3"], " ", "x", " ", 
             RowBox[{"(", 
              RowBox[{"l", "+", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}]}], ")"}]}], "+", 
            RowBox[{"6", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 FractionBox["x", "l"]}], ")"}]}]], " ", "l", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["h2", "3"], " ", "l"}], "+", 
               RowBox[{"16", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "l"}], "+", "x"}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", "h1", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 SqrtBox["3"]}], " ", "h2", " ", 
                SqrtBox[
                 RowBox[{"h1", " ", "h2", " ", 
                  SuperscriptBox["K", "3"]}]], " ", 
                SuperscriptBox["l", "2"]}], "-", 
               RowBox[{"3", " ", 
                SuperscriptBox["h1", "2"], " ", 
                SuperscriptBox["K", "3"], " ", "l", " ", "x"}], "+", 
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", 
                SuperscriptBox["h1", 
                 RowBox[{"7", "/", "2"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  FractionBox[
                   SuperscriptBox["K", "3"], "h2"], ")"}], 
                 RowBox[{"3", "/", "2"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["l", "2"]}], "-", 
                  SuperscriptBox["x", "2"]}], ")"}]}]}], ")"}]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", "h1", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 SqrtBox["3"]}], " ", "h2", " ", 
                SqrtBox[
                 RowBox[{"h1", " ", "h2", " ", 
                  SuperscriptBox["K", "3"]}]], " ", 
                SuperscriptBox["l", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["h1", "2"], " ", 
                SuperscriptBox["K", "3"], " ", "l", " ", "x"}], "+", 
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", 
                SuperscriptBox["h1", 
                 RowBox[{"7", "/", "2"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  FractionBox[
                   SuperscriptBox["K", "3"], "h2"], ")"}], 
                 RowBox[{"3", "/", "2"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["l", "2"]}], "-", 
                  SuperscriptBox["x", "2"]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}]}], ")"}], " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        FractionBox["y", "h1"]}], ")"}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900963558639*^9},
 TextAlignment->Center,ExpressionUUID->"9f58e8dc-0adf-442c-8f15-b9a90a2e762a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["V11", "Subsubsection",
 CellChangeTimes->{{3.8405534587245684`*^9, 3.8405534600614414`*^9}, 
   3.8405546032701235`*^9},ExpressionUUID->"0f1bedfb-9cd6-4b79-98f0-\
080e395799bc"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"UY11Func", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], ";"}], TraditionalForm]], "Input",
 CellChangeTimes->{3.840553717790742*^9},
 CellLabel->
  "In[273]:=",ExpressionUUID->"71bcb180-cceb-4711-a32c-eeefa71af896"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"UY11FuncDim", "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"UY11Func", "[", 
         RowBox[{"X", ",", "Y1"}], "]"}], "//.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"UX1", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"ux1", "/", 
              RowBox[{"ux1C", " ", "[", 
               RowBox[{
                RowBox[{"X", "[", "#1", "]"}], ",", 
                RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], 
            ")"}]}], " ", ",", 
          RowBox[{"UY1", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"uy1", "/", 
              RowBox[{"uyC", " ", "[", 
               RowBox[{
                RowBox[{"X", "[", "#1", "]"}], ",", 
                RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], 
            ")"}]}], ",", 
          RowBox[{"P1", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"p1", "/", 
              RowBox[{"pC1", " ", "[", 
               RowBox[{
                RowBox[{"X", "[", "#1", "]"}], ",", 
                RowBox[{"Y1", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], 
            ")"}]}], ",", 
          RowBox[{"P2", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"p2", "/", 
              RowBox[{"pC1", " ", "[", 
               RowBox[{
                RowBox[{"X", "[", "#1", "]"}], ",", "0"}], "]"}]}], " ", 
             "&"}], ")"}]}], ",", 
          RowBox[{"Pin", " ", "\[Rule]", " ", 
           RowBox[{"(", " ", 
            RowBox[{"pin", "/", "pC1"}], " ", ")"}]}], ",", 
          RowBox[{"X", "\[Rule]", " ", 
           RowBox[{"(", 
            RowBox[{"x", "/", " ", "l"}], ")"}]}], ",", 
          RowBox[{"Y1", " ", "\[Rule]", " ", 
           RowBox[{"(", 
            RowBox[{"y", "/", "h1"}], ")"}]}], ",", 
          RowBox[{"K2", " ", "\[Rule]", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"K", " ", 
              RowBox[{"(", 
               RowBox[{"h1", "/", "h2"}], ")"}]}], ")"}], "^", "3"}]}]}], 
         "}"}]}], ",", "AssumptionOnScaling"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.8405534687754354`*^9, 3.8405534872185607`*^9}, {
  3.8405535415830727`*^9, 3.8405535495689015`*^9}, {3.840553631359171*^9, 
  3.840553655728037*^9}, {3.8405537093335*^9, 3.8405537345632343`*^9}},
 CellLabel->
  "In[274]:=",ExpressionUUID->"7b6689b3-5778-4703-8139-84cffcbfaa0f"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"UY11FuncDim", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{
  3.8405536653289957`*^9, {3.840553704204904*^9, 3.840553727949862*^9}},
 CellLabel->
  "In[275]:=",ExpressionUUID->"da402027-468e-4524-a2fc-ff23cb68344d"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"48", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"]}], 
              SuperscriptBox["h2", "3"]]]}]]}], ")"}], "2"], " ", 
       SuperscriptBox["h1", "3"], " ", 
       SuperscriptBox["K", "3"], " ", "pC1"}]], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["h1", "3"], " ", 
             SuperscriptBox["K", "3"]}], 
            SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]}]], " ", 
      SuperscriptBox["h2", "3"], " ", "pin", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", 
         SqrtBox["3"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"]}], 
               SuperscriptBox["h2", "3"]]]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"]}], 
               SuperscriptBox["h2", "3"]]]}]], "-", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]]}], ")"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["h1", "3"], " ", 
            SuperscriptBox["K", "3"]}], 
           SuperscriptBox["h2", "3"]]]}], "-", 
        RowBox[{"3", " ", "a1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"l", "+", 
                 RowBox[{"2", " ", "x"}]}], ")"}]}], "l"]]}], "+", 
           RowBox[{"8", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", 
                FractionBox["x", "l"]}], ")"}]}]]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", 
                FractionBox["x", "l"]}], ")"}]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", 
                FractionBox[
                 RowBox[{"2", " ", "x"}], "l"]}], ")"}]}]]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "-", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
              FractionBox[
               RowBox[{"12", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                SuperscriptBox["x", "2"]}], 
               RowBox[{
                SuperscriptBox["h2", "3"], " ", 
                SuperscriptBox["l", "2"]}]]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
              FractionBox[
               RowBox[{"12", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                SuperscriptBox["x", "2"]}], 
               RowBox[{
                SuperscriptBox["h2", "3"], " ", 
                SuperscriptBox["l", "2"]}]]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
              FractionBox[
               RowBox[{"12", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", 
                  FractionBox[
                   SuperscriptBox["x", "2"], 
                   SuperscriptBox["l", "2"]]}], ")"}]}], 
               SuperscriptBox["h2", "3"]]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
              FractionBox[
               RowBox[{"12", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", 
                  FractionBox[
                   SuperscriptBox["x", "2"], 
                   SuperscriptBox["l", "2"]]}], ")"}]}], 
               SuperscriptBox["h2", "3"]]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         FractionBox["y", "h1"]}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"2", " ", "y"}], "h1"]}], ")"}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900969275587*^9},
 TextAlignment->Center,ExpressionUUID->"b24eb0c2-1ebf-4bcb-8d7a-9bac2151ef1b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.3 Top Region - Total Flow field", "Subsection",
 CellChangeTimes->{{3.840525406696001*^9, 3.840525413240218*^9}, {
  3.8410721478033075`*^9, 
  3.841072148476987*^9}},ExpressionUUID->"7c603eb5-2f6a-4210-bc9c-\
65e8c7d21e8c"],

Cell[CellGroupData[{

Cell["P1", "Subsubsection",
 CellChangeTimes->{{3.840554556510479*^9, 
  3.8405545572135*^9}},ExpressionUUID->"a32e1172-32b2-4709-ba6f-aacaba695c99"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"P1", "[", 
     RowBox[{"X_", ",", "Y1_"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      FormBox["G10FuncDim",
       TraditionalForm], "[", "X", "]"}], "+", 
     RowBox[{"K", " ", 
      RowBox[{
       FormBox["G11FuncDim",
        TraditionalForm], "[", "X", "]"}]}]}]}], ";"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"P1", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], "]"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.840554328755332*^9, 3.840554447860976*^9}},
 CellLabel->
  "In[276]:=",ExpressionUUID->"f348e384-56d4-49a7-9446-dad5d797ca50"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox[
      RowBox[{"pin", " ", 
       RowBox[{"(", 
        RowBox[{"l", "-", "x"}], ")"}]}], 
      RowBox[{"l", " ", "pC1"}]], "+", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"48", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"]}], 
               SuperscriptBox["h2", "3"]]]}]]}], ")"}], "2"], " ", 
        SuperscriptBox["h1", "6"], " ", 
        SuperscriptBox["K", "5"], " ", 
        SuperscriptBox["l", "2"], " ", "pC1"}]], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              SuperscriptBox["h1", "3"], " ", 
              SuperscriptBox["K", "3"]}], 
             SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]}]], " ", 
       SuperscriptBox["h2", "3"], " ", "pin", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SqrtBox["3"], " ", "h1", " ", "h2", " ", 
          SqrtBox[
           RowBox[{"h1", " ", "h2", " ", 
            SuperscriptBox["K", "3"]}]], " ", "l", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", "l"}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"8", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", "l"}], "-", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", "l"}], 
            "-", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", "l"}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
             RowBox[{"(", 
              RowBox[{"l", "-", "x"}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"4", "+", 
                 FractionBox["x", "l"]}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "l"}], "+", "x"}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", "a1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", 
             SuperscriptBox["h2", "3"], " ", 
             SuperscriptBox["l", "2"]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", 
             SuperscriptBox["h2", "3"], " ", 
             SuperscriptBox["l", "2"]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", 
                  RowBox[{"2", " ", "x"}]}], ")"}]}], "l"]], " ", 
             SuperscriptBox["h2", "3"], " ", 
             SuperscriptBox["l", "2"]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", 
                 FractionBox[
                  RowBox[{"2", " ", "x"}], "l"]}], ")"}]}]], " ", 
             SuperscriptBox["h2", "3"], " ", 
             SuperscriptBox["l", "2"]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
             SuperscriptBox["h2", "3"], " ", "l", " ", 
             RowBox[{"(", 
              RowBox[{"l", "-", 
               RowBox[{"2", " ", "x"}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", 
                 FractionBox["x", "l"]}], ")"}]}]], " ", 
             SuperscriptBox["h2", "3"], " ", "l", " ", 
             RowBox[{"(", 
              RowBox[{"l", "-", 
               RowBox[{"2", " ", "x"}]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["h2", "3"], " ", 
                SuperscriptBox["l", "2"]}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", "h1", " ", "h2", " ", 
                SqrtBox[
                 RowBox[{"h1", " ", "h2", " ", 
                  SuperscriptBox["K", "3"]}]], " ", "l", " ", "x"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                SuperscriptBox["x", "2"]}]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"8", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["h2", "3"], " ", 
                SuperscriptBox["l", "2"]}], "+", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", "h1", " ", "h2", " ", 
                SqrtBox[
                 RowBox[{"h1", " ", "h2", " ", 
                  SuperscriptBox["K", "3"]}]], " ", "l", " ", "x"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                SuperscriptBox["x", "2"]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"24", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "l"}], "+", "x"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["h2", "3"], " ", "l", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "3"}], " ", "l"}], "+", 
                  RowBox[{"7", " ", "x"}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"4", "+", 
                 FractionBox["x", "l"]}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"24", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "l"}], "+", "x"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["h2", "3"], " ", "l", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "3"}], " ", "l"}], "+", 
                  RowBox[{"7", " ", "x"}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 FractionBox["x", "l"]}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"24", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"l", "-", "x"}], ")"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox["h2", "3"], " ", "l", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "5"}], " ", "l"}], "+", 
                  RowBox[{"9", " ", "x"}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"5", " ", 
                SuperscriptBox["h2", "3"], " ", 
                SuperscriptBox["l", "2"]}], "-", 
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", "h1", " ", "h2", " ", 
                SqrtBox[
                 RowBox[{"h1", " ", "h2", " ", 
                  SuperscriptBox["K", "3"]}]], " ", "l", " ", "x"}], "+", 
               RowBox[{"12", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["l", "2"]}], "+", 
                  SuperscriptBox["x", "2"]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"5", " ", 
                SuperscriptBox["h2", "3"], " ", 
                SuperscriptBox["l", "2"]}], "+", 
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", "h1", " ", "h2", " ", 
                SqrtBox[
                 RowBox[{"h1", " ", "h2", " ", 
                  SuperscriptBox["K", "3"]}]], " ", "l", " ", "x"}], "+", 
               RowBox[{"12", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["l", "2"]}], "+", 
                  SuperscriptBox["x", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}],
         ")"}]}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419009694790354`*^9},
 TextAlignment->Center,ExpressionUUID->"f0704691-2476-4245-abbc-aee185657e4a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["U1", "Subsubsection",
 CellChangeTimes->{{3.8405545676390686`*^9, 
  3.840554568390767*^9}},ExpressionUUID->"511bdea4-b2a8-4b41-9e44-\
c32ebaffd83b"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"U1", "[", 
     RowBox[{"X_", ",", "Y1_"}], "]"}], "=", 
    RowBox[{
     RowBox[{"UX10FuncDim", "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "+", 
     RowBox[{"K", " ", 
      RowBox[{"UX11FuncDim", "[", 
       RowBox[{"X", ",", "Y1"}], "]"}]}]}]}], ";"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"U1", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], "]"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.840554499724371*^9, 3.84055453972672*^9}},
 CellLabel->
  "In[278]:=",ExpressionUUID->"384d91ae-b53a-4a3c-86f1-839cff8ce026"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox[
      RowBox[{"pin", " ", 
       RowBox[{"(", 
        RowBox[{"h1", "-", "y"}], ")"}], " ", "y"}], 
      RowBox[{"2", " ", 
       SuperscriptBox["h1", "2"], " ", "pC1"}]], "+", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"96", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"]}], 
               SuperscriptBox["h2", "3"]]]}]]}], ")"}], "2"], " ", 
        SuperscriptBox["h1", "7"], " ", 
        SuperscriptBox["K", "5"], " ", "pC1"}]], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              SuperscriptBox["h1", "3"], " ", 
              SuperscriptBox["K", "3"]}], 
             SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]}]], " ", 
       SuperscriptBox["h2", "3"], " ", "pin", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "8"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]]}], ")"}], " ", "h1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", 
             SuperscriptBox["h1", "2"], " ", 
             SuperscriptBox["K", "3"]}], "+", 
            RowBox[{"6", " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
             SuperscriptBox["h1", "2"], " ", 
             SuperscriptBox["K", "3"]}], "+", 
            RowBox[{
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", "h2", 
             " ", 
             SqrtBox[
              RowBox[{"h1", " ", "h2", " ", 
               SuperscriptBox["K", "3"]}]]}], "-", 
            RowBox[{
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 FractionBox["x", "l"]}], ")"}]}]], " ", "h2", " ", 
             SqrtBox[
              RowBox[{"h1", " ", "h2", " ", 
               SuperscriptBox["K", "3"]}]]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["l", "2"]], 
          RowBox[{"3", " ", "a1", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "16"}], " ", 
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
              SuperscriptBox["h2", "3"], " ", 
              SuperscriptBox["l", "2"]}], "-", 
             RowBox[{"16", " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"3", "+", 
                  FractionBox["x", "l"]}], ")"}]}]], " ", 
              SuperscriptBox["h2", "3"], " ", 
              SuperscriptBox["l", "2"]}], "+", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]]}]], " ", "h1", " ", "h2", " ", 
              SqrtBox[
               RowBox[{"h1", " ", "h2", " ", 
                SuperscriptBox["K", "3"]}]], " ", 
              SuperscriptBox["l", "2"]}], "+", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]]}]], " ", "h1", " ", "h2", " ", 
              SqrtBox[
               RowBox[{"h1", " ", "h2", " ", 
                SuperscriptBox["K", "3"]}]], " ", 
              SuperscriptBox["l", "2"]}], "-", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "+", 
                   RowBox[{"2", " ", "x"}]}], ")"}]}], "l"]], " ", "h1", " ", 
              "h2", " ", 
              SqrtBox[
               RowBox[{"h1", " ", "h2", " ", 
                SuperscriptBox["K", "3"]}]], " ", 
              SuperscriptBox["l", "2"]}], "-", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"3", "+", 
                  FractionBox[
                   RowBox[{"2", " ", "x"}], "l"]}], ")"}]}]], " ", "h1", " ", 
              "h2", " ", 
              SqrtBox[
               RowBox[{"h1", " ", "h2", " ", 
                SuperscriptBox["K", "3"]}]], " ", 
              SuperscriptBox["l", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", "l", 
              " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"7", " ", 
                 SuperscriptBox["h2", "3"], " ", "l"}], "-", 
                RowBox[{"24", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "-", 
                   RowBox[{"2", " ", "x"}]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"4", "+", 
                  FractionBox["x", "l"]}], ")"}]}]], " ", "l", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"7", " ", 
                 SuperscriptBox["h2", "3"], " ", "l"}], "-", 
                RowBox[{"24", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "-", 
                   RowBox[{"2", " ", "x"}]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{"12", " ", 
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"4", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
              SuperscriptBox["h1", "3"], " ", 
              SuperscriptBox["K", "3"], " ", "x", " ", 
              RowBox[{"(", 
               RowBox[{"l", "-", 
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x"}]}], ")"}]}], "-", 
             RowBox[{"12", " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"8", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]]}]], " ", 
              SuperscriptBox["h1", "3"], " ", 
              SuperscriptBox["K", "3"], " ", "x", " ", 
              RowBox[{"(", 
               RowBox[{"l", "+", 
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x"}]}], ")"}]}], "+", 
             RowBox[{"6", " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  FractionBox["x", "l"]}], ")"}]}]], " ", "l", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["h2", "3"], " ", "l"}], "+", 
                RowBox[{"16", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "l"}], "+", "x"}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]]}]], " ", "h1", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  SqrtBox["3"]}], " ", "h2", " ", 
                 SqrtBox[
                  RowBox[{"h1", " ", "h2", " ", 
                   SuperscriptBox["K", "3"]}]], " ", 
                 SuperscriptBox["l", "2"]}], "-", 
                RowBox[{"3", " ", 
                 SuperscriptBox["h1", "2"], " ", 
                 SuperscriptBox["K", "3"], " ", "l", " ", "x"}], "+", 
                RowBox[{"6", " ", 
                 SqrtBox["3"], " ", 
                 SuperscriptBox["h1", 
                  RowBox[{"7", "/", "2"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   FractionBox[
                    SuperscriptBox["K", "3"], "h2"], ")"}], 
                  RowBox[{"3", "/", "2"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["l", "2"]}], "-", 
                   SuperscriptBox["x", "2"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"4", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", "h1", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  SqrtBox["3"]}], " ", "h2", " ", 
                 SqrtBox[
                  RowBox[{"h1", " ", "h2", " ", 
                   SuperscriptBox["K", "3"]}]], " ", 
                 SuperscriptBox["l", "2"]}], "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox["h1", "2"], " ", 
                 SuperscriptBox["K", "3"], " ", "l", " ", "x"}], "+", 
                RowBox[{"6", " ", 
                 SqrtBox["3"], " ", 
                 SuperscriptBox["h1", 
                  RowBox[{"7", "/", "2"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   FractionBox[
                    SuperscriptBox["K", "3"], "h2"], ")"}], 
                  RowBox[{"3", "/", "2"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["l", "2"]}], "-", 
                   SuperscriptBox["x", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}]}], ")"}], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         FractionBox["y", "h1"]}], ")"}]}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900969650897*^9},
 TextAlignment->Center,ExpressionUUID->"1c972f0a-6ad4-44fb-817c-47d92eec78e1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["V1", "Subsubsection",
 CellChangeTimes->{{3.8405545825195155`*^9, 
  3.840554582800746*^9}},ExpressionUUID->"78b0bd41-112b-4fd5-8b5b-\
b8bce7deb68d"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"V1", "[", 
     RowBox[{"X_", ",", "Y1_"}], "]"}], "=", 
    RowBox[{
     RowBox[{"UY10FuncDim", "[", 
      RowBox[{"X", ",", "Y1"}], "]"}], "+", 
     RowBox[{"K", " ", 
      RowBox[{"UY11FuncDim", "[", 
       RowBox[{"X", ",", "Y1"}], "]"}]}]}]}], ";"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"V1", "[", 
    RowBox[{"X", ",", "Y1"}], "]"}], "]"}], TraditionalForm]}], "Input",
 CellChangeTimes->{{3.840554630662554*^9, 3.8405546789256735`*^9}, {
  3.8405547396249957`*^9, 3.840554743860161*^9}},
 CellLabel->
  "In[280]:=",ExpressionUUID->"b9e5961a-a5be-493f-b8a8-07b4a31d793e"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"48", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"]}], 
              SuperscriptBox["h2", "3"]]]}]]}], ")"}], "2"], " ", 
       SuperscriptBox["h1", "3"], " ", 
       SuperscriptBox["K", "2"], " ", "pC1"}]], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["h1", "3"], " ", 
             SuperscriptBox["K", "3"]}], 
            SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]}]], " ", 
      SuperscriptBox["h2", "3"], " ", "pin", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", 
         SqrtBox["3"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"]}], 
               SuperscriptBox["h2", "3"]]]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"]}], 
               SuperscriptBox["h2", "3"]]]}]], "-", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]]}], ")"}], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["h1", "3"], " ", 
            SuperscriptBox["K", "3"]}], 
           SuperscriptBox["h2", "3"]]]}], "-", 
        RowBox[{"3", " ", "a1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"l", "+", 
                 RowBox[{"2", " ", "x"}]}], ")"}]}], "l"]]}], "+", 
           RowBox[{"8", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", 
                FractionBox["x", "l"]}], ")"}]}]]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", 
                FractionBox["x", "l"]}], ")"}]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", 
                FractionBox[
                 RowBox[{"2", " ", "x"}], "l"]}], ")"}]}]]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"8", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "-", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
              FractionBox[
               RowBox[{"12", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                SuperscriptBox["x", "2"]}], 
               RowBox[{
                SuperscriptBox["h2", "3"], " ", 
                SuperscriptBox["l", "2"]}]]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
              FractionBox[
               RowBox[{"12", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                SuperscriptBox["x", "2"]}], 
               RowBox[{
                SuperscriptBox["h2", "3"], " ", 
                SuperscriptBox["l", "2"]}]]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
              FractionBox[
               RowBox[{"12", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", 
                  FractionBox[
                   SuperscriptBox["x", "2"], 
                   SuperscriptBox["l", "2"]]}], ")"}]}], 
               SuperscriptBox["h2", "3"]]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
              FractionBox[
               RowBox[{"12", " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", 
                  FractionBox[
                   SuperscriptBox["x", "2"], 
                   SuperscriptBox["l", "2"]]}], ")"}]}], 
               SuperscriptBox["h2", "3"]]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         FractionBox["y", "h1"]}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"2", " ", "y"}], "h1"]}], ")"}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419009698071356`*^9},
 TextAlignment->Center,ExpressionUUID->"6c67187f-a113-4114-9853-b8d125efd2e4"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.4 Bottom Region - Leading Order (Total Flow field)", "Subsection",
 CellChangeTimes->{{3.8405253836803055`*^9, 3.8405254032300186`*^9}, {
  3.8410721512419004`*^9, 
  3.8410721517887683`*^9}},ExpressionUUID->"8cc0f44e-1185-419d-9cd8-\
62b5f6d8cc4b"],

Cell[CellGroupData[{

Cell["P2", "Subsubsection",
 CellChangeTimes->{{3.84055715373695*^9, 
  3.8405571547681723`*^9}},ExpressionUUID->"9f952c34-9d87-49df-8cde-\
850955f0a442"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"FuncG201", "[", "X", "]"}], ";"}], TraditionalForm]], "Input",
 CellChangeTimes->{3.8405561139672213`*^9, 3.8405562089920025`*^9},
 CellLabel->
  "In[282]:=",ExpressionUUID->"a2117e82-f57b-4815-bf56-b9ffa2965411"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"FuncG201Dim", "[", "X", "]"}], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"FuncG201", "[", "X", "]"}], "//.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"UX2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ux2", "/", 
             RowBox[{"ux2C", " ", "[", 
              RowBox[{"X", "[", "#1", "]"}], "]"}]}], " ", "&"}], ")"}]}], 
         " ", ",", 
         RowBox[{"UY2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"uy2", "/", 
             RowBox[{"uyC", " ", "[", 
              RowBox[{"X", "[", "#1", "]"}], "]"}]}], " ", "&"}], ")"}]}], 
         ",", 
         RowBox[{"P2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p2", "/", 
             RowBox[{"pC2", " ", "[", 
              RowBox[{"X", "[", "#1", "]"}], "]"}]}], " ", "&"}], ")"}]}], 
         ",", 
         RowBox[{"P1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", "/", 
             RowBox[{"pC2", " ", "[", 
              RowBox[{"X", "[", "#1", "]"}], "]"}]}], " ", "&"}], ")"}]}], 
         ",", 
         RowBox[{"Pin", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"pin", "/", "pC2"}], ")"}]}], ",", 
         RowBox[{"X", "\[Rule]", " ", 
          RowBox[{"(", " ", 
           RowBox[{"x", "/", "l"}], ")"}]}], ",", 
         RowBox[{"Y2", "\[Rule]", " ", 
          RowBox[{"(", " ", 
           RowBox[{"y", "/", "h2"}], ")"}]}], ",", 
         RowBox[{"K2", " ", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"K", " ", 
             RowBox[{"(", 
              RowBox[{"h1", "/", "h2"}], ")"}]}], ")"}], "^", "3"}]}]}], 
        "}"}]}], ",", "AssumptionOnScaling"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.840555935989874*^9, 3.8405560372950134`*^9}, {
   3.840556068754177*^9, 3.840556119805317*^9}, {3.840556160692452*^9, 
   3.840556163913947*^9}, 3.840556213756486*^9},
 CellLabel->
  "In[283]:=",ExpressionUUID->"23d4cea7-6464-47bc-a4cd-52692a091479"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"FuncG201Dim", "[", "X", "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{3.8405562256949987`*^9},
 CellLabel->
  "In[284]:=",ExpressionUUID->"886faff2-7d0c-456f-b1b1-bf51c315d98c"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"48", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"]}], 
              SuperscriptBox["h2", "3"]]]}]]}], ")"}], "2"], " ", "pC2"}]], 
     RowBox[{"pin", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"8", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"]}], 
               SuperscriptBox["h2", "3"]]]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"6", "+", 
           FractionBox[
            RowBox[{
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]]}], 
            SqrtBox[
             FractionBox[
              RowBox[{
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"]}], 
              SuperscriptBox["h2", "3"]]]], "-", 
           FractionBox[
            RowBox[{
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 FractionBox["x", "l"]}], ")"}]}]]}], 
            SqrtBox[
             FractionBox[
              RowBox[{
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"]}], 
              SuperscriptBox["h2", "3"]]]], "+", 
           FractionBox[
            RowBox[{"6", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", 
             RowBox[{"(", 
              RowBox[{"l", "-", "x"}], ")"}]}], "l"], "-", 
           FractionBox[
            RowBox[{"6", " ", "x"}], "l"]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["h1", "3"], " ", 
           SuperscriptBox["K", "3"]}]], 
         RowBox[{"3", " ", "a1", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{
               SuperscriptBox["h1", "3"], " ", 
               SuperscriptBox["K", "3"]}], 
              SuperscriptBox["h2", "3"]]], " ", 
            RowBox[{"(", 
             RowBox[{"2", "-", 
              FractionBox[
               RowBox[{"3", " ", "x"}], "l"]}], ")"}]}]], " ", 
          SuperscriptBox["h2", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", 
                  RowBox[{"2", " ", "x"}]}], ")"}]}], "l"]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", 
                  RowBox[{"4", " ", "x"}]}], ")"}]}], "l"]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"2", " ", "x"}], "l"]}], ")"}]}]]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 FractionBox[
                  RowBox[{"3", " ", "x"}], "l"]}], ")"}]}]]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 FractionBox[
                  RowBox[{"3", " ", "x"}], "l"]}], ")"}]}]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"4", " ", "x"}], "l"]}], ")"}]}]]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
               FractionBox[
                RowBox[{"12", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 SuperscriptBox["x", "2"]}], 
                RowBox[{
                 SuperscriptBox["h2", "3"], " ", 
                 SuperscriptBox["l", "2"]}]]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"2", " ", "x"}], "l"]}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
               FractionBox[
                RowBox[{"12", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 SuperscriptBox["x", "2"]}], 
                RowBox[{
                 SuperscriptBox["h2", "3"], " ", 
                 SuperscriptBox["l", "2"]}]]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
               FractionBox[
                RowBox[{"12", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", 
                   FractionBox[
                    SuperscriptBox["x", "2"], 
                    SuperscriptBox["l", "2"]]}], ")"}]}], 
                SuperscriptBox["h2", "3"]]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"8", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
               FractionBox[
                RowBox[{"12", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", 
                   FractionBox[
                    SuperscriptBox["x", "2"], 
                    SuperscriptBox["l", "2"]]}], ")"}]}], 
                SuperscriptBox["h2", "3"]]}], ")"}]}]}], ")"}]}]}]}], 
       ")"}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419009726344657`*^9},
 TextAlignment->Center,ExpressionUUID->"933e7345-adf1-47f5-b1e8-9b07462f6236"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["U2", "Subsubsection",
 CellChangeTimes->{{3.8405571713528185`*^9, 3.840557171790286*^9}, 
   3.8405572262703753`*^9},ExpressionUUID->"8144c998-8155-4fb5-be91-\
ebabd5a79381"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"UX20FuncSub", "[", 
    RowBox[{"X", ",", "Y2"}], "]"}], ";"}], TraditionalForm]], "Input",
 CellChangeTimes->{3.840557364029098*^9},
 CellLabel->
  "In[285]:=",ExpressionUUID->"b368e7bf-462c-4f1c-a475-c43efd680783"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"UX20FuncSubDim", "[", 
     RowBox[{"X", ",", "Y2"}], "]"}], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"UX20FuncSub", "[", 
        RowBox[{"X", ",", "Y2"}], "]"}], "//.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"UX2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ux2", "/", 
             RowBox[{"ux2C", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y2", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          " ", ",", 
         RowBox[{"UY2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"uy2", "/", 
             RowBox[{"uyC", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y2", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"P2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p2", "/", 
             RowBox[{"pC2", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y2", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"P1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", "/", 
             RowBox[{"pC2", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", "0"}], "]"}]}], " ", "&"}],
            ")"}]}], ",", 
         RowBox[{"Pin", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"pin", "/", "pC2"}], ")"}]}], ",", 
         RowBox[{"X", "\[Rule]", " ", 
          RowBox[{"(", " ", 
           RowBox[{"x", "/", "l"}], ")"}]}], ",", 
         RowBox[{"Y2", "\[Rule]", " ", 
          RowBox[{"(", " ", 
           RowBox[{"y", "/", "h2"}], ")"}]}], ",", 
         RowBox[{"K2", " ", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"K", " ", 
             RowBox[{"(", 
              RowBox[{"h1", "/", "h2"}], ")"}]}], ")"}], "^", "3"}]}]}], 
        "}"}]}], ",", "AssumptionOnScaling"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.8405572556441393`*^9, 3.8405572615059195`*^9}, {
   3.840557298785201*^9, 3.8405573235238185`*^9}, 3.8405573653884172`*^9},
 CellLabel->
  "In[286]:=",ExpressionUUID->"99f7ce38-de18-4710-8781-fdcbef9a2e53"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"UX20FuncSubDim", "[", 
    RowBox[{"X", ",", "Y2"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{3.840557368811737*^9},
 CellLabel->
  "In[287]:=",ExpressionUUID->"b4feff08-0be4-4ad3-92c5-118730c55ca3"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"8", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"]}], 
               SuperscriptBox["h2", "3"]]]}]]}], ")"}], "2"], " ", 
        SuperscriptBox["h1", 
         RowBox[{"3", "/", "2"}]], " ", 
        SuperscriptBox["h2", 
         RowBox[{"7", "/", "2"}]], " ", 
        SqrtBox[
         SuperscriptBox["K", "3"]], " ", 
        SuperscriptBox["l", "3"], " ", "pC2"}]], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              SuperscriptBox["h1", "3"], " ", 
              SuperscriptBox["K", "3"]}], 
             SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]}]], " ", "pin", 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]]}]], "-", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]]}], ")"}], " ",
           "h1", " ", "h2", " ", 
          SqrtBox[
           RowBox[{"h1", " ", "h2", " ", 
            SuperscriptBox["K", "3"]}]], " ", 
          SuperscriptBox["l", "2"]}], "+", 
         RowBox[{"a1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", 
             SuperscriptBox["h2", "3"], " ", 
             SuperscriptBox["l", "2"]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", 
             SuperscriptBox["h2", "3"], " ", 
             SuperscriptBox["l", "2"]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", 
                  RowBox[{"2", " ", "x"}]}], ")"}]}], "l"]], " ", 
             SuperscriptBox["h2", "3"], " ", 
             SuperscriptBox["l", "2"]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", 
                 FractionBox[
                  RowBox[{"2", " ", "x"}], "l"]}], ")"}]}]], " ", 
             SuperscriptBox["h2", "3"], " ", 
             SuperscriptBox["l", "2"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"8", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", "h1", " ", "x", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "h2", " ", 
                SqrtBox[
                 RowBox[{"h1", " ", "h2", " ", 
                  SuperscriptBox["K", "3"]}]], " ", "l"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SuperscriptBox["h1", "2"], " ", 
                SuperscriptBox["K", "3"], " ", "x"}]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", "h1", 
             " ", "x", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "h2", " ", 
                SqrtBox[
                 RowBox[{"h1", " ", "h2", " ", 
                  SuperscriptBox["K", "3"]}]], " ", "l"}], "+", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SuperscriptBox["h1", "2"], " ", 
                SuperscriptBox["K", "3"], " ", "x"}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 SqrtBox["3"]}], " ", 
                SuperscriptBox["h2", "3"], " ", 
                SuperscriptBox["l", "2"]}], "+", 
               RowBox[{"9", " ", "h1", " ", "h2", " ", 
                SqrtBox[
                 RowBox[{"h1", " ", "h2", " ", 
                  SuperscriptBox["K", "3"]}]], " ", "l", " ", "x"}], "+", 
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["l", "2"]}], "-", 
                  SuperscriptBox["x", "2"]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SqrtBox["3"], " ", 
                SuperscriptBox["h2", "3"], " ", 
                SuperscriptBox["l", "2"]}], "+", 
               RowBox[{"9", " ", "h1", " ", "h2", " ", 
                SqrtBox[
                 RowBox[{"h1", " ", "h2", " ", 
                  SuperscriptBox["K", "3"]}]], " ", "l", " ", "x"}], "+", 
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", 
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["l", "2"]}], "+", 
                  SuperscriptBox["x", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}],
         ")"}], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"h2", " ", 
          RowBox[{"(", 
           RowBox[{"l", "+", 
            RowBox[{"a1", " ", "x"}]}], ")"}]}], "+", 
         RowBox[{"l", " ", "y"}]}], ")"}]}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.841900975773911*^9},
 TextAlignment->Center,ExpressionUUID->"9d68824d-ca33-4af3-b095-c49605ded045"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["V2", "Subsubsection",
 CellChangeTimes->{{3.840557162269985*^9, 3.840557163863616*^9}, 
   3.840557221356135*^9},ExpressionUUID->"6f75b93b-0c4e-417f-9b1a-\
0397a5460e36"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"UY20FuncSub", "[", 
    RowBox[{"X", ",", "Y2"}], "]"}], ";"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"UY20FuncSubDim", "[", 
     RowBox[{"X", ",", "Y2"}], "]"}], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"UY20FuncSub", "[", 
        RowBox[{"X", ",", "Y2"}], "]"}], "//.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"UX2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ux2", "/", 
             RowBox[{"ux2C", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y2", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          " ", ",", 
         RowBox[{"UY2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"uy2", "/", 
             RowBox[{"uyC", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y2", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"P2", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p2", "/", 
             RowBox[{"pC2", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", 
               RowBox[{"Y2", "[", "#2", "]"}]}], "]"}]}], " ", "&"}], ")"}]}],
          ",", 
         RowBox[{"P1", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", "/", 
             RowBox[{"pC2", " ", "[", 
              RowBox[{
               RowBox[{"X", "[", "#1", "]"}], ",", "0"}], "]"}]}], " ", "&"}],
            ")"}]}], ",", 
         RowBox[{"Pin", "\[Rule]", " ", 
          RowBox[{"(", 
           RowBox[{"pin", "/", "pC2"}], ")"}]}], ",", 
         RowBox[{"X", "\[Rule]", " ", 
          RowBox[{"(", " ", 
           RowBox[{"x", "/", "l"}], ")"}]}], ",", 
         RowBox[{"Y2", "\[Rule]", " ", 
          RowBox[{"(", " ", 
           RowBox[{"y", "/", "h2"}], ")"}]}], ",", 
         RowBox[{"K2", " ", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"K", " ", 
             RowBox[{"(", 
              RowBox[{"h1", "/", "h2"}], ")"}]}], ")"}], "^", "3"}]}]}], 
        "}"}]}], ",", "AssumptionOnScaling"}], "]"}]}], ";"}], 
  TraditionalForm]}], "Input",
 CellChangeTimes->{{3.8405569915857444`*^9, 3.8405570835364857`*^9}, 
   3.8405571161046653`*^9},
 CellLabel->
  "In[288]:=",ExpressionUUID->"d9d5cf00-560e-44dc-9a48-b45822f9af36"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"TextbookEq", "[", 
   RowBox[{"UY20FuncSubDim", "[", 
    RowBox[{"X", ",", "Y2"}], "]"}], "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{3.8405570276560664`*^9, 3.8405571278118935`*^9},
 CellLabel->
  "In[290]:=",ExpressionUUID->"59bf2964-c487-4b9c-aa95-d561d84ddeb7"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"48", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"4", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"]}], 
               SuperscriptBox["h2", "3"]]]}]]}], ")"}], "2"], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           SuperscriptBox["h1", "3"], " ", 
           SuperscriptBox["K", "3"]}], 
          SuperscriptBox["h2", "3"]]], " ", "pC2"}]], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["h1", "3"], " ", 
             SuperscriptBox["K", "3"]}], 
            SuperscriptBox["h2", "3"]]], " ", 
          RowBox[{"(", 
           RowBox[{"l", "-", "x"}], ")"}]}], "l"]], " ", "pin", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"a1", " ", "x"}], "l"], "+", 
         FractionBox["y", "h2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "l"], 
          RowBox[{"3", " ", 
           SuperscriptBox["a1", "3"], " ", "x", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                SqrtBox["3"], "-", 
                FractionBox[
                 RowBox[{"2", " ", 
                  SqrtBox[
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                    SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]}], ")"}]}], 
             "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SqrtBox["3"], "-", 
                FractionBox[
                 RowBox[{"2", " ", 
                  SqrtBox[
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                    SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]}], ")"}]}], 
             "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"4", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
              RowBox[{"(", 
               RowBox[{
                SqrtBox["3"], "+", 
                FractionBox[
                 RowBox[{"2", " ", 
                  SqrtBox[
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                    SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]}], ")"}]}], 
             "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"4", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
              RowBox[{"(", 
               RowBox[{
                SqrtBox["3"], "+", 
                FractionBox[
                 RowBox[{"2", " ", 
                  SqrtBox[
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                    SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]}], ")"}]}], 
             "+", 
             FractionBox[
              RowBox[{"4", " ", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"6", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]]}]], " ", 
               SuperscriptBox["h1", 
                RowBox[{"3", "/", "2"}]], " ", 
               SqrtBox[
                SuperscriptBox["K", "3"]], " ", "x", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["h2", "3"], " ", 
                  SuperscriptBox["l", "2"]}], "-", 
                 RowBox[{"4", " ", 
                  SqrtBox["3"], " ", "h1", " ", "h2", " ", 
                  SqrtBox[
                   RowBox[{"h1", " ", "h2", " ", 
                    SuperscriptBox["K", "3"]}]], " ", "l", " ", "x"}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"], " ", 
                  SuperscriptBox["x", "2"]}]}], ")"}]}], 
              RowBox[{
               SuperscriptBox["h2", 
                RowBox[{"9", "/", "2"}]], " ", 
               SuperscriptBox["l", "3"]}]], "+", 
             FractionBox[
              RowBox[{"4", " ", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   FractionBox[
                    RowBox[{"2", " ", "x"}], "l"]}], ")"}]}]], " ", 
               SuperscriptBox["h1", 
                RowBox[{"3", "/", "2"}]], " ", 
               SqrtBox[
                SuperscriptBox["K", "3"]], " ", "x", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["h2", "3"], " ", 
                  SuperscriptBox["l", "2"]}], "+", 
                 RowBox[{"4", " ", 
                  SqrtBox["3"], " ", "h1", " ", "h2", " ", 
                  SqrtBox[
                   RowBox[{"h1", " ", "h2", " ", 
                    SuperscriptBox["K", "3"]}]], " ", "l", " ", "x"}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"], " ", 
                  SuperscriptBox["x", "2"]}]}], ")"}]}], 
              RowBox[{
               SuperscriptBox["h2", 
                RowBox[{"9", "/", "2"}]], " ", 
               SuperscriptBox["l", "3"]}]], "-", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SqrtBox["3"], "-", 
                FractionBox[
                 RowBox[{"14", " ", 
                  SqrtBox[
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                    SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "-", 
                FractionBox[
                 RowBox[{"12", " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                    SuperscriptBox["h2", "3"]], ")"}], 
                   RowBox[{"3", "/", "2"}]], " ", "x", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SuperscriptBox["l", "2"]}], "+", 
                    SuperscriptBox["x", "2"]}], ")"}]}], 
                 SuperscriptBox["l", "3"]], "+", 
                FractionBox[
                 RowBox[{"4", " ", 
                  SqrtBox["3"], " ", 
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    FractionBox[
                    RowBox[{"4", " ", 
                    SuperscriptBox["x", "2"]}], 
                    SuperscriptBox["l", "2"]]}], ")"}]}], 
                 SuperscriptBox["h2", "3"]]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "+", 
                   RowBox[{"2", " ", "x"}]}], ")"}]}], "l"]], " ", 
              RowBox[{"(", 
               RowBox[{
                SqrtBox["3"], "+", 
                FractionBox[
                 RowBox[{"14", " ", 
                  SqrtBox[
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                    SuperscriptBox["h2", "3"]]], " ", "x"}], "l"], "+", 
                FractionBox[
                 RowBox[{"12", " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                    SuperscriptBox["h2", "3"]], ")"}], 
                   RowBox[{"3", "/", "2"}]], " ", "x", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SuperscriptBox["l", "2"]}], "+", 
                    SuperscriptBox["x", "2"]}], ")"}]}], 
                 SuperscriptBox["l", "3"]], "+", 
                FractionBox[
                 RowBox[{"4", " ", 
                  SqrtBox["3"], " ", 
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    FractionBox[
                    RowBox[{"4", " ", 
                    SuperscriptBox["x", "2"]}], 
                    SuperscriptBox["l", "2"]]}], ")"}]}], 
                 SuperscriptBox["h2", "3"]]}], ")"}]}]}], ")"}]}]}], "+", 
         FractionBox[
          RowBox[{"8", " ", 
           SqrtBox["3"], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["h1", "3"], " ", 
                SuperscriptBox["K", "3"]}], 
               SuperscriptBox["h2", "3"]]]}]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], "-", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]]}], ")"}], 
           " ", 
           SuperscriptBox["h1", "3"], " ", 
           SuperscriptBox["K", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["h2", "2"], "-", 
             RowBox[{"h2", " ", "y"}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["y", "2"]}]}], ")"}]}], 
          SuperscriptBox["h2", "5"]], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{
            SuperscriptBox["h2", "4"], " ", 
            SuperscriptBox["l", "3"]}]], 
          RowBox[{
           SuperscriptBox["a1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"24", " ", 
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
              SuperscriptBox["h1", 
               RowBox[{"3", "/", "2"}]], " ", 
              SuperscriptBox["h2", 
               RowBox[{"5", "/", "2"}]], " ", 
              SqrtBox[
               SuperscriptBox["K", "3"]], " ", 
              SuperscriptBox["l", "2"], " ", "x"}], "+", 
             RowBox[{"12", " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  FractionBox["x", "l"]}], ")"}]}]], " ", 
              SuperscriptBox["h1", 
               RowBox[{"3", "/", "2"}]], " ", 
              SuperscriptBox["h2", 
               RowBox[{"5", "/", "2"}]], " ", 
              SqrtBox[
               SuperscriptBox["K", "3"]], " ", 
              SuperscriptBox["l", "2"], " ", "x"}], "+", 
             RowBox[{"12", " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"3", "+", 
                  FractionBox["x", "l"]}], ")"}]}]], " ", 
              SuperscriptBox["h1", 
               RowBox[{"3", "/", "2"}]], " ", 
              SuperscriptBox["h2", 
               RowBox[{"5", "/", "2"}]], " ", 
              SqrtBox[
               SuperscriptBox["K", "3"]], " ", 
              SuperscriptBox["l", "2"], " ", "x"}], "+", 
             RowBox[{"6", " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]]}]], " ", 
              SuperscriptBox["h2", "3"], " ", 
              SuperscriptBox["l", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SqrtBox["3"], " ", "l", " ", 
                 RowBox[{"(", 
                  RowBox[{"h2", "-", "y"}], ")"}]}], "-", 
                RowBox[{"2", " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "h2"}], "-", "y"}], ")"}]}]}], ")"}]}], 
             "-", 
             RowBox[{"6", " ", 
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"4", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
              SuperscriptBox["h2", "3"], " ", 
              SuperscriptBox["l", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SqrtBox["3"], " ", "l", " ", 
                 RowBox[{"(", 
                  RowBox[{"h2", "-", "y"}], ")"}]}], "+", 
                RowBox[{"2", " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "h2"}], "-", "y"}], ")"}]}]}], ")"}]}], 
             "-", 
             RowBox[{"6", " ", 
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"4", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
              SuperscriptBox["h2", "3"], " ", 
              SuperscriptBox["l", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SqrtBox["3"], " ", "l", " ", 
                 RowBox[{"(", 
                  RowBox[{"h2", "-", "y"}], ")"}]}], "+", 
                RowBox[{"2", " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "h2"}], "-", "y"}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SqrtBox["3"], " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", "l", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["x", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"35", " ", "h2"}], "-", 
                    RowBox[{"24", " ", "y"}]}], ")"}]}], "-", 
                   RowBox[{"18", " ", 
                    SuperscriptBox["l", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"h2", "-", "y"}], ")"}]}]}], ")"}]}], "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"h1", " ", "h2"}], ")"}], 
                  RowBox[{"3", "/", "2"}]], " ", 
                 SqrtBox[
                  SuperscriptBox["K", "3"]], " ", 
                 SuperscriptBox["l", "2"], " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"15", " ", "h2"}], "-", 
                   RowBox[{"14", " ", "y"}]}], ")"}]}], "-", 
                RowBox[{"3", " ", 
                 SqrtBox["3"], " ", 
                 SuperscriptBox["h2", "3"], " ", 
                 SuperscriptBox["l", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"h2", "-", "y"}], ")"}]}], "+", 
                RowBox[{"36", " ", 
                 SuperscriptBox["h2", "3"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                    SuperscriptBox["h2", "3"]], ")"}], 
                  RowBox[{"3", "/", "2"}]], " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SuperscriptBox["l", "2"]}], "+", 
                   SuperscriptBox["x", "2"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "h2"}], "-", "y"}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "+", 
                   RowBox[{"2", " ", "x"}]}], ")"}]}], "l"]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", "l", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["x", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"35", " ", "h2"}], "-", 
                    RowBox[{"24", " ", "y"}]}], ")"}]}], "-", 
                   RowBox[{"18", " ", 
                    SuperscriptBox["l", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"h2", "-", "y"}], ")"}]}]}], ")"}]}], "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"h1", " ", "h2"}], ")"}], 
                  RowBox[{"3", "/", "2"}]], " ", 
                 SqrtBox[
                  SuperscriptBox["K", "3"]], " ", 
                 SuperscriptBox["l", "2"], " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"15", " ", "h2"}], "-", 
                   RowBox[{"14", " ", "y"}]}], ")"}]}], "+", 
                RowBox[{"3", " ", 
                 SqrtBox["3"], " ", 
                 SuperscriptBox["h2", "3"], " ", 
                 SuperscriptBox["l", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"h2", "-", "y"}], ")"}]}], "+", 
                RowBox[{"36", " ", 
                 SuperscriptBox["h2", "3"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                    SuperscriptBox["h2", "3"]], ")"}], 
                  RowBox[{"3", "/", "2"}]], " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SuperscriptBox["l", "2"]}], "+", 
                   SuperscriptBox["x", "2"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "h2"}], "-", "y"}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SuperscriptBox["h2", "3"], " ", 
              SuperscriptBox["l", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"h2", "-", "y"}], ")"}]}], "-", 
             RowBox[{"12", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"h1", " ", "h2"}], ")"}], 
               RowBox[{"3", "/", "2"}]], " ", 
              SqrtBox[
               SuperscriptBox["K", "3"]], " ", 
              SuperscriptBox["l", "2"], " ", "x", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "h2"}], "-", "y"}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]]}]], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", "x", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"33", " ", 
                 SuperscriptBox["h2", "4"], " ", 
                 SuperscriptBox["l", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"h1", " ", "h2"}], ")"}], 
                  RowBox[{"3", "/", "2"}]], " ", 
                 SqrtBox[
                  SuperscriptBox["K", "3"]], " ", "l", " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"35", " ", "h2"}], "-", 
                   RowBox[{"24", " ", "y"}]}], ")"}]}], "+", 
                RowBox[{"36", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 SuperscriptBox["x", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "h2"}], "-", "y"}], ")"}]}], "-", 
                RowBox[{"36", " ", 
                 SuperscriptBox["h2", "3"], " ", 
                 SuperscriptBox["l", "2"], " ", "y"}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  FractionBox[
                   RowBox[{"2", " ", "x"}], "l"]}], ")"}]}]], " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"]}], 
                SuperscriptBox["h2", "3"]]], " ", "x", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"33", " ", 
                 SuperscriptBox["h2", "4"], " ", 
                 SuperscriptBox["l", "2"]}], "+", 
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"h1", " ", "h2"}], ")"}], 
                  RowBox[{"3", "/", "2"}]], " ", 
                 SqrtBox[
                  SuperscriptBox["K", "3"]], " ", "l", " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"35", " ", "h2"}], "-", 
                   RowBox[{"24", " ", "y"}]}], ")"}]}], "+", 
                RowBox[{"36", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 SuperscriptBox["x", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "h2"}], "-", "y"}], ")"}]}], "-", 
                RowBox[{"36", " ", 
                 SuperscriptBox["h2", "3"], " ", 
                 SuperscriptBox["l", "2"], " ", "y"}]}], ")"}]}]}], ")"}]}]}],
          "-", 
         RowBox[{"a1", " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["h1", "3"], " ", 
             SuperscriptBox["K", "3"]}], 
            SuperscriptBox["h2", "3"]]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"24", " ", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox["y", "h2"]}], ")"}]}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox["x", "l"]}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox["y", "h2"]}], ")"}]}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", 
                 FractionBox["x", "l"]}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox["y", "h2"]}], ")"}]}], "+", 
            FractionBox[
             RowBox[{"12", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["h2", "2"], "-", 
                RowBox[{"h2", " ", "y"}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["y", "2"]}]}], ")"}]}], 
             SuperscriptBox["h2", "2"]], "+", 
            FractionBox[
             RowBox[{"12", " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"4", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["h2", "2"], "-", 
                RowBox[{"h2", " ", "y"}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["y", "2"]}]}], ")"}]}], 
             SuperscriptBox["h2", "2"]], "+", 
            FractionBox[
             RowBox[{"12", " ", 
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"4", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x"}], "l"]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["h2", "2"], "-", 
                RowBox[{"h2", " ", "y"}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["y", "2"]}]}], ")"}]}], 
             SuperscriptBox["h2", "2"]], "+", 
            FractionBox[
             RowBox[{"12", " ", 
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"4", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "+", "x"}], ")"}]}], "l"]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["h2", "2"], "-", 
                RowBox[{"h2", " ", "y"}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["y", "2"]}]}], ")"}]}], 
             SuperscriptBox["h2", "2"]], "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", 
             RowBox[{"(", 
              RowBox[{"3", "-", 
               FractionBox[
                RowBox[{"3", " ", "y"}], "h2"], "+", 
               FractionBox[
                RowBox[{"18", " ", 
                 SuperscriptBox["y", "2"]}], 
                SuperscriptBox["h2", "2"]], "-", 
               FractionBox[
                RowBox[{"36", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 SuperscriptBox["x", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["h2", "2"], "-", 
                   RowBox[{"h2", " ", "y"}], "-", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["y", "2"]}]}], ")"}]}], 
                RowBox[{
                 SuperscriptBox["h2", "5"], " ", 
                 SuperscriptBox["l", "2"]}]], "-", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "7"}], "+", 
                   FractionBox[
                    RowBox[{"11", " ", "y"}], "h2"], "+", 
                   FractionBox[
                    RowBox[{"30", " ", 
                    SuperscriptBox["y", "2"]}], 
                    SuperscriptBox["h2", "2"]]}], ")"}]}], "l"]}], ")"}]}], 
            "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               FractionBox[
                RowBox[{"3", " ", "y"}], "h2"], "+", 
               FractionBox[
                RowBox[{"30", " ", 
                 SuperscriptBox["y", "2"]}], 
                SuperscriptBox["h2", "2"]], "+", 
               FractionBox[
                RowBox[{"36", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", 
                   FractionBox[
                    SuperscriptBox["x", "2"], 
                    SuperscriptBox["l", "2"]]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   FractionBox["y", "h2"], "+", 
                   FractionBox[
                    RowBox[{"2", " ", 
                    SuperscriptBox["y", "2"]}], 
                    SuperscriptBox["h2", "2"]]}], ")"}]}], 
                SuperscriptBox["h2", "3"]], "-", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "7"}], "+", 
                   FractionBox[
                    RowBox[{"11", " ", "y"}], "h2"], "+", 
                   FractionBox[
                    RowBox[{"30", " ", 
                    SuperscriptBox["y", "2"]}], 
                    SuperscriptBox["h2", "2"]]}], ")"}]}], "l"]}], ")"}]}], 
            "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["h1", "3"], " ", 
                  SuperscriptBox["K", "3"]}], 
                 SuperscriptBox["h2", "3"]]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"2", " ", "x"}], "l"]}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{"3", "-", 
               FractionBox[
                RowBox[{"3", " ", "y"}], "h2"], "+", 
               FractionBox[
                RowBox[{"18", " ", 
                 SuperscriptBox["y", "2"]}], 
                SuperscriptBox["h2", "2"]], "-", 
               FractionBox[
                RowBox[{"36", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 SuperscriptBox["x", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["h2", "2"], "-", 
                   RowBox[{"h2", " ", "y"}], "-", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["y", "2"]}]}], ")"}]}], 
                RowBox[{
                 SuperscriptBox["h2", "5"], " ", 
                 SuperscriptBox["l", "2"]}]], "+", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "7"}], "+", 
                   FractionBox[
                    RowBox[{"11", " ", "y"}], "h2"], "+", 
                   FractionBox[
                    RowBox[{"30", " ", 
                    SuperscriptBox["y", "2"]}], 
                    SuperscriptBox["h2", "2"]]}], ")"}]}], "l"]}], ")"}]}], 
            "+", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["h1", "3"], " ", 
                   SuperscriptBox["K", "3"]}], 
                  SuperscriptBox["h2", "3"]]], " ", 
                RowBox[{"(", 
                 RowBox[{"l", "+", 
                  RowBox[{"2", " ", "x"}]}], ")"}]}], "l"]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               FractionBox[
                RowBox[{"3", " ", "y"}], "h2"], "+", 
               FractionBox[
                RowBox[{"30", " ", 
                 SuperscriptBox["y", "2"]}], 
                SuperscriptBox["h2", "2"]], "+", 
               FractionBox[
                RowBox[{"36", " ", 
                 SuperscriptBox["h1", "3"], " ", 
                 SuperscriptBox["K", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", 
                   FractionBox[
                    SuperscriptBox["x", "2"], 
                    SuperscriptBox["l", "2"]]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   FractionBox["y", "h2"], "+", 
                   FractionBox[
                    RowBox[{"2", " ", 
                    SuperscriptBox["y", "2"]}], 
                    SuperscriptBox["h2", "2"]]}], ")"}]}], 
                SuperscriptBox["h2", "3"]], "+", 
               FractionBox[
                RowBox[{"2", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["h1", "3"], " ", 
                    SuperscriptBox["K", "3"]}], 
                   SuperscriptBox["h2", "3"]]], " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "7"}], "+", 
                   FractionBox[
                    RowBox[{"11", " ", "y"}], "h2"], "+", 
                   FractionBox[
                    RowBox[{"30", " ", 
                    SuperscriptBox["y", "2"]}], 
                    SuperscriptBox["h2", "2"]]}], ")"}]}], "l"]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}]}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]],
   HoldForm], TraditionalForm]], "Output",
 CellChangeTimes->{3.8419009916038513`*^9},
 TextAlignment->Center,ExpressionUUID->"7ab09e34-4bee-4ea5-8aee-6ac26e122ce5"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1440., 745.5},
WindowMargins->{{1147.2, Automatic}, {Automatic, -4.8}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792}},
TaggingRules->{"TryRealOnly" -> False},
Magnification:>1.1 Inherited,
FrontEndVersion->"12.1 for Microsoft Windows (64-bit) (June 9, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"2a057949-d8be-4a46-a707-580bfe6daefb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 607, 10, 241, "Title",ExpressionUUID->"19273035-3e29-4c96-991c-ae2d54103ec3"],
Cell[1190, 34, 352, 5, 34, "Author",ExpressionUUID->"bcbbeaa5-27b4-4ee7-8d76-ba3e39cd575b"],
Cell[1545, 41, 190, 3, 34, "Affiliation",ExpressionUUID->"8b2733a5-9a8d-4708-af8f-61c057274fba"],
Cell[1738, 46, 1726, 27, 295, "Abstract",ExpressionUUID->"c0409e74-8f65-4914-b95a-00bc4b8216c5"],
Cell[CellGroupData[{
Cell[3489, 77, 218, 4, 73, "Section",ExpressionUUID->"2395983e-de10-4577-9e31-9b4c94b0947f"],
Cell[3710, 83, 347, 7, 38, "Text",ExpressionUUID->"5aa68ab7-2c1b-42dc-bb8c-0ed8b1fb8110"],
Cell[4060, 92, 368, 7, 38, "Text",ExpressionUUID->"c7875bf6-8b02-46ea-94f0-f6a5ad39bf73"],
Cell[4431, 101, 2211, 55, 135, "Input",ExpressionUUID->"0b960dd4-4a29-4a06-80a1-50233a1f6df7"],
Cell[6645, 158, 149, 2, 38, "Text",ExpressionUUID->"77071268-2614-47f0-8ddb-cf7ba61c0c60"],
Cell[6797, 162, 3874, 89, 238, "Input",ExpressionUUID->"353dcac6-eafd-4edc-ab92-19c7a43e76ea"],
Cell[10674, 253, 528, 12, 73, "Input",ExpressionUUID->"77f33537-db7c-40e7-9908-66fa5edf4f3a"],
Cell[11205, 267, 1364, 37, 94, "Input",ExpressionUUID->"be5b7b79-3ca4-4742-a94e-8f2a0cfffe5f"],
Cell[12572, 306, 337, 8, 30, "Input",ExpressionUUID->"0a9f229e-b00d-43a5-a26a-fad379b74286"],
Cell[12912, 316, 551, 15, 32, "Input",ExpressionUUID->"d3e10b67-726d-4abe-95ec-5818c33cd474"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13500, 336, 602, 8, 73, "Section",ExpressionUUID->"eea2d571-8449-4306-a2a9-c64778570680"],
Cell[14105, 346, 196, 3, 30, "Input",ExpressionUUID->"cec20e76-96a7-4666-bb2b-6c088bd47e8b"],
Cell[14304, 351, 1277, 19, 38, "Text",ExpressionUUID->"73870970-5ff3-4ada-9009-1e27e30f37a4"],
Cell[15584, 372, 894, 14, 63, "Text",ExpressionUUID->"eb657082-1e1e-4565-b41c-38d021bf754a"],
Cell[16481, 388, 261722, 4303, 560, "Input",ExpressionUUID->"c87f77d4-6b2a-4f50-a6e9-9333701b677f"],
Cell[278206, 4693, 901, 14, 63, "Text",ExpressionUUID->"b44a7701-412c-4896-a4a9-3eeff409dd91"],
Cell[279110, 4709, 508, 9, 63, "Text",ExpressionUUID->"1b1cc54f-7a9e-4a89-ba9b-ab8bcfe7d0a5"],
Cell[CellGroupData[{
Cell[279643, 4722, 514, 13, 30, "Input",ExpressionUUID->"23076d1a-da92-492c-8c3e-48cbfc142d2e"],
Cell[280160, 4737, 445, 14, 52, "Output",ExpressionUUID->"9310b1bc-c09d-4c7e-8ab5-f8a4574d2495"]
}, Open  ]],
Cell[280620, 4754, 899, 14, 63, "Text",ExpressionUUID->"351a562b-3f7f-4a23-ba0a-2167e901c0f2"],
Cell[CellGroupData[{
Cell[281544, 4772, 437, 9, 30, "Input",ExpressionUUID->"6f2e0931-0cf1-4569-9218-48b468c7e6ce"],
Cell[281984, 4783, 375, 11, 56, "Output",ExpressionUUID->"b966943c-5f24-4fa7-b159-929922f88734"]
}, Open  ]],
Cell[282374, 4797, 264, 6, 38, "Text",ExpressionUUID->"d97ef102-cfd4-4fb9-afd5-e1cbd6114ae7"],
Cell[CellGroupData[{
Cell[282663, 4807, 290, 4, 58, "Subsection",ExpressionUUID->"6ac3a1bd-4f2f-4f52-b0f3-b9f2bfbc715d"],
Cell[282956, 4813, 546, 10, 63, "Text",ExpressionUUID->"525056cf-99cc-4615-babe-1139819071f5"],
Cell[CellGroupData[{
Cell[283527, 4827, 2991, 76, 59, "Input",ExpressionUUID->"196d40ba-55d2-4b1e-bd89-aff1a96c25c1"],
Cell[286521, 4905, 974, 30, 62, "Output",ExpressionUUID->"3d9da367-06df-4451-89c1-b53212989d24"],
Cell[287498, 4937, 976, 30, 62, "Output",ExpressionUUID->"2f09ab58-cff0-49ce-b3b3-599dbac07b75"]
}, Open  ]],
Cell[288489, 4970, 181, 3, 38, "Text",ExpressionUUID->"9910fcd1-eb8d-4e18-83f1-57a9881512c3"],
Cell[CellGroupData[{
Cell[288695, 4977, 536, 16, 34, "Input",ExpressionUUID->"d16e26f0-6baf-4686-a356-d7bb910bfbf6"],
Cell[289234, 4995, 582, 18, 57, "Output",ExpressionUUID->"1bca8093-1fcd-498c-9453-b48d9eee41f0"]
}, Open  ]],
Cell[289831, 5016, 412, 8, 38, "Text",ExpressionUUID->"097baf14-5f8a-42bc-8596-0692dabe46f3"],
Cell[CellGroupData[{
Cell[290268, 5028, 741, 16, 52, "Input",ExpressionUUID->"a33cdf8a-7ed4-4f67-a504-a003105a70d2"],
Cell[291012, 5046, 308, 9, 34, "Output",ExpressionUUID->"af1504e1-6031-4e9c-a4f7-61c8565a4b01"],
Cell[291323, 5057, 308, 9, 34, "Output",ExpressionUUID->"8b027637-dcce-4b98-835f-649f870b582e"]
}, Open  ]],
Cell[291646, 5069, 185, 3, 38, "Text",ExpressionUUID->"7844086c-30b6-4bcd-b2e0-1638ec1346df"],
Cell[CellGroupData[{
Cell[291856, 5076, 365, 8, 30, "Input",ExpressionUUID->"03a84678-abd6-46e9-9988-713908547daa"],
Cell[292224, 5086, 306, 9, 34, "Output",ExpressionUUID->"7c6bfb4a-bfcd-4469-a1c6-52309ccb7e8d"]
}, Open  ]],
Cell[292545, 5098, 215, 5, 38, "Text",ExpressionUUID->"6728a912-ae30-42d1-bf58-b843a60d484c"],
Cell[CellGroupData[{
Cell[292785, 5107, 749, 20, 30, "Input",ExpressionUUID->"ad9c1f35-890d-4e6d-b20e-b1b72d350c2e"],
Cell[293537, 5129, 472, 15, 56, "Output",ExpressionUUID->"76ad61ee-9053-43c0-a7bf-8742bcc31e14"]
}, Open  ]],
Cell[294024, 5147, 187, 3, 38, "Text",ExpressionUUID->"cc398f7d-bba8-47bb-9e15-17e4f6232d7f"],
Cell[CellGroupData[{
Cell[294236, 5154, 541, 14, 52, "Input",ExpressionUUID->"da26abb9-25ff-42bb-b72c-99ccea1f41a2"],
Cell[294780, 5170, 309, 9, 34, "Output",ExpressionUUID->"99f29d23-7cc6-4555-aa33-81c2afa5cfd1"],
Cell[295092, 5181, 307, 9, 34, "Output",ExpressionUUID->"1a6026cd-92f1-42ed-9c20-bd42627b3b88"]
}, Open  ]],
Cell[295414, 5193, 3717, 92, 82, "Input",ExpressionUUID->"46f9be2b-ed06-421d-854c-ca4ac5ba05d9"],
Cell[299134, 5287, 288, 6, 38, "Text",ExpressionUUID->"66e6827b-d5f7-4337-acf9-f0c087e7979b"],
Cell[CellGroupData[{
Cell[299447, 5297, 3628, 91, 155, "Input",ExpressionUUID->"edad039b-2b17-4f52-a7db-fa51050b015b"],
Cell[303078, 5390, 426, 13, 55, "Output",ExpressionUUID->"8b004586-c0fb-4747-966d-6556eb1d29c0"],
Cell[303507, 5405, 424, 13, 55, "Output",ExpressionUUID->"74c6ef2d-0e9e-42e4-83c1-b695a57783bd"],
Cell[303934, 5420, 307, 9, 34, "Output",ExpressionUUID->"8bef38a2-bf82-4c44-83f8-632a7cc5481d"]
}, Open  ]],
Cell[304256, 5432, 402, 8, 38, "Text",ExpressionUUID->"64871c31-e99d-4e13-a331-6c457155e3c7"],
Cell[CellGroupData[{
Cell[304683, 5444, 1422, 25, 30, "Input",ExpressionUUID->"ad39bf18-392d-4ef4-ae96-f82f209225f8"],
Cell[306108, 5471, 3142, 94, 250, "Output",ExpressionUUID->"6ce6a48a-31a3-43e6-bbcc-36fc52cb5f7b"]
}, Open  ]],
Cell[309265, 5568, 145, 3, 38, "Text",ExpressionUUID->"fa1f6b4f-36cb-4cd1-9ebd-ad46c86ac027"],
Cell[CellGroupData[{
Cell[309435, 5575, 717, 16, 30, "Input",ExpressionUUID->"00f4efd1-acba-49c7-a713-989dd98bb6b2"],
Cell[310155, 5593, 3208, 96, 249, "Output",ExpressionUUID->"f4f072e6-5e9c-48fd-95df-032777ee05bb"]
}, Open  ]],
Cell[313378, 5692, 376, 8, 38, "Text",ExpressionUUID->"01349695-7b32-4096-be8d-3078a46cc797"]
}, Open  ]],
Cell[CellGroupData[{
Cell[313791, 5705, 268, 6, 58, "Subsection",ExpressionUUID->"a1fa3bf7-51e7-4029-9914-41a3892024a1"],
Cell[314062, 5713, 698, 18, 30, "Input",ExpressionUUID->"9e564af6-03b9-4ef2-8b62-b5324b210c99"],
Cell[314763, 5733, 428, 8, 38, "Text",ExpressionUUID->"eaf4c3e4-c048-4e27-8bca-ccfe5ce06079"],
Cell[CellGroupData[{
Cell[315216, 5745, 1682, 29, 30, "Input",ExpressionUUID->"59d1522a-de6a-425f-88c3-4ee1d09653b9"],
Cell[316901, 5776, 944, 33, 146, "Output",ExpressionUUID->"08a27d3f-3fb4-4d5f-9be5-3321c72825ce"]
}, Open  ]],
Cell[317860, 5812, 251, 5, 38, "Text",ExpressionUUID->"e6055883-f811-4ef1-9d50-6d5e5b8cf6dd"],
Cell[CellGroupData[{
Cell[318136, 5821, 350, 8, 30, "Input",ExpressionUUID->"4618f8ea-7bf9-4bae-8ed2-66686d1953bb"],
Cell[318489, 5831, 769, 25, 71, "Output",ExpressionUUID->"490324af-4537-41e9-abe9-69ce2dcac526"]
}, Open  ]],
Cell[319273, 5859, 188, 3, 38, "Text",ExpressionUUID->"971c2982-1cef-4edd-89b8-9458602e6491"],
Cell[319464, 5864, 469, 14, 32, "Input",ExpressionUUID->"c3c0168b-cc94-417b-813f-9828e56ff8d9"],
Cell[CellGroupData[{
Cell[319958, 5882, 539, 13, 30, "Input",ExpressionUUID->"6cb53f5e-6f2e-4ae2-b644-09d2b31d7474"],
Cell[320500, 5897, 884, 28, 100, "Output",ExpressionUUID->"eae2d127-82b6-4169-b4c4-f76383a7aba9"]
}, Open  ]],
Cell[321399, 5928, 873, 12, 30, "Input",ExpressionUUID->"b314aedf-407f-40cf-af6c-aae2c3426688"],
Cell[322275, 5942, 225, 4, 38, "Text",ExpressionUUID->"f98e4fd0-c439-4781-b174-f5663c3118b0"],
Cell[322503, 5948, 816, 15, 30, "Input",ExpressionUUID->"ce892f4b-78d2-4ef8-958b-f92095d74a4d"],
Cell[CellGroupData[{
Cell[323344, 5967, 290, 6, 30, "Input",ExpressionUUID->"98ffed9d-46b6-4cb0-8e23-09c221466b17"],
Cell[323637, 5975, 818, 25, 74, "Output",ExpressionUUID->"e9590aa7-cb56-4eb3-b399-c8a3abaaa894"]
}, Open  ]],
Cell[324470, 6003, 384, 7, 38, "Text",ExpressionUUID->"a48f4b84-356b-4398-b5bd-9523aeaeabc3"],
Cell[324857, 6012, 5187, 99, 73, "Input",ExpressionUUID->"190406fd-3dff-4c32-a55e-bc5a6da89551"],
Cell[CellGroupData[{
Cell[330069, 6115, 247, 4, 30, "Input",ExpressionUUID->"a99acee6-8fd9-4287-a043-7bac2bd48b61"],
Cell[330319, 6121, 3693, 107, 242, "Output",ExpressionUUID->"fe029edb-b966-4bd8-b548-b2ef394c2292"]
}, Open  ]],
Cell[334027, 6231, 752, 19, 30, "Input",ExpressionUUID->"7dcb0647-8e53-41ed-8e8e-f07f6bf92f78"],
Cell[334782, 6252, 833, 22, 44, "Text",ExpressionUUID->"2ee65efb-0100-4946-aaf9-b8b66527253d"],
Cell[CellGroupData[{
Cell[335640, 6278, 350, 6, 30, "Input",ExpressionUUID->"e681f2ee-ae44-42d5-90ed-2fbcb1a0b10b"],
Cell[335993, 6286, 668, 20, 55, "Output",ExpressionUUID->"de211820-6f2f-4020-b8d6-065e21614273"]
}, Open  ]],
Cell[336676, 6309, 405, 6, 38, "Text",ExpressionUUID->"61f67a67-f981-4d7a-af57-49d4c9bb5c34"],
Cell[CellGroupData[{
Cell[337106, 6319, 898, 14, 50, "Input",ExpressionUUID->"c77d6c5a-30e3-456e-a347-c6356a38936a"],
Cell[338007, 6335, 345, 10, 52, "Output",ExpressionUUID->"5ba3a3ba-0208-4582-aa08-7be7014883da"]
}, Open  ]],
Cell[338367, 6348, 216, 5, 38, "Text",ExpressionUUID->"5a0f047e-7939-4e4a-8c4e-f0498f999c9b"],
Cell[CellGroupData[{
Cell[338608, 6357, 475, 12, 30, "Input",ExpressionUUID->"ef5df8bb-4ff1-43fa-ae54-d8b148c9ea00"],
Cell[339086, 6371, 340, 10, 34, "Output",ExpressionUUID->"07b39fba-d3d0-4cbd-acf0-564a731b8f13"]
}, Open  ]],
Cell[339441, 6384, 345, 5, 38, "Text",ExpressionUUID->"aec21126-7f62-4af7-8e2d-cb97690c3a35"],
Cell[339789, 6391, 1111, 24, 30, "Input",ExpressionUUID->"f22187e6-26f6-4eb1-beab-f478c1e8a1b3"],
Cell[CellGroupData[{
Cell[340925, 6419, 273, 4, 30, "Input",ExpressionUUID->"4ac8c04b-33b6-47bb-8db4-7370c5175df9"],
Cell[341201, 6425, 3532, 102, 243, "Output",ExpressionUUID->"123d7c94-e4c7-424e-8804-d2af436ade8a"]
}, Open  ]],
Cell[344748, 6530, 420, 8, 38, "Text",ExpressionUUID->"cc24846d-6c4b-405c-a0a6-eeee58512196"],
Cell[CellGroupData[{
Cell[345193, 6542, 398, 7, 30, "Input",ExpressionUUID->"1a281b84-2ad3-4914-b4b9-fdea94f5d69e"],
Cell[345594, 6551, 1080, 32, 62, "Output",ExpressionUUID->"d6e33d6f-67f1-434c-ae5e-b14b52ed32a1"]
}, Open  ]],
Cell[346689, 6586, 883, 14, 38, "Text",ExpressionUUID->"e5634736-b3aa-4ff4-b5bb-3b2e29961a7d"],
Cell[CellGroupData[{
Cell[347597, 6604, 781, 16, 30, "Input",ExpressionUUID->"45ea8fc0-a81c-4b63-af53-52c1e499ff66"],
Cell[348381, 6622, 485, 15, 54, "Output",ExpressionUUID->"c241ec0c-d482-41ff-856b-2bb5c0049d71"]
}, Open  ]],
Cell[348881, 6640, 243, 4, 38, "Text",ExpressionUUID->"133fddf8-4a6e-43a4-9c42-58552ec5b7c2"],
Cell[CellGroupData[{
Cell[349149, 6648, 467, 12, 30, "Input",ExpressionUUID->"0d596993-f6c1-464c-835b-024f49365ca9"],
Cell[349619, 6662, 410, 12, 59, "Output",ExpressionUUID->"0ee57908-e1b4-45f5-baa1-87e1be77f59a"]
}, Open  ]],
Cell[350044, 6677, 245, 4, 38, "Text",ExpressionUUID->"67136dcf-f19d-4d0f-a448-24bd8ecd1952"],
Cell[350292, 6683, 1168, 25, 30, "Input",ExpressionUUID->"37d7cc37-f424-4d87-adbf-830230511a1e"],
Cell[CellGroupData[{
Cell[351485, 6712, 222, 3, 30, "Input",ExpressionUUID->"37feefd9-71a7-429c-b972-2b1a0d29f7b3"],
Cell[351710, 6717, 3095, 93, 241, "Output",ExpressionUUID->"3574661d-1fa7-4e7c-b345-13e642ad58b6"]
}, Open  ]],
Cell[354820, 6813, 329, 6, 38, "Text",ExpressionUUID->"20ed17a1-b65d-46c5-a405-88703bcd1fcc"],
Cell[CellGroupData[{
Cell[355174, 6823, 356, 7, 30, "Input",ExpressionUUID->"d739b1b2-67de-4495-b8c0-edb124caceb7"],
Cell[355533, 6832, 521, 16, 56, "Output",ExpressionUUID->"8ecbda1d-9d1c-43f0-b153-42f01db4a230"]
}, Open  ]],
Cell[356069, 6851, 244, 4, 38, "Text",ExpressionUUID->"5b9b9201-9805-431c-a638-f12536c867ce"],
Cell[CellGroupData[{
Cell[356338, 6859, 664, 13, 36, "Input",ExpressionUUID->"8923c9c0-f0e7-404c-8aa2-baca5f507bdc"],
Cell[357005, 6874, 407, 12, 55, "Output",ExpressionUUID->"f0d95bdc-883f-4471-bc68-3f756417b23a"]
}, Open  ]],
Cell[357427, 6889, 191, 3, 38, "Text",ExpressionUUID->"a60a4e9e-8434-4558-b351-6a8292ab215a"],
Cell[CellGroupData[{
Cell[357643, 6896, 465, 12, 30, "Input",ExpressionUUID->"6a80786f-9b8b-471b-9408-1a741db78e35"],
Cell[358111, 6910, 384, 11, 37, "Output",ExpressionUUID->"25a519b3-8982-47f9-95fc-7ae3ca6628a4"]
}, Open  ]],
Cell[358510, 6924, 290, 4, 38, "Text",ExpressionUUID->"2272036c-fd27-4bfb-9fbf-00eb8fcf0005"],
Cell[358803, 6930, 767, 19, 30, "Input",ExpressionUUID->"c9e65873-10f6-4e19-8fd4-e5a855c1b60a"],
Cell[CellGroupData[{
Cell[359595, 6953, 228, 5, 30, "Input",ExpressionUUID->"d0d99d76-1f28-4f76-ba1b-9d78fa1f4b9a"],
Cell[359826, 6960, 2951, 89, 227, "Output",ExpressionUUID->"f9a3f854-3455-43e6-9916-53a6dae597d2"]
}, Open  ]],
Cell[362792, 7052, 329, 5, 38, "Text",ExpressionUUID->"32e5d6b6-96a5-437b-b1b4-e8e46fd4670e"],
Cell[363124, 7059, 2133, 58, 73, "Input",ExpressionUUID->"4e80c94b-bbfa-407c-9b5e-db80fd02a3d1"],
Cell[365260, 7119, 782, 19, 30, "Input",ExpressionUUID->"ade8582a-8789-4bfd-8a7e-926fc3cd373e"],
Cell[366045, 7140, 356, 5, 38, "Text",ExpressionUUID->"a760c1da-f019-42b3-af2d-a135c8d23e7b"],
Cell[CellGroupData[{
Cell[366426, 7149, 373, 7, 50, "Input",ExpressionUUID->"536c18a4-f566-4f3a-b22a-f926113115ee"],
Cell[366802, 7158, 343, 10, 52, "Output",ExpressionUUID->"18ca7f88-be68-47c7-9ef4-8103d096a78f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[367182, 7173, 553, 11, 36, "Input",ExpressionUUID->"851cc1c0-1e87-4a8d-bfab-279266360abc"],
Cell[367738, 7186, 407, 12, 55, "Output",ExpressionUUID->"49f7886d-40e5-4c38-983c-30ee974b1b94"]
}, Open  ]],
Cell[368160, 7201, 147, 3, 38, "Text",ExpressionUUID->"6a3cc3be-8bdc-4681-8101-1aab249a01f9"],
Cell[CellGroupData[{
Cell[368332, 7208, 594, 14, 30, "Input",ExpressionUUID->"da3f8af1-da2f-4358-b371-6dcf6becb70a"],
Cell[368929, 7224, 482, 15, 54, "Output",ExpressionUUID->"86377428-4eb8-4f97-8678-501a083e5793"]
}, Open  ]],
Cell[369426, 7242, 243, 6, 38, "Text",ExpressionUUID->"705147f4-d5a9-423e-b330-fa522e695ae0"],
Cell[CellGroupData[{
Cell[369694, 7252, 476, 12, 30, "Input",ExpressionUUID->"4bc36af4-3d6b-46db-8e05-f4ad9ba9f304"],
Cell[370173, 7266, 340, 10, 52, "Output",ExpressionUUID->"7081f613-ed68-483c-ae41-cd44ea99a9d6"]
}, Open  ]],
Cell[370528, 7279, 660, 18, 30, "Input",ExpressionUUID->"36a17b40-7d8c-476d-8e06-c4b511da782a"],
Cell[CellGroupData[{
Cell[371213, 7301, 468, 12, 30, "Input",ExpressionUUID->"b359a1b8-1885-4fa3-95c4-8f687403f2de"],
Cell[371684, 7315, 426, 13, 54, "Output",ExpressionUUID->"76fd4318-eb18-427b-9047-bf4c4cc8cfbc"]
}, Open  ]],
Cell[372125, 7331, 702, 18, 30, "Input",ExpressionUUID->"47584517-9be2-41f7-8002-56a0c4eebc20"],
Cell[CellGroupData[{
Cell[372852, 7353, 460, 12, 30, "Input",ExpressionUUID->"f7578cc8-9b63-4c13-afd8-6d6741b41e88"],
Cell[373315, 7367, 384, 11, 37, "Output",ExpressionUUID->"200d790c-8562-4739-879b-3f31fa435a1b"]
}, Open  ]],
Cell[373714, 7381, 748, 19, 30, "Input",ExpressionUUID->"1ee65923-4215-4006-b7d5-6ac8286ee643"],
Cell[374465, 7402, 236, 6, 38, "Text",ExpressionUUID->"30a8f1bd-bf71-43a2-92b3-1f8ba609503b"],
Cell[CellGroupData[{
Cell[374726, 7412, 307, 6, 30, "Input",ExpressionUUID->"25640066-8433-4386-bc58-678012431c0f"],
Cell[375036, 7420, 338, 10, 34, "Output",ExpressionUUID->"97b469ba-eb8e-4989-a3c5-3d1d85b8e867"]
}, Open  ]],
Cell[375389, 7433, 464, 12, 30, "Input",ExpressionUUID->"0077fcce-05b2-4f00-95c5-68963e6d791f"],
Cell[CellGroupData[{
Cell[375878, 7449, 154, 2, 30, "Input",ExpressionUUID->"05da49d3-04a2-4f74-8288-94e01d85faa1"],
Cell[376035, 7453, 3193, 95, 239, "Output",ExpressionUUID->"a337ef2d-b65c-4c93-ad28-0dcf9b6d92d6"]
}, Open  ]],
Cell[379243, 7551, 213, 5, 38, "Text",ExpressionUUID->"e3c95c90-50d4-4f18-a9a4-02d20b8ff300"],
Cell[CellGroupData[{
Cell[379481, 7560, 325, 5, 52, "Input",ExpressionUUID->"b458403a-5e97-407a-bb54-7649dde513d4"],
Cell[379809, 7567, 2951, 89, 227, "Output",ExpressionUUID->"51f46910-f03d-4772-9488-bfb1cf09f913"],
Cell[382763, 7658, 3193, 95, 239, "Output",ExpressionUUID->"b331ac63-af40-4870-9ceb-378bf00fe696"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[386005, 7759, 496, 7, 58, "Subsection",ExpressionUUID->"bb4e20bd-020e-4381-915a-2211d2dfc9b8"],
Cell[386504, 7768, 533, 11, 139, "Text",ExpressionUUID->"e38586bd-0914-4402-ad26-b46d35acd240"],
Cell[387040, 7781, 246, 4, 38, "Text",ExpressionUUID->"dae63973-c5dd-4fd5-9fac-5a14400cded7"],
Cell[387289, 7787, 2945, 71, 73, "Input",ExpressionUUID->"17f07bba-4111-400b-9415-b99fe21e7791"],
Cell[CellGroupData[{
Cell[390259, 7862, 154, 2, 30, "Input",ExpressionUUID->"7433ace4-4c3a-41f1-95e0-42fc7724c07c"],
Cell[390416, 7866, 8786, 245, 236, "Output",ExpressionUUID->"d3f255b6-a7db-4c95-97ea-1c89b1d2a5aa"]
}, Open  ]],
Cell[399217, 8114, 322, 5, 38, "Text",ExpressionUUID->"e3ac506a-d998-4b29-9e47-b936d563d738"],
Cell[399542, 8121, 1246, 21, 52, "Input",ExpressionUUID->"c7856e43-bc16-4475-a848-9181031a270d"],
Cell[CellGroupData[{
Cell[400813, 8146, 130, 1, 30, "Input",ExpressionUUID->"b2d785a0-ac2e-46b1-b304-eaded5a27660"],
Cell[400946, 8149, 2537, 75, 66, "Output",ExpressionUUID->"afeb99b1-aa05-41ca-9ab7-82d31aefa58e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[403520, 8229, 210, 3, 30, "Input",ExpressionUUID->"06130d8c-8662-4083-850a-1863209dfa93"],
Cell[403733, 8234, 2031, 63, 223, "Output",ExpressionUUID->"274936a5-3e85-4959-9ae5-bf298a563e48"]
}, Open  ]],
Cell[405779, 8300, 381, 9, 114, "Text",ExpressionUUID->"2652e43c-10aa-4552-bb59-e3988851d90a"],
Cell[406163, 8311, 2048, 53, 73, "Input",ExpressionUUID->"3d019723-8623-48a1-8209-b16f3fe3515b"],
Cell[CellGroupData[{
Cell[408236, 8368, 301, 5, 30, "Input",ExpressionUUID->"1b7ba417-e87e-4eff-90b4-0b8c7a63f2c7"],
Cell[408540, 8375, 9077, 251, 245, "Output",ExpressionUUID->"9c633b11-e59f-41f3-9f69-9d51c2506e8e"]
}, Open  ]],
Cell[417632, 8629, 476, 11, 38, "Text",ExpressionUUID->"ef692396-d5cd-430f-bb9c-cdc751befad6"],
Cell[418111, 8642, 344, 7, 30, "Input",ExpressionUUID->"9e2148c3-f5e1-45f7-bac8-da727ff96d1a"],
Cell[418458, 8651, 450, 9, 30, "Input",ExpressionUUID->"3f5913d9-251f-49c9-99ec-a9023552eb3d"],
Cell[418911, 8662, 811, 16, 52, "Input",ExpressionUUID->"fef299ca-2d76-42a6-ad27-5a1d354c3b28"],
Cell[419725, 8680, 185, 3, 38, "Text",ExpressionUUID->"0bc4dc38-de76-4a0a-8ed2-b4c4ace4f69b"],
Cell[CellGroupData[{
Cell[419935, 8687, 130, 1, 30, "Input",ExpressionUUID->"28dac6cd-12b6-4f8d-800d-f9a43c5717a1"],
Cell[420068, 8690, 3345, 101, 66, "Output",ExpressionUUID->"ff8bb090-320a-49cb-8876-c2ae1211d0c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[423450, 8796, 208, 3, 30, "Input",ExpressionUUID->"2881d241-6546-4299-a8ec-3da66c209a66"],
Cell[423661, 8801, 2301, 70, 235, "Output",ExpressionUUID->"0967c961-b72a-49b8-9804-98662004ec0a"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[426023, 8878, 574, 8, 73, "Section",ExpressionUUID->"84d588b2-01dd-4452-9a47-59c0848e04fc"],
Cell[426600, 8888, 212, 3, 38, "Text",ExpressionUUID->"8ce6210a-5fa1-478e-a27c-2eba3c3c5cdb"],
Cell[CellGroupData[{
Cell[426837, 8895, 174, 2, 30, "Input",ExpressionUUID->"4fac735b-cac9-4266-b61f-5a105b063869"],
Cell[427014, 8899, 2894, 83, 66, "Output",ExpressionUUID->"1adee59c-8839-491a-b4d0-8962e190c7ff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[429945, 8987, 236, 3, 30, "Input",ExpressionUUID->"f3794549-0188-44a5-afda-0b7219fbaddc"],
Cell[430184, 8992, 2031, 63, 223, "Output",ExpressionUUID->"3f4309a5-a953-468d-a742-2cf9d966509d"]
}, Open  ]],
Cell[432230, 9058, 331, 5, 38, "Text",ExpressionUUID->"079c44b5-5a52-4062-9090-cafc8f2f7f21"],
Cell[CellGroupData[{
Cell[432586, 9067, 350, 6, 30, "Input",ExpressionUUID->"10278591-8261-4868-ae0d-57a3e38a7512"],
Cell[432939, 9075, 1400, 29, 37, "Output",ExpressionUUID->"8af7d750-4fe2-4fed-93e8-2573e935a173"]
}, Open  ]],
Cell[434354, 9107, 317, 6, 38, "Text",ExpressionUUID->"76671568-6484-4424-a8ad-13357343eb15"],
Cell[CellGroupData[{
Cell[434696, 9117, 1207, 22, 30, "Input",ExpressionUUID->"c91c492a-89d4-4582-b229-09f29b8b1f8c"],
Cell[435906, 9141, 2588, 68, 41, "Output",ExpressionUUID->"1dd532fe-61c3-45f7-97b7-6dabf4efeb7e"]
}, Open  ]],
Cell[438509, 9212, 274, 4, 38, "Text",ExpressionUUID->"6fd881af-0b02-4aed-b3fb-3795fdeea9fa"],
Cell[CellGroupData[{
Cell[438808, 9220, 380, 7, 30, "Input",ExpressionUUID->"fa72849e-9775-4e61-950c-f6129b46dc87"],
Cell[439191, 9229, 3194, 51, 37, "Output",ExpressionUUID->"4b9ef22c-f739-4df1-b20c-850b9d98fb03"]
}, Open  ]],
Cell[442400, 9283, 269, 6, 38, "Text",ExpressionUUID->"8cd62ae8-a8f9-459d-b6fe-063513ccd953"],
Cell[CellGroupData[{
Cell[442694, 9293, 1391, 30, 30, "Input",ExpressionUUID->"0b194382-db4d-4174-8e4d-fd85717b99c7"],
Cell[444088, 9325, 1512, 33, 51, "Output",ExpressionUUID->"b2df21db-52a4-4441-a02d-7f26b9921605"]
}, Open  ]],
Cell[445615, 9361, 419, 8, 38, "Text",ExpressionUUID->"957c1881-02b6-45ac-a667-7a2130a35235"],
Cell[CellGroupData[{
Cell[446059, 9373, 1143, 22, 30, "Input",ExpressionUUID->"358f36b3-8ad3-4f90-9488-2802393ea193"],
Cell[447205, 9397, 2272, 56, 51, "Output",ExpressionUUID->"a775b8b1-5b9f-4fe1-80b7-6836da85728b"]
}, Open  ]],
Cell[449492, 9456, 296, 4, 38, "Text",ExpressionUUID->"ca36b454-430c-48ed-835e-177994c73620"],
Cell[CellGroupData[{
Cell[449813, 9464, 280, 5, 30, "Input",ExpressionUUID->"5ead9c04-81ff-463d-917a-ed91285054ca"],
Cell[450096, 9471, 1781, 43, 51, "Output",ExpressionUUID->"b4f86cfc-66b5-4f2d-b7eb-01bdc5680c15"]
}, Open  ]],
Cell[451892, 9517, 433, 8, 38, "Text",ExpressionUUID->"99a02fb0-ed38-4b0d-86ef-ee18e86d3ec1"],
Cell[CellGroupData[{
Cell[452350, 9529, 858, 22, 30, "Input",ExpressionUUID->"a15ac0be-71c8-4dfd-8dd4-790329323a2e"],
Cell[453211, 9553, 1669, 37, 51, "Output",ExpressionUUID->"aa2ef3db-cf85-465a-87d4-c05ed6870e10"]
}, Open  ]],
Cell[454895, 9593, 242, 6, 38, "Text",ExpressionUUID->"f1f89611-8999-4a53-992f-402d6f244bdf"],
Cell[CellGroupData[{
Cell[455162, 9603, 558, 14, 30, "Input",ExpressionUUID->"89c62589-580a-456d-8528-fe5297abb6f5"],
Cell[455723, 9619, 2438, 61, 51, "Output",ExpressionUUID->"15464433-c80b-456e-a9a2-9f847eb9140b"]
}, Open  ]],
Cell[458176, 9683, 262, 6, 38, "Text",ExpressionUUID->"2260178e-a17c-4804-adf0-19f1ddeba3da"],
Cell[CellGroupData[{
Cell[458463, 9693, 850, 21, 30, "Input",ExpressionUUID->"dfc3b429-1199-4fb6-9181-7b671e447884"],
Cell[459316, 9716, 1139, 21, 35, "Output",ExpressionUUID->"fb2a5b37-ff3f-4a23-9747-23cbc1e98df7"]
}, Open  ]],
Cell[460470, 9740, 262, 6, 38, "Text",ExpressionUUID->"68572aca-2e3b-458e-9a56-64358968f141"],
Cell[CellGroupData[{
Cell[460757, 9750, 586, 18, 30, "Input",ExpressionUUID->"e545a2d3-8a38-4998-89c6-14e816b62a6e"],
Cell[461346, 9770, 1239, 23, 35, "Output",ExpressionUUID->"bee830c4-2f13-4f75-833c-84eb6cce0d6b"]
}, Open  ]],
Cell[462600, 9796, 231, 6, 38, "Text",ExpressionUUID->"e40b5ebd-99a0-4dc6-80c6-630cd01f7c6d"],
Cell[CellGroupData[{
Cell[462856, 9806, 713, 20, 30, "Input",ExpressionUUID->"d3ff29c8-2732-48c9-8185-e131713c553b"],
Cell[463572, 9828, 1086, 19, 35, "Output",ExpressionUUID->"a136a473-0fd8-4fba-a770-754d9ffaae3d"]
}, Open  ]],
Cell[464673, 9850, 359, 9, 38, "Text",ExpressionUUID->"12853a1d-7cb5-4a59-ad36-8b55e79e536e"],
Cell[CellGroupData[{
Cell[465057, 9863, 766, 21, 30, "Input",ExpressionUUID->"abd920f9-3051-4c0c-8676-9c880a887bb5"],
Cell[465826, 9886, 1267, 26, 51, "Output",ExpressionUUID->"f4d28606-228a-4038-8ecc-c84ff99974a1"]
}, Open  ]],
Cell[467108, 9915, 177, 3, 38, "Text",ExpressionUUID->"efa3b393-c8ff-4065-9c81-8606ce7ec5de"],
Cell[CellGroupData[{
Cell[467310, 9922, 505, 13, 73, "Input",ExpressionUUID->"7ddca807-fa98-4de0-84a6-0ff77968c666"],
Cell[467818, 9937, 1139, 21, 35, "Output",ExpressionUUID->"38e32e68-4427-4777-b34c-b0091d708ee7"],
Cell[468960, 9960, 1263, 26, 51, "Output",ExpressionUUID->"86fd9c1c-3955-4814-839b-1b8ef8181697"],
Cell[470226, 9988, 1090, 19, 35, "Output",ExpressionUUID->"13618c23-a559-4988-8c54-50f297c8a289"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[471365, 10013, 422, 6, 73, "Section",ExpressionUUID->"0b43a310-b976-478a-a27c-7c1f599d04c2"],
Cell[471790, 10021, 299, 9, 5, "Text",ExpressionUUID->"c773358c-9293-4a6d-b584-25a53252e164"],
Cell[CellGroupData[{
Cell[472114, 10034, 309, 5, 58, "Subsection",ExpressionUUID->"26d74ae5-523d-4290-8a7a-40549ba33886"],
Cell[472426, 10041, 197, 3, 38, "Text",ExpressionUUID->"1ebf9900-1328-4c02-b75a-77e7f922af98"],
Cell[CellGroupData[{
Cell[472648, 10048, 172, 2, 30, "Input",ExpressionUUID->"befcf539-b00c-4e50-b3a1-3e92f2c01b94"],
Cell[472823, 10052, 4310, 114, 66, "Output",ExpressionUUID->"f7ed4918-5631-4c30-b143-aacc2462317a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[477170, 10171, 210, 3, 30, "Input",ExpressionUUID->"c9937e46-7532-4e98-a929-a51b260fdbe8"],
Cell[477383, 10176, 2299, 70, 235, "Output",ExpressionUUID->"f0e00484-8482-42a9-a2da-fe480cdbfe1e"]
}, Open  ]],
Cell[479697, 10249, 248, 6, 38, "Text",ExpressionUUID->"aa97664a-a666-4669-8a98-52cd1e31a647"],
Cell[479948, 10257, 320, 8, 52, "Input",ExpressionUUID->"1c0ce236-e692-4239-90b8-ec079b7f5ee1"],
Cell[480271, 10267, 219, 5, 38, "Text",ExpressionUUID->"c4b7dc5a-039e-4bc4-b568-5e9d59d13bcb"],
Cell[CellGroupData[{
Cell[480515, 10276, 178, 3, 30, "Input",ExpressionUUID->"f46afe60-9947-41c3-add7-93fee742fd15"],
Cell[480696, 10281, 5081, 122, 66, "Output",ExpressionUUID->"89260425-79af-4141-bb00-f17f8970d049"]
}, Open  ]],
Cell[485792, 10406, 503, 9, 38, "Text",ExpressionUUID->"a4dd170b-55f4-4b60-8d66-c2075f3ebe61"],
Cell[CellGroupData[{
Cell[486320, 10419, 842, 22, 30, "Input",ExpressionUUID->"6d0c22ef-17d2-41ae-bdc2-6fe29e2cd847"],
Cell[487165, 10443, 3470, 104, 66, "Output",ExpressionUUID->"b19528c4-8a34-4d9c-b081-0a1cd5547b84"]
}, Open  ]],
Cell[CellGroupData[{
Cell[490672, 10552, 236, 4, 30, "Input",ExpressionUUID->"c98717b8-f076-4357-9e03-2125eb632e4b"],
Cell[490911, 10558, 2333, 72, 236, "Output",ExpressionUUID->"f140206e-cbb1-445d-b62d-03601695c413"]
}, Open  ]],
Cell[493259, 10633, 153, 3, 38, "Text",ExpressionUUID->"6a0c501a-2fa9-4873-9121-dc7a77520536"],
Cell[CellGroupData[{
Cell[493437, 10640, 337, 7, 30, "Input",ExpressionUUID->"4f94b34d-db0a-49c5-a68c-6c46d170f18c"],
Cell[493777, 10649, 428, 13, 55, "Output",ExpressionUUID->"8252f780-29c4-4e4e-901c-803d86fe74a7"]
}, Open  ]],
Cell[494220, 10665, 198, 3, 38, "Text",ExpressionUUID->"97cf4d11-f993-4240-9e32-110611e7af94"],
Cell[CellGroupData[{
Cell[494443, 10672, 529, 14, 30, "Input",ExpressionUUID->"97d3386e-b582-4242-8077-2de063b4e397"],
Cell[494975, 10688, 2948, 83, 65, "Output",ExpressionUUID->"f2d68575-4bf1-45c9-9145-182200bf7cf8"]
}, Open  ]],
Cell[497938, 10774, 130, 0, 38, "Text",ExpressionUUID->"85086c89-05cc-41b7-81ff-e8b1dc966e70"],
Cell[CellGroupData[{
Cell[498093, 10778, 372, 8, 30, "Input",ExpressionUUID->"68f15e40-b74b-49a8-ae35-c0214019dc93"],
Cell[498468, 10788, 606, 19, 59, "Output",ExpressionUUID->"94eca0d5-ea78-4a92-a155-93fdf26c47d8"]
}, Open  ]],
Cell[499089, 10810, 299, 9, 5, "Text",ExpressionUUID->"15c6807f-e195-45b5-bd76-58269cf7a18c"],
Cell[499391, 10821, 326, 7, 38, "Text",ExpressionUUID->"ab428f61-6b0b-4fd0-8b8b-e395559f0293"],
Cell[499720, 10830, 299, 9, 5, "Text",ExpressionUUID->"71db7268-0c09-4b6c-9c60-d79c0474c896"],
Cell[CellGroupData[{
Cell[500044, 10843, 1073, 28, 30, "Input",ExpressionUUID->"9b6cdbd9-a803-4b69-9f70-acd9e43af96d"],
Cell[501120, 10873, 919, 28, 55, "Output",ExpressionUUID->"a91325fa-e5a7-40d4-a381-e9cb43ffc331"]
}, Open  ]],
Cell[CellGroupData[{
Cell[502076, 10906, 566, 15, 30, "Input",ExpressionUUID->"566e27d6-b7a1-490a-a12e-4280f309362b"],
Cell[502645, 10923, 3854, 106, 90, "Output",ExpressionUUID->"78dc940f-1423-4168-99a5-84c5050f068f"]
}, Open  ]],
Cell[506514, 11032, 299, 7, 30, "Input",ExpressionUUID->"60a492af-e94f-4101-aa53-3a0efa4af9fd"],
Cell[506816, 11041, 199, 3, 38, "Text",ExpressionUUID->"1d394573-cbea-4660-bb23-78fbd111af61"],
Cell[CellGroupData[{
Cell[507040, 11048, 372, 8, 30, "Input",ExpressionUUID->"ed3872db-af3f-4d45-abce-8f71d5e1f8f7"],
Cell[507415, 11058, 1543, 45, 62, "Output",ExpressionUUID->"98549ece-7baf-4869-a53c-a7d8ccebd50b"]
}, Open  ]],
Cell[508973, 11106, 171, 3, 38, "Text",ExpressionUUID->"4e3de867-0a34-43ff-aee1-3ab310617ffb"],
Cell[CellGroupData[{
Cell[509169, 11113, 923, 25, 30, "Input",ExpressionUUID->"a7639073-6a95-4485-a1d5-696424eabc06"],
Cell[510095, 11140, 3160, 91, 62, "Output",ExpressionUUID->"909165f9-475e-45fc-9d93-03c191f2475a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[513292, 11236, 611, 16, 30, "Input",ExpressionUUID->"eb4866f8-5ccc-4ccd-8372-c7fdaf8712e5"],
Cell[513906, 11254, 8427, 226, 192, "Output",ExpressionUUID->"c1181d7d-5914-4366-a911-9fded6550bab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[522370, 11485, 333, 7, 30, "Input",ExpressionUUID->"83beb837-c36c-4ce0-8d78-c0646b4ab702"],
Cell[522706, 11494, 1250, 39, 62, "Output",ExpressionUUID->"451ef112-d7a3-4213-886f-899f186787cb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[523993, 11538, 599, 13, 73, "Input",ExpressionUUID->"cf7bb550-2d57-4478-8c0e-a89dd2fa07c2"],
Cell[524595, 11553, 2404, 69, 62, "Output",ExpressionUUID->"7bc5a02f-e133-4721-b03f-66d9f03a9c57"],
Cell[527002, 11624, 425, 13, 55, "Output",ExpressionUUID->"b96ccf0c-bdf7-4944-88d4-0c75c76cbef4"],
Cell[527430, 11639, 308, 9, 34, "Output",ExpressionUUID->"2fd8730b-95b4-4552-8098-14be7261cc6a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[527787, 11654, 267, 5, 58, "Subsection",ExpressionUUID->"ec909af3-0310-4c64-9858-95483af8d41d"],
Cell[528057, 11661, 219, 4, 38, "Text",ExpressionUUID->"e8fb048f-df9d-4185-afc0-c064007cbbf7"],
Cell[CellGroupData[{
Cell[528301, 11669, 227, 4, 49, "Subsubsection",ExpressionUUID->"7125cbb1-7824-4858-8c57-585bda00b262"],
Cell[528531, 11675, 196, 3, 38, "Text",ExpressionUUID->"9ceec09a-6e1b-4a73-9f04-cd5afcaa931a"],
Cell[528730, 11680, 702, 19, 30, "Input",ExpressionUUID->"a6a04698-4b8c-47b9-b3b0-f12f229b2e00"],
Cell[529435, 11701, 224, 5, 38, "Text",ExpressionUUID->"89b6776e-52f4-4805-8af1-b00b68195f33"],
Cell[CellGroupData[{
Cell[529684, 11710, 1905, 52, 50, "Input",ExpressionUUID->"7a3742af-b6ea-46a5-825a-149ea6eafc4f"],
Cell[531592, 11764, 3175, 70, 51, "Output",ExpressionUUID->"d8d20905-8f11-49ef-88d9-a7c3404a77cf"]
}, Open  ]],
Cell[534782, 11837, 300, 7, 30, "Input",ExpressionUUID->"36251e6d-4f85-4749-a290-f70633e7451f"],
Cell[CellGroupData[{
Cell[535107, 11848, 825, 21, 30, "Input",ExpressionUUID->"4eef1b5a-b13b-4fef-bfba-8f3674da88d0"],
Cell[535935, 11871, 3770, 87, 51, "Output",ExpressionUUID->"2e3eb959-6382-449e-9199-42cde9f5c7cc"]
}, Open  ]],
Cell[539720, 11961, 286, 7, 38, "Text",ExpressionUUID->"496eccd0-a2b5-4433-b40c-dc24aa75b7ed"],
Cell[CellGroupData[{
Cell[540031, 11972, 400, 9, 30, "Input",ExpressionUUID->"60a71ef5-7ff1-4714-9deb-a91d1450eda9"],
Cell[540434, 11983, 2043, 38, 53, "Output",ExpressionUUID->"3b4bffcc-62d0-47c4-b491-bd7430869007"]
}, Open  ]],
Cell[CellGroupData[{
Cell[542514, 12026, 267, 5, 30, "Input",ExpressionUUID->"c1b3225b-2b62-4dff-a259-cfe77e5225c8"],
Cell[542784, 12033, 1141, 35, 49, "Output",ExpressionUUID->"c84673dd-4e26-4b0a-96c0-0bee88d9bfbc"]
}, Open  ]],
Cell[543940, 12071, 773, 23, 88, "Text",ExpressionUUID->"e4010405-13f9-47d9-a530-92619386460c"],
Cell[CellGroupData[{
Cell[544738, 12098, 394, 9, 30, "Input",ExpressionUUID->"aed394fe-8f46-4749-88a8-2242db99fe37"],
Cell[545135, 12109, 2200, 43, 53, "Output",ExpressionUUID->"37785ca8-44b3-410e-a048-71fcd30398a9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[547372, 12157, 263, 5, 30, "Input",ExpressionUUID->"19b3f89e-1406-4d8b-a6b5-003fc6aeec62"],
Cell[547638, 12164, 1407, 41, 49, "Output",ExpressionUUID->"022b485f-dccf-484c-97d0-4524f22d90b8"]
}, Open  ]],
Cell[549060, 12208, 296, 8, 63, "Text",ExpressionUUID->"9adc5520-632c-4d6a-8daf-04a09f11b4b0"],
Cell[549359, 12218, 164, 3, 38, "Text",ExpressionUUID->"501f3f7e-058d-4ef1-92d6-668bee51b880"],
Cell[549526, 12223, 879, 22, 73, "Input",ExpressionUUID->"3e2d1db6-17f3-4005-9979-b23c0035991f"],
Cell[CellGroupData[{
Cell[550430, 12249, 928, 24, 32, "Input",ExpressionUUID->"9bab43ea-0633-4536-9b9a-3b0057a159f0"],
Cell[551361, 12275, 2903, 65, 77, "Output",ExpressionUUID->"341ff39e-fc07-4008-b096-d07f9d282b5c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[554301, 12345, 336, 7, 30, "Input",ExpressionUUID->"5070d449-6928-41e0-88a3-eb49f849ae18"],
Cell[554640, 12354, 1502, 48, 77, "Output",ExpressionUUID->"40b7de70-a814-4871-b9ba-d18c51dd2621"]
}, Open  ]],
Cell[556157, 12405, 214, 4, 38, "Text",ExpressionUUID->"4d231278-2089-405e-b85e-6ac138c0d650"],
Cell[CellGroupData[{
Cell[556396, 12413, 537, 13, 52, "Input",ExpressionUUID->"f96244cf-58b0-4f95-bf55-cbcc80088932"],
Cell[556936, 12428, 1469, 21, 35, "Output",ExpressionUUID->"eb901842-9fe8-47c4-a872-0c8fca515de8"],
Cell[558408, 12451, 1469, 21, 35, "Output",ExpressionUUID->"cb546211-5c8c-451b-bad9-dafa8d9c8e5d"]
}, Open  ]],
Cell[559892, 12475, 226, 4, 38, "Text",ExpressionUUID->"1af0b669-a63b-4b39-9542-02946527a5e5"],
Cell[560121, 12481, 604, 18, 52, "Input",ExpressionUUID->"eb4c3a90-b9b5-441c-b414-d0658c458bc2"],
Cell[560728, 12501, 245, 4, 38, "Text",ExpressionUUID->"9e6f65df-5039-4d4a-93da-1ada59945b58"],
Cell[CellGroupData[{
Cell[560998, 12509, 475, 11, 30, "Input",ExpressionUUID->"484ba47c-5470-49eb-abea-de2f06249b06"],
Cell[561476, 12522, 3842, 95, 70, "Output",ExpressionUUID->"130e8f60-f2d7-4e81-9b39-50c0429df9ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[565355, 12622, 264, 5, 30, "Input",ExpressionUUID->"c9d082aa-8440-4285-914c-8f3c6e0a4cb8"],
Cell[565622, 12629, 3162, 86, 57, "Output",ExpressionUUID->"813b80c4-cb8d-4ef7-9653-99e1281d7b55"]
}, Open  ]],
Cell[CellGroupData[{
Cell[568821, 12720, 919, 26, 32, "Input",ExpressionUUID->"69c9606b-b338-482e-94e3-d5a23b6d54c6"],
Cell[569743, 12748, 5149, 154, 91, "Output",ExpressionUUID->"1f66bcc6-47b0-4f3c-8ff6-a4539165e722"]
}, Open  ]],
Cell[CellGroupData[{
Cell[574929, 12907, 400, 12, 30, "Input",ExpressionUUID->"badf32ce-57c4-478b-9e32-8495e0c0223b"],
Cell[575332, 12921, 5090, 147, 116, "Output",ExpressionUUID->"fed567e7-82ab-4650-abfc-26711c602d7a"]
}, Open  ]],
Cell[580437, 13071, 166, 3, 38, "Text",ExpressionUUID->"db7e8bae-5db9-4da1-9c48-954c70aacda6"],
Cell[CellGroupData[{
Cell[580628, 13078, 507, 13, 52, "Input",ExpressionUUID->"af88c069-fee0-4735-9c8c-8eb6e5503bc8"],
Cell[581138, 13093, 549, 11, 35, "Output",ExpressionUUID->"4e988f3c-b9e8-4096-8768-1f4972cacf8c"],
Cell[581690, 13106, 553, 11, 35, "Output",ExpressionUUID->"6b236e8c-ef27-4fbc-9652-6c0093aef468"]
}, Open  ]],
Cell[CellGroupData[{
Cell[582280, 13122, 525, 15, 32, "Input",ExpressionUUID->"78686682-2900-4218-a69a-d982ee236eac"],
Cell[582808, 13139, 7497, 203, 146, "Output",ExpressionUUID->"d67f1be9-d987-47b1-b661-0a60707357d3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[590342, 13347, 270, 6, 32, "Input",ExpressionUUID->"5a94bb6c-4ec2-4451-8929-bdd467dec7a1"],
Cell[590615, 13355, 7004, 196, 146, "Output",ExpressionUUID->"88a9ff7e-e8f3-4925-8790-fb67d6e1cae7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[597656, 13556, 249, 5, 30, "Input",ExpressionUUID->"424dce56-ac77-43e3-a90c-9e5bd6fdde29"],
Cell[597908, 13563, 6895, 190, 145, "Output",ExpressionUUID->"65988657-9657-457c-b627-0347010923a4"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[604852, 13759, 290, 5, 49, "Subsubsection",ExpressionUUID->"b7215235-202b-4966-80ad-15eb8082e06f"],
Cell[CellGroupData[{
Cell[605167, 13768, 319, 7, 30, "Input",ExpressionUUID->"590abef7-28f2-439a-ad69-91f7b209c4b1"],
Cell[605489, 13777, 1769, 48, 40, "Output",ExpressionUUID->"ca62f61c-adb2-4d50-9e90-1419f2451f45"]
}, Open  ]],
Cell[CellGroupData[{
Cell[607295, 13830, 503, 11, 30, "Input",ExpressionUUID->"bba659d1-3da4-423b-a997-1864d73010f4"],
Cell[607801, 13843, 1615, 33, 53, "Output",ExpressionUUID->"83f5c4e9-c7c3-4ef7-b669-bcbc6b02c255"]
}, Open  ]],
Cell[CellGroupData[{
Cell[609453, 13881, 473, 10, 30, "Input",ExpressionUUID->"b90bc767-ca52-49e0-b761-897a825b1041"],
Cell[609929, 13893, 901, 23, 53, "Output",ExpressionUUID->"a84c60af-a8a5-4f2c-9447-96a9b41de419"]
}, Open  ]],
Cell[CellGroupData[{
Cell[610867, 13921, 210, 4, 30, "Input",ExpressionUUID->"95515546-5b22-4d1c-8fd6-e232d09520fb"],
Cell[611080, 13927, 2201, 56, 77, "Output",ExpressionUUID->"2d380311-7586-47d6-97e9-ba946517c80b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[613318, 13988, 764, 22, 30, "Input",ExpressionUUID->"715f0429-fe69-4979-b04f-c2ee37352235"],
Cell[614085, 14012, 1846, 50, 51, "Output",ExpressionUUID->"dbb44765-b3b0-4d1f-9da5-badecb90516f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[615968, 14067, 233, 4, 30, "Input",ExpressionUUID->"f712775d-4925-42ad-80fa-74fa0d1c7104"],
Cell[616204, 14073, 1826, 50, 51, "Output",ExpressionUUID->"d96690ab-64f4-440d-acb0-ce99400ca1b7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[618067, 14128, 293, 7, 30, "Input",ExpressionUUID->"9bcbc51a-b14b-461d-ac08-6485c15e0754"],
Cell[618363, 14137, 3366, 77, 51, "Output",ExpressionUUID->"91c4a5ce-a20d-45d1-ba13-84c2127a4575"]
}, Open  ]],
Cell[CellGroupData[{
Cell[621766, 14219, 1171, 26, 30, "Input",ExpressionUUID->"bbb76d04-ff0b-42ca-bc3a-0d5fd89d90d9"],
Cell[622940, 14247, 21392, 606, 364, "Output",ExpressionUUID->"0e3088a0-d093-4550-acfe-ca9039b02384"]
}, Open  ]],
Cell[CellGroupData[{
Cell[644369, 14858, 845, 23, 30, "Input",ExpressionUUID->"cdd43519-09f3-4026-9f21-5fedcebfd63d"],
Cell[645217, 14883, 5795, 161, 118, "Output",ExpressionUUID->"4e9dd41b-848d-472f-8295-c5b71ac67d08"]
}, Open  ]],
Cell[651027, 15047, 194, 3, 38, "Text",ExpressionUUID->"82378a2b-5631-42f7-9f32-9576a9a0cbc2"],
Cell[CellGroupData[{
Cell[651246, 15054, 581, 14, 73, "Input",ExpressionUUID->"1024d9e9-fdb6-4132-87a9-df8bb69f64d7"],
Cell[651830, 15070, 7044, 196, 146, "Output",ExpressionUUID->"809e0ec8-767c-4e9c-84cf-8bd3101857cc"],
Cell[658877, 15268, 22078, 615, 364, "Output",ExpressionUUID->"449ca525-0972-4ea0-82c5-98a9e8d0dbdc"],
Cell[680958, 15885, 5505, 157, 118, "Output",ExpressionUUID->"71b98ed9-cfc3-4cdf-8bfe-a2fd7f29d112"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[686536, 16050, 306, 5, 73, "Section",ExpressionUUID->"0a003d3b-4343-431c-bd38-8d096493f92e"],
Cell[CellGroupData[{
Cell[686867, 16059, 251, 5, 30, "Input",ExpressionUUID->"afaefb47-2f97-4fcf-af3d-a1c9f0786b8f"],
Cell[687121, 16066, 8786, 245, 236, "Output",ExpressionUUID->"39e4f906-3eab-41ec-9d36-dbffd4712790"]
}, Open  ]],
Cell[CellGroupData[{
Cell[695944, 16316, 655, 11, 30, "Input",ExpressionUUID->"3bc3f73f-46bf-4e86-be01-8e1906c3a787"],
Cell[696602, 16329, 2993, 89, 227, "Output",ExpressionUUID->"1d6a009e-df9f-47fd-8564-901ea883d565"]
}, Open  ]],
Cell[CellGroupData[{
Cell[699632, 16423, 430, 9, 30, "Input",ExpressionUUID->"03ee8fb2-622c-4762-8662-b87275950b0e"],
Cell[700065, 16434, 2068, 64, 223, "Output",ExpressionUUID->"120b0c2c-534c-42e4-8f4e-c154d4c46c32"]
}, Open  ]],
Cell[CellGroupData[{
Cell[702170, 16503, 238, 4, 30, "Input",ExpressionUUID->"f92ea485-9668-415c-a2b9-3a15be251287"],
Cell[702411, 16509, 2068, 64, 223, "Output",ExpressionUUID->"3443c4f6-7032-4645-bd0d-117fcd994f6b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[704516, 16578, 339, 7, 30, "Input",ExpressionUUID->"88b33826-0a57-4967-ae4e-bedd76d1c2cf"],
Cell[704858, 16587, 428, 13, 55, "Output",ExpressionUUID->"7084511e-1538-49aa-ab8a-89f1c78947c1"]
}, Open  ]],
Cell[705301, 16603, 172, 3, 38, "Text",ExpressionUUID->"99f9e484-64e1-49b8-8547-02e9091212be"],
Cell[CellGroupData[{
Cell[705498, 16610, 594, 15, 30, "Input",ExpressionUUID->"8f08f563-cbb8-4196-aed1-c2f9e5f68744"],
Cell[706095, 16627, 1790, 56, 211, "Output",ExpressionUUID->"651f6da3-631e-4a09-8965-eacf0dd4202b"]
}, Open  ]],
Cell[707900, 16686, 199, 3, 38, "Text",ExpressionUUID->"c6a65103-350f-4b02-a518-3bdfd21e60c4"],
Cell[CellGroupData[{
Cell[708124, 16693, 713, 18, 30, "Input",ExpressionUUID->"08db2087-1133-41e5-88fb-1f6cea8847b5"],
Cell[708840, 16713, 9288, 249, 181, "Output",ExpressionUUID->"d4599f33-6128-4238-aac8-e6fafed881bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[718165, 16967, 637, 17, 30, "Input",ExpressionUUID->"2f8f1844-6c3f-47bc-8e74-33575f9b9d2d"],
Cell[718805, 16986, 7731, 214, 185, "Output",ExpressionUUID->"bc3ec641-786f-448a-8df0-880e72dcdcba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[726573, 17205, 370, 8, 30, "Input",ExpressionUUID->"5009ec76-9943-4a9d-b7a2-3cbc9b96de52"],
Cell[726946, 17215, 606, 19, 59, "Output",ExpressionUUID->"ffac1ce9-c898-4c59-a940-25cd5279982c"]
}, Open  ]],
Cell[727567, 17237, 128, 0, 38, "Text",ExpressionUUID->"7df9a167-97b5-4293-bb64-4b5febacf720"],
Cell[CellGroupData[{
Cell[727720, 17241, 1019, 27, 30, "Input",ExpressionUUID->"ac04a579-6c35-492b-bbd1-cac92dd78010"],
Cell[728742, 17270, 748, 24, 55, "Output",ExpressionUUID->"30e77381-79d4-4e1b-a31c-e10c6898b8df"]
}, Open  ]],
Cell[729505, 17297, 116, 0, 38, "Text",ExpressionUUID->"51735f6f-cece-4832-864b-d0d0ab33da34"],
Cell[CellGroupData[{
Cell[729646, 17301, 560, 15, 30, "Input",ExpressionUUID->"7f7d05d1-5529-4cc8-ad12-99eaad99e2e4"],
Cell[730209, 17318, 7177, 202, 163, "Output",ExpressionUUID->"00e38aba-9079-460c-9263-f3117384de5a"]
}, Open  ]],
Cell[737401, 17523, 124, 0, 38, "Text",ExpressionUUID->"9c95ff48-885a-4f71-9d42-1521f8c9b7d2"],
Cell[CellGroupData[{
Cell[737550, 17527, 367, 8, 30, "Input",ExpressionUUID->"eafa38aa-314c-4dc1-9397-844e12746517"],
Cell[737920, 17537, 1107, 34, 62, "Output",ExpressionUUID->"81074133-a202-4932-923a-1f5329fe3a3d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[739064, 17576, 921, 25, 30, "Input",ExpressionUUID->"1cab1b1d-f40f-4163-b07a-e805f83ccfd4"],
Cell[739988, 17603, 1135, 35, 62, "Output",ExpressionUUID->"359c497d-56a7-4910-aacc-95b022e066f3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[741160, 17643, 537, 15, 30, "Input",ExpressionUUID->"a93764b7-91b5-42f6-9adb-7d6445964ade"],
Cell[741700, 17660, 6264, 176, 123, "Output",ExpressionUUID->"d17ffde7-9338-4eaf-848c-aec3b6157bc8"]
}, Open  ]],
Cell[747979, 17839, 847, 26, 30, "Input",ExpressionUUID->"124dfbbe-ffee-4de7-b836-119dea9613c2"],
Cell[748829, 17867, 262, 4, 38, "Text",ExpressionUUID->"f156db73-a223-4ad4-b39a-726c59bd67c3"],
Cell[CellGroupData[{
Cell[749116, 17875, 718, 18, 73, "Input",ExpressionUUID->"3cc3be6b-1f09-4921-a032-813a4933ef86"],
Cell[749837, 17895, 5574, 164, 120, "Output",ExpressionUUID->"2ac837eb-31e2-4a04-8a3c-72684c34dcac"],
Cell[755414, 18061, 306, 9, 34, "Output",ExpressionUUID->"58b01f37-b3fb-475c-8ce9-8dae8e0d7344"],
Cell[755723, 18072, 308, 9, 34, "Output",ExpressionUUID->"6c4acb07-ba96-4590-bb3b-a9c37bc4128f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[756068, 18086, 1279, 31, 30, "Input",ExpressionUUID->"625e88c8-10a5-44e0-a76b-7ae2fc3951fd"],
Cell[757350, 18119, 7643, 224, 145, "Output",ExpressionUUID->"5567a67c-10ca-481b-99ec-0f88a6519ac2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[765030, 18348, 272, 6, 30, "Input",ExpressionUUID->"8f832aeb-15f8-46c4-8c3c-4985c1e5a10e"],
Cell[765305, 18356, 1133, 35, 62, "Output",ExpressionUUID->"ff0dc7b6-408e-405e-a87d-9226c4ceb30c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[766475, 18396, 691, 21, 30, "Input",ExpressionUUID->"de30f588-6e85-41fe-8117-3e3e63d1a1bb"],
Cell[767169, 18419, 5808, 166, 118, "Output",ExpressionUUID->"d13662e6-1d2c-4d2a-9e40-81554f6160d2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[773014, 18590, 307, 7, 30, "Input",ExpressionUUID->"e6326985-bc7a-4616-9b0e-f6416da9108d"],
Cell[773324, 18599, 748, 24, 55, "Output",ExpressionUUID->"d0336ebe-e070-484f-ac81-ca6756a67f97"]
}, Open  ]],
Cell[CellGroupData[{
Cell[774109, 18628, 770, 22, 30, "Input",ExpressionUUID->"86a7dc7a-8049-4cf1-9b67-696afc7bb52e"],
Cell[774882, 18652, 7787, 222, 145, "Output",ExpressionUUID->"23b177b6-0966-4ffa-9df0-4286b52acdea"]
}, Open  ]],
Cell[782684, 18877, 228, 5, 38, "Text",ExpressionUUID->"40417323-f82a-480f-b7bf-599c9bca52db"],
Cell[CellGroupData[{
Cell[782937, 18886, 783, 20, 73, "Input",ExpressionUUID->"0324f1cf-18a3-4dce-bc01-f50aa4afdbaf"],
Cell[783723, 18908, 7983, 221, 143, "Output",ExpressionUUID->"03b6ea18-7f51-4bee-9291-c9bd8ec9bd0a"],
Cell[791709, 19131, 7709, 216, 143, "Output",ExpressionUUID->"11daf75b-058b-4d64-985a-51f845ef1b9d"],
Cell[799421, 19349, 5671, 161, 116, "Output",ExpressionUUID->"7765ddb4-253b-4f3a-8342-996ec2bee2b5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[805141, 19516, 182, 3, 73, "Section",ExpressionUUID->"666d5801-8dce-4738-ac85-618cbe9c801a"],
Cell[CellGroupData[{
Cell[805348, 19523, 293, 4, 58, "Subsection",ExpressionUUID->"fb3b0c20-0993-45a4-9d71-70bba5d441a9"],
Cell[CellGroupData[{
Cell[805666, 19531, 229, 4, 49, "Subsubsection",ExpressionUUID->"3f744ea4-0e89-4fc8-9c4b-371dbcab8cdf"],
Cell[805898, 19537, 475, 12, 52, "Input",ExpressionUUID->"4e301745-8b2b-43ba-8422-89492349c5b5"],
Cell[806376, 19551, 469, 13, 94, "Input",ExpressionUUID->"a316e0a7-c2e6-4229-9631-572a8bf3c2dc"],
Cell[806848, 19566, 775, 22, 61, "Input",ExpressionUUID->"a03fdd3d-4059-4614-970d-ba405de92ae5"],
Cell[807626, 19590, 859, 22, 30, "Input",ExpressionUUID->"5dfa33bd-c1e6-4fa5-ab2c-4a5c11308ba4"],
Cell[808488, 19614, 244, 4, 38, "Text",ExpressionUUID->"857d713c-06fa-4bae-be68-8c5e07621cb9"],
Cell[808735, 19620, 223, 7, 38, "Text",ExpressionUUID->"d40154ea-c28c-4cc4-aa53-9b477bd5729b"],
Cell[808961, 19629, 152, 3, 38, "Text",ExpressionUUID->"08a84314-99a5-4fce-b946-a06a9fa74a27"],
Cell[809116, 19634, 681, 17, 73, "Input",ExpressionUUID->"11301b0f-845d-48eb-a172-59f3d08a21ac"],
Cell[809800, 19653, 197, 4, 38, "Text",ExpressionUUID->"a43845bf-bc18-4ed8-a295-9fe818a0725d"],
Cell[810000, 19659, 939, 23, 73, "Input",ExpressionUUID->"4fda771d-762d-43f2-b896-e663650e39b2"],
Cell[810942, 19684, 146, 3, 38, "Text",ExpressionUUID->"5043f6f9-5ec8-443f-898e-f49fc5d1f220"],
Cell[811091, 19689, 746, 21, 73, "Input",ExpressionUUID->"9fa24da1-47d8-4ea5-917b-3e2e96c8148c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[811886, 19716, 155, 3, 58, "Subsection",ExpressionUUID->"69bd0bac-d683-4255-a931-0918bd45f894"],
Cell[CellGroupData[{
Cell[812066, 19723, 406, 6, 49, "Subsubsection",ExpressionUUID->"1bafd2af-159c-4745-9502-56ad696e8e22"],
Cell[CellGroupData[{
Cell[812497, 19733, 1266, 28, 94, "Input",ExpressionUUID->"566108ee-a11b-4c0f-bf80-aa321bd8e768"],
Cell[813766, 19763, 9140, 251, 150, "Output",ExpressionUUID->"98f96892-1c65-4c94-a186-d30526f95a7a"]
}, Open  ]],
Cell[822921, 20017, 753, 21, 52, "Input",ExpressionUUID->"d78bc078-395f-4a0c-bace-bd04c4cadfd7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[823711, 20043, 169, 3, 49, "Subsubsection",ExpressionUUID->"4e7a0de3-fd4f-4757-98f1-482feff78d74"],
Cell[823883, 20048, 355, 6, 38, "Text",ExpressionUUID->"98bf7274-ca44-484e-90ce-b6ea7d0b4f11"],
Cell[CellGroupData[{
Cell[824263, 20058, 1101, 29, 30, "Input",ExpressionUUID->"5ab15786-4758-4e05-84c7-f4d7cf9a9713"],
Cell[825367, 20089, 3021, 55, 429, "Output",ExpressionUUID->"7726fd72-a8e2-4c04-ac65-174512e5f601"]
}, Open  ]],
Cell[CellGroupData[{
Cell[828425, 20149, 1063, 28, 30, "Input",ExpressionUUID->"d9d4288b-8341-4c07-9640-d242387ae3d3"],
Cell[829491, 20179, 4134, 88, 267, "Output",ExpressionUUID->"178718b8-5a10-4e0c-a7b5-542c860ac622"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[833674, 20273, 183, 3, 49, "Subsubsection",ExpressionUUID->"fbfc9927-1971-462b-bf5d-3d23496f73af"],
Cell[833860, 20278, 456, 11, 30, "Input",ExpressionUUID->"7839c868-6d4c-427a-bf7c-89f795a20f24"],
Cell[CellGroupData[{
Cell[834341, 20293, 1051, 28, 30, "Input",ExpressionUUID->"d46acc4b-064f-4337-afdd-2e86de1c6b47"],
Cell[835395, 20323, 2921, 54, 417, "Output",ExpressionUUID->"7c03033d-3608-422f-bc1d-6903b7f58ad2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[838365, 20383, 323, 5, 49, "Subsubsection",ExpressionUUID->"ed6e60db-8330-4a8d-bb63-3c43974f56c3"],
Cell[838691, 20390, 1492, 37, 94, "Input",ExpressionUUID->"9d585ca6-e665-4c30-a841-b1dd6452db08"],
Cell[840186, 20429, 642, 17, 52, "Input",ExpressionUUID->"2f143267-9eb1-4d57-8fea-482d1f9bffc8"],
Cell[840831, 20448, 399, 11, 32, "Input",ExpressionUUID->"ff8f52ad-4fbc-4d01-90fc-3255159d305d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[841267, 20464, 172, 3, 49, "Subsubsection",ExpressionUUID->"d84842bc-d64b-4dcd-9f4b-8cab847a91db"],
Cell[CellGroupData[{
Cell[841464, 20471, 1203, 33, 52, "Input",ExpressionUUID->"90eda0cd-9c76-42ae-b7e2-2c56a904a44b"],
Cell[842670, 20506, 2514, 49, 577, "Output",ExpressionUUID->"38e6993e-2156-49ed-9fdb-8480d355463e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[845233, 20561, 182, 3, 49, "Subsubsection",ExpressionUUID->"cb05614d-83a2-4792-b5bd-565907af956a"],
Cell[845418, 20566, 547, 14, 30, "Input",ExpressionUUID->"9ac27044-a609-49b7-a22e-ee5e64c251c4"],
Cell[CellGroupData[{
Cell[845990, 20584, 1305, 35, 52, "Input",ExpressionUUID->"a7dea257-6cd6-4077-8a7e-32d6a8023358"],
Cell[847298, 20621, 3008, 55, 577, "Output",ExpressionUUID->"049598a4-6d5c-4fda-bc77-4a0ad2c714b2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[850355, 20682, 167, 3, 49, "Subsubsection",ExpressionUUID->"fbbbd907-92e9-4b7d-8920-d16d0bc3bd2f"],
Cell[CellGroupData[{
Cell[850547, 20689, 1849, 42, 52, "Input",ExpressionUUID->"99ca54c8-d2b8-4886-b17b-58d899fd953c"],
Cell[852399, 20733, 3292, 59, 577, "Output",ExpressionUUID->"ffbe8fab-c367-460a-a7a8-0dc9b92fb467"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[855740, 20798, 158, 3, 49, "Subsubsection",ExpressionUUID->"db66a2ac-78fc-45bb-9990-3cf8c8e388a9"],
Cell[855901, 20803, 1316, 34, 94, "Input",ExpressionUUID->"8abf5c0f-4ed6-4ac3-8703-7a2a03041eb7"],
Cell[857220, 20839, 297, 5, 38, "Text",ExpressionUUID->"4edb1769-f707-47b7-a88f-ec01a62a1641"],
Cell[857520, 20846, 597, 16, 52, "Input",ExpressionUUID->"389b34a8-0d32-4894-91ae-160c20b538fc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[858154, 20867, 169, 3, 49, "Subsubsection",ExpressionUUID->"2e5ac9da-4fb9-47ba-8295-a090bc2b0ed5"],
Cell[CellGroupData[{
Cell[858348, 20874, 1434, 35, 52, "Input",ExpressionUUID->"42c673b1-2eea-45ec-9a7c-b726e9ac5c3f"],
Cell[859785, 20911, 2340, 46, 577, "Output",ExpressionUUID->"dfe0d4fb-03af-415d-a794-0e079a08383f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[862174, 20963, 298, 4, 49, "Subsubsection",ExpressionUUID->"7691fbaf-07dc-4005-8bee-9f0f23cd9077"],
Cell[862475, 20969, 1209, 30, 52, "Input",ExpressionUUID->"73ffec47-eb06-4950-b21e-973a4961c8cc"],
Cell[863687, 21001, 877, 18, 52, "Input",ExpressionUUID->"d250bd75-e569-43b9-8369-8251f00e790e"],
Cell[864567, 21021, 576, 15, 30, "Input",ExpressionUUID->"fe3f626b-9366-4378-b0f9-d04c52e9af0e"],
Cell[865146, 21038, 333, 9, 30, "Input",ExpressionUUID->"5e88254d-4f48-42bb-947c-6f3914eb4262"],
Cell[CellGroupData[{
Cell[865504, 21051, 1947, 45, 52, "Input",ExpressionUUID->"af8aed76-245e-44c2-91f7-cda295e93a2c"],
Cell[867454, 21098, 3613, 66, 577, "Output",ExpressionUUID->"9d89e09c-01d7-4858-b99e-d53c8e83df27"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[871116, 21170, 199, 3, 49, "Subsubsection",ExpressionUUID->"8c40a79d-af9c-40f1-b941-f42080ec5ac2"],
Cell[871318, 21175, 628, 15, 52, "Input",ExpressionUUID->"fc1ff0d7-b8f2-46f3-a53c-37b9d06e5108"],
Cell[CellGroupData[{
Cell[871971, 21194, 2003, 56, 52, "Input",ExpressionUUID->"7ede82c9-3f41-4477-a54e-46faa6ab54eb"],
Cell[873977, 21252, 3140, 59, 577, "Output",ExpressionUUID->"0f3aacf4-7583-45b2-b2c8-9e94d17ad1b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[877154, 21316, 1848, 46, 52, "Input",ExpressionUUID->"74855f6d-5c03-4d39-9922-b93f50b5da33"],
Cell[879005, 21364, 3225, 60, 577, "Output",ExpressionUUID->"5972f39e-a04e-4d62-9ff7-b8f97a4dc383"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[882291, 21431, 209, 4, 58, "Subsection",ExpressionUUID->"32a52a57-e0ed-446d-a549-4e6cd59f2ec9"],
Cell[CellGroupData[{
Cell[882525, 21439, 259, 4, 49, "Subsubsection",ExpressionUUID->"74d20dc6-65a5-43bc-aef5-8a64723cdab1"],
Cell[882787, 21445, 974, 25, 73, "Input",ExpressionUUID->"56878dea-604f-448b-9a6f-4bb628887137"],
Cell[CellGroupData[{
Cell[883786, 21474, 565, 12, 35, "Input",ExpressionUUID->"5e25f4aa-f247-4d40-bbf6-9a8a403cf924"],
Cell[884354, 21488, 288, 5, 35, "Output",ExpressionUUID->"e66150a1-3c28-4c22-84c4-acc6ba99c380"]
}, Open  ]],
Cell[CellGroupData[{
Cell[884679, 21498, 1032, 29, 30, "Input",ExpressionUUID->"ff3ef10b-2d25-419b-b816-20ebeff96aaf"],
Cell[885714, 21529, 2781, 51, 427, "Output",ExpressionUUID->"aa892abc-008f-4e9c-b52b-c42b08fe7ec5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[888544, 21586, 230, 4, 49, "Subsubsection",ExpressionUUID->"83fb99ef-1aa3-4b3f-a339-38e163fa5b61"],
Cell[888777, 21592, 1171, 33, 73, "Input",ExpressionUUID->"6b381e77-fb2c-4cc8-917c-8a4d3c763089"],
Cell[CellGroupData[{
Cell[889973, 21629, 2052, 58, 52, "Input",ExpressionUUID->"7773a70f-5441-4753-8063-f42d08b2e481"],
Cell[892028, 21689, 2794, 55, 569, "Output",ExpressionUUID->"1189fc77-f511-4b2f-9189-afb7fe74e95a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[894871, 21750, 256, 4, 49, "Subsubsection",ExpressionUUID->"ebde4574-8e95-49c0-86d1-2a383653e043"],
Cell[895130, 21756, 1191, 33, 73, "Input",ExpressionUUID->"bae609df-4e63-4f86-8790-240f28453d8f"],
Cell[CellGroupData[{
Cell[896346, 21793, 2624, 67, 52, "Input",ExpressionUUID->"3569a15a-e811-49d6-97c8-cc364cef8823"],
Cell[898973, 21862, 3370, 62, 569, "Output",ExpressionUUID->"9d810847-506b-4be8-9333-b59d23e35e1a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[902392, 21930, 180, 3, 49, "Subsubsection",ExpressionUUID->"26e5edac-764e-4739-87bc-5176e741659e"],
Cell[902575, 21935, 407, 13, 30, "Input",ExpressionUUID->"dfba8af0-c9e8-4ca6-9b46-3262ab8e5df1"],
Cell[902985, 21950, 458, 14, 30, "Input",ExpressionUUID->"4fa0ba0a-8d9c-43aa-9e2a-e6ffb548cc22"],
Cell[CellGroupData[{
Cell[903468, 21968, 2728, 76, 73, "Input",ExpressionUUID->"715206f4-d183-45d7-bc8a-67b61f735d45"],
Cell[906199, 22046, 3217, 63, 569, "Output",ExpressionUUID->"7cd95243-98e7-4783-80cd-f3a8d902ef7e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[909453, 22114, 2967, 77, 93, "Input",ExpressionUUID->"9bbcc1e1-6894-4a12-a1c2-322cba42655f"],
Cell[912423, 22193, 3397, 65, 569, "Output",ExpressionUUID->"3c7502ac-a1a8-4779-bdce-b4df2d37ad77"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[915881, 22265, 168, 3, 58, "Subsection",ExpressionUUID->"7c16043b-ec94-4db1-80d4-3c40c81f4ebf"],
Cell[916052, 22270, 1304, 27, 73, "Input",ExpressionUUID->"a3feef87-8a54-439f-86f1-3a4e6fb85f38"],
Cell[CellGroupData[{
Cell[917381, 22301, 5720, 160, 155, "Input",ExpressionUUID->"c9fb64c2-ff07-4ee9-bfdf-3ba85f2b2c3d"],
Cell[923104, 22463, 3807, 77, 569, "Output",ExpressionUUID->"c391624e-2bfa-4e20-837b-b14e8f9fe4a8"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[926972, 22547, 245, 4, 73, "Section",ExpressionUUID->"84567c30-a94d-4a36-957d-c4caef31a459"],
Cell[CellGroupData[{
Cell[927242, 22555, 281, 4, 58, "Subsection",ExpressionUUID->"9023d7c1-4374-4f97-a577-26af84d1ed91"],
Cell[CellGroupData[{
Cell[927548, 22563, 154, 3, 49, "Subsubsection",ExpressionUUID->"ebe5f237-6980-4fe6-810e-4e013b8651ac"],
Cell[927705, 22568, 2491, 70, 93, "Input",ExpressionUUID->"e14f081e-7cbf-4856-a29a-b575d3f5a37a"],
Cell[CellGroupData[{
Cell[930221, 22642, 421, 11, 52, "Input",ExpressionUUID->"e2e3c2c5-2c45-4612-be84-236c0fc52823"],
Cell[930645, 22655, 325, 10, 34, "Output",ExpressionUUID->"5789bbaa-9b9e-42cf-ba3b-9ffd88892ba4"],
Cell[930973, 22667, 402, 13, 56, "Output",ExpressionUUID->"5f18ecdd-7e1c-4025-9c77-7e1ffcf315ac"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[931424, 22686, 154, 3, 49, "Subsubsection",ExpressionUUID->"84f80be7-35f5-4d96-940a-3db5dd514154"],
Cell[CellGroupData[{
Cell[931603, 22693, 2389, 65, 93, "Input",ExpressionUUID->"852df4f3-ab0d-485a-b7c5-23c2042da0b2"],
Cell[933995, 22760, 352, 10, 51, "Output",ExpressionUUID->"1f70ae8c-7e94-43ec-ae67-3ad9530a7bb1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[934384, 22775, 401, 9, 52, "Input",ExpressionUUID->"776f83ce-746b-45a1-9423-f128294278c2"],
Cell[934788, 22786, 462, 15, 52, "Output",ExpressionUUID->"62c8d810-6f0a-4acc-8a85-161c72c34aae"],
Cell[935253, 22803, 454, 14, 58, "Output",ExpressionUUID->"eea57954-bf8c-4304-bcd4-a0555aa7a83c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[935756, 22823, 156, 3, 49, "Subsubsection",ExpressionUUID->"d4edc9d1-6249-40ab-86df-ec64f795d7c7"],
Cell[CellGroupData[{
Cell[935937, 22830, 2211, 62, 93, "Input",ExpressionUUID->"7bd5002c-244d-4071-81b2-4187be840eb0"],
Cell[938151, 22894, 281, 5, 35, "Output",ExpressionUUID->"931a696c-18b4-4ea0-8c48-4d9e62ad5a8b"],
Cell[938435, 22901, 281, 5, 35, "Output",ExpressionUUID->"5a53c61a-77f8-4bab-857c-b4aec5cffd44"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[938777, 22913, 231, 4, 58, "Subsection",ExpressionUUID->"b430c486-1365-4ec2-813f-42e106a6f25f"],
Cell[CellGroupData[{
Cell[939033, 22921, 179, 3, 49, "Subsubsection",ExpressionUUID->"95c86445-d58b-42a3-84e2-f232d66a27da"],
Cell[939215, 22926, 371, 9, 30, "Input",ExpressionUUID->"d6e2b506-b112-4a31-9553-722266475222"],
Cell[939589, 22937, 2469, 70, 73, "Input",ExpressionUUID->"0652d4d5-bb1d-4e26-8ea2-d5369d73ec52"],
Cell[CellGroupData[{
Cell[942083, 23011, 287, 8, 30, "Input",ExpressionUUID->"fe39638a-b2bb-478d-9463-ca833e75f9da"],
Cell[942373, 23021, 15446, 409, 420, "Output",ExpressionUUID->"396c8942-7d61-44dd-8a70-ed2a6602800f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[957868, 23436, 180, 3, 49, "Subsubsection",ExpressionUUID->"ecf483c2-1e3e-42ce-a7e3-b962acad28d3"],
Cell[958051, 23441, 363, 9, 30, "Input",ExpressionUUID->"b74b75ea-c332-42dc-af16-a4c14483a0cb"],
Cell[958417, 23452, 2496, 69, 73, "Input",ExpressionUUID->"4df7de5e-ccce-4976-a65e-08e2020fe1e4"],
Cell[CellGroupData[{
Cell[960938, 23525, 276, 8, 30, "Input",ExpressionUUID->"dc204fd2-6e1e-4099-8b5d-8cdabc4a6bdc"],
Cell[961217, 23535, 15769, 413, 432, "Output",ExpressionUUID->"9f58e8dc-0adf-442c-8f15-b9a90a2e762a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[977035, 23954, 183, 3, 49, "Subsubsection",ExpressionUUID->"0f1bedfb-9cd6-4b79-98f0-080e395799bc"],
Cell[977221, 23959, 260, 7, 30, "Input",ExpressionUUID->"71bcb180-cceb-4711-a32c-eeefa71af896"],
Cell[977484, 23968, 2648, 70, 93, "Input",ExpressionUUID->"7b6689b3-5778-4703-8139-84cffcbfaa0f"],
Cell[CellGroupData[{
Cell[980157, 24042, 333, 8, 30, "Input",ExpressionUUID->"da402027-468e-4524-a2fc-ff23cb68344d"],
Cell[980493, 24052, 11192, 307, 304, "Output",ExpressionUUID->"b24eb0c2-1ebf-4bcb-8d7a-9bac2151ef1b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[991746, 24366, 232, 4, 58, "Subsection",ExpressionUUID->"7c603eb5-2f6a-4210-bc9c-65e8c7d21e8c"],
Cell[CellGroupData[{
Cell[992003, 24374, 149, 2, 49, "Subsubsection",ExpressionUUID->"a32e1172-32b2-4709-ba6f-aacaba695c99"],
Cell[CellGroupData[{
Cell[992177, 24380, 674, 21, 52, "Input",ExpressionUUID->"f348e384-56d4-49a7-9446-dad5d797ca50"],
Cell[992854, 24403, 16013, 415, 485, "Output",ExpressionUUID->"f0704691-2476-4245-abbc-aee185657e4a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1008916, 24824, 155, 3, 49, "Subsubsection",ExpressionUUID->"511bdea4-b2a8-4b41-9e44-c32ebaffd83b"],
Cell[CellGroupData[{
Cell[1009096, 24831, 650, 19, 52, "Input",ExpressionUUID->"384d91ae-b53a-4a3c-86f1-839cff8ce026"],
Cell[1009749, 24852, 16389, 420, 501, "Output",ExpressionUUID->"1c972f0a-6ad4-44fb-817c-47d92eec78e1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1026187, 25278, 155, 3, 49, "Subsubsection",ExpressionUUID->"78b0bd41-112b-4fd5-8b5b-b8bce7deb68d"],
Cell[CellGroupData[{
Cell[1026367, 25285, 704, 20, 52, "Input",ExpressionUUID->"b9e5961a-a5be-493f-b8a8-07b4a31d793e"],
Cell[1027074, 25307, 11194, 307, 304, "Output",ExpressionUUID->"6c67187f-a113-4114-9853-b8d125efd2e4"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1038329, 25621, 257, 4, 58, "Subsection",ExpressionUUID->"8cc0f44e-1185-419d-9cd8-62b5f6d8cc4b"],
Cell[CellGroupData[{
Cell[1038611, 25629, 154, 3, 49, "Subsubsection",ExpressionUUID->"9f952c34-9d87-49df-8cde-850955f0a442"],
Cell[1038768, 25634, 260, 6, 30, "Input",ExpressionUUID->"a2117e82-f57b-4815-bf56-b9ffa2965411"],
Cell[1039031, 25642, 2167, 60, 73, "Input",ExpressionUUID->"23d4cea7-6464-47bc-a4cd-52692a091479"],
Cell[CellGroupData[{
Cell[1041223, 25706, 258, 6, 30, "Input",ExpressionUUID->"886faff2-7d0c-456f-b1b1-bf51c315d98c"],
Cell[1041484, 25714, 13162, 352, 415, "Output",ExpressionUUID->"933e7345-adf1-47f5-b1e8-9b07462f6236"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1054695, 26072, 180, 3, 49, "Subsubsection",ExpressionUUID->"8144c998-8155-4fb5-be91-ebabd5a79381"],
Cell[1054878, 26077, 263, 7, 30, "Input",ExpressionUUID->"b368e7bf-462c-4f1c-a475-c43efd680783"],
Cell[1055144, 26086, 2461, 68, 73, "Input",ExpressionUUID->"99f7ce38-de18-4710-8781-fdcbef9a2e53"],
Cell[CellGroupData[{
Cell[1057630, 26158, 285, 7, 30, "Input",ExpressionUUID->"b4feff08-0be4-4ad3-92c5-118730c55ca3"],
Cell[1057918, 26167, 10258, 273, 334, "Output",ExpressionUUID->"9d68824d-ca33-4af3-b095-c49605ded045"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1068225, 26446, 176, 3, 49, "Subsubsection",ExpressionUUID->"6f75b93b-0c4e-417f-9b1a-0397a5460e36"],
Cell[1068404, 26451, 2557, 73, 93, "Input",ExpressionUUID->"d9d5cf00-560e-44dc-9a48-b45822f9af36"],
Cell[CellGroupData[{
Cell[1070986, 26528, 311, 7, 30, "Input",ExpressionUUID->"59bf2964-c487-4b9c-aa95-d561d84ddeb7"],
Cell[1071300, 26537, 44495, 1131, 1592, "Output",ExpressionUUID->"7ab09e34-4bee-4ea5-8aee-6ac26e122ce5"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

